@@ -1,11 +1,12 @@
 import logging
 from collections import Counter
-from datetime import datetime
+from os import getlogin
+from typing import Dict, List, Optional
 
 import pymongo
-from bson import ObjectId
 
-from scout.constants import CASE_STATUSES
+from scout.constants import CASE_STATUSES, CASE_TAGS, ID_PROJECTION
+from scout.exceptions import IntegrityError
 
 LOG = logging.getLogger(__name__)
 
@@ -13,6 +14,100 @@ LOG = logging.getLogger(__name__)
 class CaseEventHandler(object):
     """Class to handle case events for the mongo adapter"""
 
+    def get_cli_user(self) -> dict:
+        """
+        Return a faux CLI user with a login username from OS CLI if it is available.
+        """
+        try:
+            cli_user_name = getlogin()
+        except OSError:
+            # no controlling terminal
+            cli_user_name = "CLI user"
+
+        return {"_id": "CLI", "name": cli_user_name}
+
+    def add_case(self, case_obj: dict, institute_obj: dict):
+        """Add a case to the database
+        If the case already exists exception is raised.
+        Add case will only be called from CLI, or tests, so the user will be the faux CLI user with
+        a login username from OS CLI if available.
+        """
+        if self.case(case_obj["_id"], projection=ID_PROJECTION):
+            raise IntegrityError("Case %s already exists in database" % case_obj["_id"])
+        link = f"/{case_obj['owner']}/{case_obj['display_name']}"
+
+        self.create_event(
+            institute=institute_obj,
+            case=case_obj,
+            user=self.get_cli_user(),
+            link=link,
+            category="case",
+            verb="add_case",
+            subject=case_obj["display_name"],
+        )
+
+        return self.case_collection.insert_one(case_obj)
+
+    def update_case_individual(
+        self, case_obj: dict, user_obj: dict, institute_obj: dict, link: str, keep_date: bool = True
+    ):
+        """Update case with new individual data (age and/or Tissue type) for a case
+        and create an associated event"""
+        self._update_case_component(
+            case_obj, user_obj, institute_obj, link, verb="update_individual", keep_date=keep_date
+        )
+
+    def update_case_sample(
+        self, case_obj: dict, user_obj: dict, institute_obj: dict, link: str, keep_date=True
+    ):
+        """Handle update of sample data data (tissue, tumor_type, tumor_purity) for a cancer case
+        and create an associated event"""
+        self._update_case_component(
+            case_obj, user_obj, institute_obj, link, verb="update_sample", keep_date=keep_date
+        )
+
+    def _update_case_component(
+        self,
+        case_obj: dict,
+        user_obj: Optional[dict],
+        institute_obj: dict,
+        link: str,
+        verb: str,
+        keep_date: bool = True,
+    ):
+        """Update case with new sample data, and create an associated event"""
+        self.update_case(case_obj, keep_date)
+
+        if not user_obj:
+            user_obj = self.get_cli_user()
+
+        self.create_event(
+            institute=institute_obj,
+            case=case_obj,
+            user=user_obj,
+            link=link,
+            category="case",
+            verb=verb,
+            subject=case_obj["display_name"],
+        )
+
+    def update_case_cli(self, case_obj: dict, institute_obj: dict):
+        """Update case with new case obj, and create an associated CLI user event."""
+
+        link = f"/{case_obj['owner']}/{case_obj['display_name']}"
+
+        self.create_event(
+            institute=institute_obj,
+            case=case_obj,
+            user=self.get_cli_user(),
+            link=link,
+            category="case",
+            verb="update_case",
+            subject=case_obj["display_name"],
+        )
+
+        self.update_case(case_obj)
+
     def assign(self, institute, case, user, link):
         """Assign a user to a case.
 
@@ -28,11 +123,6 @@ class CaseEventHandler(object):
         Returns:
             updated_case(dict)
         """
-        LOG.info(
-            "Creating event for assigning {0} to {1}".format(
-                user["name"].encode("utf-8"), case["display_name"]
-            )
-        )
 
         self.create_event(
             institute=institute,
@@ -43,7 +133,6 @@ class CaseEventHandler(object):
             verb="assign",
             subject=case["display_name"],
         )
-        LOG.info("Updating {0} to be assigned with {1}".format(case["display_name"], user["name"]))
 
         updated_case = self.case_collection.find_one_and_update(
             {"_id": case["_id"]},
@@ -69,9 +158,6 @@ class CaseEventHandler(object):
         Returns:
             updated_case (dict): The updated case
         """
-        LOG.info(
-            "Creating event for unassigning {0} from {1}".format(user["name"], case["display_name"])
-        )
 
         self.create_event(
             institute=institute,
@@ -83,10 +169,6 @@ class CaseEventHandler(object):
             subject=case["display_name"],
         )
 
-        LOG.info(
-            "Updating {0} to be unassigned with {1}".format(case["display_name"], user["name"])
-        )
-
         # if case is not prioritized and user wishes to inactivate it:
         if case["status"] != "prioritized" and inactivate:
             # flag case as inactive:
@@ -97,7 +179,6 @@ class CaseEventHandler(object):
             {"$pull": {"assignees": user["_id"]}, "$set": {"status": case["status"]}},
             return_document=pymongo.ReturnDocument.AFTER,
         )
-        LOG.debug("Case updated")
         return updated_case
 
     def update_status(self, institute, case, user, status, link):
@@ -123,13 +204,8 @@ class CaseEventHandler(object):
             LOG.warning("Status {0} is invalid".format(status))
             return None
 
-        LOG.info(
-            "Creating event for updating status of {0} to {1}".format(case["display_name"], status)
-        )
-
         # assign case to user if user unarchives it
         if case.get("status") == "archived" and status == "active":
-            LOG.info("assign case to user {}".format(user["email"]))
             self.assign(institute, case, user, link)
 
         self.create_event(
@@ -142,13 +218,45 @@ class CaseEventHandler(object):
             subject=case["display_name"],
         )
 
-        LOG.info("Updating {0} to status {1}".format(case["display_name"], status))
         updated_case = self.case_collection.find_one_and_update(
             {"_id": case["_id"]},
             {"$set": {"status": status}},
             return_document=pymongo.ReturnDocument.AFTER,
         )
-        LOG.debug("Case updated")
+
+        return updated_case
+
+    def tag_case(
+        self, institute: Dict, case: Dict, user: Dict, tags: List[str], link: str
+    ) -> Optional[dict]:
+        """Update the status tags of a case.
+
+        This function will create an Event to log that a user have updated the
+        status of a case. Also the status of the case will be updated.
+        Status tags could be any valid keys of the CASE_TAGS constant, eg
+            ("provisional", "diagnostic", "carrier", "upd", "medical attention")
+        """
+
+        for tag in tags:
+            if tag not in CASE_TAGS.keys():
+                LOG.warning("Tag {0} is invalid".format(tag))
+                return None
+
+        self.create_event(
+            institute=institute,
+            case=case,
+            user=user,
+            link=link,
+            category="case",
+            verb="tag",
+            subject=case["display_name"],
+        )
+
+        updated_case = self.case_collection.find_one_and_update(
+            {"_id": case["_id"]},
+            {"$set": {"tags": tags}},
+            return_document=pymongo.ReturnDocument.AFTER,
+        )
 
         return updated_case
 
@@ -168,9 +276,6 @@ class CaseEventHandler(object):
         Returns:
             updated_case
         """
-        LOG.info(
-            "Creating event for updating the synopsis for case" " {0}".format(case["display_name"])
-        )
 
         self.create_event(
             institute=institute,
@@ -183,13 +288,11 @@ class CaseEventHandler(object):
             content=content,
         )
 
-        LOG.info("Updating the synopsis for case {0}".format(case["display_name"]))
         updated_case = self.case_collection.find_one_and_update(
             {"_id": case["_id"]},
             {"$set": {"synopsis": content}},
             return_document=pymongo.ReturnDocument.AFTER,
         )
-        LOG.debug("Case updated")
         return updated_case
 
     def archive_case(self, institute, case, user, link):
@@ -204,7 +307,6 @@ class CaseEventHandler(object):
         Returns:
             updated_case (dict)
         """
-        LOG.info("Creating event for archiving case {0}".format(case["display_name"]))
 
         self.create_event(
             institute=institute,
@@ -216,14 +318,11 @@ class CaseEventHandler(object):
             subject=case["display_name"],
         )
 
-        LOG.info("Change status for case {0} to 'archived'".format(case["display_name"]))
-
         updated_case = self.case_collection.find_one_and_update(
             {"_id": case["_id"]},
             {"$set": {"status": "archived"}},
             return_document=pymongo.ReturnDocument.AFTER,
         )
-        LOG.debug("Case updated")
         return updated_case
 
     def remove_variants_event(
@@ -260,7 +359,6 @@ class CaseEventHandler(object):
         Returns:
             updated_case(dict)
         """
-        LOG.info("Creating event for opening research for case" " {0}".format(case["display_name"]))
 
         self.create_event(
             institute=institute,
@@ -272,14 +370,11 @@ class CaseEventHandler(object):
             subject=case["display_name"],
         )
 
-        LOG.info("Set research_requested for case {0} to True".format(case["display_name"]))
-
         updated_case = self.case_collection.find_one_and_update(
             {"_id": case["_id"]},
             {"$set": {"research_requested": True}},
             return_document=pymongo.ReturnDocument.AFTER,
         )
-        LOG.debug("Case updated")
         return updated_case
 
     def reset_research(self, institute, case, user, link):
@@ -294,9 +389,6 @@ class CaseEventHandler(object):
         Returns:
             updated_case(dict)
         """
-
-        LOG.info("Creating event for closing research for case" " {0}".format(case["display_name"]))
-
         self.create_event(
             institute=institute,
             case=case,
@@ -307,14 +399,11 @@ class CaseEventHandler(object):
             subject=case["display_name"],
         )
 
-        LOG.info("Set research_requested for case {0} to False".format(case["display_name"]))
-
         updated_case = self.case_collection.find_one_and_update(
             {"_id": case["_id"]},
             {"$set": {"research_requested": False}},
             return_document=pymongo.ReturnDocument.AFTER,
         )
-        LOG.debug("Case updated")
         return updated_case
 
     def case_dismissed_variants(self, institute, case):
@@ -443,7 +532,6 @@ class CaseEventHandler(object):
             {"$set": {"rerun_monitoring": True}},
             return_document=pymongo.ReturnDocument.AFTER,
         )
-        LOG.debug("Case updated")
         return updated_case
 
     def unmonitor(self, institute, case, user, link):
@@ -474,7 +562,6 @@ class CaseEventHandler(object):
             {"$set": {"rerun_monitoring": False}},
             return_document=pymongo.ReturnDocument.AFTER,
         )
-        LOG.debug("Case updated")
         return updated_case
 
     def share(self, institute, case, collaborator_id, user, link):
@@ -508,7 +595,6 @@ class CaseEventHandler(object):
             {"$push": {"collaborators": collaborator_id}},
             return_document=pymongo.ReturnDocument.AFTER,
         )
-        LOG.debug("Case updated")
         return updated_case
 
     def unshare(self, institute, case, collaborator_id, user, link):
@@ -543,48 +629,45 @@ class CaseEventHandler(object):
             {"$pull": {"collaborators": collaborator_id}},
             return_document=pymongo.ReturnDocument.AFTER,
         )
-        LOG.debug("Case updated")
         return updated_case
 
-    def diagnose(self, institute, case, user, link, omim_obj, omim_inds=[], remove=False):
-        """Diagnose a case using OMIM ids.
+    def diagnose(
+        self,
+        institute: dict,
+        case: dict,
+        user: dict,
+        link: str,
+        disease_id: str,
+        affected_inds: list = [],
+        remove: bool = False,
+    ) -> Optional[dict]:
+        """Add or remove a diagnose to a case and eventually case individuals."""
 
-        Args:
-            institute (dict): A Institute object
-            case (dict): Case object
-            user (dict): A User object
-            link (str): The url to be used in the event
-            omim_obj(dict): An OMIM term dictionary
-            omim_inds(list): List of case individuals with diagnosis
-            remove(bool):
-
-        Return:
-            updated_case
-
-        """
-        omim_modif_id = omim_obj["_id"]  # OMIM ID to add or remove from case diagnoses
         updated_diagnoses = []
         case_diagnoses = case.get("diagnosis_phenotypes") or []
 
-        if remove is True:  # Remove term from case diagnoses list
+        if remove:  # Remove term from case diagnoses list
             for case_dia in case_diagnoses:
-                if case_dia.get("disease_id") == omim_modif_id:
+                if case_dia.get("disease_id") == disease_id:
                     continue
                 updated_diagnoses.append(case_dia)
         else:  # Add new diagnosis term to case diseases list
+            disease_obj = self.disease_term(disease_identifier=disease_id)
+            if disease_obj is None:
+                return
             updated_diagnoses = case_diagnoses
             new_dia = {
-                "disease_nr": omim_obj["disease_nr"],
-                "disease_id": omim_modif_id,
-                "description": omim_obj["description"],
+                "disease_nr": disease_obj["disease_nr"],
+                "disease_id": disease_id,
+                "description": disease_obj["description"],
             }
-            if omim_inds:
+            if affected_inds:
                 new_dia["individuals"] = [
                     {
                         "individual_id": ind.split("|")[0],
                         "individual_name": ind.split("|")[1],
                     }
-                    for ind in omim_inds
+                    for ind in affected_inds
                 ]
             updated_diagnoses.append(new_dia)
 
@@ -603,8 +686,8 @@ class CaseEventHandler(object):
                 category="case",
                 verb="update_diagnosis",
                 subject=case["display_name"],
-                content=omim_modif_id,
-                individuals=[ind.split("|")[1] for ind in omim_inds],
+                content=disease_id,
+                individuals=[ind.split("|")[1] for ind in affected_inds],
             )
 
         return updated_case
@@ -632,14 +715,11 @@ class CaseEventHandler(object):
             subject=link,
         )
 
-        LOG.info("Adding cohort tag {0} to {1}".format(tag, case["display_name"]))
-
         updated_case = self.case_collection.find_one_and_update(
             {"_id": case["_id"]},
             {"$addToSet": {"cohorts": tag}},
             return_document=pymongo.ReturnDocument.AFTER,
         )
-        LOG.debug("Case updated")
         return updated_case
 
     def remove_cohort(self, institute, case, user, link, tag):
@@ -665,51 +745,11 @@ class CaseEventHandler(object):
             subject=case["display_name"],
         )
 
-        LOG.info("Removing cohort tag {0} to {1}".format(tag, case["display_name"]))
-
         updated_case = self.case_collection.find_one_and_update(
             {"_id": case["_id"]},
             {"$pull": {"cohorts": tag}},
             return_document=pymongo.ReturnDocument.AFTER,
         )
-        LOG.debug("Case updated")
-        return updated_case
-
-    def mark_checked(self, institute, case, user, link, unmark=False):
-        """Mark a case as checked from an analysis point of view.
-
-        Args:
-            institute (dict): A Institute object
-            case (dict): Case object
-            user (dict): A User object
-            link (str): The url to be used in the event
-            unmark (bool): If case should ve unmarked
-
-        Return:
-            updated_case
-        """
-
-        LOG.info("Updating checked status of {}".format(case["display_name"]))
-
-        status = "not checked" if unmark else "checked"
-        self.create_event(
-            institute=institute,
-            case=case,
-            user=user,
-            link=link,
-            category="case",
-            verb="check_case",
-            subject=status,
-        )
-
-        LOG.info("Updating {0}'s checked status {1}".format(case["display_name"], status))
-        analysis_checked = False if unmark else True
-        updated_case = self.case_collection.find_one_and_update(
-            {"_id": case["_id"]},
-            {"$set": {"analysis_checked": analysis_checked}},
-            return_document=pymongo.ReturnDocument.AFTER,
-        )
-        LOG.debug("Case updated")
         return updated_case
 
     def update_clinical_filter_hpo(
@@ -736,14 +776,11 @@ class CaseEventHandler(object):
             subject=case_obj["display_name"],
         )
 
-        LOG.info("Update HPO clinical filter status for {}".format(case_obj["display_name"]))
-
         updated_case = self.case_collection.find_one_and_update(
             {"_id": case_obj["_id"]},
             {"$set": {"hpo_clinical_filter": hpo_clinical_filter}},
             return_document=pymongo.ReturnDocument.AFTER,
         )
-        LOG.debug("Case updated")
         return updated_case
 
     def update_case_group_ids(self, institute_obj, case_obj, user_obj, link, group_ids):
@@ -766,7 +803,6 @@ class CaseEventHandler(object):
             subject=case_obj["display_name"],
         )
 
-        LOG.info("Update case group ids for {}".format(case_obj["display_name"]))
         updated_case = self.case_collection.find_one_and_update(
             {"_id": case_obj["_id"]},
             {"$set": {"group": group_ids}},
@@ -799,8 +835,6 @@ class CaseEventHandler(object):
             subject=case_obj["display_name"],
         )
 
-        LOG.info("Update default panels for {}".format(case_obj["display_name"]))
-
         panel_ids = [panel["_id"] for panel in panel_objs]
 
         for existing_panel in case_obj["panels"]:
@@ -814,6 +848,5 @@ class CaseEventHandler(object):
             {"$set": {"panels": case_obj["panels"]}},
             return_document=pymongo.ReturnDocument.AFTER,
         )
-        LOG.debug("Case updated")
 
         return updated_case
