@@ -1,8 +1,10 @@
 import logging
 from datetime import datetime
+from typing import List
 
 import pymongo
 from bson import ObjectId
+from flask import flash
 
 from scout.constants import DATE_DAY_FORMATTER
 
@@ -37,7 +39,10 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
         add_fields = {
             "$addFields": {
                 "yearMonthDay": {
-                    "$dateToString": {"format": DATE_DAY_FORMATTER, "date": "$updated_at"}
+                    "$dateToString": {
+                        "format": DATE_DAY_FORMATTER,
+                        "date": "$updated_at",
+                    }
                 },
             }
         }  # Create an additional field: yearMonthDay to group and display events better later
@@ -78,19 +83,19 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
 
     def create_event(
         self,
-        institute,
-        case,
-        user,
-        link,
-        category,
-        verb,
-        subject,
-        level="specific",
-        variant=None,
-        content=None,
-        panel=None,
-        individuals=[],
-        hpo_term=None,
+        institute: dict,
+        case: dict,
+        user: dict,
+        link: str,
+        category: str,
+        verb: str,
+        subject: str,
+        level: str = "specific",
+        variant: dict = None,
+        content: dict = None,
+        panel: str = None,
+        individuals: List[dict] = [],
+        hpo_term: str = None,
     ):
         """Create a Event with the parameters given.
 
@@ -145,7 +150,6 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
         institute,
         case=None,
         variant_id=None,
-        level=None,
         comments=False,
         panel=None,
     ):
@@ -155,7 +159,6 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
           institute (dict): An institute
           case (dict): A case
           variant_id (str, optional): global variant id
-          level (str, optional): restrict comments to 'specific' or 'global'
           comments (bool, optional): restrict events to include only comments
           audits (bool, optional): restrict events to include only audits
           panel (str): A panel name
@@ -237,13 +240,13 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
 
         return self.event_collection.find(query)
 
-    def case_events_by_verb(self, category, institute, case, verb):
+    def case_events_by_verb(self, category: str, institute: dict, case: dict, verb: str):
         """Return events with a specific verb for a case of an institute
         Args:
             category (str): "case" or "variant"
             institute (dict): an institute id
             case (dict): a case id
-            verb (dict): an event action verb, example: "dismiss_variant"
+            verb (str): an event action verb, example: "dismiss_variant"
 
         Returns:
             pymongo.Cursor: Query results
@@ -292,7 +295,7 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
         if hpo_term:  # User specified an HPO term
             hpo_results = [hpo_term]
         elif omim_term:  # User specified an OMIM diagnosys, collect its associated HPO terms
-            disease_obj = self.disease_term(omim_term)
+            disease_obj = self.disease_term(omim_term, filter_project={"hpo_terms": 1})
             if disease_obj:
                 for term in disease_obj.get("hpo_terms", []):
                     hpo_results.append(term)
@@ -513,6 +516,12 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
                 }
             },
         )
+        if not updated_comment:
+            flash(
+                "Comment could not be edited because it is no longer available.",
+                "warning",
+            )
+            return
         # create an event to register that user has updated a comment
         current_time = datetime.now()
         event = dict(
