@@ -1,4 +1,5 @@
 import logging
+from typing import Dict
 
 import intervaltree
 from pymongo.errors import BulkWriteError, DuplicateKeyError
@@ -6,6 +7,7 @@ from pymongo.errors import BulkWriteError, DuplicateKeyError
 from scout.exceptions import IntegrityError
 
 LOG = logging.getLogger(__name__)
+QUERY_FIELD_EXISTS = {"$exists": True, "$ne": None}
 
 
 class GeneHandler(object):
@@ -186,11 +188,11 @@ class GeneHandler(object):
         if build == "GRCh38":
             build = "38"
 
-        LOG.info("Fetching all genes")
+        LOG.debug("Fetching all genes")
 
         hgnc_tx = {}
         if add_transcripts:
-            LOG.info("Adding transcripts")
+            LOG.debug("Adding transcripts")
             for tx in self.transcripts(build=str(build)):
                 hgnc_id = tx["hgnc_id"]
                 if not hgnc_id in hgnc_tx:
@@ -318,7 +320,7 @@ class GeneHandler(object):
         res = self.hgnc_collection.find({"aliases": symbol, "build": str(build)})
         return res
 
-    def genes_by_alias(self, build="37", genes=None):
+    def genes_by_alias(self, build=None, genes=None):
         """Return a dictionary with hgnc symbols as keys and a list of hgnc ids
              as value.
 
@@ -333,43 +335,58 @@ class GeneHandler(object):
         Returns:
             alias_genes(dict): {<hgnc_alias>: {'true': <hgnc_id>, 'ids': {<hgnc_id_1>, <hgnc_id_2>, ...}}}
         """
-        LOG.info("Fetching all genes by alias")
+        LOG.debug("Fetching all genes by alias")
         # Collect one entry for each alias symbol that exists
         alias_genes = {}
-        # Loop over all genes
-        if not genes:
-            genes = self.hgnc_collection.find({"build": str(build)})
+
+        if genes is None:
+            genes_query = {"build": str(build)} if build else {}
+            genes = self.hgnc_collection.find(
+                genes_query, projection={"hgnc_id": 1, "hgnc_symbol": 1, "aliases": 1}
+            )
 
         for gene in genes:
-            # Collect the hgnc_id
             hgnc_id = gene["hgnc_id"]
-            # Collect the true symbol given by hgnc
             hgnc_symbol = gene["hgnc_symbol"]
-            # Loop aver all aliases
+
             for alias in gene["aliases"]:
-                true_id = None
-                # If the alias is the same as hgnc symbol we know the true id
+                if alias not in alias_genes:
+                    alias_genes[alias] = {"true": None, "ids": set()}
+
+                alias_genes[alias]["ids"].add(hgnc_id)
                 if alias == hgnc_symbol:
-                    true_id = hgnc_id
-                # If the alias is already in the list we add the id
-                if alias in alias_genes:
-                    alias_genes[alias]["ids"].add(hgnc_id)
-                    if true_id:
-                        alias_genes[alias]["true"] = hgnc_id
-                else:
-                    alias_genes[alias] = {"true": hgnc_id, "ids": set([hgnc_id])}
+                    alias_genes[alias]["true"] = hgnc_id
 
         return alias_genes
 
-    def ensembl_to_hgnc_mapping(self):
+    def ensembl_to_hgnc_id_mapping(self) -> Dict[str, int]:
         """Return a dictionary with Ensembl ids as keys and hgnc_ids as values
 
         Returns:
-            mapping(dict): {"ENSG00000121410":"A1BG", ...}
+            mapping(dict): {"ENSG00000121410": 5, ...}
         """
-        pipeline = [{"$group": {"_id": {"ensembl_id": "$ensembl_id", "hgnc_id": "$hgnc_id"}}}]
-        result = self.hgnc_collection.aggregate(pipeline)
-        mapping = {res["_id"]["ensembl_id"]: res["_id"]["hgnc_id"] for res in result}
+        query = {
+            "ensembl_id": QUERY_FIELD_EXISTS,
+            "hgnc_id": QUERY_FIELD_EXISTS,
+        }
+        project = {"ensembl_id": 1, "hgnc_id": 1}
+        result = self.hgnc_collection.find(query, project)
+        mapping = {res["ensembl_id"]: res["hgnc_id"] for res in result}
+        return mapping
+
+    def hgnc_symbol_ensembl_id_mapping(self) -> Dict[str, str]:
+        """Return a dictionary with HGNC symbols as keys and Ensembl ids as values.
+
+        Returns:
+           mapping(dict): {"A1BG": "ENSG00000121410".}
+        """
+        query = {
+            "ensembl_id": QUERY_FIELD_EXISTS,
+            "hgnc_symbol": QUERY_FIELD_EXISTS,
+        }
+        project = {"ensembl_id": 1, "hgnc_symbol": 1}
+        result = self.hgnc_collection.find(query, project)
+        mapping = {res["hgnc_symbol"]: res["ensembl_id"] for res in result}
         return mapping
 
     def ensembl_genes(self, build=None, add_transcripts=False, id_transcripts=False):
@@ -388,7 +405,7 @@ class GeneHandler(object):
             add_transcripts = True
 
         for gene_obj in self.all_genes(build=build, add_transcripts=add_transcripts):
-            ensg_id = gene_obj["ensembl_id"]
+            ensg_id = gene_obj.get("ensembl_id")
             hgnc_id = gene_obj["hgnc_id"]
             transcript_objs = gene_obj.get("ens_transcripts")
             if id_transcripts and transcript_objs:
@@ -401,24 +418,6 @@ class GeneHandler(object):
 
         return genes
 
-    def to_hgnc(self, hgnc_alias, build="37"):
-        """Check if a hgnc symbol is an alias
-
-        Return the correct hgnc symbol, if not existing return None
-
-        Args:
-            hgnc_alias(str)
-
-        Returns:
-            hgnc_symbol(str)
-        """
-        result = self.hgnc_genes(hgnc_symbol=hgnc_alias, build=str(build))
-        if result:
-            for gene in result:
-                return gene["hgnc_symbol"]
-        else:
-            return None
-
     def add_hgnc_id(self, genes):
         """Add the correct hgnc id to a set of genes with hgnc symbols
 
