@@ -1,5 +1,6 @@
 import logging
 from datetime import datetime
+from typing import List, Optional, Union
 
 import pymongo
 
@@ -34,50 +35,30 @@ class InstituteHandler(object):
 
     def update_institute(
         self,
-        internal_id,
-        sanger_recipient=None,
-        sanger_recipients=None,
-        coverage_cutoff=None,
-        frequency_cutoff=None,
-        display_name=None,
-        remove_sanger=None,
-        phenotype_groups=None,
-        gene_panels=None,
-        gene_panels_matching=None,
-        group_abbreviations=None,
-        add_groups=None,
-        sharing_institutes=None,
-        cohorts=None,
-        loqusdb_ids=[],
-        alamut_key=None,
-        alamut_institution=None,
-        check_show_all_vars=None,
-    ):
-        """Update the information for an institute
+        internal_id: str,
+        sanger_recipient: Optional[str] = None,
+        sanger_recipients: Optional[List[str]] = None,
+        coverage_cutoff: Optional[int] = None,
+        frequency_cutoff: Optional[float] = None,
+        show_all_cases_status: Optional[List[str]] = None,
+        display_name: Optional[str] = None,
+        remove_sanger: Optional[str] = None,
+        phenotype_groups: Optional[List[str]] = None,
+        gene_panels: Optional[dict] = None,
+        gene_panels_matching: Optional[dict] = None,
+        group_abbreviations: Optional[List[str]] = None,
+        add_groups: Optional[bool] = None,
+        sharing_institutes: Optional[List[str]] = None,
+        cohorts: Optional[List[str]] = None,
+        loqusdb_ids: Optional[List[str]] = [],
+        alamut_key: Optional[str] = None,
+        alamut_institution: Optional[str] = None,
+        check_show_all_vars: Optional[str] = None,
+        clinvar_key: Optional[str] = None,
+        clinvar_submitters: Optional[List[str]] = None,
+    ) -> Union[dict, str]:
+        """Update the information for an institute."""
 
-        Args:
-            internal_id(str): The internal institute id
-            sanger_recipient(str): Email adress to add for sanger order
-            sanger_recipients(list): A list of sanger recipients email addresses
-            coverage_cutoff(int): Update coverage cutoff
-            frequency_cutoff(float): New frequency cutoff
-            display_name(str): New display name
-            remove_sanger(str): Email adress for sanger user to be removed
-            phenotype_groups(iterable(str)): New phenotype groups
-            gene_panels(dict): a dictionary of panels with key=panel_name and value=display_name
-            gene_panels_matching(dict): panels to limit search of matching variants (managed, causatives) to. Dict with key=panel_name and value=display_name
-            group_abbreviations(iterable(str))
-            add_groups(bool): If groups should be added. If False replace groups
-            sharing_institutes(list(str)): Other institutes to share cases with
-            cohorts(list(str)): patient cohorts
-            loqusdb_ids(list(str)): list of ids of loqusdb instances Scout is connected to
-            alamut_key(str): optional, Alamut Plus API key -> https://extranet.interactive-biosoftware.com/alamut-visual-plus_API.html
-            alamut_institution: optional, Alamut Plus API Institute ID -> https://extranet.interactive-biosoftware.com/alamut-visual-plus_API.html
-
-        Returns:
-            updated_institute(dict)
-
-        """
         add_groups = add_groups or False
         institute_obj = self.institute(internal_id)
         if not institute_obj:
@@ -117,6 +98,7 @@ class InstituteHandler(object):
             "gene_panels_matching": gene_panels_matching,
             "loqusdb_id": loqusdb_ids,
             "sanger_recipients": sanger_recipients,
+            "clinvar_submitters": clinvar_submitters,
         }
         for key, value in GENERAL_SETTINGS.items():
             if value not in [None, ""]:
@@ -140,13 +122,15 @@ class InstituteHandler(object):
                 existing_groups[hpo_term] = {"name": description, "abbr": abbreviation}
             updates["$set"]["phenotype_groups"] = existing_groups
 
-        for key, value in {
+        ADMIN_SETTINGS = {
             "alamut_key": alamut_key,
             "alamut_institution": alamut_institution,
-        }.items():
-            if value is None:
-                continue
-            updates["$set"][key] = value if value else None
+            "clinvar_key": clinvar_key,
+            "show_all_cases_status": show_all_cases_status,
+        }
+        for key, value in ADMIN_SETTINGS.items():
+            if value not in [None, "", []]:
+                updates["$set"][key] = value
 
         updates["$set"]["check_show_all_vars"] = check_show_all_vars is not None
 
@@ -162,12 +146,9 @@ class InstituteHandler(object):
 
         return updated_institute
 
-    def institute(self, institute_id):
+    def institute(self, institute_id: str):
         """Featch a single institute from the backend
 
-        Args:
-            institute_id(str)
-
         Returns:
             Institute object
         """
@@ -177,15 +158,9 @@ class InstituteHandler(object):
 
         return institute_obj
 
-    def safe_genes_filter(self, institute_id):
+    def safe_genes_filter(self, institute_id: str) -> List[int]:
         """Returns a list of "safe" HGNC IDs to filter variants with. These genes are retrieved from the institute.gene_panels_matching
-        Can be used to limit secondary findings when retrieving other causatives or matching managed variants
-
-        Args:
-            institute_id(str): _id of an institute
-
-        Returns:
-            safe_genes(list of HGNC ids)
+        Can be used to limit secondary findings when retrieving other causatives or matching managed variants.
         """
         safe_genes = []
         institute_obj = self.institute(institute_id)
@@ -193,7 +168,7 @@ class InstituteHandler(object):
             return safe_genes  # return an empty list
         for panel_name in institute_obj.get("gene_panels_matching", {}).keys():
             safe_genes += self.panel_to_genes(panel_name=panel_name, gene_format="hgnc_id")
-        return safe_genes
+        return list(set(safe_genes))
 
     def institutes(self, institute_ids=None):
         """Fetch all institutes.
