@@ -1,6 +1,7 @@
 import logging
 import re
 from datetime import datetime, timedelta
+from typing import Optional, Union
 
 from scout.constants import (
     CLINSIG_MAP,
@@ -11,6 +12,8 @@ from scout.constants import (
     TRUSTED_REVSTAT_LEVEL,
 )
 
+CRITERION_EXCLUDE_OPERATOR = {False: "$in", True: "$nin"}
+
 LOG = logging.getLogger(__name__)
 
 
@@ -74,7 +77,11 @@ class QueryHandler(object):
         return variants_query
 
     def build_variant_query(
-        self, query=None, institute_ids=[], category="snv", variant_type=["clinical"]
+        self,
+        query: Optional[dict] = None,
+        institute_ids: Optional[list] = [],
+        category: Optional[Union[str, list]] = "snv",
+        variant_type: Optional[list] = ["clinical"],
     ):
         """Build a mongo query across multiple cases.
         Translate query options from a form into a complete mongo query dictionary.
@@ -91,7 +98,7 @@ class QueryHandler(object):
         Args:
             query(dict): A query dictionary for the database, from a query form.
             institute_ids: a list of institute _ids
-            category(str): 'snv', 'sv', 'str' 'cancer_sv' or 'cancer'
+            category(str): 'snv', 'sv', 'str' 'cancer_sv' or 'cancer' OR a LIST(str) of the same
             variant_type(str): 'clinical' or 'research'
 
         Possible query dict keys:
@@ -110,7 +117,12 @@ class QueryHandler(object):
 
         mongo_variant_query["hgnc_symbols"] = {"$in": query["hgnc_symbols"]}
         mongo_variant_query["variant_type"] = {"$in": variant_type}
-        mongo_variant_query["category"] = category
+
+        if not category:
+            category = "snv"
+        mongo_variant_query["category"] = (
+            {"$in": category} if isinstance(category, list) else category
+        )
 
         select_cases = None
         select_case_obj = None
@@ -256,7 +268,11 @@ class QueryHandler(object):
             if criterion in ["hgnc_symbols", "gene_panels"]:
                 gene_query = self.gene_filter(query, build=build)
                 if len(gene_query) > 0 or "hpo" in query.get("gene_panels", []):
-                    mongo_query["hgnc_ids"] = {"$in": gene_query}
+                    mongo_query["hgnc_ids"] = {
+                        CRITERION_EXCLUDE_OPERATOR[
+                            bool(query.get("gene_panels_exclude"))
+                        ]: gene_query
+                    }
                 continue
 
             if criterion == "chrom" and query.get("chrom"):  # filter by coordinates
@@ -298,8 +314,8 @@ class QueryHandler(object):
         # there is only 'clinsig' criterion among the primary terms right now
         primary_terms = False
 
-        # gnomad_frequency, local_obs, clingen_ngi, swegen, spidex_human, cadd_score, genetic_models, mvl_tag, clinvar_tag, cosmic_tag
-        # functional_annotations, region_annotations, size, svtype, decipher, depth, alt_count, control_frequency, tumor_frequency
+        # gnomad_frequency, local_obs, local_obs_freq, clingen_ngi, swegen, swegen_freq, spidex_human, cadd_score, genetic_models, mvl_tag, clinvar_tag, cosmic_tag
+        # functional_annotations, region_annotations, size, svtype, decipher, depth, alt_count, somatic_score, control_frequency, tumor_frequency
         secondary_terms = False
 
         # check if any of the primary criteria was specified in the query
@@ -353,7 +369,6 @@ class QueryHandler(object):
             else:
                 mongo_query["$and"] = coordinate_query
 
-        LOG.info("mongo query: %s", mongo_query)
         return mongo_query
 
     def affected_inds_query(self, mongo_query, case_id, gt_query):
@@ -364,7 +379,8 @@ class QueryHandler(object):
             case_id(str): _id of a case
             gt_selected(dict or None): dict if user specified a genotype value in genotypes form field, else None
         """
-        case_obj = self.case(case_id=case_id)
+        CASE_AFFECTED_INDS_PROJECTION = {"individuals": 1}
+        case_obj = self.case(case_id=case_id, projection=CASE_AFFECTED_INDS_PROJECTION)
         case_inds = case_obj.get("individuals", [])
 
         gt_query = gt_query or {"$nin": ["0/0", "./.", "./0", "0/."]}
@@ -564,27 +580,49 @@ class QueryHandler(object):
 
             if criterion == "gnomad_frequency":
                 gnomad = query.get("gnomad_frequency")
-                if gnomad == "-1":
-                    # -1 means to exclude all variants that exists in gnomad
-                    mongo_query["gnomad_frequency"] = {"$exists": False}
-                else:
-                    # Replace comma with dot
+                mongo_secondary_query.append(
+                    {
+                        "$or": [
+                            {"gnomad_frequency": {"$lt": float(gnomad)}},
+                            {"gnomad_frequency": {"$exists": False}},
+                        ]
+                    }
+                )
+
+            for local_obs_old_type in [
+                "local_obs_old",
+                "local_obs_cancer_germline_old",
+                "local_obs_cancer_somatic_old",
+            ]:
+                if criterion == local_obs_old_type:
+                    local_obs = query.get(local_obs_old_type)
                     mongo_secondary_query.append(
                         {
                             "$or": [
-                                {"gnomad_frequency": {"$lt": float(gnomad)}},
-                                {"gnomad_frequency": {"$exists": False}},
+                                {local_obs_old_type: None},
+                                {local_obs_old_type: {"$lt": local_obs + 1}},
                             ]
                         }
                     )
 
-            if criterion == "local_obs":
-                local_obs = query.get("local_obs")
+            if criterion == "local_obs_freq":
+                local_obs_freq = query.get("local_obs_freq")
                 mongo_secondary_query.append(
                     {
                         "$or": [
-                            {"local_obs_old": None},
-                            {"local_obs_old": {"$lt": local_obs + 1}},
+                            {"local_obs_old_freq": None},
+                            {"local_obs_old_freq": {"$lt": local_obs_freq}},
+                        ]
+                    }
+                )
+
+            if criterion == "swegen_freq":
+                swegen = query.get("swegen_freq")
+                mongo_secondary_query.append(
+                    {
+                        "$or": [
+                            {"swegen_mei_max": {"$lt": float(swegen)}},
+                            {"swegen_mei_max": {"$exists": False}},
                         ]
                     }
                 )
@@ -646,6 +684,13 @@ class QueryHandler(object):
 
                 mongo_secondary_query.append({"$or": spidex_query_or_part})
 
+            if criterion == "revel":
+                revel = query["revel"]
+                revel_query = {"revel": {"$gt": float(revel)}}
+                revel_query = {"$or": [revel_query, {"revel": {"$exists": False}}]}
+
+                mongo_secondary_query.append(revel_query)
+
             if criterion == "cadd_score":
                 cadd = query["cadd_score"]
                 cadd_query = {"cadd_score": {"$gt": float(cadd)}}
@@ -700,6 +745,16 @@ class QueryHandler(object):
             if criterion == "alt_count":
                 mongo_secondary_query.append({"tumor.alt_depth": {"$gt": query.get("alt_count")}})
 
+            if criterion == "somatic_score":
+                mongo_secondary_query.append(
+                    {
+                        "$or": [
+                            {"somatic_score": {"$gt": query.get("somatic_score")}},
+                            {"somatic_score": {"$exists": False}},
+                        ]
+                    }
+                )
+
             if criterion == "control_frequency":
                 mongo_secondary_query.append(
                     {"normal.alt_freq": {"$lt": float(query.get("control_frequency"))}}
@@ -721,6 +776,26 @@ class QueryHandler(object):
                 mongo_secondary_query.append({"cosmic_ids": {"$exists": True}})
                 mongo_secondary_query.append({"cosmic_ids": {"$ne": None}})
 
+            if criterion == "fusion_score":
+                mongo_secondary_query.append(
+                    {"fusion_score": {"$gte": float(query.get("fusion_score"))}}
+                )
+            if criterion == "ffpm":
+                mongo_secondary_query.append({"samples.0.ffpm": {"$gte": float(query.get("ffpm"))}})
+            if criterion == "junction_reads":
+                mongo_secondary_query.append(
+                    {"samples.0.read_depth": {"$gte": int(query.get("junction_reads"))}}
+                )
+            if criterion == "split_reads":
+                mongo_secondary_query.append(
+                    {"samples.0.split_read": {"$gte": int(query.get("split_reads"))}}
+                )
+            if criterion == "fusion_caller":
+                fusion_caller_query = []
+                for caller in query.get("fusion_caller", []):
+                    fusion_caller_query.append({caller: "Pass"})
+                mongo_secondary_query.append({"$or": fusion_caller_query})
+
         return mongo_secondary_query
 
 
