@@ -1,13 +1,11 @@
 # -*- coding: utf-8 -*-
 # stdlib modules
 import logging
-import pathlib
 import re
-import tempfile
+from typing import Any
 
 # Third party modules
 import pymongo
-from cyvcf2 import VCF
 
 # Local modules
 from scout.utils.coordinates import is_par
@@ -20,9 +18,11 @@ LOG = logging.getLogger(__name__)
 MATCHQ = "$match"
 CARRIER = r"[12]"  # same as re.compile()"1|2")
 
+CASE_VARIANT_GET_BUILD_PROJECTION = {"genome_build": 1}
+CASE_CAUSATIVES_PROJECTION = {"causatives": 1, "partial_causatives": 1}
+
 
 class VariantHandler(VariantLoader):
-
     """Methods to handle variants in the mongo adapter"""
 
     def add_gene_info(self, variant_obj, gene_panels=None, build=None):
@@ -141,7 +141,9 @@ class VariantHandler(VariantLoader):
 
             variant_gene["common"] = hgnc_gene
             # Add the associated disease terms
-            variant_gene["disease_terms"] = self.disease_terms(hgnc_id)
+            variant_gene["disease_terms"] = self.disease_terms_by_gene(
+                hgnc_id, filter_project={"inheritance": 1, "description": 1, "source": 1}
+            )
 
         return variant_obj
 
@@ -204,7 +206,7 @@ class VariantHandler(VariantLoader):
 
         return result
 
-    def count_variants(self, case_id, query, variant_ids, category):
+    def count_variants(self, case_id, query, variant_ids, category, build="37"):
         """Returns number of variants
 
         Arguments:
@@ -217,26 +219,18 @@ class VariantHandler(VariantLoader):
              integer
         """
 
-        query = self.build_query(case_id, query=query, variant_ids=variant_ids, category=category)
+        query = self.build_query(
+            case_id, query=query, variant_ids=variant_ids, category=category, build=build
+        )
         return self.variant_collection.count_documents(query)
 
-    def sanger_variants(self, institute_id=None, case_id=None):
-        """Return all variants with sanger information
-
-        Args:
-            institute_id(str)
-            case_id(str)
-
-        Returns:
-            res(pymongo.Cursor): A Cursor with all variants with sanger activity
-        """
-        query = {"validation": {"$exists": True}}
-        if institute_id:
-            query["institute_id"] = institute_id
-        if case_id:
-            query["case_id"] = case_id
-
-        return self.variant_collection.find(query)
+    def variant_update_field(self, variant_id: str, field_name: str, field_value: Any) -> dict:
+        """Updates the value of the given key(field_name) in the variant document in the database."""
+        return self.variant_collection.find_one_and_update(
+            {"_id": variant_id},
+            {"$set": {field_name: field_value}},
+            return_document=pymongo.ReturnDocument.AFTER,
+        )
 
     def variant(
         self,
@@ -245,6 +239,7 @@ class VariantHandler(VariantLoader):
         case_id=None,
         simple_id=None,
         variant_type="clinical",
+        projection=None,
     ):
         """Returns the specified variant.
 
@@ -272,10 +267,12 @@ class VariantHandler(VariantLoader):
             # search with a unique id
             query["_id"] = document_id
 
-        variant_obj = self.variant_collection.find_one(query)
+        variant_obj = self.variant_collection.find_one(query, projection=projection)
         if not variant_obj:
             return variant_obj
-        case_obj = self.case(case_id=variant_obj["case_id"])
+        case_obj = self.case(
+            case_id=variant_obj["case_id"], projection=CASE_VARIANT_GET_BUILD_PROJECTION
+        )
 
         if case_obj:
             variant_obj = self.add_gene_info(
@@ -375,7 +372,13 @@ class VariantHandler(VariantLoader):
             case_id = event["_id"]["case"]
             variant_id = event["_id"]["variant_id"]
             var_obj = self.variant(case_id=case_id, document_id=variant_id)
-            case_obj = self.case(case_id=case_id)
+            CASE_VERIFIED_PROJECTION = {
+                "display_name": 1,
+                "individuals": 1,
+                "status": 1,
+                "partial_causatives": 1,
+            }
+            case_obj = self.case(case_id=case_id, projection=CASE_VERIFIED_PROJECTION)
             if not case_obj or not var_obj:
                 continue  # Take into account that stuff might have been removed from database
             if var_obj.get("validation") is None or var_obj.get("validation") == "Not validated":
@@ -405,7 +408,7 @@ class VariantHandler(VariantLoader):
         causatives = []
 
         if case_id:
-            case_obj = self.case_collection.find_one({"_id": case_id})
+            case_obj = self.case_collection.find_one({"_id": case_id}, CASE_CAUSATIVES_PROJECTION)
             causatives = [causative for causative in case_obj.get("causatives", [])]
 
         elif institute_id:
@@ -519,14 +522,14 @@ class VariantHandler(VariantLoader):
         )
         causative_ids = set()
         for case_event in causative_events:
-            case_obj = self.case(case_event.get("case"))
+            case_obj = self.case(case_event.get("case"), projection=CASE_CAUSATIVES_PROJECTION)
             if case_obj is None:
                 continue
 
             for var_id in case_obj.get("causatives", []):
                 causative_ids.add(var_id)
 
-            for var_id, _ in case_obj.get("patial_causatives", {}).items():
+            for var_id, _ in case_obj.get("partial_causatives", {}).items():
                 causative_ids.add(var_id)
 
         filters = {"_id": {"$in": list(causative_ids)}}
@@ -551,16 +554,19 @@ class VariantHandler(VariantLoader):
                 "institute": case_obj["owner"],
                 "verb": {"$in": ["mark_causative", "mark_partial_causative"]},
                 "category": "variant",
-            }
+            },
+            {"case": 1, "link": 1, "subject": 1},
         )
+
         positional_variant_ids = set()
         for var_event in var_causative_events:
             if var_event["case"] == case_obj["_id"]:
                 # exclude causatives from the same case
                 continue
-            other_case = self.case(var_event["case"])
+
+            other_case = self.case(var_event["case"], CASE_CAUSATIVES_PROJECTION)
             if other_case is None:
-                # Other variant belongs to a case that doesn't exist any more
+                # Other variant belongs to a case that doesn't exist anymore
                 continue
             other_link = var_event["link"]
             # link contains other variant ID
@@ -576,7 +582,7 @@ class VariantHandler(VariantLoader):
                 0:4
             ]  # example: [ "17", "7577559", "G" "A"]
 
-            for variant_type in ["clinical", "reseach"]:
+            for variant_type in ["clinical", "research"]:
                 positional_variant_ids.add(generate_md5_key(other_var_simple + [variant_type]))
 
         return self.match_affected_gt(case_obj, positional_variant_ids, limit_genes)
@@ -601,18 +607,27 @@ class VariantHandler(VariantLoader):
 
         var_causative_events = self.event_collection.find(
             {
-                "verb": "mark_causative",
+                "verb": {"$in": ["mark_causative", "mark_partial_causative"]},
                 "subject": {"$in": [clinical_variant, research_variant]},
                 "category": "variant",
             }
         )
 
+        CASE_VARIANT_OTHER_CAUSATIVES_PROJECTION = {
+            "collaborators": 1,
+            "causatives": 1,
+            "display_name": 1,
+            "owner": 1,
+            "partial_causatives": 1,
+        }
         yielded_other_causative_ids = []
         for var_event in var_causative_events:
             if var_event["case"] == case_obj["_id"]:
                 # This is the variant the search started from, do not collect it
                 continue
-            other_case = self.case(var_event["case"])
+            other_case = self.case(
+                var_event["case"], projection=CASE_VARIANT_OTHER_CAUSATIVES_PROJECTION
+            )
             if other_case is None:
                 # Other variant belongs to a case that doesn't exist any more
                 continue
@@ -669,7 +684,7 @@ class VariantHandler(VariantLoader):
         result = self.variant_collection.delete_many(query)
         LOG.info("{0} variants deleted".format(result.deleted_count))
 
-    def overlapping(self, variant_obj):
+    def overlapping(self, variant_obj, limit=30):
         """Return overlapping variants.
 
         Look at the genes that a variant overlaps to.
@@ -699,7 +714,7 @@ class VariantHandler(VariantLoader):
         }
         sort_key = [("rank_score", pymongo.DESCENDING)]
         # We collect the 30 most severe overlapping variants
-        variants = self.variant_collection.find(query).sort(sort_key).limit(30)
+        variants = self.variant_collection.find(query).sort(sort_key).limit(limit)
 
         return variants
 
@@ -779,7 +794,7 @@ class VariantHandler(VariantLoader):
 
         # Collect the result in a dictionary
         variants = {}
-        case_obj = self.case(case_id=case_id)
+        case_obj = self.case(case_id=case_id, projection=CASE_VARIANT_GET_BUILD_PROJECTION)
 
         for var in self.variant_collection.find(query):
             variants[var["variant_id"]] = self.add_gene_info(
@@ -825,7 +840,7 @@ class VariantHandler(VariantLoader):
             variant_file(str): string path to a VCF file on disk
         """
         variant_file = None
-        for var_type in ["snv", "sv", "str", "cancer"]:
+        for var_type in ["snv", "sv", "str", "cancer", "mei"]:
             if category != var_type:
                 continue
             if variant_type == "clinical":
@@ -834,75 +849,6 @@ class VariantHandler(VariantLoader):
                 variant_file = case_obj["vcf_files"].get("_".join(["vcf", var_type, "research"]))
         return variant_file
 
-    def get_region_vcf(
-        self,
-        case_obj,
-        chrom=None,
-        start=None,
-        end=None,
-        gene_obj=None,
-        variant_type="clinical",
-        category="snv",
-        rank_threshold=None,
-    ):
-        """Produce a reduced vcf with variants from the specified coordinates
-           This is used for the alignment viewer.
-
-        Args:
-            case_obj(dict): A case from the scout database
-            variant_type(str): 'clinical' or 'research'. Default: 'clinical'
-            category(str): "snv", "sv", "str", "cancer". Default: 'snv'
-            rank_threshold(float): Only load variants above this score. Default: 5
-            chrom(str): Load variants from a certain chromosome
-            start(int): Specify the start position
-            end(int): Specify the end position
-            gene_obj(dict): A gene object from the database
-
-        Returns:
-            file_name(str): Path to the temporary file
-        """
-        rank_threshold = rank_threshold or -100
-
-        variant_file = self.get_variant_file(case_obj, category, variant_type)
-        if not variant_file:
-            raise FileNotFoundError("VCF file does not seem to exist")
-
-        try:
-            vcf_obj = VCF(variant_file)
-        except Exception:
-            raise FileNotFoundError(
-                "Could not access {}. The file is missing or malformed".format(variant_file)
-            )
-
-        region = ""
-
-        if gene_obj:
-            chrom = gene_obj["chromosome"]
-            start = gene_obj["start"]
-            end = gene_obj["end"]
-
-        if chrom:
-            if start and end:
-                region = "{0}:{1}-{2}".format(chrom, start, end)
-            else:
-                region = "{0}".format(chrom)
-
-        else:
-            rank_threshold = rank_threshold or 5
-
-        with tempfile.NamedTemporaryFile(mode="w", delete=False) as temp:
-            file_name = str(pathlib.Path(temp.name))
-            for header_line in vcf_obj.raw_header.split("\n"):
-                if len(header_line) > 3:
-                    temp.write(header_line + "\n")
-            try:
-                for variant in vcf_obj(region):
-                    temp.write(str(variant))
-            except Exception:
-                raise FileNotFoundError("Could not find index for {}".format(variant_file))
-
-        return file_name
-
     def case_variants_count(self, case_id, institute_id, variant_type=None, force_update_case=True):
         """Returns the sum of all variants for a case by type
 
@@ -947,7 +893,10 @@ class VariantHandler(VariantLoader):
             }
         }
         pipeline = [match, group]
-        results = self.variant_collection.aggregate(pipeline)
+        results = list(self.variant_collection.aggregate(pipeline))
+
+        omics_results = list(self.omics_variant_collection.aggregate(pipeline))
+        results.extend(omics_results)
 
         variants_by_type = {}
         for item in results:
