@@ -1,5 +1,6 @@
 import logging
 from collections import Counter
+from typing import Dict, List
 
 import pymongo
 
@@ -187,14 +188,11 @@ class VariantEventHandler(object):
         )
         return updated_variant
 
-    def sanger_ordered(self, institute_id=None, user_id=None, case_id=None):
+    def sanger_ordered(
+        self, institute_id: str = None, user_id: str = None, case_id: str = None
+    ) -> List[Dict[str, List]]:
         """Get all variants with validations ever ordered.
 
-        Args:
-            institute_id(str) : The id of an institute
-            user_id(str) : The id of an user
-            case_id(str) : Id of a case
-
         Returns:
             sanger_ordered(list) : a list of dictionaries, each with "case_id" as keys
                 and list of variant ids (variant_id, not _id) as values
@@ -216,14 +214,11 @@ class VariantEventHandler(object):
         sanger_ordered = [item for item in results]
         return sanger_ordered
 
-    def validated(self, institute_id=None, user_id=None, case_id=None):
+    def validated(
+        self, institute_id: str = None, user_id: str = None, case_id: str = None
+    ) -> List[Dict[str, List]]:
         """Get all variants that have been validated.
 
-        Args:
-            institute_id(str) : The id of an institute
-            user_id(str) : The id of an user
-            case_id(str) : Id of a case
-
         Returns:
             validated(list) : a list of dictionaries, each with "case_id" as keys
                 and list of variant ids (variant_id, not _id) as values
@@ -371,10 +366,12 @@ class VariantEventHandler(object):
         )
         return updated_variant
 
-    def mark_partial_causative(self, institute, case, user, link, variant, omim_terms, hpo_terms):
+    def mark_partial_causative(
+        self, institute, case, user, link, variant, disease_terms, hpo_terms
+    ):
         """Create an event for marking a variant as partial causative.
            When a variant is marked as partial causative the case will not be marked as solved.
-           Partial causatives have associated phenotypes (OMIM and HPO terms)
+           Partial causatives have associated diseases phenotypes (OMIM/ORPHA and HPO terms)
 
         Arguments:
           institute (dict): An Institute object
@@ -382,7 +379,7 @@ class VariantEventHandler(object):
           user (dict): A User object
           link (str): The url to be used in the event
           variant (variant): A variant object
-          omim_terms(list): A list of OMIM diagnoses. Example: ['145590', '615349']
+          disease_terms(list): A list of diagnoses. Example: ['OMIM:145590', 'OMIM:615349']
           hpo_terms(list): A list of HPO terms. example: ['Febrile seizures_HP:0002373', 'Abnormality of the clavicle_HP:0000889']
 
         Returns:
@@ -408,7 +405,7 @@ class VariantEventHandler(object):
         # update partial causative object
         case_partial_causatives = case.get("partial_causatives") or {}
         case_partial_causatives[variant["_id"]] = {
-            "diagnosis_phenotypes": omim_terms,
+            "diagnosis_phenotypes": disease_terms,
             "phenotype_terms": hpo_objs_list,
         }
 
