@@ -3,9 +3,11 @@
 import logging
 from datetime import datetime
 
+import cyvcf2
+
 # Third party modules
 import pymongo
-from cyvcf2 import VCF
+from cyvcf2 import VCF, Variant
 from intervaltree import IntervalTree
 from pymongo.errors import BulkWriteError, DuplicateKeyError
 
@@ -22,14 +24,15 @@ from scout.parse.variant.headers import (
     parse_rank_results_header,
     parse_vep_header,
 )
+from scout.parse.variant.ids import parse_simple_id
 from scout.parse.variant.managed_variant import parse_managed_variant_id
 from scout.parse.variant.rank_score import parse_rank_score
+from scout.utils.sort import get_load_priority
 
 LOG = logging.getLogger(__name__)
 
 
 class VariantLoader(object):
-
     """Methods to handle variant loading in the mongo adapter"""
 
     def update_variant(self, variant_obj):
@@ -123,7 +126,7 @@ class VariantLoader(object):
             else:
                 variant_obj = self.variant_collection.find_one({"_id": compound["variant"]})
             if variant_obj:
-                # If the variant exosts we try to collect as much info as possible
+                # If the variant exists we try to collect as much info as possible
                 not_loaded = False
                 compound["rank_score"] = variant_obj["rank_score"]
                 compound["is_dismissed"] = len(variant_obj.get("dismiss_variant", [])) > 0
@@ -198,87 +201,88 @@ class VariantLoader(object):
         """
 
         case_id = case_obj["_id"]
-        # Possible categories 'snv', 'sv', 'str', 'cancer', 'cancer_sv':
-        categories = set()
-        # Possible variant types 'clinical', 'research':
-        variant_types = set()
-
-        for file_type in FILE_TYPE_MAP:
-            if case_obj.get("vcf_files", {}).get(file_type):
-                categories.add(FILE_TYPE_MAP[file_type]["category"])
-                variant_types.add(FILE_TYPE_MAP[file_type]["variant_type"])
+        # Possible categories 'snv', 'sv', 'str', 'cancer', 'cancer_sv'. Sort according to load order to ensure Cancer SNVs before
+        # Cancer SVs, in particular, and keep a consistent variant_id collision resolution order.
+        # Possible variant types are 'clinical', 'research'.
+        load_variants = {
+            (FILE_TYPE_MAP[file_type]["variant_type"], FILE_TYPE_MAP[file_type]["category"])
+            for file_type in FILE_TYPE_MAP
+            if case_obj.get("vcf_files", {}).get(file_type)
+        }
 
         coding_intervals = self.get_coding_intervals(build=build)
         # Loop over all intervals
         for chrom in CHROMOSOMES:
             intervals = coding_intervals.get(chrom, IntervalTree())
-            for var_type in variant_types:
-                for category in categories:
-                    LOG.info(
-                        "Updating compounds on chromosome:{0}, type:{1}, category:{2} for case:{3}".format(
-                            chrom, var_type, category, case_id
-                        )
+            for var_type, category in sorted(
+                list(load_variants),
+                key=lambda tup: get_load_priority(variant_type=tup[0], category=tup[1]),
+            ):
+                LOG.info(
+                    "Updating compounds on chromosome:{0}, type:{1}, category:{2} for case:{3}".format(
+                        chrom, var_type, category, case_id
+                    )
+                )
+
+                # Fetch all variants from a chromosome
+                query = {"variant_type": var_type, "chrom": chrom}
+
+                # Get all variants from the database of the specific type
+                variant_objs = self.variants(
+                    case_id=case_id,
+                    query=query,
+                    category=category,
+                    nr_of_variants=-1,
+                    sort_key="position",
+                )
+
+                # Initiate a bulk
+                bulk = {}
+                current_region = None
+                special = False
+
+                # Loop over the variants and check if they are in a coding region
+                for var_obj in variant_objs:
+                    var_id = var_obj["_id"]
+                    var_chrom = var_obj["chromosome"]
+                    var_start = var_obj["position"]
+                    var_end = var_obj["end"] + 1
+
+                    update_bulk = True
+                    new_region = None
+
+                    # Check if the variant is in a coding region
+                    genomic_regions = coding_intervals.get(var_chrom, IntervalTree()).overlap(
+                        var_start, var_end
                     )
 
-                    # Fetch all variants from a chromosome
-                    query = {"variant_type": var_type, "chrom": chrom}
+                    # If the variant is in a coding region
+                    if genomic_regions:
+                        # We know there is data here so get the interval id
+                        new_region = genomic_regions.pop().data
 
-                    # Get all variants from the database of the specific type
-                    variant_objs = self.variants(
-                        case_id=case_id,
-                        query=query,
-                        category=category,
-                        nr_of_variants=-1,
-                        sort_key="position",
-                    )
+                    if new_region and (new_region == current_region):
+                        # If the variant is in the same region as previous
+                        # we add it to the same bulk
+                        update_bulk = False
 
-                    # Initiate a bulk
-                    bulk = {}
-                    current_region = None
-                    special = False
+                    current_region = new_region
 
-                    # Loop over the variants and check if they are in a coding region
-                    for var_obj in variant_objs:
-                        var_id = var_obj["_id"]
-                        var_chrom = var_obj["chromosome"]
-                        var_start = var_obj["position"]
-                        var_end = var_obj["end"] + 1
+                    # If the variant is not in a current region we update the compounds
+                    # from the previous region, if any. Otherwise continue
+                    if update_bulk and bulk:
+                        self.update_compounds(bulk)
+                        self.update_mongo_compound_variants(bulk)
+                        bulk = {}
 
-                        update_bulk = True
-                        new_region = None
+                    if new_region:
+                        bulk[var_id] = var_obj
 
-                        # Check if the variant is in a coding region
-                        genomic_regions = coding_intervals.get(var_chrom, IntervalTree()).overlap(
-                            var_start, var_end
-                        )
+                if not bulk:
+                    continue
 
-                        # If the variant is in a coding region
-                        if genomic_regions:
-                            # We know there is data here so get the interval id
-                            new_region = genomic_regions.pop().data
-
-                        if new_region and (new_region == current_region):
-                            # If the variant is in the same region as previous
-                            # we add it to the same bulk
-                            update_bulk = False
-
-                        current_region = new_region
-
-                        # If the variant is not in a current region we update the compounds
-                        # from the previous region, if any. Otherwise continue
-                        if update_bulk and bulk:
-                            self.update_compounds(bulk)
-                            self.update_mongo_compound_variants(bulk)
-                            bulk = {}
-
-                        if new_region:
-                            bulk[var_id] = var_obj
-
-                    if not bulk:
-                        continue
-
-                    self.update_compounds(bulk)
-                    self.update_mongo_compound_variants(bulk)
+                self.update_compounds(bulk)
+                self.update_mongo_compound_variants(bulk)
 
         LOG.info("All compounds updated")
 
@@ -360,6 +364,9 @@ class VariantLoader(object):
         sample_info=None,
         custom_images=None,
         local_archive_info=None,
+        gene_to_panels=None,
+        hgncid_to_gene=None,
+        genomic_intervals=None,
     ):
         """Perform the loading of variants
 
@@ -386,10 +393,6 @@ class VariantLoader(object):
             nr_inserted(int)
         """
         build = build or "37"
-        genes = [gene_obj for gene_obj in self.all_genes(build=build)]
-        gene_to_panels = self.gene_to_panels(case_obj)
-        hgncid_to_gene = self.hgncid_to_gene(genes=genes, build=build)
-        genomic_intervals = self.get_coding_intervals(genes=genes, build=build)
 
         LOG.info("Start inserting {0} {1} variants into database".format(variant_type, category))
         start_insertion = datetime.now()
@@ -413,6 +416,7 @@ class VariantLoader(object):
             rank_score = parse_rank_score(variant.INFO.get("RankScore"), case_obj["_id"])
             pathogenic = is_pathogenic(variant)
             managed = self._is_managed(variant, category)
+            causative = self._is_causative_other_cases(variant, category)
 
             # Check if the variant should be loaded at all
             # if rank score is None means there are no rank scores annotated, all variants will be loaded
@@ -423,6 +427,7 @@ class VariantLoader(object):
                 or (rank_score > rank_threshold)
                 or mt_variant
                 or pathogenic
+                or causative
                 or managed
                 or category in ["str"]
             ):
@@ -543,23 +548,50 @@ class VariantLoader(object):
 
         return nr_inserted
 
+    def _is_causative_other_cases(
+        self,
+        variant: cyvcf2.Variant,
+        category: str = "snv",
+        build: str = "37",
+    ) -> bool:
+        """Check if variant is on the list of causatives from other cases, also from other institutes.
+        All variants that have been marked causative will be loaded, even if the other case does not exist anymore, or has been reclassified.
+        """
+
+        coordinates = parse_coordinates(variant, category, build)
+
+        variant_prefix = parse_simple_id(
+            coordinates["chrom"],
+            str(coordinates["position"]),
+            coordinates["ref"],
+            coordinates["alt"],
+        )
+        clinical_variant = "".join([variant_prefix, "_clinical"])
+        research_variant = "".join([variant_prefix, "_research"])
+
+        var_causative_events_count = len(
+            list(
+                self.event_collection.find(
+                    {
+                        "verb": {"$in": ["mark_causative", "mark_partial_causative"]},
+                        "category": "variant",
+                        "subject": {"$in": [clinical_variant, research_variant]},
+                    }
+                )
+            )
+        )
+        return var_causative_events_count > 0
+
     def _is_managed(
         self,
-        variant,
-        category="snv",
-        build="37",
-    ):
-        """Check if variant is on the managaged list.
+        variant: cyvcf2.Variant,
+        category: str = "snv",
+        build: str = "37",
+    ) -> bool:
+        """Check if variant is on the managed list.
         All variants on the list will be loaded regardless of the kind of relevance.
 
-        Arguments:
-            variant(cyvcf2.Variant)
-            category(str): snv, sv, str, cancer, cancer_sv
-            build(str): "37" or "38"
-
-        Returns:
-            is_managed(boolean)
-
+        Returns true if variant is matched with a variant on the managed list.
         """
 
         coordinates = parse_coordinates(variant, category, build)
@@ -579,6 +611,16 @@ class VariantLoader(object):
             is not None
         )
 
+    def _has_variants_in_file(self, variant_file: str) -> bool:
+        """Check if variant file has any variants."""
+        try:
+            vcf_obj = VCF(variant_file)
+            var = next(vcf_obj)
+            return True
+        except StopIteration as err:
+            LOG.warning("Variant file %s does not include any variants", variant_file)
+            return False
+
     def load_variants(
         self,
         case_obj,
@@ -617,107 +659,99 @@ class VariantLoader(object):
 
         nr_inserted = 0
 
-        variant_file = None
-        if variant_type == "clinical":
-            if category == "snv":
-                variant_file = case_obj["vcf_files"].get("vcf_snv")
-            elif category == "sv":
-                variant_file = case_obj["vcf_files"].get("vcf_sv")
-            elif category == "str":
-                LOG.debug("Attempt to load STR VCF.")
-                variant_file = case_obj["vcf_files"].get("vcf_str")
-            elif category == "cancer":
-                # Currently this implies a paired tumor normal
-                variant_file = case_obj["vcf_files"].get("vcf_cancer")
-            elif category == "cancer_sv":
-                # ditto for paired tumor normal
-                variant_file = case_obj["vcf_files"].get("vcf_cancer_sv")
-        elif variant_type == "research":
-            if category == "snv":
-                variant_file = case_obj["vcf_files"].get("vcf_snv_research")
-            elif category == "sv":
-                variant_file = case_obj["vcf_files"].get("vcf_sv_research")
-            elif category == "cancer":
-                variant_file = case_obj["vcf_files"].get("vcf_cancer_research")
-            elif category == "cancer_sv":
-                variant_file = case_obj["vcf_files"].get("vcf_cancer_sv_research")
+        variant_files = []
+        for vcf_file_key in FILE_TYPE_MAP.keys():
+            if FILE_TYPE_MAP[vcf_file_key]["variant_type"] != variant_type:
+                continue
+            if FILE_TYPE_MAP[vcf_file_key]["category"] != category:
+                continue
 
-        if not variant_file:
-            raise SyntaxError("Vcf file does not seem to exist")
+            LOG.debug("Attempt to load %s %s VCF.", variant_type, category.upper())
+            variant_file = case_obj["vcf_files"].get(vcf_file_key)
+            if variant_file:
+                variant_files.append(variant_file)
 
-        # Check if there are any variants in file
-        try:
-            vcf_obj = VCF(variant_file)
-            var = next(vcf_obj)
-        except StopIteration as err:
-            LOG.warning("Variant file %s does not include any variants", variant_file)
-            return nr_inserted
-        # We need to reload the file
-        vcf_obj = VCF(variant_file)
-
-        # Parse the neccessary headers from vcf file
-        rank_results_header = parse_rank_results_header(vcf_obj)
-
-        local_archive_info = parse_local_archive_header(vcf_obj)
-
-        vep_header = parse_vep_header(vcf_obj)
-        if vep_header:
-            LOG.info("Found VEP header %s", "|".join(vep_header))
-
-        # This is a dictionary to tell where ind are in vcf
-        individual_positions = {}
-        for i, ind in enumerate(vcf_obj.samples):
-            individual_positions[ind] = i
-
-        # Dictionary for cancer analysis
-        sample_info = {}
-        if category in ("cancer", "cancer_sv"):
-            for ind in case_obj["individuals"]:
-                if ind["phenotype"] == 2:
-                    sample_info[ind["individual_id"]] = "case"
-                else:
-                    sample_info[ind["individual_id"]] = "control"
-
-        # Check if a region scould be uploaded
-        region = ""
-        if gene_obj:
-            chrom = gene_obj["chromosome"]
-            # Add same padding as VEP
-            start = max(gene_obj["start"] - 5000, 0)
-            end = gene_obj["end"] + 5000
-        if chrom:
-            # We want to load all variants in the region regardless of rank score
-            rank_threshold = rank_threshold or -1000
-            if not (start and end):
-                raise SyntaxError("Specify chrom start and end")
-            region = "{0}:{1}-{2}".format(chrom, start, end)
-        else:
-            rank_threshold = rank_threshold or 0
-
-        variants = vcf_obj(region)
-
-        try:
-            nr_inserted = self._load_variants(
-                variants=variants,
-                variant_type=variant_type,
-                case_obj=case_obj,
-                individual_positions=individual_positions,
-                rank_threshold=rank_threshold,
-                institute_id=institute_id,
-                build=build,
-                rank_results_header=rank_results_header,
-                vep_header=vep_header,
-                category=category,
-                sample_info=sample_info,
-                custom_images=custom_images,
-                local_archive_info=local_archive_info,
+        if not variant_files:
+            raise SyntaxError(
+                "VCF files for {} {} does not seem to exist".format(category, variant_type)
             )
-        except Exception as error:
-            LOG.exception("unexpected error")
-            LOG.warning("Deleting inserted variants")
-            self.delete_variants(case_obj["_id"], variant_type)
-            raise error
 
-        self.update_variant_rank(case_obj, variant_type, category=category)
+        gene_to_panels = self.gene_to_panels(case_obj)
+        genes = [gene_obj for gene_obj in self.all_genes(build=build)]
+        hgncid_to_gene = self.hgncid_to_gene(genes=genes, build=build)
+        genomic_intervals = self.get_coding_intervals(genes=genes, build=build)
+
+        for variant_file in variant_files:
+            if not self._has_variants_in_file(variant_file):
+                continue
+
+            vcf_obj = VCF(variant_file)
+
+            # Parse the necessary headers from vcf file
+            rank_results_header = parse_rank_results_header(vcf_obj)
+
+            local_archive_info = parse_local_archive_header(vcf_obj)
+
+            vep_header = parse_vep_header(vcf_obj)
+            if vep_header:
+                LOG.debug("Found VEP header %s", "|".join(vep_header))
+
+            # This is a dictionary to tell where ind are in vcf
+            individual_positions = {ind: i for i, ind in enumerate(vcf_obj.samples)}
+
+            # Dictionary for cancer analysis
+            sample_info = {}
+            if category in ("cancer", "cancer_sv"):
+                for ind in case_obj["individuals"]:
+                    if ind["phenotype"] == 2:
+                        sample_info[ind["individual_id"]] = "case"
+                    else:
+                        sample_info[ind["individual_id"]] = "control"
+
+            # Check if a region should be uploaded
+            region = ""
+            if gene_obj:
+                chrom = gene_obj["chromosome"]
+                # Add same padding as VEP
+                start = max(gene_obj["start"] - 5000, 0)
+                end = gene_obj["end"] + 5000
+            if chrom:
+                # We want to load all variants in the region regardless of rank score
+                rank_threshold = rank_threshold or -1000
+                if not (start and end):
+                    raise SyntaxError("Specify chrom start and end")
+                region = "{0}:{1}-{2}".format(chrom, start, end)
+            else:
+                rank_threshold = rank_threshold or 0
+
+            variants = vcf_obj(region)
+
+            try:
+                nr_inserted = self._load_variants(
+                    variants=variants,
+                    variant_type=variant_type,
+                    case_obj=case_obj,
+                    individual_positions=individual_positions,
+                    rank_threshold=rank_threshold,
+                    institute_id=institute_id,
+                    build=build,
+                    rank_results_header=rank_results_header,
+                    vep_header=vep_header,
+                    category=category,
+                    sample_info=sample_info,
+                    custom_images=custom_images,
+                    local_archive_info=local_archive_info,
+                    gene_to_panels=gene_to_panels,
+                    hgncid_to_gene=hgncid_to_gene,
+                    genomic_intervals=genomic_intervals,
+                )
+            except Exception as error:
+                LOG.exception("unexpected error")
+                LOG.warning("Deleting inserted variants")
+                self.delete_variants(case_obj["_id"], variant_type)
+                raise error
+
+        if nr_inserted:
+            self.update_variant_rank(case_obj, variant_type, category=category)
 
         return nr_inserted
