@@ -1,4 +1,5 @@
 """Code for CLI base"""
+
 import logging
 import pathlib
 
@@ -100,7 +101,7 @@ def get_app(ctx=None):
 )
 @click.option(
     "--loglevel",
-    default="DEBUG",
+    default="INFO",
     type=click.Choice(LOG_LEVELS),
     help="Set the level of log output.",
     show_default=True,
