@@ -8,6 +8,7 @@ from .exac import exac as exac_command
 from .hgnc import hgnc as hgnc_command
 from .hpo import hpo as hpo_command
 from .omim import omim as omim_command
+from .orpha import orpha as orpha_command
 
 
 @click.group()
@@ -23,4 +24,5 @@ download.add_command(hgnc_command)
 download.add_command(ensembl_command)
 download.add_command(exac_command)
 download.add_command(omim_command)
+download.add_command(orpha_command)
 download.add_command(everything_command)
