@@ -29,6 +29,11 @@ LOG = logging.getLogger(__name__)
     type=click.Path(exists=True),
     help="path to clinical cancer SV VCF file to be loaded",
 )
+@click.option(
+    "--vcf-mei",
+    type=click.Path(exists=True),
+    help="path to clinical MEI VCF file to be loaded",
+)
 @click.option(
     "--vcf-str",
     type=click.Path(exists=True),
@@ -42,7 +47,6 @@ LOG = logging.getLogger(__name__)
     default=True,
     help="Transfer user actions from old variants when updating.",
 )
-@click.option("--no-variants", is_flag=False)
 @click.argument("config", type=click.File("r"), required=False)
 @click.option("--peddy-ped", type=click.Path(exists=True), help="path to a peddy.ped file")
 @click.option("--peddy-sex", type=click.Path(exists=True), help="path to a sex_check.csv file")
@@ -53,12 +57,12 @@ def case(
     vcf_sv,
     vcf_cancer,
     vcf_cancer_sv,
+    vcf_mei,
     vcf_str,
     owner,
     ped,
     update,
     config,
-    no_variants,
     peddy_ped,
     peddy_sex,
     peddy_check,
@@ -74,7 +78,7 @@ def case(
         LOG.warning("Please provide either scout config or ped file")
         raise click.Abort()
 
-    # Scout needs a config object with the neccessary information
+    # Scout needs a config object with the necessary information
     # If no config is used create a dictionary
     config_raw = yaml.load(config, Loader=yaml.SafeLoader) if config else {}
 
@@ -88,6 +92,7 @@ def case(
             vcf_str=vcf_str,
             vcf_cancer=vcf_cancer,
             vcf_cancer_sv=vcf_cancer_sv,
+            vcf_mei=vcf_mei,
             peddy_ped=peddy_ped,
             peddy_sex=peddy_sex,
             peddy_check=peddy_check,
