@@ -48,7 +48,11 @@ def abort_if_false(ctx, param, value):
     help="Path to directory with resource files",
 )
 @click.option("--hgnc", type=click.Path(exists=True))
-@click.option("--exac", type=click.Path(exists=True), help="Path to file with EXAC pLi scores")
+@click.option(
+    "--exac",
+    type=click.Path(exists=True),
+    help="Path to file with EXaC / GnomAD pLi constraint scores",
+)
 @click.option(
     "--ensgenes37",
     type=click.Path(exists=True),
@@ -82,7 +86,7 @@ def abort_if_false(ctx, param, value):
 @click.option(
     "--hpoterms",
     type=click.Path(exists=True),
-    help=("Path to file with HPO terms. This is the " "file called hpo.obo"),
+    help="Path to file with HPO terms. This is the file called hpo.obo",
 )
 @click.option(
     "--hpo_to_genes",
@@ -92,6 +96,29 @@ def abort_if_false(ctx, param, value):
         "phenotype_to_genes.txt"
     ),
 )
+@click.option(
+    "--hpo-phenotype-annotation",
+    type=click.Path(exists=True),
+    help=(
+        "Path to file with map from HPO disease (OMIM and ORPHA) to phenotype term with annotation. This is the file  called phenotype.hpoa"
+    ),
+)
+@click.option(
+    "--orpha-to-hpo",
+    type=click.Path(exists=True),
+    help=(
+        "Path to file mapping ORPHA codes to HPO terms. This is the file called "
+        "orphadata_en_product4.xml"
+    ),
+)
+@click.option(
+    "--orpha-to-genes",
+    type=click.Path(exists=True),
+    help=(
+        "Path to file mapping ORPHA codes to genes. This is the file called "
+        "orphadata_en_product6.xml"
+    ),
+)
 @with_appcontext
 @click.pass_context
 def database(
@@ -111,6 +138,9 @@ def database(
     hpogenes,
     hpoterms,
     hpo_to_genes,
+    hpo_phenotype_annotation,
+    orpha_to_hpo,
+    orpha_to_genes,
     files,
 ):
     """Setup a scout database."""
@@ -128,11 +158,12 @@ def database(
 
     adapter = context.obj["adapter"]
 
+    # Populate resource_files with the paths specified for each resource
     resource_files = {
         "mim2gene_path": mim2gene,
         "genemap_path": genemap,
         "hgnc_path": hgnc,
-        "exac_path": exac,
+        "constaints_path": exac,
         "genes37_path": ensgenes37,
         "genes38_path": ensgenes38,
         "transcripts37_path": enstx37,
@@ -140,8 +171,13 @@ def database(
         "hpogenes_path": hpogenes,
         "hpoterms_path": hpoterms,
         "hpo_to_genes_path": hpo_to_genes,
+        "hpo_phenotype_annotation_path": hpo_phenotype_annotation,
+        "orpha_to_hpo_path": orpha_to_hpo,
+        "orpha_to_genes_path": orpha_to_genes,
     }
     LOG.info("Setting up database %s", context.obj["mongodb"])
+
+    # If a folder was supplied, populate resource_files with paths to the contents
     if files:
         for path in pathlib.Path(files).glob("**/*"):
             if path.stem == "mim2genes":
@@ -150,8 +186,8 @@ def database(
                 resource_files["genemap_path"] = str(path.resolve())
             if path.stem == "hgnc":
                 resource_files["hgnc_path"] = str(path.resolve())
-            if path.stem == "fordist_cleaned_exac_r03_march16_z_pli_rec_null_data":
-                resource_files["exac_path"] = str(path.resolve())
+            if path.stem == "gnomad.v4.0.constraint_metrics":
+                resource_files["constraint_path"] = str(path.resolve())
             if path.stem == "ensembl_genes_37":
                 resource_files["genes37_path"] = str(path.resolve())
             if path.stem == "ensembl_genes_38":
@@ -166,6 +202,12 @@ def database(
                 resource_files["hpoterms_path"] = str(path.resolve())
             if path.stem == "phenotype_to_genes":
                 resource_files["hpo_to_genes_path"] = str(path.resolve())
+            if path.stem == "phenotype":
+                resource_files["hpo_phenotype_annotation_path"] = str(path.resolve())
+            if path.stem == "orphadata_en_product4":
+                resource_files["orpha_to_hpo_path"] = str(path.resolve())
+            if path.stem == "orphadata_en_product6":
+                resource_files["orpha_to_genes_path"] = str(path.resolve())
 
     setup_scout(
         adapter=adapter,
