@@ -1,9 +1,7 @@
 import logging
-from pprint import pprint as pp
 
 import click
 import pymongo
-from flask.cli import with_appcontext
 
 from scout.server.extensions import store
 
@@ -55,13 +53,22 @@ LOG = logging.getLogger(__name__)
     type=click.Path(exists=True),
     help="path to research VCF with cancer structural variants to be added",
 )
+@click.option(
+    "--vcf-mei",
+    type=click.Path(exists=True),
+    help="path to clinical mei variants to be added",
+)
+@click.option(
+    "--vcf-mei-research",
+    type=click.Path(exists=True),
+    help="path to research mei variants to be added",
+)
 @click.option(
     "--reupload-sv",
     is_flag=True,
     help="Remove all SVs and re upload from existing files",
 )
 @click.option("--rankscore-treshold", help="Set a new rank score treshold if desired")
-@click.option("--rankmodel-version", help="Update the rank model version")
 @click.option("--sv-rankmodel-version", help="Update the SV rank model version")
 @click.pass_context
 def case(
@@ -78,15 +85,15 @@ def case(
     vcf_sv_research,
     vcf_cancer_research,
     vcf_cancer_sv_research,
+    vcf_mei,
+    vcf_mei_research,
     reupload_sv,
     rankscore_treshold,
-    rankmodel_version,
     sv_rankmodel_version,
 ):
     """
     Update a case in the database
     """
-    adapter = store
 
     if not case_id:
         if not (case_name and institute):
@@ -96,7 +103,7 @@ def case(
             raise click.Abort()
 
     # Check if the case exists
-    case_obj = adapter.case(case_id=case_id, institute_id=institute, display_name=case_name)
+    case_obj = store.case(case_id=case_id, institute_id=institute, display_name=case_name)
 
     if not case_obj:
         LOG.warning("Case %s could not be found", case_id)
@@ -104,7 +111,7 @@ def case(
 
     case_changed = False
     if collaborator:
-        if not adapter.institute(collaborator):
+        if not store.institute(collaborator):
             LOG.warning("Institute %s could not be found", collaborator)
             return
         if not collaborator in case_obj["collaborators"]:
@@ -112,41 +119,27 @@ def case(
             case_obj["collaborators"].append(collaborator)
             LOG.info("Adding collaborator %s", collaborator)
 
-    if vcf:
-        LOG.info("Updating 'vcf_snv' to %s", vcf)
-        case_obj["vcf_files"]["vcf_snv"] = vcf
-        case_changed = True
-    if vcf_sv:
-        LOG.info("Updating 'vcf_sv' to %s", vcf_sv)
-        case_obj["vcf_files"]["vcf_sv"] = vcf_sv
-        case_changed = True
-    if vcf_cancer:
-        LOG.info("Updating 'vcf_cancer' to %s", vcf_cancer)
-        case_obj["vcf_files"]["vcf_cancer"] = vcf_cancer
-        case_changed = True
-    if vcf_cancer_sv:
-        LOG.info("Updating 'vcf_cancer_sv' to %s", vcf_cancer_sv)
-        case_obj["vcf_files"]["vcf_cancer_sv"] = vcf_cancer_sv
-        case_changed = True
-    if vcf_research:
-        LOG.info("Updating 'vcf_research' to %s", vcf_research)
-        case_obj["vcf_files"]["vcf_research"] = vcf_research
-        case_changed = True
-    if vcf_sv_research:
-        LOG.info("Updating 'vcf_sv_research' to %s", vcf_sv_research)
-        case_obj["vcf_files"]["vcf_sv_research"] = vcf_sv_research
-        case_changed = True
-    if vcf_cancer_research:
-        LOG.info("Updating 'vcf_cancer_research' to %s", vcf_cancer_research)
-        case_obj["vcf_files"]["vcf_cancer_research"] = vcf_cancer_research
-        case_changed = True
-    if vcf_cancer_sv_research:
-        LOG.info("Updating 'vcf_cancer_sv_research' to %s", vcf_cancer_sv_research)
-        case_obj["vcf_files"]["vcf_cancer_sv_research"] = vcf_cancer_sv_research
+    for key_name, key in [
+        ("vcf_snv", vcf),
+        ("vcf_sv", vcf_sv),
+        ("vcf_cancer", vcf_cancer),
+        ("vcf_cancer_sv", vcf_cancer_sv),
+        ("vcf_research", vcf_research),
+        ("vcf_sv_research", vcf_sv_research),
+        ("vcf_cancer_research", vcf_cancer_research),
+        ("vcf_cancer_sv_research", vcf_cancer_sv_research),
+        ("vcf_mei", vcf_mei),
+        ("vcf_mei_research", vcf_mei_research),
+    ]:
+        if key is None:
+            continue
+        LOG.info(f"Updating '{key_name}' to {key}")
+        case_obj["vcf_files"][key_name] = key
         case_changed = True
 
     if case_changed:
-        adapter.update_case(case_obj)
+        institute_obj = store.institute(case_obj["owner"])
+        store.update_case_cli(case_obj, institute_obj)
 
     if reupload_sv:
         LOG.info("Set needs_check to True for case %s", case_id)
@@ -158,7 +151,7 @@ def case(
         if vcf_sv:
             updates["vcf_files.vcf_sv_research"] = vcf_sv_research
 
-        updated_case = adapter.case_collection.find_one_and_update(
+        updated_case = store.case_collection.find_one_and_update(
             {"_id": case_id},
             {"$set": updates},
             return_document=pymongo.ReturnDocument.AFTER,
@@ -166,8 +159,8 @@ def case(
         rankscore_treshold = rankscore_treshold or updated_case.get("rank_score_threshold", 5)
         # Delete and reload the clinical SV variants
         if updated_case["vcf_files"].get("vcf_sv"):
-            adapter.delete_variants(case_id, variant_type="clinical", category="sv")
-            adapter.load_variants(
+            store.delete_variants(case_id, variant_type="clinical", category="sv")
+            store.load_variants(
                 updated_case,
                 variant_type="clinical",
                 category="sv",
@@ -175,13 +168,13 @@ def case(
             )
         # Delete and reload research SV variants
         if updated_case["vcf_files"].get("vcf_sv_research"):
-            adapter.delete_variants(case_id, variant_type="research", category="sv")
+            store.delete_variants(case_id, variant_type="research", category="sv")
             if updated_case.get("is_research"):
-                adapter.load_variants(
+                store.load_variants(
                     updated_case,
                     variant_type="research",
                     category="sv",
                     rank_threshold=int(rankscore_treshold),
                 )
         # Update case variants count
-        adapter.case_variants_count(case_obj["_id"], case_obj["owner"], force_update_case=True)
+        store.case_variants_count(case_obj["_id"], case_obj["owner"], force_update_case=True)
