@@ -37,18 +37,18 @@ LOG = logging.getLogger(__name__)
 @with_appcontext
 def hpo(hpoterms, hpo_to_genes):
     """
-    Update the hpo terms in the database. Fetch the latest release and update terms.
+    Update the HPO terms in the database. Fetch the latest release and update terms.
     """
-    LOG.info("Running scout update hpo")
+    LOG.info("Running Scout update HPO")
     adapter = store
 
-    LOG.info("Dropping HPO terms")
-    adapter.hpo_term_collection.delete_many({})
-    LOG.debug("HPO terms dropped")
-
     if hpoterms:
         hpoterms = get_file_handle(hpoterms)
     if hpo_to_genes:
         hpo_to_genes = get_file_handle(hpo_to_genes)
 
-    load_hpo_terms(adapter, hpo_lines=hpoterms, hpo_gene_lines=hpo_to_genes)
+    load_hpo_terms(
+        adapter,
+        hpo_lines=hpoterms,
+        hpo_gene_lines=hpo_to_genes,
+    )
