@@ -11,11 +11,10 @@ from .acmg import ACMG_COMPLETE_MAP, ACMG_CRITERIA, ACMG_MAP, ACMG_OPTIONS, REV_
 from .case_tags import (
     ANALYSIS_TYPES,
     CANCER_PHENOTYPE_MAP,
-    CASE_REPORT_CASE_FEATURES,
-    CASE_REPORT_CASE_IND_FEATURES,
     CASE_REPORT_VARIANT_TYPES,
     CASE_SEARCH_TERMS,
     CASE_STATUSES,
+    CASE_TAGS,
     CUSTOM_CASE_REPORTS,
     PHENOTYPE_MAP,
     REV_PHENOTYPE_MAP,
@@ -30,17 +29,34 @@ from .clinvar import (
     ALLELE_OF_ORIGIN,
     ASSERTION_METHOD,
     ASSERTION_METHOD_CIT,
+    CLINVAR_ASSERTION_METHOD_CIT_DB_OPTIONS,
     CLINVAR_INHERITANCE_MODELS,
     CLINVAR_SV_TYPES,
-    CLNSIG_TERMS,
     COLLECTION_METHOD,
-    PHENO_DBS,
+    CONDITION_PREFIX,
+    GERMLINE_CLASSIF_TERMS,
+    MULTIPLE_CONDITION_EXPLANATION,
 )
 from .clnsig import CLINSIG_MAP, REV_CLINSIG_MAP, TRUSTED_REVSTAT_LEVEL
-from .file_types import FILE_TYPE_MAP
-from .filters import CLINICAL_FILTER_BASE, CLINICAL_FILTER_BASE_CANCER, CLINICAL_FILTER_BASE_SV
+from .disease_parsing import (
+    DISEASE_INHERITANCE_TERMS,
+    ENTRY_PATTERN,
+    INHERITANCE_TERMS_MAPPER,
+    MIMNR_PATTERN,
+    OMIM_STATUS_MAP,
+)
+from .file_types import FILE_TYPE_MAP, OMICS_FILE_TYPE_MAP
+from .filters import (
+    CLINICAL_FILTER_BASE,
+    CLINICAL_FILTER_BASE_CANCER,
+    CLINICAL_FILTER_BASE_MEI,
+    CLINICAL_FILTER_BASE_OUTLIER,
+    CLINICAL_FILTER_BASE_SV,
+)
 from .gene_tags import (
+    GENE_CONSTRAINT_LABELS,
     GENE_PANELS_INHERITANCE_MODELS,
+    GNOMAD_CONSTRAINT_FILENAME,
     INCOMPLETE_PENETRANCE_MAP,
     INHERITANCE_PALETTE,
     MODELS_MAP,
@@ -51,16 +67,17 @@ from .gene_tags import (
     VALID_MODELS,
 )
 from .igv_tracks import CASE_SPECIFIC_TRACKS, HUMAN_REFERENCE, IGV_TRACKS, USER_DEFAULT_TRACKS
-from .indexes import INDEXES
+from .indexes import ID_PROJECTION, INDEXES
 from .phenotype import (
     COHORT_TAGS,
     HPO_URL,
     HPOTERMS_URL,
+    ORPHA_URLS,
     PHENOTYPE_GROUPS,
     UPDATE_DISEASES_RESOURCES,
 )
 from .query_terms import FUNDAMENTAL_CRITERIA, PRIMARY_CRITERIA, SECONDARY_CRITERIA
-from .so_terms import SEVERE_SO_TERMS, SO_TERM_KEYS, SO_TERMS
+from .so_terms import SEVERE_SO_TERMS, SEVERE_SO_TERMS_SV, SO_TERM_KEYS, SO_TERMS
 from .variant_tags import (
     CANCER_SPECIFIC_VARIANT_DISMISS_OPTIONS,
     CANCER_TIER_OPTIONS,
@@ -72,17 +89,20 @@ from .variant_tags import (
     GENETIC_MODELS_PALETTE,
     MANUAL_RANK_OPTIONS,
     MOSAICISM_OPTIONS,
+    OUTLIER_TYPES,
     SPIDEX_HUMAN,
     SPIDEX_LEVELS,
     SV_TYPES,
     VARIANT_CALL,
     VARIANT_FILTERS,
     VARIANT_GENOTYPES,
-    VARIANT_REPORT_VARIANT_FEATURES,
+    VARIANTS_TARGET_FROM_CATEGORY,
 )
 from .variants_export import (
     CANCER_EXPORT_HEADER,
     EXPORT_HEADER,
+    EXPORTED_VARIANTS_LIMIT,
+    FUSION_EXPORT_HEADER,
     MITODEL_HEADER,
     MT_COV_STATS_HEADER,
     MT_EXPORT_HEADER,
@@ -129,15 +149,35 @@ CHROMOSOME_INTEGERS = {chrom: i + 1 for i, chrom in enumerate(CHROMOSOMES)}
 PAR_COORDINATES = {
     "37": {
         "X": IntervalTree(
-            [Interval(60001, 2699521, "par1"), Interval(154931044, 155260561, "par2")]
+            [
+                Interval(60001, 2699521, "par1"),
+                Interval(154931044, 155260561, "par2"),
+                Interval(88456972, 92375509, "xtr"),
+            ],
+        ),
+        "Y": IntervalTree(
+            [
+                Interval(10001, 2649521, "par1"),
+                Interval(59034050, 59363567, "par2"),
+                Interval(2917959, 6102616, "xtr"),
+            ]
         ),
-        "Y": IntervalTree([Interval(10001, 2649521, "par1"), Interval(59034050, 59363567, "par2")]),
     },
     "38": {
         "X": IntervalTree(
-            [Interval(10001, 2781480, "par1"), Interval(155701383, 156030896, "par2")]
+            [
+                Interval(10001, 2781480, "par1"),
+                Interval(155701383, 156030896, "par2"),
+                Interval(89201883, 93120510, "xtr"),
+            ]
+        ),
+        "Y": IntervalTree(
+            [
+                Interval(10001, 2781480, "par1"),
+                Interval(56887903, 57217416, "par2"),
+                Interval(3049918, 6234575, "xtr"),
+            ]
         ),
-        "Y": IntervalTree([Interval(10001, 2781480, "par1"), Interval(56887903, 57217416, "par2")]),
     },
 }
 
@@ -166,15 +206,24 @@ CALLERS = {
         {"id": "ascat", "name": "ASCAT"},
         {"id": "dellycnv", "name": "DellyCNV"},
         {"id": "tiddit", "name": "TIDDIT"},
+        {"id": "igh_dux4", "name": "IGH-DUX4 detection"},
     ],
+    "mei": [{"id": "retroseq", "name": "RetroSeq"}],
     "sv": [
         {"id": "gatk", "name": "GATK"},
         {"id": "cnvnator", "name": "CNVnator"},
+        {"id": "cnvpytor", "name": "CNVpytor"},
         {"id": "delly", "name": "Delly"},
+        {"id": "sniffles", "name": "Sniffles"},
         {"id": "tiddit", "name": "TIDDIT"},
         {"id": "manta", "name": "Manta"},
     ],
     "str": [{"id": "expansionhunter", "name": "ExpansionHunter"}],
+    "fusion": [
+        {"id": "arriba", "name": "Arriba"},
+        {"id": "starfusion", "name": "STARfusion"},
+        {"id": "fusioncatcher", "name": "FusionCatcher"},
+    ],
 }
 
 BND_ALT_PATTERN = re.compile(r".*[\],\[](.*?):(.*?)[\],\[]")
