@@ -1,4 +1,4 @@
-ANALYSIS_TYPES = ("wgs", "wes", "mixed", "unknown", "panel", "panel-umi", "external", "wts")
+ANALYSIS_TYPES = ("external", "mixed", "ogm", "panel", "panel-umi", "unknown", "wes", "wgs", "wts")
 
 # keys are used in the load report cli, while key_name is saved in case database documents
 CUSTOM_CASE_REPORTS = {
@@ -33,29 +33,6 @@ CUSTOM_CASE_REPORTS = {
     },
 }
 
-CASE_REPORT_CASE_FEATURES = [
-    "display_name",
-    "created_at",
-    "updated_at",
-    "status",
-    "madeline_info",
-    "synopsis",
-    "phenotype_terms",
-    "diagnosis_phenotypes",
-    "panels",
-]
-
-CASE_REPORT_CASE_IND_FEATURES = [
-    "display_name",
-    "sex",
-    "confirmed_sex",
-    "phenotype",
-    "phenotype_human",
-    "analysis_type",
-    "predicted_ancestry",
-    "confirmed_parent",
-]
-
 CASE_REPORT_VARIANT_TYPES = {
     "causatives_detailed": "causatives",
     "partial_causatives_detailed": "partial_causatives",
@@ -83,59 +60,100 @@ CANCER_PHENOTYPE_MAP = {1: "normal", 2: "tumor", 0: "unknown", -9: "unknown"}
 REV_PHENOTYPE_MAP = {value: key for key, value in PHENOTYPE_MAP.items()}
 
 CASE_STATUSES = ("prioritized", "inactive", "active", "solved", "archived", "ignored")
+CASE_TAGS = {
+    "provisional": {
+        "label": "Provisional",
+        "description": "Variant flagged causative has provisional diagnostic status",
+    },
+    "diagnostic": {
+        "label": "Diagnostic",
+        "description": "Variant flagged causative has definitive diagnostic status",
+    },
+    "incidental": {
+        "label": "Incidental",
+        "description": "A variant flagged causative is an incidental/secondary finding",
+    },
+    "carrier": {
+        "label": "Carrier",
+        "description": "Assay performed to identify carrier status found variant present",
+    },
+    "medical": {
+        "label": "Medical attention",
+        "description": "Case needs medical specialist attention - eg findings with unclear connection to phenotype",
+    },
+    "technical": {
+        "label": "Technical attention",
+        "description": "Case needs technical specialist attention - eg findings with unclear technical status",
+    },
+    "upd": {
+        "label": "UPD",
+        "description": "UniParental Disomy determined causative eg by Chromograph or Gens",
+    },
+    "smn": {"label": "SMN", "description": "SMN assay found causative eg by SMNCopyNumberCaller"},
+    "fshd": {"label": "FSHD", "description": "FSHD assay (OGM) found causative"},
+    "rna": {"label": "RNA", "description": "RNA assay with no markable variant found causative"},
+    "structural": {
+        "label": "Other structural",
+        "description": "Structural variation with no call or complex combination of called variants found causative, as evident via e.g. Chromograph or Gens",
+    },
+}
 
 VERBS_MAP = {
-    "assign": "was assigned to",
-    "unassign": "was unassigned from",
-    "status": "updated the status for",
-    "comment": "commented on",
-    "comment_update": "updated a comment for",
-    "synopsis": "updated synopsis for",
-    "pin": "pinned variant",
-    "unpin": "removed pinned variant",
-    "sanger": "ordered sanger sequencing for",
-    "cancel_sanger": "cancelled sanger order for",
-    "archive": "archived",
-    "open_research": "opened research mode for",
-    "reset_research": "canceled research mode request for",
-    "mark_causative": "marked causative for",
-    "unmark_causative": "unmarked causative for",
-    "mark_partial_causative": "mark partial causative for",
-    "unmark_partial_causative": "unmarked partial causative for",
-    "manual_rank": "updated manual rank for",
-    "cancer_tier": "updated cancer tier for",
-    "add_phenotype": "added HPO term for",
-    "remove_phenotype": "removed HPO term for",
-    "remove_variants": "removed variants for",
-    "add_case": "added case",
-    "update_case": "updated case",
-    "update_individual": "updated individuals for",
-    "check_case": "marked case as",
-    "share": "shared case with",
-    "unshare": "revoked access for",
-    "rerun": "requested rerun of",
-    "rerun_reset": "canceled rerun of",
-    "rerun_monitor": "requested rerun monitoring for",
-    "rerun_unmonitor": "disabled rerun monitoring for",
-    "validate": "marked validation status for",
-    "update_diagnosis": "updated diagnosis for",
-    "add_cohort": "updated cohort for",
-    "remove_cohort": "removed cohort for",
     "acmg": "updated ACMG classification for",
-    "dismiss_variant": "dismissed variant for",
-    "reset_dismiss_variant": "reset dismissed variant status for",
-    "reset_dismiss_all_variants": "reset all dismissed variants for",
-    "mosaic_tags": "updated mosaic tags for",
-    "update_default_panels": "updated default panels for",
-    "update_clinical_filter_hpo": "updated clinical filter HPO status for",
-    "mme_add": "exported to Matchmaker patient",
-    "mme_remove": "removed from Matchmaker patient",
+    "add_case": "added case",
+    "add_cohort": "updated cohort for",
+    "add_phenotype": "added HPO term for",
+    "archive": "archived",
+    "assign": "was assigned to",
     "beacon_add": "exported variants to the Beacon",
     "beacon_remove": "removed variants from the Beacon",
-    "filter_stash": "stored a filter for",
+    "cancel_sanger": "cancelled sanger order for",
+    "cancer_tier": "updated cancer tier for",
+    "clinvar_add": "added a variant to a ClinVar submission",
+    "clinvar_remove": "removed a variant from a ClinVar submission",
+    "check_case": "marked case as",
+    "comment": "commented on",
+    "comment_update": "updated a comment for",
+    "dismiss_variant": "dismissed variant for",
     "filter_audit": "marked case audited with filter",
-    "update_sample": "updated sample data for",
+    "filter_stash": "stored a filter for",
+    "filter_unaudit": "un-audited a filter for",
+    "manual_rank": "updated manual rank for",
+    "mark_causative": "marked causative for",
+    "mark_partial_causative": "mark partial causative for",
+    "mme_add": "exported to Matchmaker patient",
+    "mme_remove": "removed from Matchmaker patient",
+    "mosaic_tags": "updated mosaic tags for",
+    "open_research": "opened research mode for",
+    "pin": "pinned variant",
+    "remove_cohort": "removed cohort for",
+    "remove_phenotype": "removed HPO term for",
+    "remove_variants": "removed variants for",
+    "rerun": "requested rerun of",
+    "rerun_monitor": "requested rerun monitoring for",
+    "rerun_reset": "canceled rerun of",
+    "rerun_unmonitor": "disabled rerun monitoring for",
+    "reset_dismiss_all_variants": "reset all dismissed variants for",
+    "reset_dismiss_variant": "reset dismissed variant status for",
+    "reset_research": "canceled research mode request for",
+    "sanger": "ordered sanger sequencing for",
+    "share": "shared case with",
+    "status": "updated the status for",
+    "tag": "tagged the case for",
+    "synopsis": "updated synopsis for",
+    "unmark_causative": "unmarked causative for",
+    "unmark_partial_causative": "unmarked partial causative for",
+    "unpin": "removed pinned variant",
+    "update_case": "updated case",
     "update_case_group_ids": "updated case group ids for",
+    "update_clinical_filter_hpo": "updated clinical filter HPO status for",
+    "update_default_panels": "updated default panels for",
+    "update_diagnosis": "updated diagnosis for",
+    "update_individual": "updated individuals for",
+    "update_sample": "updated sample data for",
+    "unassign": "was unassigned from",
+    "unshare": "revoked access for",
+    "validate": "marked validation status for",
 }
 
 # Font-awesome jcons used by VERBS_ICONS_MAP
@@ -242,6 +260,7 @@ CASE_SEARCH_TERMS = {
     },
     "panel": {"label": "Gene Panel", "prefix": "panel:", "placeholder": "example:NMD"},
     "status": {"label": "Case Status", "prefix": "status:", "placeholder": "example:active"},
+    "tags": {"label": "Tags", "prefix": "tags:", "placeholder": "example:medical"},
     "track": {"label": "Analysis Track", "prefix": "track:", "placeholder": "rare or cancer"},
     "pheno_group": {
         "label": "Phenotype Group",
