@@ -1,4 +1,4 @@
-CLINVAR_API_URL = "https://submit.ncbi.nlm.nih.gov/api/v1/submissions/"
+CLINVAR_API_URL_DEFAULT = "https://submit.ncbi.nlm.nih.gov/api/v1/submissions/"
 PRECLINVAR_URL = "https://preclinvar.scilifelab.se"
 
 ASSERTION_METHOD = "ACMG Guidelines, 2015"
@@ -27,16 +27,16 @@ CLINVAR_HEADER = {
     "inner_stop": "Inner stop",
     "outer_stop": "Outer stop",
     "variations_ids": "Variation identifiers",
-    "condition_id_type": "Condition ID type",  # default = 'HPO'
+    "condition_id_type": "Condition ID type",
     "condition_id_value": "Condition ID value",
     "condition_comment": "Condition comment",
-    "clinsig": "Clinical significance",
-    "clinsig_comment": "Comment on clinical significance",
+    "explanation_for_multiple_conditions": "Explanation for multiple conditions",
+    "clinsig": "Germline classification",
+    "clinsig_comment": "Comment on classification",
     "last_evaluated": "Date last evaluated",
     "variant_comment": "Comment on variant",
     "inheritance_mode": "Mode of inheritance",
-    "clinsig_cit": "Clinical significance citations",
-    "clinsig_comment": "Comment on clinical significance",
+    "clinsig_cit": "Classification citations",
     "drug_response": "Drug response condition",
     "funct_conseq": "Functional consequence",
     "funct_conseq_comment": "Comment on functional consequence",
@@ -75,7 +75,7 @@ CASEDATA_HEADER = {
 # The following items are defined in the ClinVar API specifications:
 # https://www.ncbi.nlm.nih.gov/clinvar/docs/api_http/
 ####################################################################
-CLNSIG_TERMS = [
+GERMLINE_CLASSIF_TERMS = [
     "Pathogenic",
     "Likely pathogenic",
     "Uncertain significance",
@@ -110,24 +110,23 @@ REVSTAT_TERMS = {
 CLINVAR_INHERITANCE_MODELS = [
     "Autosomal dominant inheritance",
     "Autosomal recessive inheritance",
+    "Mitochondrial inheritance",
+    "Genetic anticipation",
+    "Sporadic",
+    "Sex-limited autosomal dominant",
+    "X-linked recessive inheritance",
+    "X-linked dominant inheritance",
+    "Y-linked inheritance",
+    "Other",
+    "X-linked inheritance",
+    "Codominant",
+    "Semidominant inheritance",
+    "Autosomal unknown",
     "Autosomal dominant inheritance with maternal imprinting",
     "Autosomal dominant inheritance with paternal imprinting",
-    "Autosomal unknown",
-    "Codominant",
-    "Genetic anticipation",
-    "Mitochondrial inheritance",
     "Multifactorial inheritance",
-    "Oligogenic inheritance",
-    "Other",
-    "Semidominant inheritance",
-    "Somatic mutation",
-    "Sporadic",
     "Unknown mechanism",
-    "Sex-limited autosomal dominant",
-    "X-linked inheritance",
-    "X-linked dominant inheritance",
-    "X-linked recessive inheritance",
-    "Y-linked inheritance",
+    "Oligogenic inheritance",
 ]
 
 CLINVAR_SV_TYPES = [
@@ -178,13 +177,16 @@ COLLECTION_METHOD = [
     NOT_PROVIDED,
 ]
 
-# Available databases used to describe phenotypes (Key/Description)
-PHENO_DBS = {
-    "HPO": "HPO",
-    "MedGen": "MedGen",
-    "MeSH": "MeSH",
-    "MONDO": "MONDO",
-    "OMIM": "OMIM",
-    "Orphanet": "Orphanet",
-    "UMLS": "UMLS",
+# Database that describe a condition with associated eventual prefix
+CONDITION_PREFIX = {
+    "HPO": "HP:",
+    "MedGen": "",
+    "MeSH": "",
+    "MONDO": "MONDO:",
+    "OMIM": "",
+    "Orphanet": "ORPHA",
 }
+
+CLINVAR_ASSERTION_METHOD_CIT_DB_OPTIONS = {"DOI", "pmc", "PMID"}
+
+MULTIPLE_CONDITION_EXPLANATION = ["Novel disease", "Uncertain", "Co-occurring"]
