@@ -4,8 +4,11 @@ HG19REF_URL = (
 )
 HG19REF_INDEX_URL = "https://s3.amazonaws.com/igv.broadinstitute.org/genomes/seq/1kg_v37/human_g1k_v37_decoy.fasta.fai"
 HG19CYTOBAND_URL = "https://s3.amazonaws.com/igv.broadinstitute.org/genomes/seq/hg19/cytoBand.txt"
+HG19ALIAS_URL = "https://s3.amazonaws.com/igv.org.genomes/hg19/hg19_alias.tab"
+
 HG38REF_URL = "https://s3.amazonaws.com/igv.broadinstitute.org/genomes/seq/hg38/hg38.fa"
 HG38REF_INDEX_URL = "https://s3.amazonaws.com/igv.broadinstitute.org/genomes/seq/hg38/hg38.fa.fai"
+HG38ALIAS_URL = "https://s3.amazonaws.com/igv.org.genomes/hg38/hg38_alias.tab"
 HG38CYTOBAND_URL = (
     "https://s3.amazonaws.com/igv.broadinstitute.org/annotations/hg38/cytoBandIdeo.txt"
 )
@@ -29,16 +32,20 @@ HG19CLINVAR_SVS_URL = (
 
 # Human genome reference genome build 37. Always displayed
 HUMAN_REFERENCE_37 = {
+    "id": "hg19",
     "fastaURL": HG19REF_URL,
     "indexURL": HG19REF_INDEX_URL,
     "cytobandURL": HG19CYTOBAND_URL,
+    "aliasURL": HG19ALIAS_URL,
 }
 
 # Human genome reference genome build 38. Always displayed
 HUMAN_REFERENCE_38 = {
+    "id": "hg38",
     "fastaURL": HG38REF_URL,
     "indexURL": HG38REF_INDEX_URL,
     "cytobandURL": HG38CYTOBAND_URL,
+    "aliasURL": HG38ALIAS_URL,
 }
 
 # igv.js track settings common for all users and all cases. Selectable by users
