@@ -31,11 +31,16 @@ PRIMARY_CRITERIA = ["clinsig"]
 # such as a Pathogenic ClinSig.
 SECONDARY_CRITERIA = [
     "gnomad_frequency",
-    "local_obs",
+    "local_obs_old",
+    "local_obs_cancer_somatic_old",
+    "local_obs_cancer_germline_old",
+    "local_obs_freq",
     "clingen_ngi",
     "swegen",
+    "swegen_freq",
     "spidex_human",
     "cadd_score",
+    "revel",
     "genetic_models",
     "genotypes",
     "functional_annotations",
@@ -45,9 +50,15 @@ SECONDARY_CRITERIA = [
     "decipher",
     "depth",
     "alt_count",
+    "somatic_score",
     "control_frequency",
     "mvl_tag",
     "clinvar_tag",
     "cosmic_tag",
     "tumor_frequency",
+    "fusion_score",
+    "ffpm",
+    "junction_reads",
+    "split_reads",
+    "fusion_caller",
 ]
