@@ -2,56 +2,6 @@ from collections import OrderedDict
 
 from .gene_tags import INHERITANCE_PALETTE
 
-VARIANT_REPORT_VARIANT_FEATURES = [
-    "_id",
-    "variant_id",
-    "display_name",
-    "case_id",
-    "sanger_ordered",
-    "validation",
-    "phenotypes",
-    "chromosome",
-    "position",
-    "end",
-    "end_chrom",
-    "callers",
-    "cytoband_start",
-    "cytoband_end",
-    "reference",
-    "alternative",
-    "dbsnp_id",
-    "panels",
-    "samples",
-    "frequency",
-    "dbsnp_id",
-    "thousandg_link",
-    "thousand_genomes_frequency",
-    "max_thousand_genomes_frequency",
-    "max_exac_frequency",
-    "exac_frequency",
-    "gnomad_frequency",
-    "variant_rank",
-    "rank_score",
-    "manual_rank",
-    "cancer_tier",
-    "cadd_score",
-    "genetic_models",
-    "acmg_classification",
-    "genes",  # This is a list of dictionaries with gene info
-    "hgnc_symbols",  # This is a list of gene symbols (strings)
-    "comments",
-    "category",
-    "dismiss_variant",
-    "variant_rank",
-    "sub_category",
-    "end_chrom",
-    "length",
-    "str_repid",
-    "str_display_ru",
-    "str_ru",
-    "str_status",
-]
-
 CONSEQUENCE = (
     "deleterious",
     "deleterious_low_confidence",
@@ -87,6 +37,8 @@ FEATURE_TYPES = (
 
 SV_TYPES = ("ins", "del", "dup", "cnv", "inv", "bnd")
 
+OUTLIER_TYPES = ("splicing", "expression")
+
 GENETIC_MODELS = (
     ("AR_hom", "Autosomal Recessive Homozygote"),
     ("AR_hom_dn", "Autosomal Recessive Homozygote De Novo"),
@@ -560,3 +512,14 @@ MOSAICISM_OPTIONS = {
         "evidence": ["allele_count"],
     },
 }
+
+VARIANTS_TARGET_FROM_CATEGORY = {
+    "sv": "variants.sv_variants",
+    "cancer": "variants.cancer_variants",
+    "cancer_sv": "variants.cancer_sv_variants",
+    "mei": "variants.mei_variants",
+    "snv": "variants.variants",
+    "str": "variants.str_variants",
+    "fusion": "variants.fusion_variants",
+    "outlier": "omics_variants.outliers",
+}
