@@ -5,6 +5,7 @@ This means add a default institute, a user and the internal definitions such as
 transcripts, hpo terms etc
 
 """
+
 import logging
 
 import yaml
@@ -17,17 +18,18 @@ from scout.demo import cancer_load_path, load_path, panel_path, rnafusion_load_p
 
 ### Import demo files ###
 from scout.demo.resources import demo_files
-from scout.load import load_cytobands, load_hgnc_genes, load_hpo, load_transcripts
+from scout.load import load_cytobands, load_hgnc_genes, load_transcripts
+from scout.load.disease import load_disease_terms
+from scout.load.hpo import load_hpo_terms
 
 # Resources
 from scout.parse.case import parse_case_data
 from scout.parse.panel import parse_gene_panel
 from scout.resources import cytoband_files
+from scout.utils.ensembl_biomart_clients import EnsemblBiomartHandler
 from scout.utils.handle import get_file_handle
 from scout.utils.scout_requests import (
-    fetch_ensembl_genes,
-    fetch_ensembl_transcripts,
-    fetch_exac_constraint,
+    fetch_constraint,
     fetch_genes_to_hpo_to_disease,
     fetch_hgnc,
     fetch_mim_files,
@@ -49,12 +51,12 @@ def setup_scout(
 
     WARNING: If the instance is populated all collections will be deleted
 
-    Build insert a institute and an admin user.
-    There are multiple sources of information that is used by scout and that needs to exist for
-    scout to work proper.
+    Build and insert an institute and an admin user.
 
+    Multiple sources of information that are used by scout need to exist for
+    scout to work properly.
     Genes:
-         Scout uses HGNC as the source for gene identifiers en ensembl as source for coordinates.
+         Scout uses HGNC as the source for gene identifiers and ENSEMBL as source for coordinates.
          Additional information of disease connections for genes if fetched from OMIM.
          Link between hpo terms and genes is fetched from HPO
          For more details check the documentation.
@@ -123,22 +125,24 @@ def setup_scout(
     else:
         hgnc_lines = fetch_hgnc()
 
-    if resource_files.get("exac_path"):
-        exac_lines = [line for line in get_file_handle(resource_files.get("exac_path"))]
+    if resource_files.get("constraint_path"):
+        exac_lines = [line for line in get_file_handle(resource_files.get("constraint_path"))]
     else:
-        exac_lines = fetch_exac_constraint()
+        exac_lines = fetch_constraint()
 
     # Load cytobands into cytoband collection
     for genome_build, cytobands_path in cytoband_files.items():
         load_cytobands(cytobands_path, genome_build, adapter)
 
+    # Load genes
     builds = ["37", "38"]
     for build in builds:
         genes_path = "genes{}_path".format(build)
+        ensembl_client = EnsemblBiomartHandler(build=build)
         if resource_files.get(genes_path):
             ensembl_genes = get_file_handle(resource_files[genes_path])
         else:
-            ensembl_genes = fetch_ensembl_genes(build=build)
+            ensembl_genes = ensembl_client.stream_resource(interval_type="genes")
 
         hgnc_genes = load_hgnc_genes(
             adapter=adapter,
@@ -157,13 +161,14 @@ def setup_scout(
             ensembl_id = gene_obj["ensembl_id"]
             ensembl_genes[ensembl_id] = gene_obj
 
+        # Load transcripts
         tx_path = "transcripts{}_path".format(build)
         if resource_files.get(tx_path):
             ensembl_transcripts = get_file_handle(resource_files[tx_path])
         else:
-            ensembl_transcripts = fetch_ensembl_transcripts(build=build)
+            ensembl_transcripts = ensembl_client.stream_resource(interval_type="transcripts")
         # Load the transcripts for a certain build
-        transcripts = load_transcripts(adapter, ensembl_transcripts, build, ensembl_genes)
+        load_transcripts(adapter, ensembl_transcripts, build, ensembl_genes)
 
     hpo_terms_handle = None
     if resource_files.get("hpoterms_path"):
@@ -173,15 +178,39 @@ def setup_scout(
     if resource_files.get("hpo_to_genes_path"):
         hpo_to_genes_handle = get_file_handle(resource_files["hpo_to_genes_path"])
 
-    hpo_disease_handle = None
-    if resource_files.get("hpo_disease_path"):
-        hpo_disease_handle = get_file_handle(resource_files["hpo_disease_path"])
+    hpo_annotation_handle = None
+    if resource_files.get("hpo_phenotype_annotation_path"):
+        hpo_annotation_handle = get_file_handle(resource_files["hpo_phenotype_annotation_path"])
 
-    load_hpo(
+    orpha_to_hpo_handle = None
+    if resource_files.get("orpha_to_genes_path"):
+        orpha_to_hpo_handle = get_file_handle(resource_files["orpha_to_hpo_path"])
+
+    orpha_to_genes_handle = None
+    if resource_files.get("orpha_to_genes_path"):
+        orpha_to_genes_handle = get_file_handle(resource_files["orpha_to_genes_path"])
+
+    orpha_inheritance_handle = None
+    if resource_files.get("orpha_inheritance_path"):
+        orpha_inheritance_handle = get_file_handle(resource_files["orpha_inheritance_path"])
+
+    alias_genes = adapter.genes_by_alias()
+    # Load HPO terms
+    load_hpo_terms(
         adapter=adapter,
-        disease_lines=genemap_lines,
         hpo_lines=hpo_terms_handle,
         hpo_gene_lines=hpo_to_genes_handle,
+        alias_genes=alias_genes,
+    )
+    # Load diseases
+    load_disease_terms(
+        adapter=adapter,
+        genemap_lines=genemap_lines,
+        genes=alias_genes,
+        hpo_annotation_lines=hpo_annotation_handle,
+        orpha_to_hpo_lines=orpha_to_hpo_handle,
+        orpha_to_genes_lines=orpha_to_genes_handle,
+        orpha_inheritance_lines=orpha_inheritance_handle,
     )
 
     # If demo we load a gene panel and some case information
