@@ -1,13 +1,15 @@
 """Code for parsing ensembl information"""
+
 import logging
+from typing import Any, Dict, List
 
 LOG = logging.getLogger(__name__)
 
 
 def parse_ensembl_line(line, header):
-    """Parse an ensembl formated line
+    """Parse an ensembl formatted line
 
-    This parser should be able to handle any ensembl formated line in tsv format, regardless if
+    This parser should be able to handle any ensembl formatted line in tsv format, regardless if
     it is exons, transcripts or genes.
 
     Args:
@@ -44,23 +46,19 @@ def parse_ensembl_line(line, header):
         update_exon_info(ensembl_info, word, value)
         update_utr_info(ensembl_info, word, value)
         update_refseq_info(ensembl_info, word, value)
+        update_mane_info(ensembl_info, word, value)
     return ensembl_info
 
 
-def parse_transcripts(transcript_lines):
+def parse_transcripts(transcript_lines: List[str]) -> Dict[str, dict]:
     """Parse and massage the transcript information
 
     There could be multiple lines with information about the same transcript.
     This is why it is necessary to parse the transcripts first and then return a dictionary
     where all information has been merged.
-
-    Args:
-        transcript_lines(): Iterable with strings
-
-    Returns:
-        parsed_transcripts(dict): Map from enstid -> transcript info
     """
     LOG.info("Parsing transcripts")
+
     transcripts = parse_ensembl_transcripts(transcript_lines)
 
     # Since there can be multiple lines with information about the same transcript
@@ -95,18 +93,23 @@ def parse_transcripts(transcript_lines):
         if tx.get("refseq_ncrna"):
             tx_info["nc_rna"].add(tx["refseq_ncrna"])
 
+        # Add MANE-related info
+        for mane in ["mane_select", "mane_plus_clinical"]:
+            if tx.get(mane):
+                tx_info[mane] = tx[mane]
+
     return parsed_transcripts
 
 
 def parse_ensembl_genes(lines):
-    """Parse lines with ensembl formated genes
+    """Parse lines with ensembl formatted genes
 
     This is designed to take a biomart dump with genes from ensembl.
     Mandatory columns are:
     'Gene ID' 'Chromosome' 'Gene Start' 'Gene End' 'HGNC symbol'
 
     Args:
-        lines(iterable(str)): An iterable with ensembl formated genes
+        lines(iterable(str)): An iterable with ensembl formatted genes
     Yields:
         ensembl_gene(dict): A dictionary with the relevant information
     """
@@ -123,14 +126,14 @@ def parse_ensembl_genes(lines):
 
 
 def parse_ensembl_transcripts(lines):
-    """Parse lines with ensembl formated transcripts
+    """Parse lines with ensembl formatted transcripts
 
     This is designed to take a biomart dump with transcripts from ensembl.
     Mandatory columns are:
     'Gene ID' 'Transcript ID' 'Transcript Start' 'Transcript End' 'RefSeq mRNA'
 
     Args:
-        lines(iterable(str)): An iterable with ensembl formated genes
+        lines(iterable(str)): An iterable with ensembl formatted genes
     Yields:
         ensembl_transcript(dict): A dictionary with the relevant information
     """
@@ -146,13 +149,13 @@ def parse_ensembl_transcripts(lines):
 
 
 def parse_ensembl_exons(lines):
-    """Parse lines with ensembl formated exons
+    """Parse lines with ensembl formatted exons
 
     This is designed to take a biomart dump with exons from ensembl.
     Check documentation for spec for download
 
     Args:
-        lines(iterable(str)): An iterable with ensembl formated exons
+        lines(iterable(str)): An iterable with ensembl formatted exons
     Yields:
         ensembl_gene(dict): A dictionary with the relevant information
     """
@@ -219,8 +222,8 @@ def parse_ensembl_exons(lines):
         yield exon
 
 
-def update_gene_info(ensembl_info, word, value):
-    """Extract gene info from Ensembl formated line"""
+def update_gene_info(ensembl_info: Dict[str, Any], word: str, value: str) -> Dict[str, Any]:
+    """Extract gene info from Ensembl formatted line"""
     if "gene" in word:
         if "id" in word:
             ensembl_info["ensembl_gene_id"] = value
@@ -231,8 +234,8 @@ def update_gene_info(ensembl_info, word, value):
     return ensembl_info
 
 
-def update_transcript_info(ensembl_info, word, value):
-    """Extract transcript info from Ensembl formated line"""
+def update_transcript_info(ensembl_info: Dict[str, Any], word: str, value: str) -> Dict[str, Any]:
+    """Extract transcript info from Ensembl formatted line"""
     if "transcript" in word:
         if "id" in word:
             ensembl_info["ensembl_transcript_id"] = value
@@ -243,8 +246,8 @@ def update_transcript_info(ensembl_info, word, value):
     return ensembl_info
 
 
-def update_exon_info(ensembl_info, word, value):
-    """Extract exon info from Ensembl formated line"""
+def update_exon_info(ensembl_info: Dict[str, Any], word: str, value: str) -> Dict[str, Any]:
+    """Extract exon info from Ensembl formatted line"""
     if "exon" in word:
         if "start" in word:
             ensembl_info["exon_start"] = int(value)
@@ -257,8 +260,8 @@ def update_exon_info(ensembl_info, word, value):
     return ensembl_info
 
 
-def update_utr_info(ensembl_info, word, value):
-    """Extract UTR info from Ensembl formated line"""
+def update_utr_info(ensembl_info: Dict[str, Any], word: str, value: str) -> Dict[str, Any]:
+    """Extract UTR info from Ensembl formatted line"""
     if "utr" in word:
         if "start" in word:
             if "5" in word:
@@ -273,8 +276,8 @@ def update_utr_info(ensembl_info, word, value):
     return ensembl_info
 
 
-def update_refseq_info(ensembl_info, word, value):
-    """Extract RefSeq info from Ensembl formated line"""
+def update_refseq_info(ensembl_info: Dict[str, Any], word: str, value: str) -> Dict[str, Any]:
+    """Extract RefSeq info from Ensembl formatted line"""
     if "refseq" in word:
         if "mrna" in word:
             if "predicted" in word:
@@ -285,3 +288,12 @@ def update_refseq_info(ensembl_info, word, value):
         if "ncrna" in word:
             ensembl_info["refseq_ncrna"] = value
     return ensembl_info
+
+
+def update_mane_info(ensembl_info: Dict[str, Any], word: str, value: str) -> Dict[str, Any]:
+    """Extract MANE Plus Clinical and MANE Select info from an Ensembl formatted line."""
+    if "mane select" in word:
+        ensembl_info["mane_select"] = value
+    if "mane plus clinical" in word:
+        ensembl_info["mane_plus_clinical"] = value
+    return ensembl_info
