@@ -1,5 +1,4 @@
 import logging
-from pprint import pprint as pp
 
 logger = logging.getLogger(__name__)
 
@@ -25,6 +24,7 @@ def parse_hgnc_line(line, header):
     hgnc_gene["hgnc_symbol"] = hgnc_symbol
     hgnc_gene["hgnc_id"] = int(raw_info["hgnc_id"].split(":")[-1])
     hgnc_gene["description"] = raw_info["name"]
+    hgnc_gene["location"] = raw_info["location"]  # cytoband
 
     # We want to have the current symbol as an alias
     aliases = set([hgnc_symbol, hgnc_symbol.upper()])
