@@ -52,16 +52,21 @@ def omim_terms(store, case_obj):
     if case_disorders:
         for disorder in case_disorders:
             if isinstance(disorder, dict):
-                disorder = disorder.get("disease_nr")
-            omim_term = store.disease_term(disorder)
-            if omim_term is None:
+                disorder = disorder.get("disease_id")
+            # Historically diagnosis_phenotypes was saved as a list of id:s,
+            # at that time no other coding systems were present in the database
+            elif isinstance(disorder, int):
+                disorder = f"OMIM:{disorder}"
+            disease_term = store.disease_term(disorder)
+            if disease_term is None:
                 LOG.warning(f"Disease term {disorder} could not be found in database.")
                 continue
-            disorder_obj = {
-                "id": ":".join(["MIM", str(disorder)]),
-                "label": omim_term.get("description"),
-            }
-            disorders.append(disorder_obj)
+            if disease_term["source"] == "OMIM":
+                disorder_obj = {
+                    "id": disorder.replace("OMIM", "MIM"),
+                    "label": disease_term.get("description"),
+                }
+                disorders.append(disorder_obj)
     return disorders
 
 
@@ -100,17 +105,17 @@ def genomic_features(store, case_obj, sample_name, candidate_vars, genes_only):
 
     for var in candidate_vars:
         vari_id = var.split("|")[0]
-        gene_symbol = None
         var_obj = store.sample_variant(vari_id, sample_name)
         if var_obj is None:
             continue
-        if "|" in var:  # Share a gene symbol from a SV
-            gene_symbol = var.split("|")[1]
-            g_feature = {"gene": {"id": gene_symbol}}
-            g_features.append(g_feature)
+
+        selected_gene: str = var.split("|")[1] if "|" in var else None
+
+        if var_obj["category"] not in ["snv", "snv_research", "cancer", "cancer_research"]:
+            g_features.append({"gene": {"id": selected_gene}})
             continue
 
-        # SNV variant
+        # "snv", "snv_research", "cancer", "cancer_research" variants
         hgnc_genes = var_obj.get("hgnc_ids")
         if not hgnc_genes:
             continue
@@ -118,7 +123,12 @@ def genomic_features(store, case_obj, sample_name, candidate_vars, genes_only):
             gene_caption = store.hgnc_gene_caption(hgnc_id, case_obj["genome_build"])
             if not gene_caption:
                 continue
-            g_feature = {"gene": {"id": gene_caption.get("hgnc_symbol")}}
+
+            gene_symbol: str = gene_caption.get("hgnc_symbol")
+            if selected_gene and gene_symbol != selected_gene:
+                continue
+
+            g_feature = {"gene": {"id": gene_symbol}}
             if genes_only is True:  # Disclose only gene info
                 g_features.append(g_feature)
                 continue
@@ -133,6 +143,7 @@ def genomic_features(store, case_obj, sample_name, candidate_vars, genes_only):
                 "alternateBases": var_obj["alternative"],
                 "shareVariantLevelData": True,
             }
+
             zygosity = None
             # collect zygosity for the given sample
             zygosities = var_obj[
@@ -175,9 +186,11 @@ def parse_matches(patient_id, match_objs):
     parsed_matches = []
 
     for match_obj in match_objs:
-        # convert match date from millisecond to readable date
-        milliseconds_date = match_obj["created"]["$date"]
-        mdate = datetime.datetime.fromtimestamp(milliseconds_date / 1000.0)
+        match_date = match_obj["created"]["$date"]
+        try:  # Patientmatcher < 4.5 returns dates in milliseconds
+            mdate = datetime.datetime.fromtimestamp(match_date / 1000.0)
+        except TypeError:  # Patientmatcher >= 4.5 returns dates in isoformat
+            mdate = datetime.datetime.strptime(match_date, "%Y-%m-%dT%H:%M:%S.%fZ")
         match_type = "external"
         matching_patients = []
 
