@@ -1,6 +1,8 @@
 """Code to parse panel information"""
+
 import logging
 from datetime import datetime
+from typing import Dict, List, Optional
 
 from scout.constants import (
     INCOMPLETE_PENETRANCE_MAP,
@@ -233,7 +235,12 @@ def parse_genes(gene_lines):
 
 
 def parse_gene_panel(
-    path, institute="cust000", panel_id="test", panel_type="clinical", genes=None, **kwargs
+    path,
+    institute="cust000",
+    panel_id="test",
+    panel_type="clinical",
+    genes=None,
+    **kwargs,
 ):
     """Parse the panel info and return a gene panel
 
@@ -268,17 +275,14 @@ def parse_gene_panel(
     return gene_panel
 
 
-def parse_panel_app_gene(app_gene, hgnc_map, confidence):
-    """Parse a panel app formatted gene.
+def parse_panel_app_gene(
+    app_gene: dict,
+    ensembl_gene_hgnc_id_map: Dict[str, int],
+    hgnc_symbol_ensembl_gene_map: Dict[str, str],
+    confidence: str,
+) -> dict:
+    """Parse a panel app-formatted gene."""
 
-    Args:
-        app_gene(dict): dict with panel app info, where Ensembl ids are present as a loist with key "EnsembleGeneIds"
-        hgnc_map(dict): a dictionary with Ensembl IDs as keys and HGNC ids as values
-        confidence(str): enum green|amber|red
-
-    Returns:
-        gene_info(dict): Scout infromation
-    """
     gene_info = {}
     confidence_level = app_gene["LevelOfConfidence"]
     # Return empty gene if not confident gene
@@ -288,8 +292,22 @@ def parse_panel_app_gene(app_gene, hgnc_map, confidence):
     hgnc_symbol = app_gene["GeneSymbol"]
 
     ensembl_ids = app_gene["EnsembleGeneIds"]
+
+    if not ensembl_ids:  # This gene is probably tagged as ensembl_ids_known_missing on PanelApp
+        if hgnc_symbol in hgnc_symbol_ensembl_gene_map:
+            LOG.warning(
+                f"PanelApp gene {hgnc_symbol} does not contain Ensembl IDs. Using Ensembl IDs from internal gene collection instead."
+            )
+            ensembl_ids = [hgnc_symbol_ensembl_gene_map[hgnc_symbol]]
+        else:
+            LOG.warning(
+                f"PanelApp gene {hgnc_symbol} does not contain Ensembl IDs and gene symbol does not correspond to a gene in scout."
+            )
+
     hgnc_ids = set(
-        hgnc_map.get(ensembl_id) for ensembl_id in ensembl_ids if hgnc_map.get(ensembl_id)
+        ensembl_gene_hgnc_id_map.get(ensembl_id)
+        for ensembl_id in ensembl_ids
+        if ensembl_gene_hgnc_id_map.get(ensembl_id)
     )
     if not hgnc_ids:
         LOG.warning("Gene %s does not exist in database. Skipping gene...", hgnc_symbol)
@@ -314,8 +332,13 @@ def parse_panel_app_gene(app_gene, hgnc_map, confidence):
 
 
 def parse_panel_app_panel(
-    panel_info, hgnc_map, institute="cust000", panel_type="clinical", confidence="green"
-):
+    panel_info: dict,
+    ensembl_gene_hgnc_id_map: Dict[str, int],
+    hgnc_symbol_ensembl_gene_map: Dict[str, str],
+    institute: Optional[str] = "cust000",
+    panel_type: Optional[str] = "clinical",
+    confidence: Optional[str] = "green",
+) -> dict:
     """Parse a PanelApp panel
 
     Args:
@@ -346,7 +369,9 @@ def parse_panel_app_panel(
     nr_excluded = 0
     nr_genes = 0
     for nr_genes, gene in enumerate(panel_info["Genes"], 1):
-        gene_info = parse_panel_app_gene(gene, hgnc_map, confidence)
+        gene_info = parse_panel_app_gene(
+            gene, ensembl_gene_hgnc_id_map, hgnc_symbol_ensembl_gene_map, confidence
+        )
         if not gene_info:
             nr_excluded += 1
             continue
