@@ -57,21 +57,12 @@ def sv_length(pos, end, chrom, end_chrom, svlen=None):
     return end - pos
 
 
-def sv_end(pos, alt, svend=None, svlen=None):
+def sv_end(pos: int, alt: str, svend: int = None, svlen: int = None) -> int:
     """Return the end coordinate for a structural variant
     The END field from INFO usually works fine, although for some cases like insertions the callers
      set end to same as pos. In those cases we can hope that there is a svlen...
 
     Translocations needs their own treatment as usual
-
-    Args:
-        pos(int)
-        alt(str)
-        svend(int)
-        svlen(int)
-
-    Returns:
-        end(int)
     """
     end = svend
 
@@ -80,9 +71,8 @@ def sv_end(pos, alt, svend=None, svlen=None):
         if match:
             end = int(match.group(2))
 
-    if svend == pos:
-        if svlen:
-            end = pos + svlen
+    if end is None and svlen:
+        end = pos + svlen
 
     return end
 
@@ -150,7 +140,7 @@ def parse_coordinates(variant, category, build="37"):
     ref = variant.REF
     ref_len = len(ref)
 
-    if category in ["sv", "cancer_sv"]:
+    if category in ["sv", "cancer_sv", "fusion"]:
         svtype = variant.INFO.get("SVTYPE")
         if svtype:
             svtype = svtype.lower()
@@ -170,13 +160,20 @@ def parse_coordinates(variant, category, build="37"):
             end_chrom=end_chrom,
             svlen=variant.INFO.get("SVLEN"),
         )
+    elif category == "mei":
+        sub_category = "mei"
+        end = int(variant.end)
+        length = alt_len
+        if ref_len != alt_len:
+            sub_category = "mei"
+            length = abs(ref_len - alt_len)
     else:
         sub_category = "snv"
         end = int(variant.end)
         length = alt_len
         if ref_len != alt_len:
             sub_category = "indel"
-            abs(ref_len - alt_len)
+            length = abs(ref_len - alt_len)
 
     coordinates = {
         "chrom": chrom,
