@@ -18,7 +18,13 @@ Uses 'DV' to describe number of paired ends that supports the event and
 
 """
 
+import logging
+from typing import Dict, List, Optional, Tuple, Union
+
+import cyvcf2
+
 GENOTYPE_MAP = {0: "0", 1: "1", -1: "."}
+LOG = logging.getLogger(__name__)
 
 
 def parse_genotypes(variant, individuals, individual_positions):
@@ -61,6 +67,12 @@ def parse_genotype(variant, ind, pos):
     ##FORMAT=<ID=ADIR,Number=1,Type=String,Description="Number of in-repeat reads consistent with the allele">
     ##FORMAT=<ID=ADSP,Number=1,Type=String,Description="Number of spanning reads consistent with the allele">
 
+    MEI specific format fields
+    ##FORMAT=<ID=CLIP3,Number=1,Type=Float,Description="Number of soft clipped reads downstream of the breakpoint">
+    ##FORMAT=<ID=CLIP5,Number=1,Type=Float,Description="Number of soft clipped reads upstream of the breakpoint">
+    ##FORMAT=<ID=SP,Number=1,Type=Float,Description="Number of correctly mapped read pairs spanning breakpoint, useful for estimation of size of insertion">
+    ##FORMAT=<ID=SP,Number=1,Type=Float,Description="Number of correctly mapped read pairs spanning breakpoint, useful for estimation of size of insertion">
+
     Args:
         variant(cyvcf2.Variant)
         ind_id(dict): A dictionary with individual information
@@ -91,26 +103,111 @@ def parse_genotype(variant, ind, pos):
     (flanking_ref, flanking_alt) = _parse_format_entry(variant, pos, "ADFL")
     (inrepeat_ref, inrepeat_alt) = _parse_format_entry(variant, pos, "ADIR")
 
+    # TRGT long read STR specific
+    (_, mc_alt) = _parse_format_entry_trgt_mc(variant, pos)
+    gt_call["alt_mc"] = mc_alt
+
+    (sd_ref, sd_alt) = _parse_format_entry(variant, pos, "SD", float)
+    (ap_ref, ap_alt) = _parse_format_entry(variant, pos, "AP", float)
+    (am_ref, am_alt) = _parse_format_entry(variant, pos, "AM", float)
+
+    # MEI specific
+    (spanning_mei_ref, clip5_alt, clip3_alt) = get_mei_reads(
+        variant, pos
+    )  # allowing mei SP to override STR ADSP for spanning
+
     # SV specific
     (paired_end_ref, paired_end_alt) = get_paired_ends(variant, pos)
     (split_read_ref, split_read_alt) = get_split_reads(variant, pos)
 
     alt_depth = get_alt_depth(
-        variant, pos, paired_end_alt, split_read_alt, spanning_alt, flanking_alt, inrepeat_alt
+        variant,
+        pos,
+        paired_end_alt,
+        split_read_alt,
+        spanning_alt,
+        flanking_alt,
+        inrepeat_alt,
+        clip5_alt,
+        clip3_alt,
     )
     gt_call["alt_depth"] = alt_depth
 
     ref_depth = get_ref_depth(
-        variant, pos, paired_end_ref, split_read_ref, spanning_ref, flanking_ref, inrepeat_ref
+        variant,
+        pos,
+        paired_end_ref,
+        split_read_ref,
+        spanning_ref,
+        flanking_ref,
+        inrepeat_ref,
+        spanning_mei_ref,
     )
     gt_call["ref_depth"] = ref_depth
     gt_call["read_depth"] = get_read_depth(variant, pos, alt_depth, ref_depth)
     gt_call["alt_frequency"] = get_alt_frequency(variant, pos)
     gt_call["genotype_quality"] = int(variant.gt_quals[pos])
+    gt_call["ffpm"] = get_ffpm_info(variant, pos)
+    gt_call["split_read"] = split_read_alt
 
     return gt_call
 
 
+def get_mei_reads(variant: cyvcf2.Variant, pos: Dict[str, int]) -> Tuple[int, ...]:
+    """Get MEI caller read details from FORMAT tags.
+    Returns:
+        tuple(int, int, int) spanning_ref, clip5p_alt, clip3p_alt
+    """
+    spanning_ref = None
+    clip5_alt = None
+    clip3_alt = None
+
+    # Number of (reference) variant spanning reads
+    if "SP" in variant.FORMAT:
+        try:
+            values = variant.format("SP")[pos]
+            ref_value = int(values[0])
+            if ref_value >= 0:
+                spanning_ref = ref_value
+        except ValueError as _ignore_error:
+            pass
+
+    # Number of split reads upstream (supporting alt)
+    if "CLIP5" in variant.FORMAT:
+        try:
+            values = variant.format("CLIP5")[pos]
+            alt_value = int(values[0])
+            if alt_value >= 0:
+                clip5_alt = alt_value
+        except ValueError as _ignore_error:
+            pass
+
+    if "CLIP3" in variant.FORMAT:
+        try:
+            values = variant.format("CLIP3")[pos]
+            alt_value = int(values[0])
+            if alt_value >= 0:
+                clip3_alt = alt_value
+        except ValueError as _ignore_error:
+            pass
+
+    return (spanning_ref, clip5_alt, clip3_alt)
+
+
+def get_ffpm_info(variant: cyvcf2.Variant, pos: Dict[str, int]) -> Optional[int]:
+    """Get FUSION caller read details from FORMAT tags.
+    Returns:
+        tuple(int, int, int) supporting_reads, split_reads, ffpm
+    """
+    # Fusion fragments per million total RNA-seq fragments
+    if "FFPM" in variant.FORMAT:
+        try:
+            values = variant.format("FFPM")[pos]
+            return int(values[0])
+        except ValueError as _ignore_error:
+            pass
+
+
 def get_paired_ends(variant, pos):
     """Get paired ends"""
     # SV specific
@@ -225,53 +322,71 @@ def get_read_depth(variant, pos, alt_depth, ref_depth):
 
 
 def get_ref_depth(
-    variant, pos, paired_end_ref, split_read_ref, spanning_ref, flanking_ref, inrepeat_ref
+    variant,
+    pos,
+    paired_end_ref,
+    split_read_ref,
+    spanning_ref,
+    flanking_ref,
+    inrepeat_ref,
+    spanning_mei_ref,
 ):
     """Get reference read depth"""
     ref_depth = int(variant.gt_ref_depths[pos])
-    if ref_depth == -1:
-        if any([paired_end_ref, split_read_ref]):
-            ref_depth = 0
-            if paired_end_ref:
-                ref_depth += paired_end_ref
-            if split_read_ref:
-                ref_depth += split_read_ref
+    if ref_depth != -1:
+        return ref_depth
 
-        if any([spanning_ref, flanking_ref, inrepeat_ref]):
-            ref_depth = 0
-            if spanning_ref:
-                ref_depth += spanning_ref
-            if flanking_ref:
-                ref_depth += flanking_ref
-            if inrepeat_ref:
-                ref_depth += inrepeat_ref
+    REF_ITEMS_LIST: List[tuple] = [
+        (paired_end_ref, split_read_ref),
+        (spanning_ref, flanking_ref, inrepeat_ref),
+    ]
+
+    for list in REF_ITEMS_LIST:
+        if all(item is None for item in list):
+            continue
+        ref_depth = 0
+        for item in list:
+            if item:
+                ref_depth += item
+
+    if spanning_mei_ref:
+        ref_depth += spanning_mei_ref
     return ref_depth
 
 
 def get_alt_depth(
-    variant, pos, paired_end_alt, split_read_alt, spanning_alt, flanking_alt, inrepeat_alt
+    variant,
+    pos,
+    paired_end_alt,
+    split_read_alt,
+    spanning_alt,
+    flanking_alt,
+    inrepeat_alt,
+    clip5_alt,
+    clip3_alt,
 ):
     """Get alternative read depth"""
     alt_depth = int(variant.gt_alt_depths[pos])
-    if alt_depth == -1:
-        if "VD" in variant.FORMAT:
-            alt_depth = int(variant.format("VD")[pos][0])
+    if alt_depth != -1:
+        return alt_depth
 
-        if any([paired_end_alt, split_read_alt]):
-            alt_depth = 0
-            if paired_end_alt:
-                alt_depth += paired_end_alt
-            if split_read_alt:
-                alt_depth += split_read_alt
+    if "VD" in variant.FORMAT:
+        alt_depth = int(variant.format("VD")[pos][0])
+
+    ALT_ITEMS_LIST: List[tuple] = [
+        (paired_end_alt, split_read_alt),
+        (clip5_alt, clip3_alt),
+        (spanning_alt, flanking_alt, inrepeat_alt),
+    ]
+
+    for list in ALT_ITEMS_LIST:
+        if all(item is None for item in list):
+            continue
+        alt_depth = 0
+        for item in list:
+            if item:
+                alt_depth += item
 
-        if any([spanning_alt, flanking_alt, inrepeat_alt]):
-            alt_depth = 0
-            if spanning_alt:
-                alt_depth += spanning_alt
-            if flanking_alt:
-                alt_depth += flanking_alt
-            if inrepeat_alt:
-                alt_depth += inrepeat_alt
     return alt_depth
 
 
@@ -288,33 +403,48 @@ def get_str_so(variant, pos):
     return str_so
 
 
-def _parse_format_entry(variant, pos, format_entry_name):
-    """Parse genotype format entry for named integer values.
-    Expects that ref/alt values could be separated by /.
+def split_values(values: List[str]) -> List[str]:
+    """
+    Expects that ref/alt values could be separated by "/" or ",".
 
-    Args:
-        variant(cyvcf2.Variant)
-        pos(int): individual position in VCF
-        format_entry_name: name of format entry
-    Returns:
-        (ref(int), alt(int)) tuple
+    """
+    new_values = []
+    for value in values:
+        for delim in ["/", ","]:
+            if delim in value:
+                new_values = list(value.split(delim))
+
+    if new_values:
+        return new_values
+
+    return values
+
+
+def _parse_format_entry(
+    variant: cyvcf2.Variant,
+    pos: int,
+    format_entry_name: str,
+    number_format: Optional[Union[float, int]] = int,
+) -> Tuple[Union[float, int], ...]:
+    """Parse genotype format entry for named integer values.
+    Expects that ref/alt values could be separated by "/" or ",".
+    Give individual position in VCF as pos and name of format entry to parse as format_entry_name.
     """
 
     ref = None
     alt = None
     if format_entry_name in variant.FORMAT:
         try:
-            value = variant.format(format_entry_name)[pos]
-            values = list(value.split("/"))
+            values = split_values(variant.format(format_entry_name)[pos])
 
             ref_value = None
             alt_value = None
 
             if len(values) > 1:
-                ref_value = int(values[0])
-                alt_value = int(values[1])
+                ref_value = (number_format)(values[0])
+                alt_value = (number_format)(values[1])
             if len(values) == 1:
-                alt_value = int(values[0])
+                alt_value = (number_format)(values[0])
             if ref_value >= 0:
                 ref = ref_value
             if alt_value >= 0:
@@ -322,3 +452,54 @@ def _parse_format_entry(variant, pos, format_entry_name):
         except (ValueError, TypeError) as _ignore_error:
             pass
     return (ref, alt)
+
+
+def _parse_format_entry_trgt_mc(variant: cyvcf2.Variant, pos: int):
+    """Parse genotype entry for TRGT FORMAT MC
+
+    The MC format contains the Motif Counts for each allele, separated with "," and each motif in an expansion,
+    as a "_" separated list of the different available enumerated motifs. For some loci,
+    only certain motifs count towards a pathologic size, and if so a PathologicStruc INFO key is passed.
+    E.g. for non-reference motifs and more complex loci or alleles with different motifs.
+    As usual, VCF lines are decomposed, so at most one alt is present per entry.
+    The GT position gives us a ref index for any allele 0 in the call.
+    """
+
+    mc_ref = None
+    mc_alt = None
+
+    if "MC" not in variant.FORMAT:
+        return (mc_ref, mc_alt)
+
+    mc = variant.format("MC")[pos]
+    if not mc:
+        return (mc_ref, mc_alt)
+
+    ref_idx = None
+    gt = variant.genotypes[pos]
+    if gt:
+        for idx, allele in enumerate(gt):
+            if allele == 0:
+                ref_idx = idx
+
+    pathologic_struc = variant.INFO.get("PathologicStruc", None)
+    pathologic_counts = 0
+    for idx, allele in enumerate(mc.split(",")):
+        mcs = allele.split("_")
+
+        if len(mcs) > 1:
+            pathologic_mcs = pathologic_struc or range(len(mcs))
+
+            for index, count in enumerate(mcs):
+                if index in pathologic_mcs:
+                    pathologic_counts += int(count)
+        else:
+            pathologic_counts = int(allele)
+
+        if ref_idx is not None and idx == ref_idx:
+            mc_ref = pathologic_counts
+            continue
+
+        mc_alt = pathologic_counts
+
+    return (mc_ref, mc_alt)
