@@ -1,4 +1,7 @@
 import logging
+from typing import Any, Dict, List, Optional
+
+from cyvcf2 import Variant
 
 from scout.constants import CHR_PATTERN
 from scout.exceptions import VcfError
@@ -11,7 +14,7 @@ from .compound import parse_compounds
 from .conservation import parse_conservations
 from .coordinates import parse_coordinates
 from .deleteriousness import parse_cadd
-from .frequency import parse_frequencies, parse_sv_frequencies
+from .frequency import parse_frequencies, parse_mei_frequencies, parse_sv_frequencies
 from .gene import parse_genes
 from .genotype import parse_genotypes
 from .ids import parse_ids
@@ -23,7 +26,7 @@ LOG = logging.getLogger(__name__)
 
 
 def parse_variant(
-    variant,
+    variant: Variant,
     case,
     variant_type="clinical",
     rank_results_header=None,
@@ -44,7 +47,7 @@ def parse_variant(
         vep_header(list)
         individual_positions(dict): Explain what position each individual has
                                     in vcf
-        category(str): 'snv', 'sv', 'str', 'cancer' or 'cancer_sv'
+        category(str): 'snv', 'sv', 'str', 'cancer', 'cancer_sv' or 'fusion'
         local_archive_info(dict): date and total count for local obs
     Returns:
          parsed_variant(dict): Parsed variant
@@ -140,44 +143,19 @@ def parse_variant(
     parsed_variant["azlength"] = call_safe(int, variant.INFO.get("AZLENGTH"))
     parsed_variant["azqual"] = call_safe(float, variant.INFO.get("AZQUAL"))
 
-    ################ Add STR info if present ################
-
-    # repeat id generally corresponds to gene symbol
-    parsed_variant["str_repid"] = call_safe(str, variant.INFO.get("REPID"))
-
-    # repeat unit - used e g in PanelApp naming of STRs
-    parsed_variant["str_ru"] = call_safe(str, variant.INFO.get("RU"))
-
-    # repeat unit - used e g in PanelApp naming of STRs
-    parsed_variant["str_display_ru"] = call_safe(str, variant.INFO.get("DisplayRU"))
-
-    # repeat ref - reference copy number
-    parsed_variant["str_ref"] = call_safe(int, variant.INFO.get("REF"))
-
-    # repeat len - number of repeats found in case
-    parsed_variant["str_len"] = call_safe(int, variant.INFO.get("RL"))
-
-    # str status - this indicates the severity of the expansion level
-    parsed_variant["str_status"] = call_safe(str, variant.INFO.get("STR_STATUS"))
-
-    # str normal max - max number of repeats to call an STR variant normal
-    parsed_variant["str_normal_max"] = call_safe(int, variant.INFO.get("STR_NORMAL_MAX"))
-
-    # str pathological min - min number of repeats to call an STR variant pathologic
-    parsed_variant["str_pathologic_min"] = call_safe(int, variant.INFO.get("STR_PATHOLOGIC_MIN"))
-
-    # str disease - disease name annotation
-    parsed_variant["str_disease"] = call_safe(str, variant.INFO.get("Disease"))
-
-    # str disease inheritance mode string annotation
-    parsed_variant["str_inheritance_mode"] = call_safe(str, variant.INFO.get("InheritanceMode"))
-
-    # str source dict with display string, source type and entry id
-    set_source(parsed_variant, variant)
-
+    # STR variant info
+    set_str_info(variant, parsed_variant)
+    # STR source dict with display string, source type and entry id
+    set_str_source(parsed_variant, variant)
     parsed_variant["str_swegen_mean"] = call_safe(float, variant.INFO.get("SweGenMean"))
     parsed_variant["str_swegen_std"] = call_safe(float, variant.INFO.get("SweGenStd"))
 
+    # MEI variant info
+    set_mei_info(variant, parsed_variant)
+
+    # Add Fusion info
+    set_fusion_info(variant, parsed_variant)
+
     ################# Add somatic info ##################
     parsed_variant["somatic_score"] = call_safe(int, variant.INFO.get("SOMATICSCORE"))
 
@@ -191,7 +169,10 @@ def parse_variant(
     parsed_variant["custom"] = parse_custom_data(variant.INFO.get("SCOUT_CUSTOM"))
 
     ### Add gene and transcript information
-    parsed_transcripts = add_gene_and_transcript_info(parsed_variant, variant, vep_header)
+    if parsed_variant.get("category") == "fusion":
+        parsed_transcripts = add_gene_and_transcript_info_for_fusions(parsed_variant)
+    else:
+        parsed_transcripts = add_gene_and_transcript_info(parsed_variant, variant, vep_header)
 
     ################# Add clinsig prediction #################
     set_clnsig(parsed_variant, variant, parsed_transcripts)
@@ -201,8 +182,15 @@ def parse_variant(
 
     parsed_variant["frequencies"] = frequencies
 
+    # loqus archive frequencies
+
+    # RD germline, for MIP and Balsamic
     # SNVs contain INFO field Obs, SVs contain clinical_genomics_loqusObs
-    local_obs_old = variant.INFO.get("Obs") or variant.INFO.get("clinical_genomics_loqusObs")
+    local_obs_old = (
+        variant.INFO.get("Obs")
+        or variant.INFO.get("clinical_genomics_loqusObs")
+        or variant.INFO.get("clin_obs")
+    )
     if local_obs_old:
         parsed_variant["local_obs_old"] = int(local_obs_old)
 
@@ -210,18 +198,30 @@ def parse_variant(
     parsed_variant["local_obs_hom_old"] = call_safe(int, variant.INFO.get("Hom"))
 
     # SVs only
-    parsed_variant["local_obs_old_freq"] = call_safe(
-        float, variant.INFO.get("clinical_genomics_loqusFrq")
-    )
+    local_frq_old = variant.INFO.get("clinical_genomics_loqusFrq") or variant.INFO.get("Frq")
+    parsed_variant["local_obs_old_freq"] = call_safe(float, local_frq_old)
     set_local_archive_info(parsed_variant, local_archive_info)
-    if local_archive_info and "Date" in local_archive_info:
-        parsed_variant["local_obs_old_date"] = local_archive_info.get("Date")
 
-    if local_archive_info and "NrCases" in local_archive_info:
-        parsed_variant["local_obs_old_nr_cases"] = local_archive_info.get("NrCases")
+    # Cancer (Balsamic) Germline and Somatic loqus archives
+    parsed_variant["local_obs_cancer_germline_old"] = call_safe(
+        int, variant.INFO.get("Cancer_Germline_Obs")
+    )
+    parsed_variant["local_obs_cancer_germline_hom_old"] = call_safe(
+        int, variant.INFO.get("Cancer_Germline_Hom")
+    )
+    parsed_variant["local_obs_cancer_germline_old_freq"] = call_safe(
+        float, variant.INFO.get("Cancer_Germline_Frq")
+    )
 
-    if local_archive_info and "Description" in local_archive_info:
-        parsed_variant["local_obs_old_desc"] = local_archive_info.get("Description")
+    parsed_variant["local_obs_cancer_somatic_old"] = call_safe(
+        int, variant.INFO.get("Cancer_Somatic_Obs")
+    )
+    parsed_variant["local_obs_cancer_somatic_hom_old"] = call_safe(
+        int, variant.INFO.get("Cancer_Somatic_Hom")
+    )
+    parsed_variant["local_obs_cancer_somatic_old_freq"] = call_safe(
+        float, variant.INFO.get("Cancer_Somatic_Frq")
+    )
 
     ###################### Add severity predictions ######################
     parsed_variant["cadd_score"] = parse_cadd(variant, parsed_transcripts)
@@ -229,12 +229,9 @@ def parse_variant(
 
     if len(parsed_transcripts) > 0:
         parsed_variant["revel_score"] = parsed_transcripts[0].get(
-            "revel"
+            "revel_rankscore"
         )  # This is actually the value of REVEL_rankscore
-
-        parsed_variant["revel"] = parsed_transcripts[0].get(
-            "revel_score"
-        )  # This is actually the value of REVEL_score
+        parsed_variant["revel"] = get_highest_revel_score(parsed_transcripts)
 
     ###################### Add conservation ######################
     parsed_variant["conservation"] = parse_conservations(variant, parsed_transcripts)
@@ -246,6 +243,11 @@ def parse_variant(
     for key in sv_frequencies:
         parsed_variant["frequencies"][key] = sv_frequencies[key]
 
+    ###################### Add MEI specific annotations #####################
+    mei_frequencies = parse_mei_frequencies(variant)
+    for key in mei_frequencies:
+        parsed_variant["frequencies"][key] = mei_frequencies[key]
+
     ###################### Add Cancer specific annotations ######################
     # MSK_MVL indicates if variants are in the MSK managed variant list
     # https://www.ncbi.nlm.nih.gov/pmc/articles/PMC5437632/
@@ -256,6 +258,15 @@ def parse_variant(
     return parsed_variant
 
 
+def get_highest_revel_score(parsed_transcripts: List[dict]) -> Optional[float]:
+    """Retrieve the highest REVEL_score value from parsed variant transcripts."""
+    tx_revel_scores: List(float) = [
+        tx.get("revel_raw_score") for tx in parsed_transcripts if tx.get("revel_raw_score") != None
+    ]
+    if tx_revel_scores:
+        return max(tx_revel_scores)
+
+
 def get_genmod_key(case):
     """Gen genmod key
 
@@ -266,7 +277,6 @@ def get_genmod_key(case):
     """
     case_id = case["_id"]
     if "-" in case_id:
-        LOG.debug("iCase ID contains '-'. Using display_name as case _id.")
         return case["display_name"]
     return case["_id"]
 
@@ -287,6 +297,40 @@ def get_variant_alternative(variant, category):
         return "."
 
 
+def set_mei_info(variant: Variant, parsed_variant: Dict[str, Any]):
+    """
+    ################# Add MEI info ##################
+    """
+    mei_info = parse_mei_info(variant.INFO.get("MEINFO"))
+    if mei_info:
+        parsed_variant["mei_name"] = mei_info["name"]
+        parsed_variant["mei_polarity"] = mei_info["polarity"]
+
+
+def parse_mei_info(mei_info: str) -> Optional[dict]:
+    """Parse variants MEINFO field into a mei info dict
+
+    <ID=MEINFO,Number=4,Type=String,Description="Mobile element info of the form NAME,START,END,POLARITY">
+
+    Returns:
+        mei info dict with keys name, start, end, polariry.
+    """
+
+    if not mei_info:
+        return
+
+    mei = mei_info.split(",")
+    if len(mei) != 4:
+        return
+
+    return {
+        "name": mei[0],
+        "start": mei[1],
+        "end": mei[2],
+        "polarity": mei[3],
+    }
+
+
 def get_filters(variant):
     """Get variant filters
 
@@ -348,12 +392,149 @@ def set_dbsnp_id(parsed_variant, variant_id):
         parsed_variant["dbsnp_id"] = variant_id
 
 
-def set_source(parsed_variant, variant):
-    """Set source in parsed_variant
-    Args:
-        parsed_variant(dict)
-        variant(cyvcf2.Variant)
+def set_str_info(variant: Variant, parsed_variant: Dict[str, Any]):
     """
+    ################ Add STR info if present ################
+    """
+    # repeat id generally corresponds to gene symbol
+    parsed_variant["str_repid"] = call_safe(str, variant.INFO.get("REPID"))
+
+    # repeat id from trgt - generally corresponds to gene symbol and/or disease
+    parsed_variant["str_trid"] = call_safe(str, variant.INFO.get("TRID"))
+
+    # repeat unit - used e g in PanelApp naming of STRs
+    parsed_variant["str_struc"] = call_safe(str, variant.INFO.get("STRUC"))
+
+    # repeat motif(s) - used e g in TRGT MC motif splits
+    parsed_variant["str_motifs"] = call_safe(str, variant.INFO.get("MOTIFS"))
+
+    # repeat pathologic motifs structure - list of indicies of pathologic motifs counting towards MC
+    parsed_variant["str_pathologic_struc"] = call_safe(str, variant.INFO.get("PathologicStruc"))
+
+    # repeat unit - used e g in PanelApp naming of STRs
+    parsed_variant["str_ru"] = call_safe(str, variant.INFO.get("RU"))
+
+    # repeat unit - used e g in PanelApp naming of STRs
+    parsed_variant["str_display_ru"] = call_safe(str, variant.INFO.get("DisplayRU"))
+
+    # repeat ref - reference copy number
+    parsed_variant["str_ref"] = call_safe(int, variant.INFO.get("REF"))
+
+    # repeat len - number of repeats found in case
+    parsed_variant["str_len"] = call_safe(int, variant.INFO.get("RL"))
+
+    # str status - this indicates the severity of the expansion level
+    parsed_variant["str_status"] = call_safe(str, variant.INFO.get("STR_STATUS"))
+
+    # str normal max - max number of repeats to call an STR variant normal
+    parsed_variant["str_normal_max"] = call_safe(int, variant.INFO.get("STR_NORMAL_MAX"))
+
+    # str pathological min - min number of repeats to call an STR variant pathologic
+    parsed_variant["str_pathologic_min"] = call_safe(int, variant.INFO.get("STR_PATHOLOGIC_MIN"))
+
+    # str disease - disease name annotation
+    parsed_variant["str_disease"] = call_safe(str, variant.INFO.get("Disease"))
+
+    # str disease inheritance mode string annotation
+    parsed_variant["str_inheritance_mode"] = call_safe(str, variant.INFO.get("InheritanceMode"))
+
+
+def set_fusion_info(variant: Variant, parsed_variant: Dict[str, Any]):
+    """Add Fusion information if present."""
+
+    def replace_nan(value: str, nan_value: str = "nan", replace_by: Any = "") -> str:
+        if value == nan_value:
+            return replace_by
+        else:
+            return value
+
+    def set_found_db(found_db_info: Optional[str]) -> Optional[List[str]]:
+        """Set the found_db value according to the value found in the VCF."""
+        if found_db_info not in [None, "[]", ""]:
+            return found_db_info.split(",")
+
+    parsed_variant["gene_a"] = call_safe(str, variant.INFO.get("GENEA", ""))
+    parsed_variant["gene_b"] = call_safe(str, variant.INFO.get("GENEB", ""))
+    parsed_variant["tool_hits"] = call_safe(int, variant.INFO.get("TOOL_HITS", 0))
+    parsed_variant["found_db"] = set_found_db(call_safe(str, variant.INFO.get("FOUND_DB")))
+    parsed_variant["fusion_score"] = call_safe(float, variant.INFO.get("SCORE", None))
+    parsed_variant["hgnc_id_a"] = call_safe(int, variant.INFO.get("HGNC_ID_A", 0))
+    parsed_variant["hgnc_id_b"] = call_safe(int, variant.INFO.get("HGNC_ID_B", 0))
+    parsed_variant["orientation"] = replace_nan(
+        call_safe(str, variant.INFO.get("ORIENTATION", "")), nan_value="nan,nan"
+    )
+    parsed_variant["frame_status"] = call_safe(
+        str, replace_nan(variant.INFO.get("FRAME_STATUS", ""))
+    )
+    parsed_variant["transcript_id_a"] = call_safe(
+        str, replace_nan(variant.INFO.get("TRANSCRIPT_ID_A", ""))
+    )
+    parsed_variant["transcript_id_b"] = call_safe(
+        str, replace_nan(variant.INFO.get("TRANSCRIPT_ID_B", ""))
+    )
+    parsed_variant["exon_number_a"] = call_safe(
+        str, call_safe(int, replace_nan(variant.INFO.get("EXON_NUMBER_A", "")))
+    )
+    parsed_variant["exon_number_b"] = call_safe(
+        str, call_safe(int, replace_nan(variant.INFO.get("EXON_NUMBER_B", "")))
+    )
+    parsed_variant["fusion_genes"] = [parsed_variant["gene_a"], parsed_variant["gene_b"]]
+
+
+def add_gene_and_transcript_info_for_fusions(
+    parsed_variant: Dict[str, Any]
+) -> List[Optional[Dict]]:
+    """Add gene and transcript info for fusions. Return list of parsed
+    transcripts for later use in parsing.
+        Args:
+            parsed_variant(dict)
+        Return:
+            parsed_transcripts(list)
+    """
+
+    parsed_transcripts = []
+    genes = []
+    hgnc_ids = []
+    hgnc_symbols = []
+
+    for suffix in ["a", "b"]:
+        # If fusions have transcript information about a fusion partner
+        parsed_transcript = {}
+        if parsed_variant.get(f"transcript_id_{suffix}"):
+            # Add transcript info to genes if available
+            parsed_transcript = {
+                "transcript_id": parsed_variant[f"transcript_id_{suffix}"],
+                "hgnc_id": parsed_variant[f"hgnc_id_{suffix}"],
+                "hgnc_symbol": parsed_variant[f"gene_{suffix}"],
+                "exon": parsed_variant[f"exon_number_{suffix}"],
+            }
+            parsed_transcripts.append(parsed_transcript)
+
+        if parsed_variant.get(f"hgnc_id_{suffix}"):
+            if parsed_variant.get(f"gene_{suffix}"):
+                # Add hgnc_symbol to variant if available
+                hgnc_symbols.append(parsed_variant.get(f"gene_{suffix}"))
+
+            # Add hgnc_id to variant if available
+            hgnc_ids.append(parsed_variant.get(f"hgnc_id_{suffix}"))
+
+            genes.append(
+                {
+                    "hgnc_symbol": parsed_variant[f"gene_{suffix}"],
+                    "hgnc_id": parsed_variant[f"hgnc_id_{suffix}"],
+                    "transcripts": [parsed_transcript] if parsed_transcript else [],
+                }
+            )
+
+    parsed_variant["genes"] = genes
+    parsed_variant["hgnc_ids"] = hgnc_ids
+    parsed_variant["hgnc_symbols"] = hgnc_symbols
+
+    return parsed_transcripts
+
+
+def set_str_source(parsed_variant: Dict[str, Any], variant: Variant):
+    """Set source in parsed_variant"""
     str_source_display = variant.INFO.get("SourceDisplay")
     str_source_type = variant.INFO.get("Source")
     str_source_id = variant.INFO.get("SourceId")
