@@ -1,14 +1,16 @@
 """Code for flask app"""
+
 import logging
 import os
 from datetime import timedelta
+from typing import Dict, Union
+from urllib.parse import parse_qsl, unquote, urlsplit
 
 import coloredlogs
-from flask import Flask, current_app, redirect, request, url_for
-from flask_babel import Babel
+from flask import Flask, redirect, request, url_for
 from flask_cors import CORS
 from flask_login import current_user
-from flaskext.markdown import Markdown
+from markdown import markdown as python_markdown
 from markupsafe import Markup
 
 from . import extensions
@@ -23,6 +25,7 @@ from .blueprints import (
     institutes,
     login,
     managed_variants,
+    omics_variants,
     panels,
     phenomodels,
     phenotypes,
@@ -31,24 +34,8 @@ from .blueprints import (
     variants,
 )
 
-try:
-    from urllib.parse import unquote
-except ImportError:
-    from urllib2 import unquote
-
-
 LOG = logging.getLogger(__name__)
 
-try:
-    from chanjo_report.server.app import configure_template_filters
-    from chanjo_report.server.blueprints import report_bp
-    from chanjo_report.server.extensions import api as chanjo_api
-except ImportError:
-    chanjo_api = None
-    report_bp = None
-    configure_template_filters = None
-    LOG.info("chanjo report not installed!")
-
 
 def create_app(config_file=None, config=None):
     """Flask app factory function."""
@@ -72,6 +59,7 @@ def create_app(config_file=None, config=None):
         app.config["REMEMBER_COOKIE_DURATION"] = session_duration
 
     app.json.sort_keys = False
+
     current_log_level = LOG.getEffectiveLevel()
     coloredlogs.install(level="DEBUG" if app.debug else current_log_level)
     configure_extensions(app)
@@ -111,12 +99,11 @@ def configure_extensions(app):
     extensions.store.init_app(app)
     extensions.login_manager.init_app(app)
     extensions.mail.init_app(app)
-
-    Markdown(app)
+    extensions.clinvar_api.init_app(app)
 
     if app.config.get("SQLALCHEMY_DATABASE_URI"):
+        extensions.chanjo_report.init_app(app)
         LOG.info("Chanjo extension enabled")
-        configure_coverage(app)
 
     if app.config.get("LOQUSDB_SETTINGS"):
         LOG.info("LoqusDB enabled")
@@ -161,14 +148,18 @@ def configure_extensions(app):
         # setup connection to google oauth2
         configure_oauth_login(app)
 
-    if app.config.get("CLOUD_IGV_TRACKS"):
-        LOG.info("Collecting IGV tracks from cloud resources")
-        extensions.cloud_tracks.init_app(app)
+    if app.config.get("CUSTOM_IGV_TRACKS") or app.config.get("CLOUD_IGV_TRACKS"):
+        LOG.info("Collecting IGV tracks from cloud or local resources")
+        extensions.config_igv_tracks.init_app(app)
 
     if app.config.get("PHENOPACKET_API_URL"):
         LOG.info("Enable Phenopacket API")
         extensions.phenopacketapi.init_app(app)
 
+    if app.config.get("BIONANO_ACCESS"):
+        LOG.info("Enable BioNano Access API")
+        extensions.bionano_access.init_app(app)
+
 
 def register_blueprints(app):
     """Register Flask blueprints."""
@@ -188,9 +179,18 @@ def register_blueprints(app):
     app.register_blueprint(diagnoses.omim_bp)
     app.register_blueprint(institutes.overview)
     app.register_blueprint(managed_variants.managed_variants_bp)
+    app.register_blueprint(omics_variants.omics_variants_bp)
 
 
 def register_filters(app):
+    @app.template_filter()
+    def human_longint(value: Union[int, str]) -> str:
+        """Convert a long integers int or string representation into a human easily readable number."""
+        value = str(value)
+        if value.isnumeric():
+            return "{:,}".format(int(value)).replace(",", "&thinsp;")
+        return value
+
     @app.template_filter()
     def human_decimal(number, ndigits=4):
         """Return a standard representation of a decimal number.
@@ -213,11 +213,15 @@ def register_filters(app):
             return 0
         if number < min_number:
             # make human readable and sane
-            return "< {}".format(min_number)
+            return "<{}".format(min_number)
 
         # round all other numbers
         return round(number, ndigits)
 
+    @app.template_filter()
+    def markdown(text: str) -> Markup:
+        return Markup(python_markdown(text))
+
     @app.template_filter()
     def tuple_list_to_dict(tuple_list, key_elem, value_elem):
         """Accepts a list of tuples and returns a dictionary with tuple element = key_elem as keys and tuple element = value_elem as values"""
@@ -229,6 +233,11 @@ def register_filters(app):
         """Decode a string with encoded hex values."""
         return unquote(string)
 
+    @app.template_filter()
+    def url_args(url: str) -> Dict[str, str]:
+        """Return all arguments and values present in a string URL."""
+        return dict(parse_qsl(urlsplit(url).query))
+
     @app.template_filter()
     def cosmic_prefix(cosmicId):
         """If cosmicId is an integer, add 'COSM' as prefix
@@ -244,6 +253,16 @@ def register_filters(app):
         cursor_copy = pymongo_cursor.clone()
         return len(list(cursor_copy))
 
+    @app.template_filter()
+    def list_intersect(list1, list2) -> list:
+        """Returns the elements that are common in 2 lists"""
+        return list(set(list1) & set(list2))
+
+    @app.template_filter()
+    def list_remove_none(in_list: list) -> list:
+        """Returns a list after removing any None values from it."""
+        return [item for item in in_list if item is not None]
+
 
 def register_tests(app):
     @app.template_test("existing")
@@ -292,38 +311,3 @@ def configure_email_logging(app):
         )
     )
     app.logger.addHandler(mail_handler)
-
-
-def configure_coverage(app):
-    """Setup coverage related extensions."""
-    # setup chanjo report
-    app.config["SQLALCHEMY_TRACK_MODIFICATIONS"] = True if app.debug else False
-    if chanjo_api:
-        chanjo_api.init_app(app)
-        configure_template_filters(app)
-        # register chanjo report blueprint
-        app.register_blueprint(report_bp, url_prefix="/reports")
-
-    babel = Babel()
-
-    def get_locale():
-        """Determine locale to use for translations."""
-        accept_languages = current_app.config.get("ACCEPT_LANGUAGES", ["en"])
-
-        # first check request args
-        session_language = Markup.escape(request.args.get("lang"))
-        if session_language in accept_languages:
-            current_app.logger.info("using session language: %s", session_language)
-            return session_language
-
-        # language can be forced in config
-        user_language = current_app.config.get("REPORT_LANGUAGE")
-        if user_language:
-            return user_language
-
-        # try to guess the language from the user accept header that
-        # the browser transmits.  We support de/fr/en in this example.
-        # The best match wins.
-        return request.accept_languages.best_match(accept_languages)
-
-    babel.init_app(app, locale_selector=get_locale)
