@@ -4,12 +4,15 @@ import json
 import logging
 import os.path
 import shutil
+from ast import literal_eval
 from io import BytesIO
 from operator import itemgetter
+from typing import Generator, Optional, Union
 
 from cairosvg import svg2png
 from flask import (
     Blueprint,
+    Response,
     abort,
     current_app,
     flash,
@@ -24,12 +27,14 @@ from flask import (
 from flask_login import current_user
 
 from scout.constants import DATE_DAY_FORMATTER
+from scout.server.blueprints.variants.controllers import activate_case
 from scout.server.extensions import beacon, phenopacketapi, store
 from scout.server.utils import (
     html_to_pdf_file,
     institute_and_case,
     jsonconverter,
     templated,
+    user_cases,
     user_institutes,
     zip_dir_to_obj,
 )
@@ -52,25 +57,57 @@ cases_bp = Blueprint(
 @templated("cases/index.html")
 def index():
     """Display a list of all user institutes."""
-    institute_objs = user_institutes(store, current_user)
-    institutes_count = (
-        (institute_obj, sum(1 for i in store.cases(collaborator=institute_obj["_id"])))
-        for institute_obj in institute_objs
-        if institute_obj
-    )
-    return dict(institutes=institutes_count)
+
+    institutes_cases_count = []
+
+    institute_ids_nr_cases: dict[str, int] = {
+        item["_id"]["institute"]: item["count"] for item in user_cases(store, current_user)
+    }  # Don't include institutes without cases
+
+    for institute_obj in sorted(user_institutes(store, current_user), key=lambda d: d["_id"]):
+        institute_id = institute_obj["_id"]
+        if institute_id not in institute_ids_nr_cases:  # Institute doesn't have any case
+            institutes_cases_count.append((institute_obj, 0))
+        else:
+            institutes_cases_count.append((institute_obj, institute_ids_nr_cases[institute_id]))
+
+    return dict(institutes=institutes_cases_count)
 
 
 @cases_bp.route("/<institute_id>/<case_name>")
+@cases_bp.route("/case/case_id/<case_id>")
 @templated("cases/case.html")
-def case(institute_id, case_name):
-    """Display one case."""
+def case(
+    case_name: Optional[str] = None,
+    institute_id: Optional[str] = None,
+    case_id: Optional[str] = None,
+):
+    """Display one case.
+    Institute and display_name pairs uniquely specify a case.
+    So do case_id, but we still call institute_and_case again to fetch institute
+    and reuse its user access verification.
+    """
+    if case_id:
+        case_obj = store.case(case_id=case_id, projection={"display_name": 1, "owner": 1})
+
+        if not case_obj:
+            flash("Case {} does not exist in database!".format(case_id))
+            return abort(404)
+
+        case_name = case_obj.get("display_name")
+        institute_id = case_obj.get("owner")
+
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
     if not case_obj:
         flash("Case {} does not exist in database!".format(case_name))
         return redirect(request.referrer)
 
-    data = controllers.case(store, institute_obj, case_obj)
+    hide_matching = (
+        literal_eval(request.args.get("hide_matching"))
+        if request.args.get("hide_matching")
+        else True
+    )
+    data = controllers.case(store, institute_obj, case_obj, hide_matching)
 
     return dict(
         **data,
@@ -82,7 +119,22 @@ def case(institute_id, case_name):
 def sma(institute_id, case_name):
     """Visualize case SMA data - SMN CN calls"""
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
-    data = controllers.case(store, institute_obj, case_obj)
+    data = controllers.sma_case(store, institute_obj, case_obj)
+
+    activate_case(store, institute_obj, case_obj, current_user)
+
+    return dict(format="html", **data)
+
+
+@cases_bp.route("/<institute_id>/<case_name>/bionano", methods=["GET"])
+@templated("cases/case_bionano.html")
+def bionano(institute_id, case_name):
+    """Visualize case BioNano data - FSHD calls"""
+    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+    data = controllers.bionano_case(store, institute_obj, case_obj)
+
+    activate_case(store, institute_obj, case_obj, current_user)
+
     return dict(format="html", **data)
 
 
@@ -198,31 +250,33 @@ def case_synopsis(institute_id, case_name):
 @cases_bp.route("/api/v1/<institute_id>/<case_name>/case_report", methods=["GET"])
 def api_case_report(institute_id, case_name):
     """API endpoint that returns case report json data"""
-    data = controllers.case_report_content(store, institute_id, case_name)
-    json_data = json.dumps({"data": data}, default=jsonconverter)
-    return json_data
+    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+    data = controllers.case_report_content(
+        store=store, institute_obj=institute_obj, case_obj=case_obj
+    )
+    return json.dumps({"data": data}, default=jsonconverter)
 
 
 @cases_bp.route("/<institute_id>/<case_name>/case_report", methods=["GET"])
 @templated("cases/case_report.html")
 def case_report(institute_id, case_name):
-    """Visualize case report"""
-    data = controllers.case_report_content(store, institute_id, case_name)
+    """Visualize case report."""
+    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+    data = controllers.case_report_content(
+        store=store, institute_obj=institute_obj, case_obj=case_obj
+    )
     return dict(format="html", **data)
 
 
 @cases_bp.route("/<institute_id>/<case_name>/pdf_report", methods=["GET"])
 def pdf_case_report(institute_id, case_name):
     """Download a pdf report for a case"""
-
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
-    data = controllers.case_report_content(store, institute_id, case_name)
-
+    data = controllers.case_report_content(
+        store=store, institute_obj=institute_obj, case_obj=case_obj
+    )
     # add coverage report on the bottom of this report
-    if (
-        current_app.config.get("SQLALCHEMY_DATABASE_URI")
-        and case_obj.get("track", "rare") != "cancer"
-    ):
+    if current_app.config.get("chanjo_report") and case_obj.get("track", "rare") != "cancer":
         data["coverage_report"] = controllers.coverage_report_contents(
             request.url_root, institute_obj, case_obj
         )
@@ -298,21 +352,19 @@ def case_diagnosis(institute_id, case_name):
     user_obj = store.user(current_user.email)
     link = url_for(".case", institute_id=institute_id, case_name=case_name)
 
-    omim_id = request.form["omim_term"].split("|")[0]
-    omim_inds = request.form.getlist("omim_inds")  # Individual-level phenotypes
+    disease_id = request.form["disease_term"].split("|")[0]
+    affected_inds = request.form.getlist("affected_inds")  # Individual-level phenotypes
 
-    if not "OMIM:" in omim_id:  # Could be an omim number provided by user
-        omim_id = ":".join(["OMIM", omim_id])
-
-    # Make sure omim term exists in database:
-    omim_obj = store.disease_term(omim_id.strip())
-    if omim_obj is None:
-        flash("Couldn't find any disease term with id: {}".format(omim_id), "warning")
-        return redirect(request.referrer)
-
-    remove = True if request.args.get("remove") == "yes" else False
-    store.diagnose(institute_obj, case_obj, user_obj, link, omim_obj, omim_inds, remove)
-    return redirect("#".join([link, "omim_assign"]))
+    store.diagnose(
+        institute=institute_obj,
+        case=case_obj,
+        user=user_obj,
+        link=link,
+        disease_id=disease_id.strip(),
+        affected_inds=affected_inds,
+        remove=True if request.args.get("remove") == "yes" else False,
+    )
+    return redirect("#".join([link, "disease_assign"]))
 
 
 @cases_bp.route("/<institute_id>/<case_name>/phenotypes", methods=["POST"])
@@ -406,23 +458,21 @@ def phenotype_import(institute_id, case_name):
         flash("Please provide a phenotype file (json or hash format)", "warning")
         return redirect("#".join([case_url, "phenotypes_panel"]))
 
-    if phenopacket_file:
-        phenopacket = phenopacketapi.file_import(phenopacket_file)
+    try:
+        if phenopacket_file:
+            phenopacket = phenopacketapi.file_import(phenopacket_file)
 
-    phenopacket_hash = request.form.get("phenopacket_hash")
+        if phenopacket_hash:
+            phenopacket = phenopacketapi.get_hash(phenopacket_hash)
 
-    if phenopacket_hash:
-        phenopacket = phenopacketapi.get_hash(phenopacket_hash)
-
-    if phenopacket is None:
-        flash("An error occurred while retrieving Phenopacket info", "warning")
-
-    else:
         phenopacketapi.add_phenopacket_to_case(
             store, institute_obj, case_obj, user_obj, case_url, phenopacket
         )
+        return redirect("#".join([case_url, "phenotypes_panel"]))
 
-    return redirect("#".join([case_url, "phenotypes_panel"]))
+    except Exception as ex:
+        flash(f"An error occurred while retrieving Phenopacket info: {ex}", "warning")
+        return redirect(case_url)
 
 
 @cases_bp.route("/<institute_id>/<case_name>/phenotypes/actions", methods=["POST"])
@@ -537,6 +587,10 @@ def status(institute_id, case_name):
     else:
         store.update_status(institute_obj, case_obj, user_obj, status, link)
 
+    tags = request.form.getlist("tags")
+    if tags or case_obj.get("tags") and tags != case_obj.get("tags"):
+        store.tag_case(institute_obj, case_obj, user_obj, tags, link)
+
     return redirect(request.referrer)
 
 
@@ -547,9 +601,9 @@ def assign(institute_id, case_name, user_id=None, inactivate=False):
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
     link = url_for(".case", institute_id=institute_id, case_name=case_name)
     if user_id:
-        user_obj = store.user(user_id)
+        user_obj = store.user(user_id=user_id)
     else:
-        user_obj = store.user(current_user.email)
+        user_obj = store.user(email=current_user.email)
     if request.form.get("action") == "DELETE":
         store.unassign(institute_obj, case_obj, user_obj, link, inactivate)
     else:
@@ -598,12 +652,13 @@ def hpoterms():
     return jsonify(json_terms)
 
 
-@cases_bp.route("/api/v1/omim-terms")
-def omimterms():
+@cases_bp.route("/api/v1/disease-terms")
+def diseaseterms():
     query = request.args.get("query")
+    source = request.args.get("source") or None
     if query is None:
         return abort(500)
-    terms = store.query_omim(query=query)
+    terms = store.query_disease(query=query, source=source)
     json_terms = [
         {"name": "{} | {}".format(term["_id"], term["description"]), "id": term["_id"]}
         for term in terms[:7]
@@ -677,6 +732,9 @@ def mark_causative(institute_id, case_name, variant_id, partial_causative=False)
             )
         else:
             store.mark_causative(institute_obj, case_obj, user_obj, link, variant_obj)
+        if "tags" in request.form:
+            tags = request.form.getlist("tags")
+            store.tag_case(institute_obj, case_obj, user_obj, tags, link)
     elif request.form["action"] == "DELETE":
         if partial_causative == "True":
             store.unmark_partial_causative(institute_obj, case_obj, user_obj, link, variant_obj)
@@ -1003,7 +1061,7 @@ def host_chr_image(institute_id, case_name, individual, image):
 
 
 def host_image_aux(institute_id, case_name, individual, image, key):
-    """Auxilary function for generate absolute file paths"""
+    """Auxiliary function for generate absolute file paths"""
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
     # Find path
     for ind in case_obj["individuals"]:
@@ -1021,6 +1079,26 @@ def host_image_aux(institute_id, case_name, individual, image, key):
                 return redirect("/public/static/file-earmark-x.svg")
 
 
+@cases_bp.route("/<institute_id>/<case_name>/custom_images")
+def host_custom_image_aux(institute_id: str, case_name: str) -> Optional[Response]:
+    """Adds absolute path to a custom image path and returns the image."""
+
+    def custom_images_paths(d: Union[dict, list]) -> Generator:
+        """returns all paths saved under custom images for a case - both case images and variant images."""
+        for v in d.values():
+            if isinstance(v, dict):
+                yield from custom_images_paths(v)
+            elif isinstance(v, list):
+                for image in v:
+                    yield image.get("path")
+
+    _, case_obj = institute_and_case(store, institute_id, case_name)
+    custom_images_values: list = list(custom_images_paths(case_obj.get("custom_images", {})))
+    if request.args.get("image_path") in custom_images_values:
+        abs_path: str = os.path.abspath(request.args.get("image_path"))
+        return send_file(abs_path)
+
+
 def _generate_csv(header, lines):
     """Download a text file composed of any header and lines"""
     yield header + "\n"
