@@ -2,11 +2,19 @@ import csv
 import logging
 from datetime import datetime
 from tempfile import NamedTemporaryFile
+from typing import List, Optional
 
-from flask import current_app, flash
+from flask import flash
+from flask_login import current_user
+from werkzeug.datastructures import ImmutableMultiDict
 
 from scout.constants.acmg import ACMG_MAP
-from scout.constants.clinvar import CASEDATA_HEADER, CLINVAR_HEADER, SCOUT_CLINVAR_SV_TYPES_MAP
+from scout.constants.clinvar import (
+    CASEDATA_HEADER,
+    CLINVAR_HEADER,
+    CONDITION_PREFIX,
+    SCOUT_CLINVAR_SV_TYPES_MAP,
+)
 from scout.constants.variant_tags import MANUAL_RANK_OPTIONS
 from scout.models.clinvar import clinvar_variant
 from scout.server.extensions import clinvar_api, store
@@ -65,12 +73,21 @@ def _set_var_form_common_fields(var_form, variant_obj, case_obj):
         var_form.gene_symbol.data = ",".join(variant_obj.get("hgnc_symbols", []))
     var_form.last_evaluated.data = datetime.now()
     var_form.hpo_terms.choices = [
-        (hpo.get("phenotype_id"), " - ".join([hpo.get("phenotype_id"), hpo.get("feature")]))
+        (
+            hpo.get("phenotype_id").replace("HP:", ""),
+            " - ".join([hpo.get("phenotype_id"), hpo.get("feature")]),
+        )
         for hpo in case_obj.get("phenotype_terms", [])
     ]
     var_form.omim_terms.choices = [
-        (omim.get("disease_nr"), " - ".join([str(omim.get("disease_nr")), omim.get("description")]))
-        for omim in case_obj.get("diagnosis_phenotypes", [])
+        (term.get("disease_nr"), " - ".join([str(term.get("disease_nr")), term.get("description")]))
+        for term in case_obj.get("diagnosis_phenotypes", [])
+        if term["disease_id"].startswith("OMIM")
+    ]
+    var_form.orpha_terms.choices = [
+        (term.get("disease_nr"), " - ".join([str(term.get("disease_nr")), term.get("description")]))
+        for term in case_obj.get("diagnosis_phenotypes", [])
+        if term["disease_id"].startswith("ORPHA")
     ]
 
 
@@ -90,7 +107,7 @@ def _get_snv_var_form(variant_obj, case_obj):
     var_form.variations_ids.data = var_ids.split(";")[0]
     var_form.chromosome.data = variant_obj.get("chromosome")
     var_form.start.data = variant_obj.get("position")
-    var_form.stop.data = variant_obj.get("position")
+    var_form.stop.data = variant_obj.get("end")
     return var_form
 
 
@@ -219,20 +236,22 @@ def _parse_tx_hgvs(clinvar_var, form):
     clinvar_var["hgvs"] = tx_hgvs.split(":")[1]
 
 
-def _set_conditions(clinvar_var, form):
-    """Set condition_id_type and condition_id_value for a clinvar variant
+def _set_conditions(clinvar_var: dict, form: ImmutableMultiDict):
+    """Set condition_id_type and condition_id_values for a ClinVar variant."""
 
-    Args:
-        clinvar_var(dict): scout.models.clinvar.clinvar_variant
-        form(werkzeug.datastructures.ImmutableMultiDic)
-    """
-    clinvar_var["condition_id_type"] = form.get("condition_type")
-    clinvar_var["condition_id_value"] = ";".join(form.getlist("conditions"))
+    condition_db: str = form.get("condition_type")
+    clinvar_var["condition_id_type"] = condition_db
+    condition_prefix: str = CONDITION_PREFIX[condition_db]
+    clinvar_var["condition_id_value"] = ";".join(
+        [f"{condition_prefix}{condition_id}" for condition_id in form.getlist("conditions")]
+    )
+    if bool(form.get("multiple_condition_explanation")):
+        clinvar_var["explanation_for_multiple_conditions"] = form["multiple_condition_explanation"]
 
 
 def parse_variant_form_fields(form):
     """Parses input values provided by the user in the ClinVar add_one form
-       and creates a Variant ClinVar dictionary to be saved in database (clinvar collection)
+       and creates a Variant ClinVar dictionary to be saved in database (ClinVar collection)
 
     Args:
         form(werkzeug.datastructures.ImmutableMultiDic): form submitted by a user
@@ -248,13 +267,16 @@ def parse_variant_form_fields(form):
             clinvar_var[key] = form[key]
 
     clinvar_var["_id"] = "_".join([form["case_id"], form["local_id"]])
+    clinvar_var["assertion_method_cit"] = ":".join(
+        [form["assertion_method_cit_db"], form["assertion_method_cit_id"]]
+    )
     _parse_tx_hgvs(clinvar_var, form)
     _set_conditions(clinvar_var, form)
     if form.get("dbsnp_id"):
         clinvar_var["variations_ids"] = form["dbsnp_id"]
 
     if clinvar_var.get("ref_seq") and clinvar_var.get("hgvs"):
-        # Variant is described by RefSeq and HGVS already, remove redundanti fields from submission
+        # Variant is described by RefSeq and HGVS already, remove redundant fields from submission
         for item in ["chromosome", "start", "stop", "ref", "alt"]:
             clinvar_var.pop(item)
 
@@ -329,9 +351,10 @@ def update_clinvar_submission_status(request_obj, institute_id, submission_id):
 
     if update_status in ["open", "closed", "submitted"]:  # open or close a submission
         store.update_clinvar_submission_status(institute_id, submission_id, update_status)
-    if update_status == "register_id":  # register an official clinvar submission ID
+    if update_status == "register_id":  # register an official ClinVar submission ID
+        clinvar_id: str = request_obj.form.get("clinvar_id").replace(" ", "") or None
         store.update_clinvar_id(
-            clinvar_id=request_obj.form.get("clinvar_id"),
+            clinvar_id=clinvar_id if clinvar_id else None,
             submission_id=submission_id,
         )
     if update_status == "delete":  # delete a submission
@@ -396,33 +419,6 @@ def json_api_submission(submission_id):
         return clinvar_api.convert_to_json(variant_file.name, casedata_file.name, extra_params)
 
 
-def validate_submission(submission_id):
-    """Validate a submission object and documents using the ClinVar API
-
-    Args:
-        submission_id(str): the database id of a clinvar submission
-
-    Returns:
-        str/None: A submission ID (i.e. SUB2192122) or None if submission was not validated
-    """
-    # Convert submission objects to json:
-    code, conversion_res = json_api_submission(submission_id)
-
-    if code != 200:  # Connection or conversion object errors
-        flash(str(conversion_res), "warning")
-        return
-
-    code, valid_res = clinvar_api.validate_json(
-        subm_data=conversion_res, api_key=current_app.config.get("CLINVAR_API_KEY")
-    )
-
-    if code != 201:  # Connection or conversion object errors
-        flash(str(valid_res.__dict__), "warning")
-        return
-
-    return valid_res.json().get("id")
-
-
 def send_api_submission(institute_id, submission_id, key):
     """Convert and validate ClinVar submission data to json.
        If json submission is validated, submit it using the ClinVar API
@@ -439,19 +435,37 @@ def send_api_submission(institute_id, submission_id, key):
         flash(str(conversion_res), "warning")
         return
 
-    # Send submission with the same name (SUBxyz) that was assigned by ClinVar
-    conversion_res["submissionName"] = store.get_clinvar_id(submission_id)
+    clinvar_id = store.get_clinvar_id(
+        submission_id
+    )  # This is the official ID associated with this submission in Clinvar (ex: SUB999999)
 
-    code, submit_res = clinvar_api.submit_json(conversion_res, key)
+    if clinvar_id:  # Check if submission object has already an associated ClinVar ID
+        conversion_res["submissionName"] = clinvar_id
 
-    if code in [200, 201, 204]:  # 204 is returned only for dry runs - used for testing
-        flash("Submission saved successfully", "success")
+    service_url, code, submit_res = clinvar_api.submit_json(conversion_res, key)
+
+    if code in [200, 201]:
+        clinvar_id = submit_res.json().get("id")
+        flash(
+            f"Submission sent to API URL '{service_url}'. Saved successfully with ID: {clinvar_id}",
+            "success",
+        )
+
+        # Update ClinVar submission ID with the ID returned from ClinVar
+        store.update_clinvar_id(
+            clinvar_id=clinvar_id,
+            submission_id=submission_id,
+        )
+        # Update submission status as submitted
         store.update_clinvar_submission_status(
             institute_id=institute_id, submission_id=submission_id, status="submitted"
         )
 
     else:
-        flash(str(submit_res.json()), "warning")
+        flash(
+            f"Submission sent to API URL '{service_url}'. Returned the following error: {str(submit_res.json())}",
+            "warning",
+        )
 
 
 def clinvar_submission_file(submission_id, csv_type, clinvar_subm_id):
@@ -543,3 +557,64 @@ def _clinvar_submission_header(submission_objs, csv_type):
                 continue
             custom_header[key] = value
     return custom_header
+
+
+def add_variant_to_submission(institute_obj: dict, case_obj: dict, form: ImmutableMultiDict):
+    """It is invoked by the 'clinvar_save' endpoint. Adds one variant with eventual CaseData observations to an open (or new) ClinVar submission."""
+
+    variant_data: dict = parse_variant_form_fields(form)
+    casedata_list: List[dict] = parse_casedata_form_fields(form)
+    institute_id = institute_obj["_id"]
+
+    # retrieve or create an open ClinVar submission:
+    subm: dict = store.get_open_clinvar_submission(institute_id, current_user._id)
+    # save submission objects in submission:
+    result: Optional[dict] = store.add_to_submission(subm["_id"], (variant_data, casedata_list))
+    if result:
+        flash(
+            "An open ClinVar submission was updated correctly with submitted data",
+            "success",
+        )
+        # Create user-related events
+        variant_obj: dict = store.variant(document_id=variant_data.get("local_id"))
+        user_obj: dict = store.user(user_id=current_user._id)
+        for category in ["case", "variant"]:
+            store.create_event(
+                institute=institute_obj,
+                case=case_obj,
+                user=user_obj,
+                link=f"/{institute_id}/{case_obj['display_name']}/{variant_obj['_id']}",
+                category=category,
+                verb="clinvar_add",
+                variant=variant_obj,
+                subject=variant_obj["display_name"],
+            )
+
+
+def remove_item_from_submission(submission: str, object_type: str, subm_variant_id: str):
+    """It is invoked by the clinvar_delete_object endpoint. Removes a variant (+ casedata) or casedata info only from one ClinVar submission object."""
+
+    store.delete_clinvar_object(
+        object_id=subm_variant_id,
+        object_type=object_type,
+        submission_id=submission,
+    )
+
+    # If variant itself is removed, register event
+    if object_type == "variant_data":
+        variant_id: str = subm_variant_id.split("_")[-1]
+        variant_obj: dict = store.variant(document_id=variant_id)
+        institute_obj: dict = store.institute(institute_id=variant_obj["institute"])
+        case_obj: dict = store.case(case_id=variant_obj["case_id"])
+        user_obj: dict = store.user(user_id=current_user._id)
+        for category in ["case", "variant"]:
+            store.create_event(
+                institute=institute_obj,
+                case=case_obj,
+                user=user_obj,
+                link=f"/{variant_obj['_id']}/{case_obj['display_name']}/{variant_id}",
+                category=category,
+                verb="clinvar_remove",
+                variant=variant_obj,
+                subject=variant_obj["display_name"],
+            )
