@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 from flask import flash, redirect, url_for
 
-from scout.server.links import add_gene_links, add_tx_links, omim
+from scout.constants import GENE_CONSTRAINT_LABELS
+from scout.server.links import add_gene_links, add_tx_links, disease_link
 from scout.server.utils import document_generated
 
 
@@ -31,8 +32,8 @@ def genes(store, query):
     return dict(genes=genes_subset, last_updated=last_updated, nr_genes=(nr_genes_37, nr_genes_38))
 
 
-def gene(store, hgnc_id):
-    """Parse information about a gene."""
+def gene(store, hgnc_id: str):
+    """Populate information about a gene."""
     res = {
         "builds": {"37": None, "38": None},
         "symbol": None,
@@ -43,33 +44,37 @@ def gene(store, hgnc_id):
 
     for build in res["builds"]:
         record = store.hgnc_gene(hgnc_id, build=build)
-        if record:
-            record["position"] = "{this[chromosome]}:{this[start]}-{this[end]}".format(this=record)
-            res["aliases"] = record["aliases"]
-            res["hgnc_id"] = record["hgnc_id"]
-            res["description"] = record["description"]
-            res["builds"][build] = record
-            res["symbol"] = record["hgnc_symbol"]
-            res["description"] = record["description"]
-            res["entrez_id"] = record.get("entrez_id")
-            res["pli_score"] = record.get("pli_score")
+        if not record:
+            continue
 
-            add_gene_links(record, int(build))
+        record["position"] = "{this[chromosome]}:{this[start]}-{this[end]}".format(this=record)
+        res["aliases"] = record["aliases"]
+        res["hgnc_id"] = record["hgnc_id"]
+        res["description"] = record["description"]
+        res["builds"][build] = record
+        res["symbol"] = record["hgnc_symbol"]
+        res["description"] = record["description"]
+        res["entrez_id"] = record.get("entrez_id")
 
-            res["omim_id"] = record.get("omim_id")
-            res["incomplete_penetrance"] = record.get("incomplete_penetrance", False)
-            res["inheritance_models"] = record.get("inheritance_models", [])
-            for transcript in record["transcripts"]:
-                transcript["position"] = "{this[chrom]}:{this[start]}-{this[end]}".format(
-                    this=transcript
-                )
-                add_tx_links(transcript, build, record["hgnc_symbol"])
+        for constraint in GENE_CONSTRAINT_LABELS.keys():
+            if record.get(constraint):
+                res[constraint] = record.get(constraint)
 
-            for phenotype in record.get("phenotypes", []):
-                phenotype["omim_link"] = omim(phenotype.get("mim_number"))
+        add_gene_links(record, build=int(build))
 
-            if not res["record"]:
-                res["record"] = record
+        res["omim_id"] = record.get("omim_id")
+        res["incomplete_penetrance"] = record.get("incomplete_penetrance", False)
+        res["inheritance_models"] = record.get("inheritance_models", [])
+        for transcript in record["transcripts"]:
+            transcript["position"] = "{this[chrom]}:{this[start]}-{this[end]}".format(
+                this=transcript
+            )
+            add_tx_links(transcript, build, record["hgnc_symbol"])
+
+        record["disease_terms"] = add_disease_information_to_gene(store, hgnc_id=hgnc_id)
+
+        if not res["record"]:
+            res["record"] = record
 
     # If none of the genes where found
     if not any(res.values()):
@@ -78,6 +83,15 @@ def gene(store, hgnc_id):
     return res
 
 
+def add_disease_information_to_gene(store, hgnc_id: str):
+    disease_terms = store.disease_terms_by_gene(hgnc_id)
+
+    for disease in disease_terms:
+        disease_id = disease["disease_id"]
+        disease["disease_link"] = disease_link(disease_id=disease_id)
+    return disease_terms
+
+
 def genes_to_json(store, query, build):
     """Fetch matching genes and convert to JSON."""
     gene_query = store.hgnc_genes(query, build, search=True)
