@@ -1,13 +1,22 @@
 # -*- coding: utf-8 -*-
 import datetime
 import logging
-import re
+from typing import Dict, List, Optional, Tuple
 
-from flask import current_app, flash, url_for
+from flask import Response, current_app, flash, url_for
 from flask_login import current_user
 from pymongo import ASCENDING, DESCENDING
+from pymongo.cursor import Cursor
+from werkzeug.datastructures import Headers, MultiDict
 
-from scout.constants import CASE_SEARCH_TERMS, CASE_STATUSES, PHENOTYPE_GROUPS
+from scout.adapter.mongo.base import MongoAdapter
+from scout.constants import (
+    CASE_SEARCH_TERMS,
+    CASE_STATUSES,
+    DATE_DAY_FORMATTER,
+    ID_PROJECTION,
+    PHENOTYPE_GROUPS,
+)
 from scout.server.blueprints.variant.utils import predictions, update_representative_gene
 from scout.server.extensions import beacon, store
 from scout.server.utils import institute_and_case, user_institutes
@@ -65,28 +74,6 @@ def get_timeline_data(limit):
     return timeline_results
 
 
-def verified_vars(institute_id):
-    """Create content to be displayed on institute verified page
-
-    Args:
-        institute_id(str): institute["_id"] value
-
-    Returns:
-        verified(list): list of variant objects (True positive or False Positive)
-    """
-    verified = []
-    for variant_obj in store.verified(institute_id=institute_id):
-        variant_genes = variant_obj.get("genes", [])
-        if variant_obj["category"] in ["snv", "cancer"]:
-            update_representative_gene(
-                variant_obj, variant_genes
-            )  # required to display cDNA and protein change
-        variant_obj.update(predictions(variant_genes))
-        verified.append(variant_obj)
-
-    return verified
-
-
 def verified_stats(institute_id, verified_vars):
     """Create content to be displayed on institute verified page, stats chart
 
@@ -110,6 +97,29 @@ def verified_stats(institute_id, verified_vars):
     return true_pos, false_pos, n_validations_ordered - (true_pos + false_pos)
 
 
+def decorate_institute_variant(variant_obj: dict) -> Optional[dict]:
+    """Fetch data relative to causative/verified variants to be displayed in the institute pages."""
+
+    case_obj = store.case(variant_obj["case_id"])
+    if not case_obj:
+        return
+    variant_genes = variant_obj.get("genes", [])
+    if variant_obj["category"] in ["snv", "cancer"]:
+        update_representative_gene(
+            variant_obj, variant_genes
+        )  # required to display cDNA and protein change
+    variant_obj.update(predictions(variant_genes))
+    variant_obj["case_obj"] = {
+        "display_name": case_obj["display_name"],
+        "individuals": case_obj["individuals"],
+        "status": case_obj.get("status"),
+        "partial_causatives": case_obj.get("partial_causatives", []),
+        "rank_model_version": case_obj.get("rank_model_version"),
+        "sv_rank_model_version": case_obj.get("sv_rank_model_version"),
+    }
+    return variant_obj
+
+
 def causatives(institute_obj, request):
     """Create content to be displayed on institute causatives page
 
@@ -133,26 +143,31 @@ def causatives(institute_obj, request):
     causatives = []
 
     for variant_obj in store.institute_causatives(institute_obj=institute_obj, limit_genes=hgnc_id):
-        variant_genes = variant_obj.get("genes", [])
-        if variant_obj["category"] in ["snv", "cancer"]:
-            update_representative_gene(
-                variant_obj, variant_genes
-            )  # required to display cDNA and protein change
-        variant_obj.update(predictions(variant_genes))
-        case_obj = store.case(variant_obj["case_id"])
-        if not case_obj:
-            continue
-        variant_obj["case_obj"] = {
-            "display_name": case_obj["display_name"],
-            "individuals": case_obj["individuals"],
-            "status": case_obj.get("status"),
-            "partial_causatives": case_obj.get("partial_causatives", []),
-        }
-        causatives.append(variant_obj)
+        decorated_variant = decorate_institute_variant(variant_obj)
+        if decorated_variant:
+            causatives.append(variant_obj)
 
     return causatives
 
 
+def verified_vars(institute_id):
+    """Create content to be displayed on institute verified page
+
+    Args:
+        institute_id(str): institute["_id"] value
+
+    Returns:
+        verified(list): list of variant objects (True positive or False Positive)
+    """
+    verified = []
+    for variant_obj in store.verified(institute_id=institute_id):
+        decorated_variant = decorate_institute_variant(variant_obj)
+        if decorated_variant:
+            verified.append(variant_obj)
+
+    return verified
+
+
 def institutes():
     """Returns institutes info available for a user
     Returns:
@@ -176,7 +191,9 @@ def institutes():
                 "sanger_recipients": sanger_recipients,
                 "frequency_cutoff": ins_obj.get("frequency_cutoff", "None"),
                 "phenotype_groups": ins_obj.get("phenotype_groups", PHENOTYPE_GROUPS),
-                "case_count": sum(1 for i in store.cases(collaborator=ins_obj["_id"])),
+                "case_count": sum(
+                    1 for i in store.cases(collaborator=ins_obj["_id"], projection=ID_PROJECTION)
+                ),
             }
         )
     return institutes
@@ -224,7 +241,10 @@ def populate_beacon_form(institute_obj):
             ):  # If dataset doesn't already exist, add the option to create it
                 continue
             dset_options.append(
-                (institute_build, f"{institute_obj['_id']} public dataset - Genome build {build}")
+                (
+                    institute_build,
+                    f"{institute_obj['_id']} public dataset - Genome build {build}",
+                )
             )
 
         beacon_form.beacon_dataset.choices = dset_options
@@ -243,12 +263,13 @@ def populate_institute_form(form, institute_obj):
     institutes_tuples = []
     for inst in store.institutes():
         if not inst["_id"] == institute_obj["_id"]:
-            institutes_tuples.append(((inst["_id"], inst["display_name"])))
+            institutes_tuples.append((inst["_id"], f'{inst["display_name"]} - {inst["_id"]}'))
 
     form.display_name.default = institute_obj.get("display_name")
     form.institutes.choices = institutes_tuples
     form.coverage_cutoff.default = institute_obj.get("coverage_cutoff")
     form.frequency_cutoff.default = institute_obj.get("frequency_cutoff")
+    form.show_all_cases_status.data = institute_obj.get("show_all_cases_status") or ["prioritized"]
 
     # collect all available default HPO terms and populate the pheno_groups form select with these values
     default_phenotypes = [choice[0].split(" ")[0] for choice in form.pheno_groups.choices]
@@ -271,35 +292,69 @@ def populate_institute_form(form, institute_obj):
     form.gene_panels.choices = sorted(panel_set, key=lambda tup: tup[1])
     form.gene_panels_matching.choices = sorted(panel_set, key=lambda tup: tup[1])
 
+    institute_users: List[Tuple] = [
+        (user["name"], user["email"]) for user in store.users(institute=institute_obj["_id"])
+    ]
+    form.clinvar_emails.choices = institute_users
+
     return default_phenotypes
 
 
-def update_institute_settings(store, institute_obj, form):
-    """Update institute settings with data collected from institute form
-
-    Args:
-        score(adapter.MongoAdapter)
-        institute_id(str)
-        form(dict)
-
-    Returns:
-        updated_institute(dict)
-
+def get_sanger_recipients(form: MultiDict) -> List[str]:
+    """
+    Return list of Sanger recipients from form multiselect.
     """
     sanger_recipients = []
-    sharing_institutes = []
-    phenotype_groups = []
-    gene_panels = {}
-    gene_panels_matching = {}
-    group_abbreviations = []
-    cohorts = []
-
     for email in form.getlist("sanger_emails"):
         sanger_recipients.append(email.strip())
 
+    return sanger_recipients
+
+
+def get_clinvar_submitters(form: MultiDict) -> Optional[List[str]]:
+    """
+    Return list of ClinVar sumbitters from form multiselect.
+    This is not available on the form for unprivileged users, only admin.
+    """
+
+    clinvar_submitters = None
+    if current_user.is_admin:
+        clinvar_submitters = []
+        for email in form.getlist("clinvar_emails"):
+            clinvar_submitters.append(email.strip())
+    return clinvar_submitters
+
+
+def get_loqusdb_ids(form: MultiDict) -> Optional[List[str]]:
+    """
+    Return loqusdb ids from the form multiselect.
+    This is not available on the form for unprivileged users, only admin.
+    """
+    if current_user.is_admin is False:
+        return None
+
+    return form.getlist("loqusdb_id")
+
+
+def get_gene_panels(store: MongoAdapter, form: MultiDict, tag: str) -> Dict:
+    """
+    Return gene panel objects checked in the corresponding form multiselect.
+
+    tag as in the form e.g. "gene_panels" or "gene_panels_matching".
+    """
+    return store.gene_panels_dict(panel_names=form.getlist(tag))
+
+
+def update_institute_settings(store: MongoAdapter, institute_obj: Dict, form: MultiDict) -> Dict:
+    """Update institute settings with data collected from institute form."""
+
+    sharing_institutes = []
     for inst in form.getlist("institutes"):
         sharing_institutes.append(inst)
 
+    phenotype_groups = []
+    group_abbreviations = []
+
     for pheno_group in form.getlist("pheno_groups"):
         phenotype_groups.append(pheno_group.split(" ,")[0])
         group_abbreviations.append(pheno_group[pheno_group.find("( ") + 2 : pheno_group.find(" )")])
@@ -308,42 +363,30 @@ def update_institute_settings(store, institute_obj, form):
         phenotype_groups.append(form["hpo_term"].split(" |")[0])
         group_abbreviations.append(form["pheno_abbrev"])
 
-    for panel_name in form.getlist("gene_panels"):
-        panel_obj = store.gene_panel(panel_name)
-        if panel_obj is None:
-            continue
-        gene_panels[panel_name] = panel_obj["display_name"]
-
-    for panel_name in form.getlist("gene_panels_matching"):
-        panel_obj = store.gene_panel(panel_name)
-        if panel_obj is None:
-            continue
-        gene_panels_matching[panel_name] = panel_obj["display_name"]
-
+    cohorts = []
     for cohort in form.getlist("cohorts"):
         cohorts.append(cohort.strip())
 
-    loqusdb_ids = form.getlist("loqusdb_id")
-    if current_user.is_admin is False:
-        loqusdb_ids = None
-
     updated_institute = store.update_institute(
         internal_id=institute_obj["_id"],
-        sanger_recipients=sanger_recipients,
+        sanger_recipients=get_sanger_recipients(form),
         coverage_cutoff=int(form.get("coverage_cutoff")),
         frequency_cutoff=float(form.get("frequency_cutoff")),
+        show_all_cases_status=form.getlist("show_all_cases_status"),
         display_name=form.get("display_name"),
         phenotype_groups=phenotype_groups,
-        gene_panels=gene_panels,
-        gene_panels_matching=gene_panels_matching,
+        gene_panels=get_gene_panels(store, form, "gene_panels"),
+        gene_panels_matching=get_gene_panels(store, form, "gene_panels_matching"),
         group_abbreviations=group_abbreviations,
         add_groups=False,
         sharing_institutes=sharing_institutes,
         cohorts=cohorts,
-        loqusdb_ids=loqusdb_ids,
+        loqusdb_ids=get_loqusdb_ids(form),
         alamut_key=form.get("alamut_key"),
         alamut_institution=form.get("alamut_institution"),
         check_show_all_vars=form.get("check_show_all_vars"),
+        clinvar_key=form.get("clinvar_key"),
+        clinvar_submitters=get_clinvar_submitters(form),
     )
     return updated_institute
 
@@ -398,30 +441,40 @@ def cases(store, request, institute_id):
     name_query = None
     if request.args.get("search_term"):
         name_query = "".join(
-            [request.args.get("search_type"), re.escape(request.args["search_term"].strip())]
+            [
+                request.args.get("search_type"),
+                request.args["search_term"].strip(),
+            ]
         )
     data["name_query"] = name_query
     limit = int(request.args.get("search_limit")) if request.args.get("search_limit") else 100
     data["form"] = populate_case_filter_form(request.args)
 
-    prioritized_cases = store.prioritized_cases(institute_id=institute_id)
-    all_cases = store.cases(
-        collaborator=institute_id,
-        name_query=name_query,
-        skip_assigned=request.args.get("skip_assigned"),
-        is_research=request.args.get("is_research"),
-        has_rna_data=request.args.get("has_rna"),
-        verification_pending=request.args.get("validation_ordered"),
-        has_clinvar_submission=request.args.get("clinvar_submitted"),
-    )
-    all_cases = _sort_cases(data, request, all_cases)
+    ALL_CASES_PROJECTION = {
+        "analysis_date": 1,
+        "assignees": 1,
+        "beacon": 1,
+        "case_id": 1,
+        "display_name": 1,
+        "individuals": 1,
+        "is_rerun": 1,
+        "is_research": 1,
+        "mme_submission": 1,
+        "owner": 1,
+        "panels": 1,
+        "status": 1,
+        "track": 1,
+        "vcf_files": 1,
+    }
 
-    data["nr_cases"] = store.nr_cases(institute_id=institute_id)
     data["status_ncases"] = store.nr_cases_by_status(institute_id=institute_id)
-    data["sanger_unevaluated"] = get_sanger_unevaluated(store, institute_id, current_user.email)
+    data["nr_cases"] = sum(data["status_ncases"].values())
 
-    case_groups = {status: [] for status in CASE_STATUSES}
-    nr_cases = 0
+    sanger_ordered_not_validated: Tuple[Dict[str, list]] = get_sanger_unevaluated(
+        store, institute_id, current_user.email
+    )
+    data["sanger_unevaluated"]: Dict[str, list] = sanger_ordered_not_validated[0]
+    data["sanger_validated_by_others"]: Dict[str, list] = sanger_ordered_not_validated[1]
 
     # local function to add info to case obj
     def populate_case_obj(case_obj):
@@ -449,28 +502,51 @@ def cases(store, request, institute_id):
         case_obj["display_track"] = TRACKS[case_obj.get("track", "rare")]
         return case_obj
 
-    for nr_cases, case_obj in enumerate(all_cases.limit(limit), 1):
-        case_obj = populate_case_obj(case_obj)
-        case_groups[case_obj["status"]].append(case_obj)
+    case_groups = {status: [] for status in CASE_STATUSES}
 
-    if prioritized_cases:
-        extra_prioritized = 0
-        for case_obj in prioritized_cases:
-            if any(
-                group_obj.get("display_name") == case_obj.get("display_name")
-                for group_obj in case_groups[case_obj["status"]]
-            ):
-                continue
-            else:
-                extra_prioritized += 1
-                case_obj = populate_case_obj(case_obj)
-                case_groups[case_obj["status"]].append(case_obj)
-        # extra prioritized cases are potentially shown in addition to the case query limit
-        nr_cases += extra_prioritized
+    nr_cases_showall_statuses = (
+        0  # Nr of cases for the case statuses where all cases should be shown
+    )
+    # In institute settings, retrieve all case status categories for which all cases should be displayed
+    status_show_all_cases: List[str] = institute_obj.get("show_all_cases_status") or ["prioritized"]
+    for status in status_show_all_cases:
+        cases_in_status = store.cases_by_status(
+            institute_id=institute_id, status=status, projection=ALL_CASES_PROJECTION
+        )
+        cases_in_status = _sort_cases(data, request, cases_in_status)
+        for case_obj in cases_in_status:
+            populate_case_obj(case_obj)
+            nr_cases_showall_statuses += 1
+            case_groups[status].append(case_obj)
+
+    # Retrieve cases for the remaining status categories
+    all_cases = store.cases(
+        collaborator=institute_id,
+        name_query=name_query,
+        skip_assigned=request.args.get("skip_assigned"),
+        is_research=request.args.get("is_research"),
+        has_rna_data=request.args.get("has_rna"),
+        verification_pending=request.args.get("validation_ordered"),
+        has_clinvar_submission=request.args.get("clinvar_submitted"),
+        projection=ALL_CASES_PROJECTION,
+    )
+    all_cases = _sort_cases(data, request, all_cases)
+
+    nr_cases = 0
+    for case_obj in all_cases:
+        case_status = case_obj["status"]
+        if case_status in status_show_all_cases:
+            continue
+        if nr_cases == limit:
+            break
+        populate_case_obj(case_obj)
+        case_groups[case_status].append(case_obj)
+        nr_cases += 1
 
     data["cases"] = [(status, case_groups[status]) for status in CASE_STATUSES]
-    data["found_cases"] = nr_cases
+    data["found_cases"] = nr_cases + nr_cases_showall_statuses
     data["limit"] = limit
+
     return data
 
 
@@ -488,66 +564,179 @@ def populate_case_filter_form(params):
     return form
 
 
-def get_sanger_unevaluated(store, institute_id, user_id):
-    """Get all variants for an institute having Sanger validations ordered but still not evaluated
+def _get_unevaluated_variants_for_case(
+    case_obj: dict, var_ids_list: List[str], sanger_validated_by_user_by_case: Dict[str, List[str]]
+) -> Tuple[Dict[str, list]]:
+    """Returns the variants with Sanger ordered by a user that need validation or are validated by another user."""
 
-    Args:
-        store(scout.adapter.MongoAdapter)
-        institute_id(str)
+    case_display_name: str = case_obj["display_name"]
+    case_id: str = case_obj["_id"]
+
+    def _variant_has_sanger_ordered(variant_obj: dict) -> bool:
+        """Returns True if the sanger_ordered status of a variant is True, else False."""
+
+        if (
+            variant_obj is None
+            or variant_obj.get("sanger_ordered") is None
+            or variant_obj.get("sanger_ordered") is False
+        ):
+            return False
+        return True
+
+    unevaluated_by_case = {case_display_name: []}
+    evaluated_by_others_by_case = {case_display_name: []}
+    for var_id in var_ids_list:
+        # For each variant with sanger validation ordered
+        variant_obj = store.variant(document_id=var_id, case_id=case_id)
+
+        # Double check that Sanger was ordered (and not canceled) for the variant
+        if _variant_has_sanger_ordered(variant_obj) is False:
+            continue
+
+        validation = variant_obj.get("validation", "not_evaluated")
+
+        # Check that the variant is not evaluated
+        if validation in ["True positive", "False positive"]:
+            if var_id in sanger_validated_by_user_by_case.get(
+                case_id, []
+            ):  # User had validated this variant
+                continue
+
+            # Another user has validated the variant
+            evaluated_by_others_by_case[case_display_name].append(variant_obj["_id"])
+        else:
+            unevaluated_by_case[case_display_name].append(variant_obj["_id"])
+
+    return unevaluated_by_case, evaluated_by_others_by_case
+
+
+def get_sanger_unevaluated(
+    store: MongoAdapter, institute_id: str, user_id: str
+) -> Tuple[List[Dict[str, list]]]:
+    """Return all variant with Sanger sequencing ordered by a user with validation missing or validated by another user.
 
     Returns:
-        unevaluated: a list that looks like this: [ {'case1': [varID_1, varID_2, .., varID_n]}, {'case2' : [varID_1, varID_2, .., varID_n]} ],
+        unevaluated: a list that looks like this: [ {'case1': [varID_1, varID_2, .., varID_n]}, .. ],
                      where the keys are case_ids and the values are lists of variants with Sanger ordered but not yet validated
+        evaluated_by_others: a list that looks like the one above where varID_1, varID_2 etc are variants validated by some other user
 
     """
+    sanger_ordered_by_user_by_case: Dict[str, List[str]] = {
+        case_variants["_id"]: case_variants["vars"]
+        for case_variants in store.sanger_ordered(institute_id=institute_id, user_id=user_id)
+    }
+    sanger_validated_by_user_by_case: Dict[str, List[str]] = {
+        case_variants["_id"]: case_variants["vars"]
+        for case_variants in store.validated(institute_id=institute_id, user_id=user_id)
+    }
 
-    # Retrieve a list of ids for variants with Sanger ordered grouped by case from the 'event' collection
-    # This way is much faster than querying over all variants in all cases of an institute
-    sanger_ordered_by_case = store.sanger_ordered(institute_id, user_id)
     unevaluated = []
+    evaluated_by_others = []
 
-    # for each object where key==case and value==[variant_id with Sanger ordered]
-    for item in sanger_ordered_by_case:
-        case_id = item["_id"]
+    for case_id, var_ids_list in sanger_ordered_by_user_by_case.items():
         # Get the case to collect display name
-        case_obj = store.case(case_id=case_id)
+        CASE_SANGER_UNEVALUATED_PROJECTION = {"display_name": 1}
+        case_obj = store.case(case_id=case_id, projection=CASE_SANGER_UNEVALUATED_PROJECTION)
 
         if not case_obj:  # the case might have been removed
             continue
 
         case_display_name = case_obj.get("display_name")
-
-        # List of variant document ids
-        varid_list = item["vars"]
-
-        unevaluated_by_case = {}
-        unevaluated_by_case[case_display_name] = []
-
-        for var_id in varid_list:
-            # For each variant with sanger validation ordered
-            variant_obj = store.variant(document_id=var_id, case_id=case_id)
-
-            # Double check that Sanger was ordered (and not canceled) for the variant
-            if (
-                variant_obj is None
-                or variant_obj.get("sanger_ordered") is None
-                or variant_obj.get("sanger_ordered") is False
-            ):
-                continue
-
-            validation = variant_obj.get("validation", "not_evaluated")
-
-            # Check that the variant is not evaluated
-            if validation in ["True positive", "False positive"]:
-                continue
-
-            unevaluated_by_case[case_display_name].append(variant_obj["_id"])
+        unevaluated_by_case, evaluated_by_others_by_case = _get_unevaluated_variants_for_case(
+            case_obj=case_obj,
+            var_ids_list=var_ids_list,
+            sanger_validated_by_user_by_case=sanger_validated_by_user_by_case,
+        )
 
         # If for a case there is at least one Sanger validation to evaluate add the object to the unevaluated objects list
         if len(unevaluated_by_case[case_display_name]) > 0:
             unevaluated.append(unevaluated_by_case)
 
-    return unevaluated
+        if len(evaluated_by_others_by_case[case_display_name]) > 0:
+            evaluated_by_others.append(evaluated_by_others_by_case)
+
+    return unevaluated, evaluated_by_others
+
+
+def export_gene_variants(
+    store: MongoAdapter, gene_symbol: str, pymongo_cursor: Cursor, variant_count: int
+) -> Response:
+    """Export 500 gene variants for an institute resulting from a customer query"""
+
+    def generate(header, lines):
+        yield header + "\n"
+        for line in lines:
+            yield line + "\n"
+
+    data: dict = gene_variants(
+        store=store,
+        pymongo_cursor=pymongo_cursor,
+        variant_count=variant_count,
+        per_page=500,
+    )
+
+    DOCUMENT_HEADER = [
+        "Case Display Name",
+        "Institute",
+        "Position",
+        "Score",
+        "Genes",
+        "GnomAD Frequency",
+        "CADD Score",
+        "Region",
+        "Function",
+        "HGVS",
+    ]
+
+    export_lines = []
+    for variant in data.get("variants", []):
+        variant_line = []
+        variant_line.append(variant.get("case_display_name"))  # Case Display Name
+        variant_line.append(variant.get("institute"))  # Institute
+        variant_line.append(variant.get("display_name"))  # Position
+        variant_line.append(str(variant.get("rank_score", "")))  # Score
+        variant_genes = [
+            gene.get("hgnc_symbol", gene.get("hgnc_id")) for gene in variant.get("genes", [])
+        ]
+        variant_line.append(" | ".join(variant_genes))  # Genes
+
+        gnomad_freq = []
+        if "gnomad_mt_homoplasmic_frequency" in variant:
+            gnomad_freq.append(
+                f"gnomAD(MT) hom:{str(round(variant.get('gnomad_mt_homoplasmic_frequency'),4))}"
+            )
+        if "gnomad_mt_heteroplasmic_frequency" in variant:
+            gnomad_freq.append(
+                f"gnomAD(MT) het:{str(round(variant.get('gnomad_mt_heteroplasmic_frequency'),4))}"
+            )
+        if "gnomad_frequency" in variant:
+            gnomad_freq.append(f"gnomAD:{str(round(variant.get('gnomad_frequency'),4))}")
+        if "max_gnomad_frequency" in variant:
+            gnomad_freq.append(f"gnomAD (max):{str(round(variant.get('max_gnomad_frequency'),4))}")
+        variant_line.append(" | ".join(gnomad_freq) if gnomad_freq else "-")  # GnomAD Frequency
+
+        variant_line.append(
+            str(round(variant.get("cadd_score"), 1)) if variant.get("cadd_score") else "-"
+        )  # CADD score
+        variant_line.append(" | ".join(variant.get("region_annotations", [])))  # Region
+        variant_line.append(" | ".join(variant.get("functional_annotations", [])))  # Function
+        variant_line.append(variant.get("hgvs", "-"))  # HGVS
+
+        export_lines.append(",".join(variant_line))
+
+    headers = Headers()
+    today = datetime.datetime.now().strftime(DATE_DAY_FORMATTER)
+    headers.add(
+        "Content-Disposition",
+        "attachment",
+        filename=f"{gene_symbol}_gene_variants_{today}.csv",
+    )
+    # return a csv with the exported variants
+    return Response(
+        generate(",".join(DOCUMENT_HEADER), export_lines),
+        mimetype="text/csv",
+        headers=headers,
+    )
 
 
 def gene_variants(store, pymongo_cursor, variant_count, page=1, per_page=50):
@@ -593,7 +782,10 @@ def update_variant_genes(store, variant_obj, genome_build):
 
     hgvs_c = []
     hgvs_p = []
-    gene_symbols = set()
+    gene_symbols = []
+    canonical_transcripts = []
+    functional_annotations = []
+    region_annotations = []
 
     for gene_obj in variant_obj.get("genes", []):
         hgnc_id = gene_obj.get("hgnc_id")
@@ -606,15 +798,22 @@ def update_variant_genes(store, variant_obj, genome_build):
         gene_obj["hgnc_symbol"] = gene_caption["hgnc_symbol"]
         gene_obj["description"] = gene_caption["description"]
 
-        gene_symbols.add(gene_obj["hgnc_symbol"])
+        gene_symbols.append(gene_obj["hgnc_symbol"])
+
+        # ensure annotations are populated
+        functional_annotations.append(gene_obj.get("functional_annotation"))
+        region_annotations.append(gene_obj.get("region_annotation"))
 
         # gather HGVS info from gene transcripts
-        (hgvs_nucleotide, hgvs_protein) = get_hgvs(gene_obj)
+        (canonical_transcript, hgvs_nucleotide, hgvs_protein) = get_hgvs(gene_obj)
+
+        canonical_transcripts.append(canonical_transcript)
         hgvs_c.append(hgvs_nucleotide)
         hgvs_p.append(hgvs_protein)
 
-    if len(gene_symbols) == 1:
-        variant_obj["hgvs"] = hgvs_str(list(gene_symbols), hgvs_p, hgvs_c)
+    variant_obj["hgvs"] = hgvs_str(gene_symbols, canonical_transcripts, hgvs_p, hgvs_c)
+    variant_obj["region_annotations"] = get_annotations(gene_symbols, region_annotations)
+    variant_obj["functional_annotations"] = get_annotations(gene_symbols, functional_annotations)
 
 
 def get_genome_build(variant_case_obj):
@@ -625,28 +824,51 @@ def get_genome_build(variant_case_obj):
     return "37"
 
 
-def get_hgvs(gene_obj):
-    """Analyse gene object
+def get_hgvs(gene_obj: Dict) -> Tuple[str, str, str]:
+    """Analyse gene object for hgvs info
     Return:
-       (hgvs_nucleotide, hgvs_protein)"""
+       (canonical_transcript, hgvs_nucleotide, hgvs_protein)"""
+    canonical_transcript = ""
     hgvs_nucleotide = "-"
     hgvs_protein = ""
 
     transcripts_list = gene_obj.get("transcripts")
     for transcript_obj in transcripts_list:
         if transcript_obj.get("is_canonical") is True:
+            canonical_transcript = transcript_obj.get("transcript_id")
             hgvs_nucleotide = str(transcript_obj.get("coding_sequence_name"))
             hgvs_protein = str(transcript_obj.get("protein_sequence_name"))
-    return (hgvs_nucleotide, hgvs_protein)
+            break
+    return (canonical_transcript, hgvs_nucleotide, hgvs_protein)
 
 
-def hgvs_str(gene_symbols, hgvs_p, hgvs_c):
-    """ """
-    if hgvs_p[0] != "None":
-        return hgvs_p[0]
-    if hgvs_c[0] != "None":
-        return hgvs_c[0]
-    return "-"
+def get_annotations(gene_symbols: List, gene_annotations: List) -> List:
+    """Get annotations for variant from the db transcript level from each gene
+    and make a final string. Only add gene symbols if there is more than one gene for the variant.
+    """
+    if len(gene_annotations) == 1:
+        return gene_annotations
+
+    variant_annotations = set()
+    for gene_symbol, gene_annotation in zip(gene_symbols, gene_annotations):
+        variant_annotations.add(gene_symbol + ":" + gene_annotation)
+    return sorted(list(variant_annotations))
+
+
+def hgvs_str(gene_symbols, canonical_transcripts, hgvs_ps, hgvs_cs):
+    """Produce HGVS string from canonical transcripts, gene symbols, dna and protein changes."""
+    hgvs = "-"
+    for transcript, gene, hgvs_c, hgvs_p in zip(
+        canonical_transcripts, gene_symbols, hgvs_cs, hgvs_ps
+    ):
+        hgvs = f"{transcript} ({gene})"
+
+        if hgvs_c != "None":
+            hgvs += " " + hgvs_c
+        if hgvs_p != "None":
+            hgvs += " " + hgvs_p
+
+    return hgvs
 
 
 def lock_filter(store, user_obj, filter_id):
