@@ -11,11 +11,13 @@ from wtforms import (
     SubmitField,
     validators,
 )
-from wtforms.widgets import TextInput
+from wtforms.widgets import PasswordInput, TextInput
 
 from scout.constants import CASE_SEARCH_TERMS, PHENOTYPE_GROUPS
+from scout.models.case import STATUS
 
 CASE_SEARCH_KEY = [(value["prefix"], value["label"]) for key, value in CASE_SEARCH_TERMS.items()]
+CATEGORY_CHOICES = [("snv", "SNV"), ("sv", "SV")]
 
 
 class NonValidatingSelectField(SelectField):
@@ -95,6 +97,21 @@ class InstituteForm(FlaskForm):
 
     check_show_all_vars = BooleanField("Preselect 'Show also variants only present in unaffected'")
 
+    clinvar_key = StringField("API key", widget=PasswordInput(hide_value=False))
+
+    clinvar_emails = NonValidatingSelectMultipleField(
+        "ClinVar submitters",
+        validators=[
+            validators.Optional(),
+        ],
+        choices=[],
+    )
+
+    show_all_cases_status = NonValidatingSelectMultipleField(
+        "Always display all cases from the following categories",
+        choices=[(status, status) for status in STATUS],
+    )
+
     submit_btn = SubmitField("Save settings")
 
 
@@ -126,22 +143,24 @@ class GeneVariantFiltersForm(FlaskForm):
     """Base FiltersForm for SNVs"""
 
     variant_type = SelectMultipleField(choices=[("clinical", "clinical"), ("research", "research")])
+    category = SelectMultipleField(choices=CATEGORY_CHOICES)
     hgnc_symbols = TagListField(
         "HGNC Symbols (comma-separated, case sensitive)", validators=[validators.InputRequired()]
     )
-    filter_variants = SubmitField(label="Filter variants")
     rank_score = IntegerField(default=15)
     phenotype_terms = TagListField("HPO terms (comma-separated)")
     phenotype_groups = TagListField("Phenotype groups")
     similar_case = TagListField("Phenotypically similar case")
     cohorts = TagListField("Cohorts")
+    filter_variants = SubmitField(label="Filter variants")
+    filter_export_variants = SubmitField(label="Filter and export variants")
 
 
 class CaseFilterForm(FlaskForm):
     """Takes care of cases filtering in cases page"""
 
     search_type = SelectField("Search by", [validators.Optional()], choices=CASE_SEARCH_KEY)
-    search_term = StringField("Search cases")
+    search_term = StringField("Search cases", default="")
     search_limit = IntegerField("Limit", [validators.Optional()], default=100)
     skip_assigned = BooleanField("Hide assigned")
     is_research = BooleanField("Research only")
