@@ -2,16 +2,7 @@
 import json
 import logging
 
-from flask import (
-    Blueprint,
-    current_app,
-    flash,
-    jsonify,
-    redirect,
-    render_template,
-    request,
-    url_for,
-)
+from flask import Blueprint, flash, jsonify, redirect, render_template, request
 from flask_login import current_user
 from pymongo import DESCENDING
 
@@ -127,6 +118,7 @@ def lock_filter(institute_id, filter_id):
 @templated("overview/gene_variants.html")
 def gene_variants(institute_id):
     """Display a list of SNV variants."""
+
     page = int(request.form.get("page", 1))
     result_size = None
     institute_obj = institute_and_case(store, institute_id)
@@ -137,11 +129,13 @@ def gene_variants(institute_id):
         form = GeneVariantFiltersForm(request.args)
     else:  # POST
         form = GeneVariantFiltersForm(request.form)
+
         if form.variant_type.data == []:
             form.variant_type.data = ["clinical"]
-
         variant_type = form.data.get("variant_type")
 
+        category = form.data.get("category") or ["snv", "sv"]
+
         update_form_hgnc_symbols(store=store, case_obj=None, form=form)
 
         # If no valid gene is provided, redirect to form
@@ -152,14 +146,24 @@ def gene_variants(institute_id):
         variants_query = store.build_variant_query(
             query=form.data,
             institute_ids=[inst["_id"] for inst in user_institutes(store, current_user)],
-            category="snv",
+            category=category,
             variant_type=variant_type,
         )  # This is the actual query dictionary, not the cursor with results
 
         results = store.variant_collection.find(variants_query).sort(
             [("rank_score", DESCENDING)]
         )  # query results
+
         result_size = store.variant_collection.count_documents(variants_query)
+
+        if request.form.get("filter_export_variants"):
+            return controllers.export_gene_variants(
+                store=store,
+                gene_symbol=request.form.get("hgnc_symbols").split(",")[0].strip(),
+                pymongo_cursor=results,
+                variant_count=result_size,
+            )
+
         data = controllers.gene_variants(
             store, results, result_size, page
         )  # decorated variant results, max 50 in a page
