@@ -1,20 +1,35 @@
-"""Code for login controllers"""
+import logging
 
-DETECTIVES = [
-    "Dick Tracy",
-    "Miss Marple",
-    "Sherlock Holmes",
-    "Dr. Watson",
-    "Hercule Poirot",
-    "Jules Maigret",
-    "Inspector Morse",
-    "Dexter Morgan",
-    "Stella Gibson",
-    "Dale Cooper",
-    "Jessica Fletcher",
-    "Inspector Closseau",
-    "Columbo",
-]
+from flask import current_app, flash
+
+from scout.server.extensions import ldap_manager
+
+LOG = logging.getLogger(__name__)
+
+
+def ldap_authorized(userid, password):
+    """Log in a LDAP user
+
+    Args:
+        userid(str): user id provided in ldap login form (usually and email)
+        password(str): user passord provided in ldap loding form
+
+    Returns:
+        authorized(bool): True or False
+    """
+    authorized = False
+    try:
+        authorized = ldap_manager.authenticate(
+            username=userid,
+            password=password,
+            base_dn=current_app.config.get("LDAP_BASE_DN") or current_app.config.get("LDAP_BINDDN"),
+            attribute=current_app.config.get("LDAP_USER_LOGIN_ATTR")
+            or current_app.config.get("LDAP_SEARCH_ATTR"),
+        )
+    except Exception as ex:
+        flash(ex, "danger")
+
+    return authorized
 
 
 def event_rank(count):
