@@ -3,24 +3,17 @@ import datetime
 import json
 import logging
 
-from flask import (
-    Blueprint,
-    Response,
-    escape,
-    flash,
-    redirect,
-    render_template,
-    request,
-    send_file,
-    url_for,
-)
+from flask import Blueprint, Response, flash, redirect, render_template, request, send_file, url_for
 from flask_login import current_user
+from markupsafe import escape
 
 from scout.constants import DATE_DAY_FORMATTER
 from scout.export.panel import export_gene_panels
 from scout.server.blueprints.cases.controllers import check_outdated_gene_panel
 from scout.server.extensions import store
 from scout.server.utils import (
+    case_has_chanjo2_coverage,
+    case_has_chanjo_coverage,
     html_to_pdf_file,
     institute_and_case,
     jsonconverter,
@@ -59,7 +52,6 @@ def panels():
     if request.method == "POST" and request.form.get("search_for"):
         # Query db for panels containing the search string. This is done with autocompletion
         # therefor only one(1) hgnc_id will be received from the form.
-        hgnc_symbols = []
         search_string = escape(request.form.get("search_for"))
         try:
             hgnc_symbols = parse_raw_gene_ids([search_string])
@@ -91,18 +83,17 @@ def panels():
     panel_versions = {}
     for name in panel_names:
         panels = store.gene_panels(panel_id=name, include_hidden=True)
-        panel_versions[name] = [
-            panel_obj
-            for panel_obj in panels
-            if controllers.shall_display_panel(panel_obj, current_user)
-        ]
+        panel_versions[name] = [panel_obj for panel_obj in panels]
+
     panel_groups = []
     for institute_obj in institutes:
-        institute_panels = (
-            panel_obj
-            for panel_obj in store.latest_panels(institute_obj["_id"], include_hidden=True)
-            if controllers.shall_display_panel(panel_obj, current_user)
-        )
+        institute_panels = []
+        for panel in store.latest_panels(institute_obj["_id"], include_hidden=True):
+            panel["writable"] = (
+                "" if controllers.panel_write_granted(panel, current_user) else "disabled"
+            )
+            institute_panels.append(panel)
+
         panel_groups.append((institute_obj, institute_panels))
     return dict(
         panel_groups=panel_groups,
@@ -140,7 +131,6 @@ def panel(panel_id):
         raw_hgnc_id = request.form["hgnc_id"]
         if "|" in raw_hgnc_id:
             raw_hgnc_id = raw_hgnc_id.split(" | ", 1)[0]
-        hgnc_id = 0
         try:
             hgnc_id = int(raw_hgnc_id)
         except ValueError:
@@ -168,6 +158,9 @@ def panel(panel_id):
     if request.args.get("case_id"):
         case_obj = store.case(request.args["case_id"])
 
+        case_has_chanjo_coverage(case_obj)
+        case_has_chanjo2_coverage(case_obj)
+
         case_obj["outdated_panels"] = {}
         panel_name = panel_obj["panel_name"]
         latest_panel = store.gene_panel(panel_name)
