@@ -1,11 +1,13 @@
 import logging
 import os
-from base64 import b64encode
+from typing import Dict, List, Optional
 
 import requests
-from flask import Markup, current_app, flash, url_for
+from flask import abort, current_app, flash, url_for
 from flask_login import current_user
+from markupsafe import Markup
 
+from scout.adapter import MongoAdapter
 from scout.constants import (
     ACMG_COMPLETE_MAP,
     ACMG_CRITERIA,
@@ -13,6 +15,7 @@ from scout.constants import (
     ACMG_OPTIONS,
     CANCER_SPECIFIC_VARIANT_DISMISS_OPTIONS,
     CANCER_TIER_OPTIONS,
+    CASE_TAGS,
     DISMISS_VARIANT_OPTIONS,
     IGV_TRACKS,
     INHERITANCE_PALETTE,
@@ -25,18 +28,19 @@ from scout.server.blueprints.variant.utils import (
     update_variant_case_panels,
 )
 from scout.server.blueprints.variants.utils import update_case_panels
-from scout.server.extensions import cloud_tracks, gens
-from scout.server.links import get_variant_links
+from scout.server.extensions import LoqusDB, config_igv_tracks, gens
+from scout.server.links import disease_link, get_variant_links
 from scout.server.utils import (
     case_has_alignments,
     case_has_mt_alignments,
-    institute_and_case,
+    case_has_rna_tracks,
     user_institutes,
-    variant_case,
+    variant_institute_and_case,
 )
 
 from .utils import (
     add_gene_info,
+    associate_variant_genes_with_case_panels,
     callers,
     clinsig_human,
     default_panels,
@@ -51,7 +55,7 @@ from .utils import (
 LOG = logging.getLogger(__name__)
 
 
-def tx_overview(variant_obj):
+def tx_overview(variant_obj: dict):
     """Prepares the content of the transcript overview to be shown on variant and general report pages.
        Basically show transcripts that contain RefSeq or are canonical.
 
@@ -125,28 +129,7 @@ def tx_overview(variant_obj):
     )
 
 
-def has_rna_tracks(case_obj):
-    """Returns True if one of more individuals of the case contain RNA-seq data
-
-    Args:
-        case_obj(dict)
-    Returns
-        True or False (bool)
-    """
-    # Display junctions track if available for any of the individuals
-    for ind in case_obj.get("individuals", []):
-        # Track contains 2 files and they should both be present
-        splicej_bed = ind.get("splice_junctions_bed")
-        rna_cov_bw = ind.get("rna_coverage_bigwig")
-        if None in [splicej_bed, rna_cov_bw]:
-            continue
-        if False in [os.path.exists(splicej_bed), os.path.exists(rna_cov_bw)]:
-            continue
-        return True
-    return False
-
-
-def get_igv_tracks(build="37"):
+def get_igv_tracks(build: str = "37") -> set:
     """Return all available IGV tracks for the given genome build, as a set
 
     Args:
@@ -159,27 +142,25 @@ def get_igv_tracks(build="37"):
     # Collect hardcoded tracks, common for all Scout instances
     for track in IGV_TRACKS.get(build, []):
         igv_tracks.add(track.get("name"))
-    # Collect instance-specif cloud public tracks, if available
-    if hasattr(cloud_tracks, "public_tracks"):
-        for track in cloud_tracks.public_tracks.get(build, []):
+    # Collect instance-specific public tracks, if available
+    if hasattr(config_igv_tracks, "tracks"):
+        for track in config_igv_tracks.tracks.get(build, []):
             igv_tracks.add(track.get("name"))
     return igv_tracks
 
 
 def variant(
-    store,
-    institute_id,
-    case_name,
-    variant_id=None,
-    variant_obj=None,
-    add_case=True,
-    add_other=True,
-    get_overlapping=True,
-    variant_category=None,
-    variant_type=None,
-    case_obj=None,
-    institute_obj=None,
-):
+    store: MongoAdapter,
+    variant_id: Optional[str],
+    institute_id: str = None,
+    case_name: str = None,
+    variant_obj: dict = None,
+    add_other: bool = True,
+    get_overlapping: bool = True,
+    variant_type: str = None,
+    case_obj: dict = None,
+    institute_obj: dict = None,
+) -> Optional[dict]:
     """Pre-process a single variant for the detailed variant view.
 
     Adds information from case and institute that is not present on the variant
@@ -191,11 +172,9 @@ def variant(
         case_name(str)
         variant_id(str)
         variant_obj(dict)
-        add_case(bool): If info about files case should be added
         add_other(bool): If information about other causatives should be added
         get_overlapping(bool): If overlapping variants should be collected
         variant_type(str): in ["clinical", "research"]
-        variant_category(str): ["snv", "str", "sv", "cancer", "cancer_sv"]
         institute_obj(scout.models.Institute)
         case_obj(scout.models.Case)
 
@@ -216,15 +195,19 @@ def variant(
         }
 
     """
-    if not (institute_obj and case_obj):
-        institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+
     # If the variant is already collected we skip this part
     if not variant_obj:
         # NOTE this will query with variant_id == document_id, not the variant_id.
         variant_obj = store.variant(variant_id)
 
-    if variant_obj is None or variant_obj.get("case_id") != case_obj["_id"]:
-        return None
+    if not variant_obj:
+        return abort(404)
+
+    if not (institute_obj and case_obj):
+        (institute_obj, case_obj) = variant_institute_and_case(
+            store, variant_obj, institute_id, case_name
+        )
 
     variant_type = variant_type or variant_obj.get("variant_type", "clinical")
 
@@ -248,16 +231,15 @@ def variant(
 
     # add default panels extra gene information
     panels = default_panels(store, case_obj)
+
     add_gene_info(store, variant_obj, gene_panels=panels, genome_build=genome_build)
 
     # Update some case panels info from db and populate it on variant to avoid showing removed panels
     update_case_panels(store, case_obj)
     # The hierarchical call order is relevant: cases are used to populate variants
-    update_variant_case_panels(store, case_obj, variant_obj)
+    update_variant_case_panels(case_obj, variant_obj)
 
-    # Add information about bam files and create a region vcf
-    if add_case:
-        variant_case(store, case_obj, variant_obj)
+    associate_variant_genes_with_case_panels(case_obj, variant_obj)
 
     # Provide basic info on alignment files availability for this case
     case_has_alignments(case_obj)
@@ -288,7 +270,9 @@ def variant(
         )
 
     variant_obj["matching_ranked"] = store.get_matching_manual_ranked_variants(
-        variant_obj, user_institutes(store, current_user), exclude_cases=[case_obj["_id"]]
+        variant_obj,
+        user_institutes(store, current_user),
+        exclude_cases=[case_obj["_id"]],
     )
 
     # Gather display information for the genes
@@ -316,7 +300,7 @@ def variant(
     # Add general variant links
     variant_obj.update(get_variant_links(institute_obj, variant_obj, int(genome_build)))
     variant_obj["frequencies"] = frequencies(variant_obj)
-    if variant_category in ["snv", "cancer"]:
+    if variant_category in ["snv", "cancer", "mei"]:
         # This is to convert a summary of frequencies to a string
         variant_obj["frequency"] = frequency(variant_obj)
     # Format clinvar information
@@ -326,15 +310,15 @@ def variant(
     update_representative_gene(variant_obj, variant_genes)
 
     # Add display information about callers
-    variant_obj["callers"] = callers(variant_obj, category=variant_category)
+    variant_obj["callers"] = callers(variant_obj)
 
     # Convert affection status to strings for the template
     is_affected(variant_obj, case_obj)
 
     if variant_obj.get("genetic_models"):
         variant_models = set(model.split("_", 1)[0] for model in variant_obj["genetic_models"])
-        all_models = variant_obj.get("all_models", set())
-        variant_obj["is_matching_inheritance"] = set.intersection(variant_models, all_models)
+        omim_models = variant_obj.get("omim_models", set())
+        variant_obj["is_matching_inheritance"] = set.intersection(variant_models, omim_models)
 
     # Prepare classification information for visualisation
     classification = variant_obj.get("acmg_classification")
@@ -366,10 +350,9 @@ def variant(
             **CANCER_SPECIFIC_VARIANT_DISMISS_OPTIONS,
         }
 
-    # re-encode images as base64
-    if variant_obj.get("custom_images"):
-        for img in variant_obj["custom_images"]:
-            img["data"] = b64encode(img["data"]).decode("utf-8")
+    for gene in variant_obj.get("genes", []):
+        for disease in gene.get("disease_terms", []):
+            disease["disease_link"] = disease_link(disease_id=disease["_id"])
 
     tx_overview(variant_obj)
 
@@ -387,16 +370,17 @@ def variant(
         "dismiss_variant_options": dismiss_options,
         "mosaic_variant_options": MOSAICISM_OPTIONS,
         "ACMG_OPTIONS": ACMG_OPTIONS,
+        "case_tag_options": CASE_TAGS,
         "inherit_palette": INHERITANCE_PALETTE,
-        "igv_tracks": get_igv_tracks(genome_build),
-        "splice_junctions_tracks": has_rna_tracks(case_obj),
+        "igv_tracks": get_igv_tracks("38" if variant_obj["is_mitochondrial"] else genome_build),
+        "has_rna_tracks": case_has_rna_tracks(case_obj),
         "gens_info": gens.connection_settings(genome_build),
         "evaluations": evaluations,
         "rank_score_results": variant_rank_scores(store, case_obj, variant_obj),
     }
 
 
-def variant_rank_scores(store, case_obj, variant_obj):
+def variant_rank_scores(store: MongoAdapter, case_obj: dict, variant_obj: dict) -> list:
     """Retrive rank score values and ranges for the variant
 
     Args:
@@ -414,9 +398,6 @@ def variant_rank_scores(store, case_obj, variant_obj):
     ):  # Retrieve rank score results saved in variant document
         rank_score_results = variant_obj.get("rank_score_results")
 
-    rm_link_prefix = None
-    rm_file_extension = None
-
     if variant_obj.get("category") == "sv":
         rank_model_version = case_obj.get("sv_rank_model_version")
         rm_link_prefix = current_app.config.get("SV_RANK_MODEL_LINK_PREFIX")
@@ -441,18 +422,13 @@ def variant_rank_scores(store, case_obj, variant_obj):
     return rank_score_results
 
 
-def get_loqusdb_obs_cases(store, variant_obj, category, obs_families=[]):
-    """Get a list of cases where variant observations occurred.
-    These are only the cases the user has access to.
-
-    Args:
-        store (scout.adapter.MongoAdapter)
-        variant_obj(scout.models.Variant) it's the variant the loqusdb stats are computer for
-        category(str)
-        obs_families(list). List of all cases in loqusdb where variant occurred
-
-    Returns:
-        obs_cases(list).
+def get_loqusdb_obs_cases(
+    store: MongoAdapter, variant_obj: dict, category: str, obs_families: list = []
+) -> List[dict]:
+    """Get a list of cases where variant observations occurred. These are only the cases the user has access to.
+    We need to add links to the variant in other cases where the variant has been observed.
+    First we need to make sure that the user has access to these cases. The user_institute_ids holds
+    information about what institutes the user has access to.
     """
     obs_cases = []
     user_institutes_ids = set([inst["_id"] for inst in user_institutes(store, current_user)])
@@ -487,27 +463,9 @@ def get_loqusdb_obs_cases(store, variant_obj, category, obs_families=[]):
     return obs_cases
 
 
-def observations(store, loqusdb, case_obj, variant_obj):
-    """Query observations for a variant.
-
-    Check if variant_obj have been observed before ni the loqusdb instance.
+def observations(store: MongoAdapter, loqusdb: LoqusDB, variant_obj: dict) -> Dict[str, dict]:
+    """Check if variant_obj have been observed before in the loqusdb instances available in the institute settings.
     If not return empty dictionary.
-
-    We need to add links to the variant in other cases where the variant has been observed.
-    First we need to make sure that the user has access to these cases. The user_institute_ids holds
-    information about what institutes the user has access to.
-
-    Loop over the case ids from loqusdb and check if they exist in the scout instance.
-    Also make sure that we do not link to the observation that is the current variant.
-
-    Args:
-        store (scout.adapter.MongoAdapter)
-        loqusdb (scout.server.extensions.LoqusDB)
-        case_obj (scout.models.Case)
-        variant_obj (scout.models.Variant)
-
-    Returns:
-        obs_data(dict) with loqusdb id as key and observations stats as value
     """
     obs_data = {}
     institute_id = variant_obj["institute"]
@@ -528,25 +486,26 @@ def observations(store, loqusdb, case_obj, variant_obj):
     loqus_query = loqusdb.get_loqus_query(variant_obj, category)
 
     for loqus_id in inst_loqus_ids:  # Loop over all loqusdb instances of an institute
-        obs_data[loqus_id] = {}
-        loqus_settings = loqusdb.loqusdb_settings.get(loqus_id)
+        # collect observation on that loqusdb instance
+        obs_data[loqus_id] = loqusdb.get_variant(loqus_query, loqusdb_id=loqus_id)
 
-        if loqus_settings is None:  # An instance might have been renamed or removed
-            flash(f"Could not connect to the preselected loqusdb '{loqus_id}' instance", "warning")
-            obs_data[loqus_id]["total"] = "N/A"
-            continue
-        obs_data[loqus_id] = loqusdb.get_variant(
-            loqus_query, loqusdb_id=loqus_id
-        )  # collect observation on that loqus instance
-
-        if not obs_data[loqus_id]:  # data is an empty dictionary
-            # Collect count of variants in variant's case
-            obs_data[loqus_id] = loqusdb.get_variant(loqus_query, loqusdb_id=loqus_id)
-            if obs_data[loqus_id].get("total"):
-                obs_data[loqus_id]["observations"] = 0
+        if obs_data[loqus_id] is None:
+            flash(
+                f"Could not find a Loqus instance with id:{loqus_id}",
+                "warning",
+            )
+            obs_data[loqus_id]["observations"] = "N/A"
             continue
 
-        # collect cases where observations occurred
+        if obs_data[loqus_id] == {}:  # Variant was not found
+            obs_data[loqus_id]["observations"] = 0
+            continue
+
+        # Check if the current case is represented in the loqusdb instance
+        obs_data[loqus_id]["case_match"] = variant_obj["case_id"] in obs_data[loqus_id].get(
+            "families", []
+        )
+        # collect other cases where observations occurred
         obs_data[loqus_id]["cases"] = get_loqusdb_obs_cases(
             store, variant_obj, category, obs_data[loqus_id].get("families", [])
         )
@@ -555,14 +514,11 @@ def observations(store, loqusdb, case_obj, variant_obj):
 
 
 def str_variant_reviewer(
-    store,
-    case_obj,
-    variant_id,
-):
+    store: MongoAdapter,
+    case_obj: dict,
+    variant_id: str,
+) -> dict:
     """Controller populating data and calling REViewer Service to fetch svg.
-    Args:
-        case_obj(dict)
-        variant_obj(dict)
     Returns:
         data(dict): {"individuals": list(dict())}}
             individual dicts being dict with keys:
@@ -618,7 +574,7 @@ def str_variant_reviewer(
     }
 
 
-def variant_acmg(store, institute_id, case_name, variant_id):
+def variant_acmg(store: MongoAdapter, institute_id: str, case_name: str, variant_id: str):
     """Collect data relevant for rendering ACMG classification form.
 
     Args:
@@ -630,8 +586,15 @@ def variant_acmg(store, institute_id, case_name, variant_id):
     Returns:
         data(dict): Things for the template
     """
-    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
     variant_obj = store.variant(variant_id)
+
+    if not variant_obj:
+        return abort(404)
+
+    institute_obj, case_obj = variant_institute_and_case(
+        store, variant_obj, institute_id, case_name
+    )
+
     return dict(
         institute=institute_obj,
         case=case_obj,
@@ -641,7 +604,9 @@ def variant_acmg(store, institute_id, case_name, variant_id):
     )
 
 
-def check_reset_variant_classification(store, evaluation_obj, link):
+def check_reset_variant_classification(
+    store: MongoAdapter, evaluation_obj: dict, link: str
+) -> bool:
     """Check if this was the last ACMG evaluation left on the variant.
     If there is still a classification we want to remove the classification.
 
@@ -654,32 +619,47 @@ def check_reset_variant_classification(store, evaluation_obj, link):
 
     """
 
-    if len(list(store.get_evaluations_case_specific(evaluation_obj["variant_specific"]))) == 0:
-        variant_obj = store.variant(document_id=evaluation_obj["variant_specific"])
-        acmg_classification = variant_obj.get("acmg_classification")
-        if isinstance(acmg_classification, int):
-            institute_obj, case_obj = institute_and_case(
-                store,
-                evaluation_obj["institute"]["_id"],
-                evaluation_obj["case"]["display_name"],
-            )
-            user_obj = store.user(current_user.email)
+    if list(store.get_evaluations_case_specific(evaluation_obj["variant_specific"])):
+        return False
 
-            new_acmg = None
-            store.submit_evaluation(
-                variant_obj=variant_obj,
-                user_obj=user_obj,
-                institute_obj=institute_obj,
-                case_obj=case_obj,
-                link=link,
-                classification=new_acmg,
-            )
-            return True
+    variant_obj = store.variant(document_id=evaluation_obj["variant_specific"])
 
-    return False
+    if not variant_obj:
+        return abort(404)
+
+    acmg_classification = variant_obj.get("acmg_classification")
+
+    if not isinstance(acmg_classification, int):
+        return False
+
+    institute_obj, case_obj = variant_institute_and_case(
+        store,
+        variant_obj,
+        evaluation_obj["institute"]["_id"],
+        evaluation_obj["case"]["display_name"],
+    )
+    user_obj = store.user(current_user.email)
+
+    new_acmg = None
+    store.submit_evaluation(
+        variant_obj=variant_obj,
+        user_obj=user_obj,
+        institute_obj=institute_obj,
+        case_obj=case_obj,
+        link=link,
+        classification=new_acmg,
+    )
+    return True
 
 
-def variant_acmg_post(store, institute_id, case_name, variant_id, user_email, criteria):
+def variant_acmg_post(
+    store: MongoAdapter,
+    institute_id: str,
+    case_name: str,
+    variant_id: str,
+    user_email: str,
+    criteria: list,
+) -> dict:
     """Calculate an ACMG classification based on a list of criteria.
 
     Args:
@@ -694,8 +674,15 @@ def variant_acmg_post(store, institute_id, case_name, variant_id, user_email, cr
         data(dict): Things for the template
 
     """
-    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
     variant_obj = store.variant(variant_id)
+
+    if not variant_obj:
+        return abort(404)
+
+    institute_obj, case_obj = variant_institute_and_case(
+        store, variant_obj, institute_id, case_name
+    )
+
     user_obj = store.user(user_email)
     variant_link = url_for(
         "variant.variant",
