@@ -1,12 +1,14 @@
 import logging
+from typing import Dict, List, Optional, Tuple
 
+from scout.adapter import MongoAdapter
 from scout.constants import ACMG_COMPLETE_MAP, CALLERS, CLINSIG_MAP, SO_TERMS
 from scout.server.links import add_gene_links, add_tx_links
 
 LOG = logging.getLogger(__name__)
 
 
-def add_panel_specific_gene_info(panel_info):
+def add_panel_specific_gene_info(panel_info: List[dict]) -> dict:
     """Adds manually curated information from a gene panel to a gene
 
     The panel info is a list of dictionaries since there can be multiple infos about a panel.
@@ -59,13 +61,9 @@ def add_panel_specific_gene_info(panel_info):
     return panel_specific
 
 
-def update_representative_gene(variant_obj, variant_genes):
+def update_representative_gene(variant_obj: dict, variant_genes: List[dict]):
     """Set the gene with most severe consequence as being representative
     Used for display purposes
-
-    Args:
-        variant_obj(Variant): a variant object
-        variant_genes(list(Genes): a list of genes
     """
 
     if variant_genes:
@@ -91,7 +89,22 @@ def update_representative_gene(variant_obj, variant_genes):
         variant_obj["first_rep_gene"] = None
 
 
-def update_transcripts_information(variant_gene, hgnc_gene, variant_obj, genome_build=None):
+def update_transcript_mane(hgnc_transcript: dict, transcript: dict, variant_gene: dict):
+    """Updates MANE key/values for a transcript in genome build 38. Updates variant gene with functional annotation derived from MANE transcripts."""
+    for key in ["mane_select", "mane_plus_clinical"]:
+        if hgnc_transcript.get(key):
+            transcript[f"{key}_transcript"] = hgnc_transcript[key]
+            variant_gene[f"{key}_functional_annotation"] = transcript.get("functional_annotations")
+        else:
+            transcript.pop(f"{key}_transcript", None)
+
+
+def update_transcripts_information(
+    variant_gene: dict,
+    hgnc_gene: dict,
+    variant_obj: dict,
+    genome_build: Optional[str] = None,
+):
     """Collect tx info from the hgnc gene and panels and update variant transcripts
 
     Since the hgnc information are continuously being updated we need to run this each time a
@@ -100,14 +113,7 @@ def update_transcripts_information(variant_gene, hgnc_gene, variant_obj, genome_
     This function will:
         - Add a dictionary with tx_id -> tx_info to the hgnc variant
         - Add information from the panel
-        - Adds a list of refseq transcripts
-
-    Args:
-        variant_gene(dict): the gene information from the variant
-        hgnc_gene(dict): the hgnc gene information
-        varaiant_obj(scout.models.Variant)
-        genome_build(str): genome build
-
+        - Adds a list of RefSeq transcripts
     """
     genome_build = genome_build or "37"
     disease_associated_no_version = variant_gene.get("disease_associated_no_version", set())
@@ -126,17 +132,24 @@ def update_transcripts_information(variant_gene, hgnc_gene, variant_obj, genome_
     # First loop over the variants transcripts
     for transcript in variant_gene.get("transcripts", []):
         tx_id = transcript["transcript_id"]
+
         hgnc_transcript = transcripts_dict.get(tx_id)
         # If the tx does not exist in ensembl anymore we skip it
         if not hgnc_transcript:
             continue
 
+        if genome_build == "38":
+            update_transcript_mane(
+                hgnc_transcript=hgnc_transcript, transcript=transcript, variant_gene=variant_gene
+            )
+
         # Check in the common information if it is a primary transcript
         if hgnc_transcript.get("is_primary"):
             transcript["is_primary"] = True
 
         # Add the transcript links
         add_tx_links(transcript, genome_build, hgnc_symbol)
+
         # If the transcript has a ref seq identifier we add that
         # to the variants transcript
         refseq_id = hgnc_transcript.get("refseq_id")
@@ -149,63 +162,32 @@ def update_transcripts_information(variant_gene, hgnc_gene, variant_obj, genome_
         if refseq_id in disease_associated_no_version:
             transcript["is_disease_associated"] = True
 
-        # Since a ensemble transcript can have multiple refseq identifiers we add all of
+        # Since an Ensembl transcript can have multiple RefSeq identifiers we add all of
         # those
         transcript["refseq_identifiers"] = hgnc_transcript.get("refseq_identifiers", [])
         transcript["change_str"] = transcript_str(transcript, hgnc_symbol)
 
 
-def update_variant_case_panels(store, case_obj, variant_obj):
+def update_variant_case_panels(case_obj: dict, variant_obj: dict):
     """Populate variant with case gene panels with info on e.g. if a panel was removed on variant_obj.
     Variant objects panels are only a list of matching panel names.
 
-    The case_obj should be up to date first. Call update_case_panels() as needed in context:
+    The case_obj should be up-to-date first. Call update_case_panels() as needed in context:
     to save some resources we do not call it here for each variant.
-
-    Args:
-        store(adapter.MongoAdapter)
-        case_obj(dict):     case_obj with updated panels - update_case_panels() first
-        variant_obj(dict)
     """
-
+    variant_obj["case_panels"] = []
     variant_panel_names = variant_obj.get("panels") or []
-    case_panel_objs = [
-        panel
-        for panel in (case_obj.get("panels") or [])
-        if panel["panel_name"] in variant_panel_names
-    ]
-
-    variant_obj["case_panels"] = case_panel_objs
+    for latest_panel in case_obj.get("latest_panels") or []:
+        if latest_panel["panel_name"] not in variant_panel_names:
+            continue
+        if not set(latest_panel["hgnc_ids"]).isdisjoint(variant_obj["hgnc_ids"]):
+            variant_obj["case_panels"].append(latest_panel)
 
 
-def add_gene_info(store, variant_obj, gene_panels=None, genome_build=None):
-    """Adds information to variant genes from hgnc genes and selected gene panels.
-
-    Variants are annotated with gene and transcript information from VEP. In Scout the database
-    keeps updated and extended information about genes and transcript. This function will compliment
-     the VEP information with the updated database information.
-    Also there is sometimes additional information that are manually curated in the gene panels.
-    Only the selected panels passed to this function (typically default) are used.
-    This information needs to be added to the variant before sending it to the template.
-
-    This function will loop over all genes and add that extra information.
-
-    Args:
-        store(scout.adapter.MongoAdapter)
-        variant_obj(dict): A variant from the database
-        gene_panels(list(dict)): List of panels from database
-        genome_build(str)
-
-    Returns:
-        variant_obj
-    """
-    gene_panels = gene_panels or []
-    genome_build = genome_build or "37"
-
-    # Add a variable that checks if there are any refseq transcripts
-
-    # extra_info will hold information from gene panels
+def get_extra_info(gene_panels: list) -> Dict[int, dict]:
+    """Parse out extra information from gene panels."""
     extra_info = {}
+
     for panel_obj in gene_panels:
         for gene_info in panel_obj["genes"]:
             hgnc_id = gene_info["hgnc_id"]
@@ -213,20 +195,51 @@ def add_gene_info(store, variant_obj, gene_panels=None, genome_build=None):
                 extra_info[hgnc_id] = []
 
             extra_info[hgnc_id].append(gene_info)
+    return extra_info
 
-    # Loop over the genes in the variant object to add information
-    # from hgnc_genes and panel genes to the variant object
-    variant_obj["has_refseq"] = False
-    variant_obj["disease_associated_transcripts"] = []
-    all_models = set()
 
-    # seed genes structure for (STR) variants that have only hgnc_ids
+def seed_genes_with_only_hgnc_id(variant_obj: dict):
+    """Seed genes structure for (STR) variants that have only hgnc_ids."""
     if not variant_obj.get("genes") and variant_obj.get("hgnc_ids"):
         variant_obj["genes"] = []
         for hgnc_id in variant_obj.get("hgnc_ids"):
             variant_gene = {"hgnc_id": hgnc_id}
             variant_obj["genes"].append(variant_gene)
 
+
+def add_gene_info(
+    store: MongoAdapter,
+    variant_obj: dict,
+    gene_panels: Optional[List[dict]] = None,
+    genome_build: Optional[str] = None,
+):
+    """Adds information to variant genes from hgnc genes and selected gene panels.
+
+    Variants are annotated with gene and transcript information from VEP. In Scout the database
+    keeps updated and extended information about genes and transcript. This function will complement
+    the VEP information with the updated database information.
+    Also there is sometimes additional information that is manually curated in the gene panels.
+    Only the selected panels passed to this function (typically the case default panels) are used.
+    This information needs to be added to the variant before sending it to the template.
+
+    This function will loop over all genes and add that extra information.
+    """
+    gene_panels = gene_panels or []
+    genome_build = genome_build or "37"
+
+    institute = store.institute(variant_obj["institute"])
+
+    extra_info = get_extra_info(gene_panels)
+
+    seed_genes_with_only_hgnc_id(variant_obj)
+
+    # Loop over the genes in the variant object to add information
+    # from hgnc_genes and panel genes to the variant object
+    # Add a variable that checks if there are any refseq transcripts
+    variant_obj["has_refseq"] = False
+    variant_obj["disease_associated_transcripts"] = []
+    all_models = set()
+
     if variant_obj.get("genes"):
         for variant_gene in variant_obj["genes"]:
             hgnc_id = variant_gene["hgnc_id"]
@@ -248,8 +261,7 @@ def add_gene_info(store, variant_obj, gene_panels=None, genome_build=None):
             update_transcripts_information(variant_gene, hgnc_gene, variant_obj, genome_build)
 
             variant_gene["common"] = hgnc_gene
-
-            add_gene_links(variant_gene, genome_build)
+            add_gene_links(variant_gene, genome_build, institute=institute)
 
             # Add disease associated transcripts from panel to variant
             for refseq_id in panel_info.get("disease_associated_transcripts", []):
@@ -257,20 +269,39 @@ def add_gene_info(store, variant_obj, gene_panels=None, genome_build=None):
                 variant_obj["disease_associated_transcripts"].append(transcript_str)
 
             # Add the associated disease terms
-            disease_terms = store.disease_terms(hgnc_id)
-            variant_gene["disease_terms"] = disease_terms
+            disease_terms = store.disease_terms_by_gene(
+                hgnc_id, filter_project={"inheritance": 1, "source": 1}
+            )
 
-            all_models = all_models.union(set(variant_gene["manual_inheritance"]))
-            omim_models = set()
-            for disease_term in variant_gene.get("disease_terms", []):
-                omim_models.update(disease_term.get("inheritance", []))
-            variant_gene["omim_inheritance"] = list(omim_models)
+            all_models.update(set(variant_gene["manual_inheritance"]))
 
-            all_models = all_models.union(omim_models)
+            update_inheritance_model(variant_gene, all_models, disease_terms)
 
     variant_obj["all_models"] = all_models
 
 
+def update_inheritance_model(variant_gene: dict, all_models: set, disease_terms: list):
+    """Update OMIM inheritance model for variant gene - and update the all models
+    variable to contain all inheritance models suggested for the gene/disorder.
+
+    ORPHA disorders can be more of the umbrella kind, where many genes and inheritance
+    models are implied. Those models are still added to all_models for the variant, but not to the list
+    of OMIM inheritance models for the particular gene.
+    """
+    inheritance_models = set()
+    omim_inheritance_models = set()
+
+    for disease_term in disease_terms:
+        inheritance_models.update(disease_term.get("inheritance", []))
+
+        if disease_term.get("source") == "OMIM":
+            omim_inheritance_models.update(inheritance_models)
+
+    variant_gene["omim_inheritance"] = list(omim_inheritance_models)
+
+    all_models.update(inheritance_models)
+
+
 def predictions(genes):
     """Adds information from variant specific genes to display.
 
@@ -302,96 +333,72 @@ def predictions(genes):
     return data
 
 
-def frequencies(variant_obj):
-    """Add frequencies in the correct way for the template
-
-    This function converts the raw annotations to something better to visualize.
-    GnomAD is mandatory and will always be shown.
+def frequencies(variant_obj: dict) -> list[Tuple]:
+    """Convert raw annotations to a more visual format with frequencies.
 
     Args:
         variant_obj(scout.models.Variant)
 
     Returns:
-        frequencies(list(tuple)): A list of frequencies to display
+        list of tuple: A list of frequencies to display.
     """
     is_mitochondrial_variant = variant_obj.get("chromosome") == "MT"
+    category = variant_obj["category"]
 
-    if variant_obj["category"] == "sv":
-        freqs = {
-            "gnomad_frequency": {
-                "display_name": "GnomAD",
-                "link": variant_obj.get("gnomad_sv_link"),
-            },
-            "clingen_cgh_benign": {
-                "display_name": "ClinGen CGH (benign)",
-                "link": None,
-            },
-            "clingen_cgh_pathogenic": {
-                "display_name": "ClinGen CGH (pathogenic)",
-                "link": None,
-            },
-            "clingen_ngi": {"display_name": "ClinGen NGI", "link": None},
-            "clingen_mip": {"display_name": "ClinGen MIP", "link": None},
-            "swegen": {"display_name": "SweGen", "link": None},
-            "decipher": {"display_name": "Decipher", "link": None},
-            "thousand_genomes_frequency": {"display_name": "1000G", "link": None},
-            "thousand_genomes_frequency_left": {
-                "display_name": "1000G(left)",
-                "link": None,
-            },
-            "thousand_genomes_frequency_right": {
-                "display_name": "1000G(right)",
-                "link": None,
-            },
-        }
-    else:
-        freqs = {
-            "gnomad_frequency": {
-                "display_name": "GnomAD",
-                "link": variant_obj.get("gnomad_link"),
-            },
-            "thousand_genomes_frequency": {
-                "display_name": "1000G",
-                "link": variant_obj.get("thousandg_link"),
-            },
-            "max_thousand_genomes_frequency": {
-                "display_name": "1000G(max)",
-                "link": variant_obj.get("thousandg_link"),
-            },
-            "exac_frequency": {
-                "display_name": "ExAC",
-                "link": variant_obj.get("exac_link"),
-            },
-            "max_exac_frequency": {
-                "display_name": "ExAC(max)",
-                "link": variant_obj.get("exac_link"),
-            },
-            "gnomad_mt_homoplasmic_frequency": {
-                "display_name": "GnomAD MT, homoplasmic",
-                "link": variant_obj.get("gnomad_link"),
-            },
-            "gnomad_mt_heteroplasmic_frequency": {
-                "display_name": "GnomAD MT, heteroplasmic",
-                "link": variant_obj.get("gnomad_link"),
-            },
-        }
+    # Define frequency mappings for each category
+    frequency_mappings = {
+        "sv": {
+            "gnomad_frequency": ("GnomAD", variant_obj.get("gnomad_sv_link")),
+            "clingen_cgh_benign": ("ClinGen CGH (benign)", None),
+            "clingen_cgh_pathogenic": ("ClinGen CGH (pathogenic)", None),
+            "clingen_ngi": ("ClinGen NGI", None),
+            "clingen_mip": ("ClinGen MIP", None),
+            "swegen": ("SweGen", None),
+            "decipher": ("Decipher", None),
+            "thousand_genomes_frequency": ("1000G", None),
+            "thousand_genomes_frequency_left": ("1000G(left)", None),
+            "thousand_genomes_frequency_right": ("1000G(right)", None),
+            "colorsdb_af": ("CoLoRSdb", None),
+        },
+        "mei": {
+            "swegen_alu": ("SweGen ALU", None),
+            "swegen_herv": ("SweGen HERV", None),
+            "swegen_l1": ("SweGen L1", None),
+            "swegen_sva": ("SweGen SVA", None),
+            "swegen_mei_max": ("SweGen MEI(max)", None),
+        },
+        "snv": {
+            "gnomad_frequency": ("GnomAD", variant_obj.get("gnomad_link")),
+            "thousand_genomes_frequency": ("1000G", variant_obj.get("thousandg_link")),
+            "max_thousand_genomes_frequency": ("1000G(max)", variant_obj.get("thousandg_link")),
+            "exac_frequency": ("ExAC", variant_obj.get("exac_link")),
+            "max_exac_frequency": ("ExAC(max)", variant_obj.get("exac_link")),
+            "swegen": ("SweGen", variant_obj.get("swegen_link")),
+            "gnomad_mt_homoplasmic_frequency": (
+                "GnomAD MT, homoplasmic",
+                variant_obj.get("gnomad_link"),
+            ),
+            "gnomad_mt_heteroplasmic_frequency": (
+                "GnomAD MT, heteroplasmic",
+                variant_obj.get("gnomad_link"),
+            ),
+            "colorsdb_af": ("CoLoRSdb", None),
+        },
+    }
+
+    # Select the appropriate frequency dictionary
+    freqs = frequency_mappings.get(category, frequency_mappings["snv"])
 
     frequency_list = []
-    for freq_key in freqs:
-        display_name = freqs[freq_key]["display_name"]
+    for freq_key, (display_name, link) in freqs.items():
         value = variant_obj.get(freq_key)
-        link = freqs[freq_key]["link"]
-        # Always add gnomad for non-mitochondrial variants
+
         if freq_key == "gnomad_frequency":
             if is_mitochondrial_variant:
                 continue
-            # If gnomad not found search for exac
-            if not value:
-                value = variant_obj.get("exac_frequency")
-            value = value or "NA"
+            value = value or variant_obj.get("exac_frequency") or "NA"
 
-        # Always add gnomad MT frequencies for mitochondrial variants
-        elif freq_key.startswith("gnomad_mt_") and is_mitochondrial_variant:
+        if freq_key.startswith("gnomad_mt_") and is_mitochondrial_variant:
             value = value or "NA"
 
         if value:
@@ -416,6 +423,8 @@ def frequency(variant_obj):
         variant_obj.get("exac_frequency") or 0,
         variant_obj.get("gnomad_frequency") or 0,
         variant_obj.get("gnomad_mt_homoplasmic_frequency") or 0,
+        variant_obj.get("swegen_mei_max") or 0,
+        variant_obj.get("colorsdb_af") or 0,
     )
 
     if most_common_frequency > 0.05:
@@ -516,18 +525,12 @@ def end_position(variant_obj):
     return variant_obj["position"] + (num_bases - 1)
 
 
-def default_panels(store, case_obj):
+def default_panels(store: MongoAdapter, case_obj: dict) -> List[dict]:
     """Return the panels that are decided to be default for a case.
 
-    Check what panels that are default, fetch those and add them to a list.
-
-    Args:
-        store(scout.adapter.MongoAdapter)
-        case_obj(scout.models.Case)
-
-    Returns:
-        default_panels(list(dict))
+    Check what panels that are default, fetch those and return them in a list.
 
+    case_obj is a dict after scout.models.Case.
     """
     default_panels = []
     # Add default panel information to variant
@@ -588,19 +591,33 @@ def clinsig_human(variant_obj):
         yield clinsig_obj
 
 
-def callers(variant_obj, category="snv"):
+def callers(variant_obj):
     """Return info about callers.
 
     Args:
         variant_obj(scout.models.Variant)
-        category(str)
 
     Returns:
         calls(list(str)): A list of the callers that identified the variant
     """
+    category = variant_obj.get("category", "snv")
     calls = set()
     for caller in CALLERS[category]:
         if variant_obj.get(caller["id"]):
             calls.add((caller["name"], variant_obj[caller["id"]]))
 
     return list(calls)
+
+
+def associate_variant_genes_with_case_panels(case_obj: Dict, variant_obj: Dict) -> None:
+    """Add associated gene panels to each gene in variant object"""
+
+    genes = variant_obj.get("genes", [])
+
+    for gene in genes:
+        hgnc_id = gene["hgnc_id"]
+        matching_panels = []
+        for panel in case_obj.get("latest_panels", []):
+            if hgnc_id in panel["hgnc_ids"]:
+                matching_panels.append(panel["panel_name"])
+        gene["associated_gene_panels"] = matching_panels
