@@ -1,10 +1,19 @@
 import logging
 
-from flask import Blueprint, current_app, flash, jsonify, redirect, request, url_for
+from flask import (
+    Blueprint,
+    current_app,
+    flash,
+    jsonify,
+    redirect,
+    render_template,
+    request,
+    url_for,
+)
 from flask_login import current_user
 from markupsafe import Markup
 
-from scout.constants import ACMG_CRITERIA, ACMG_MAP
+from scout.constants import ACMG_CRITERIA, ACMG_MAP, ACMG_OPTIONS
 from scout.server.blueprints.variant.controllers import check_reset_variant_classification
 from scout.server.blueprints.variant.controllers import evaluation as evaluation_controller
 from scout.server.blueprints.variant.controllers import observations, str_variant_reviewer
@@ -38,16 +47,47 @@ def update_tracks_settings():
     # update user in database with custom tracks info
     user_obj["igv_tracks"] = selected_tracks
     store.update_user(user_obj)
+    setattr(current_user, "igv_tracks", selected_tracks)
     return redirect(request.referrer)
 
 
+@variant_bp.route("/document_id/<variant_id>")
+def variant_by_id(variant_id):
+    """Display variant given by its document id. This includes its unique case name.
+    The view template is selected based on the variant category."""
+    data = variant_controller(
+        store=store,
+        variant_id=variant_id,
+    )
+    if data is None:
+        flash("An error occurred while retrieving variant object", "danger")
+        return redirect(url_for("public.index"))
+
+    if current_app.config.get("LOQUSDB_SETTINGS"):
+        LOG.debug("Fetching loqusdb information for %s", variant_id)
+        data["observations"] = observations(store, loqusdb, data["variant"])
+
+    if data["variant"].get("category") == "sv":
+        return render_template("variant/sv-variant.html", **data)
+
+    if data["variant"].get("category") == "cancer":
+        return render_template("variant/cancer-variant.html", **data)
+
+    return render_template("variant/variant.html", **data)
+
+
 @variant_bp.route("/<institute_id>/<case_name>/<variant_id>")
 @templated("variant/variant.html")
-def variant(institute_id, case_name, variant_id):
+def variant(variant_id, institute_id=None, case_name=None):
     """Display a specific SNV variant."""
     LOG.debug("Variants view requesting data for variant %s", variant_id)
 
-    data = variant_controller(store, institute_id, case_name, variant_id=variant_id)
+    data = variant_controller(
+        store=store,
+        variant_id=variant_id,
+        institute_id=institute_id,
+        case_name=case_name,
+    )
     if data is None:
         flash("An error occurred while retrieving variant object", "danger")
         return redirect(
@@ -56,7 +96,7 @@ def variant(institute_id, case_name, variant_id):
 
     if current_app.config.get("LOQUSDB_SETTINGS"):
         LOG.debug("Fetching loqusdb information for %s", variant_id)
-        data["observations"] = observations(store, loqusdb, data["case"], data["variant"])
+        data["observations"] = observations(store, loqusdb, data["variant"])
 
     return data
 
@@ -67,7 +107,9 @@ def cancer_variant(institute_id, case_name, variant_id):
     """Display a specific SNV variant."""
     LOG.debug("Variants view requesting data for variant %s", variant_id)
 
-    data = variant_controller(store, institute_id, case_name, variant_id=variant_id)
+    data = variant_controller(
+        store=store, variant_id=variant_id, institute_id=institute_id, case_name=case_name
+    )
     if data is None:
         flash("An error occurred while retrieving variant object", "danger")
         return redirect(
@@ -80,7 +122,7 @@ def cancer_variant(institute_id, case_name, variant_id):
 
     if current_app.config.get("LOQUSDB_SETTINGS"):
         LOG.debug("Fetching loqusdb information for %s", variant_id)
-        data["observations"] = observations(store, loqusdb, data["case"], data["variant"])
+        data["observations"] = observations(store, loqusdb, data["variant"])
 
     return data
 
@@ -89,7 +131,12 @@ def cancer_variant(institute_id, case_name, variant_id):
 @templated("variant/sv-variant.html")
 def sv_variant(institute_id, case_name, variant_id):
     """Display a specific structural variant."""
-    data = variant_controller(store, institute_id, case_name, variant_id)
+    data = variant_controller(
+        store=store,
+        variant_id=variant_id,
+        institute_id=institute_id,
+        case_name=case_name,
+    )
 
     if data is None:
         flash("An error occurred while retrieving variant object", "danger")
@@ -99,7 +146,7 @@ def sv_variant(institute_id, case_name, variant_id):
 
     if current_app.config.get("LOQUSDB_SETTINGS"):
         LOG.debug("Fetching loqusdb information for %s", variant_id)
-        data["observations"] = observations(store, loqusdb, data["case"], data["variant"])
+        data["observations"] = observations(store, loqusdb, data["variant"])
 
     return data
 
@@ -262,7 +309,7 @@ def variant_update(institute_id, case_name, variant_id):
 @variant_bp.route("/evaluations/<evaluation_id>", methods=["GET", "POST"])
 @templated("variant/acmg.html")
 def evaluation(evaluation_id):
-    """Show or delete an ACMG evaluation."""
+    """Show, edit or delete an ACMG evaluation."""
 
     evaluation_obj = store.get_evaluation(evaluation_id)
     if evaluation_obj is None:
@@ -282,12 +329,15 @@ def evaluation(evaluation_id):
             flash("Cleared ACMG classification.", "info")
 
         return redirect(link)
+
     return dict(
         evaluation=evaluation_obj,
+        edit=bool(request.args.get("edit")),
         institute=evaluation_obj["institute"],
         case=evaluation_obj["case"],
         variant=evaluation_obj["variant"],
         CRITERIA=ACMG_CRITERIA,
+        ACMG_OPTIONS=ACMG_OPTIONS,
     )
 
 
