@@ -1,34 +1,43 @@
+import decimal
 import logging
 import re
-from datetime import date
+from typing import Any, Dict, List, Optional
 
-import bson
 from flask import Response, flash, session, url_for
 from flask_login import current_user
-from pymongo.errors import DocumentTooLarge
-from werkzeug.datastructures import Headers, MultiDict
+from markupsafe import Markup
+from pymongo.cursor import CursorType
+from werkzeug.datastructures import Headers, ImmutableMultiDict, MultiDict
+from wtforms import DecimalField
 
+from scout.adapter import MongoAdapter
 from scout.constants import (
     ACMG_COMPLETE_MAP,
     ACMG_MAP,
+    CANCER_EXPORT_HEADER,
     CANCER_SPECIFIC_VARIANT_DISMISS_OPTIONS,
     CANCER_TIER_OPTIONS,
     CHROMOSOMES,
     CHROMOSOMES_38,
     CLINSIG_MAP,
     DISMISS_VARIANT_OPTIONS,
+    EXPORT_HEADER,
+    EXPORTED_VARIANTS_LIMIT,
+    FUSION_EXPORT_HEADER,
     MANUAL_RANK_OPTIONS,
     MOSAICISM_OPTIONS,
     SPIDEX_HUMAN,
     VARIANT_FILTERS,
+    VARIANTS_TARGET_FROM_CATEGORY,
 )
-from scout.constants.variants_export import CANCER_EXPORT_HEADER, EXPORT_HEADER
 from scout.server.blueprints.variant.utils import (
+    callers,
     clinsig_human,
     predictions,
     update_representative_gene,
     update_variant_case_panels,
 )
+from scout.server.blueprints.variants.forms import BetterDecimalField
 from scout.server.links import add_gene_links, cosmic_links, str_source_link
 from scout.server.utils import (
     case_has_alignments,
@@ -37,12 +46,29 @@ from scout.server.utils import (
     user_institutes,
 )
 
-from .forms import FILTERSFORMCLASS, CancerSvFiltersForm, SvFiltersForm
+from .forms import FILTERSFORMCLASS, CancerSvFiltersForm, FusionFiltersForm, SvFiltersForm
 from .utils import update_case_panels
 
+NUM = re.compile(r"\d+")
+
 LOG = logging.getLogger(__name__)
 
 
+def get_variants_page(form=ImmutableMultiDict) -> int:
+    """Get current variants page from request data"""
+    pages = form.getlist("page")
+    if pages:
+        return int(Markup.escape(pages[0]))
+    else:
+        return 1
+
+
+def get_expand_search(form=ImmutableMultiDict) -> bool:
+    """Checks whether to expand filters window or not"""
+    pages = form.getlist("page")
+    return pages == ["1"]
+
+
 def populate_force_show_unaffected_vars(institute_obj, form):
     """Whenever a user institute contains the key/value check_show_all_vars=True,
     then all variants (and not only those occurring in affected individuals) should be shown
@@ -124,7 +150,7 @@ def variants(
         if case_obj.get("group"):
             variant_obj["group_assessments"] = _get_group_assessments(store, case_obj, variant_obj)
 
-        update_variant_case_panels(store, case_obj, variant_obj)
+        update_variant_case_panels(case_obj, variant_obj)
 
         variants.append(
             parse_variant(
@@ -209,6 +235,52 @@ def sv_variants(store, institute_obj, case_obj, variants_query, variant_count, p
     return {"variants": variants, "more_variants": more_variants}
 
 
+def mei_variants(
+    store: MongoAdapter,
+    institute_obj: Dict,
+    case_obj: Dict,
+    variants_query: CursorType,
+    variant_count: int,
+    page: int = 1,
+    per_page: int = 50,
+) -> Dict[str, Any]:
+    """Pre-process list of MEI variants."""
+    skip_count = per_page * max(page - 1, 0)
+
+    more_variants = variant_count > (skip_count + per_page)
+    variants = []
+    genome_build = str(case_obj.get("genome_build", "37"))
+    if genome_build not in ["37", "38"]:
+        genome_build = "37"
+
+    case_dismissed_vars = store.case_dismissed_variants(institute_obj, case_obj)
+
+    for variant_obj in variants_query.skip(skip_count).limit(per_page):
+        # show previous classifications for research variants
+        clinical_var_obj = variant_obj
+        if variant_obj["variant_type"] == "research":
+            clinical_var_obj = store.variant(
+                case_id=case_obj["_id"],
+                simple_id=variant_obj["simple_id"],
+                variant_type="clinical",
+            )
+        if clinical_var_obj is not None:
+            variant_obj["clinical_assessments"] = get_manual_assessments(clinical_var_obj)
+
+        variants.append(
+            parse_variant(
+                store,
+                institute_obj,
+                case_obj,
+                variant_obj,
+                genome_build=genome_build,
+                case_dismissed_vars=case_dismissed_vars,
+            )
+        )
+
+    return {"variants": variants, "more_variants": more_variants}
+
+
 def str_variants(
     store, institute_obj, case_obj, variants_query, variant_count, page=1, per_page=50
 ):
@@ -235,6 +307,46 @@ def str_variants(
     return return_view_data
 
 
+def fusion_variants(
+    store, institute_obj, case_obj, variants_query, variant_count, page=1, per_page=50
+):
+    """Pre-process list of fusion variants."""
+    skip_count = per_page * max(page - 1, 0)
+
+    more_variants = variant_count > (skip_count + per_page)
+    variants = []
+    genome_build = str(case_obj.get("genome_build", "38"))
+    if genome_build not in ["37", "38"]:
+        genome_build = "38"
+
+    case_dismissed_vars = store.case_dismissed_variants(institute_obj, case_obj)
+
+    for variant_obj in variants_query.skip(skip_count).limit(per_page):
+        # show previous classifications for research variants
+        clinical_var_obj = variant_obj
+        if variant_obj["variant_type"] == "research":
+            clinical_var_obj = store.variant(
+                case_id=case_obj["_id"],
+                simple_id=variant_obj["simple_id"],
+                variant_type="clinical",
+            )
+        if clinical_var_obj is not None:
+            variant_obj["clinical_assessments"] = get_manual_assessments(clinical_var_obj)
+
+        parsed_variant = parse_variant(
+            store,
+            institute_obj,
+            case_obj,
+            variant_obj,
+            genome_build=genome_build,
+            case_dismissed_vars=case_dismissed_vars,
+        )
+
+        variants.append(parsed_variant)
+
+    return {"variants": variants, "more_variants": more_variants}
+
+
 def get_manual_assessments(variant_obj):
     """Return manual assessments ready for display.
 
@@ -399,7 +511,7 @@ def update_variant_genes(store, variant_obj, genome_build):
 
     if variant_genes is not None:
         for gene_obj in variant_genes:
-            # If there is no hgnc id there is nothin we can do
+            # If there is no hgnc id there is nothing we can do
             if not gene_obj["hgnc_id"]:
                 continue
             # Else we collect the gene object and check the id
@@ -416,27 +528,6 @@ def update_variant_genes(store, variant_obj, genome_build):
     return has_changed
 
 
-def update_variant_store(store, variant_obj):
-    """
-    Update variants in db store if anything changed.
-    Args:
-        store(scout.adapter.MongoAdapter)
-        variant_obj(scout.models.Variant)
-
-        update(boolean): upsert only if this is set true
-
-        get_compounds(bool): if compounds should be added to added to the returned variant object
-
-    """
-    try:
-        variant_obj = store.update_variant(variant_obj)
-    except DocumentTooLarge:
-        flash(
-            f"An error occurred while updating info for variant: {variant_obj['_id']} (pymongo_errors.DocumentTooLarge: {len(bson.BSON.encode(variant_obj))})",
-            "warning",
-        )
-
-
 def _compound_follow_filter_freq(compound, compound_var_obj, query_form):
     """When compound follow filter is selected, apply relevant settings from the query filter onto dismissing compounds.
 
@@ -588,6 +679,14 @@ def _compound_follow_filter_in_compound(compound, compound_var_obj, query_form):
                 compound["is_dismissed"] = True
                 return True
 
+            split_any_gene_items = [
+                possible_gene_item.split(":")[-1]
+                for possible_gene_item in compound_items
+                if ":" in possible_gene_item
+            ]
+            if split_any_gene_items:
+                compound_items = split_any_gene_items
+
             if set(compound_items).isdisjoint(set(query_form_items)):
                 compound["is_dismissed"] = True
                 return True
@@ -625,7 +724,6 @@ def _compound_follow_filter_clnsig(compound, compound_var_obj, query_form):
         str_re = re.compile("|".join(query_str_rank))
 
         compound_clnsig = compound_var_obj.get("clnsig")
-        LOG.debug("compound_var_obj %s", compound_var_obj)
         if compound_clnsig:
             for compound_clnsig_item in compound_clnsig:
                 clnsig_value = compound_clnsig_item.get("value")
@@ -740,7 +838,6 @@ def hide_compounds_query(store, variant_obj, query_form):
             if not compound_var_obj:
                 compound["is_dismissed"] = True
                 continue
-
             compound_follow_filter(compound, compound_var_obj, query_form)
 
 
@@ -775,11 +872,18 @@ def parse_variant(
     compounds_have_changed = False
     if get_compounds:
         compounds_have_changed = update_compounds(store, variant_obj, case_dismissed_vars)
+        if update and compounds_have_changed:
+            store.variant_update_field(
+                variant_id=variant_obj["_id"],
+                field_name="compounds",
+                field_value=variant_obj["compounds"],
+            )
 
     genes_have_changed = update_variant_genes(store, variant_obj, genome_build)
-
-    if update and (compounds_have_changed or genes_have_changed):
-        update_variant_store(store, variant_obj)
+    if update and genes_have_changed:
+        store.variant_update_field(
+            variant_id=variant_obj["_id"], field_name="genes", field_value=variant_obj["genes"]
+        )
 
     variant_obj["comments"] = store.events(
         institute_obj,
@@ -820,6 +924,9 @@ def parse_variant(
     if not "end_chrom" in variant_obj:
         variant_obj["end_chrom"] = variant_obj["chromosome"]
 
+    # common motif count for STR variants
+    variant_obj["str_mc"] = get_str_mc(variant_obj)
+
     # variant level links shown on variants page
     variant_obj["cosmic_links"] = cosmic_links(variant_obj)
     variant_obj["str_source_link"] = str_source_link(variant_obj)
@@ -828,6 +935,9 @@ def parse_variant(
 
     update_representative_gene(variant_obj, variant_genes)
 
+    # Add display information about callers
+    variant_obj["callers"] = callers(variant_obj)
+
     # annotate filters
     variant_obj["filters"] = [
         VARIANT_FILTERS[f]
@@ -838,8 +948,32 @@ def parse_variant(
     return variant_obj
 
 
+def get_str_mc(variant_obj: dict) -> Optional[int]:
+    """Return variant Short Tandem Repeat motif count, either as given by its ALT MC value
+    from the variant FORMAT field, or as a number given in the ALT on the form
+    '<STR123>'.
+    """
+    alt_mc = None
+    if variant_obj["alternative"] == ".":
+        return alt_mc
+
+    for sample in variant_obj["samples"]:
+        if sample["genotype_call"] in ["./.", ".|", "0/0", "0|0"]:
+            continue
+        alt_mc = sample.get("alt_mc")
+    if alt_mc:
+        return alt_mc
+
+    alt_num = NUM.search(variant_obj["alternative"])
+    if alt_num:
+        alt_mc = int(alt_num.group())
+        return alt_mc
+
+    return None
+
+
 def download_str_variants(case_obj, variant_objs):
-    """Download filtered STR variants for a case to an excel file
+    """Download filtered STR variants for a case to a CSV file
 
     Args:
         case_obj(dict)
@@ -867,16 +1001,14 @@ def download_str_variants(case_obj, variant_objs):
     ]
 
     export_lines = []
-    for variant in variant_objs:
+    for variant in variant_objs.limit(EXPORTED_VARIANTS_LIMIT):
         variant_line = []
         variant_line.append(str(variant.get("variant_rank", "")))  # index
         variant_line.append(variant.get("str_repid"))  # Repeat locus
         variant_line.append(
             variant.get("str_display_ru", variant.get("str_ru", ""))
         )  # Reference repeat unit
-        variant_line.append(
-            variant.get("alternative", "").replace("STR", "").replace("<", "").replace(">", "")
-        )  # Estimated size
+        variant_line.append(get_str_mc(variant) or ".")  # Estimated size
         variant_line.append(str(variant.get("str_ref", "")))  # Reference size
         variant_line.append(str(variant.get("str_status", "")))  # Status
         gt_cell = ""
@@ -905,21 +1037,18 @@ def download_str_variants(case_obj, variant_objs):
     )
 
 
-def download_variants(store, case_obj, variant_objs):
-    """Download filtered variants for a case to an excel file
-
-    Args:
-        store(adapter.MongoAdapter)
-        case_obj(dict)
-        variant_objs(PyMongo cursor)
+def download_variants(
+    store: MongoAdapter, case_obj: dict, variant_objs: CursorType, category: Optional[str] = None
+) -> Response:
+    """Download filtered variants for a case to a CSV file
 
     Returns:
         an HTTP response containing a csv file
     """
-    document_header = variants_export_header(case_obj)
-    export_lines = []
-    # Return max 500 variants
-    export_lines = variant_export_lines(store, case_obj, variant_objs.limit(500))
+    document_header = variants_export_header(case_obj, category)
+    export_lines = variant_export_lines(
+        store, case_obj, variant_objs.limit(EXPORTED_VARIANTS_LIMIT), category
+    )
 
     def generate(header, lines):
         yield header + "\n"
@@ -940,85 +1069,168 @@ def download_variants(store, case_obj, variant_objs):
     )
 
 
-def variant_export_lines(store, case_obj, variants_query):
+def variant_export_lines_common(store: MongoAdapter, variant: dict, case_obj: dict) -> list:
+    """
+    Get common variant info to be exported. Returns a list to be merged into a string
+    in suitable export format.
+    """
+    variant_line = []
+    position = variant["position"]
+    change = variant["reference"] + ">" + variant["alternative"]
+    variant_line.append(variant.get("rank_score", "N/A"))
+    variant_line.append(variant["chromosome"])
+    variant_line.append(position)
+    variant_line.append(change)
+    variant_line.append("_".join([str(position), change]))
+
+    gene_list: List[dict] = variant.get("genes", [])
+
+    if gene_list:
+        gene_info = variant_export_genes_info(store, gene_list, case_obj.get("genome_build"))
+        variant_line += gene_info
+    else:
+        empty_col = 0
+        while empty_col < 5:
+            variant_line.append(
+                "-"
+            )  # empty HGNC id, empty gene name, two empty transcripts columns, and consequence
+            empty_col += 1
+
+    if variant.get("cadd_score"):
+        variant_line.append(round(variant["cadd_score"], 2))
+    else:
+        variant_line.append("N/A")
+
+    if variant.get("gnomad_frequency"):
+        variant_line.append(round(variant["gnomad_frequency"], 5))
+    else:
+        variant_line.append("N/A")
+
+    return variant_line
+
+
+def get_fusion_variant_field(variant: dict, field: str) -> str:
+    """Get fusion variant fields that could be from multiple fusion partners.
+    Split if comma separated, and join with 'or' sign, so as not to interfere with csv file generation.
+    Avoid empty values and use "N/A" instead.
+    """
+    value = variant.get(field, "N/A")
+    if "," in value:
+        value = value.split(",")
+    if isinstance(value, list):
+        value = " | ".join(value)
+    if value is None or value == []:
+        value = "N/A"
+    return value
+
+
+def get_fusion_exons(variant: dict) -> str:
+    """Get RNAfusion specific variant exons for all genes/transcripts listed. Join with pipe 'or' character."""
+    exon = ""
+    for gene in variant.get("genes", []):
+        for transcript in gene.get("transcripts", []):
+            if bool(transcript.get("exon")):
+                if exon:
+                    exon = exon + " | "
+                exon = exon + transcript["exon"]
+
+    return exon
+
+
+def variant_export_lines_fusion(variant: dict, case_obj: dict) -> list:
+    """Get RNAfusion specific variant info to be exported. Returns a list to be merged into a string
+    in suitable export format.
+    """
+    variant_line = []
+
+    for field in ["fusion_genes", "orientation", "frame_status", "found_db"]:
+        variant_line.append(get_fusion_variant_field(variant, field))
+
+    variant_line.append(get_fusion_exons(variant))
+
+    variant_gts = variant["samples"]  # list of coverage and gt calls for case samples
+    for individual in case_obj["individuals"]:
+        for variant_gt in variant_gts:
+            if individual["individual_id"] != variant_gt["sample_id"]:
+                continue
+            variant_line.append(variant_gt.get("read_depth", "N/A"))
+            variant_line.append(variant_gt.get("split_read", "N/A"))
+            variant_line.append(variant_gt.get("ffpm", "N/A"))
+
+    return variant_line
+
+
+def variant_export_lines_cancer(variant: dict) -> list:
+    """
+    Get cancer specific variant info to be exported. Returns a list to be merged into a string
+    in suitable export format.
+    """
+    variant_line = []
+
+    # Add cancer and normal VAFs
+    for sample in ["tumor", "normal"]:
+        allele = variant.get(sample)
+        if not allele:
+            variant_line.append("-")
+            continue
+        alt_freq = round(allele.get("alt_freq", 0), 4)
+        alt_depth = allele.get("alt_depth")
+        ref_depth = allele.get("ref_depth")
+
+        vaf_sample = f"{alt_freq} ({alt_depth}|{ref_depth})"
+        variant_line.append(vaf_sample)
+
+    # ADD eventual COSMIC ID
+    cosmic_ids = variant.get("cosmic_ids") or ["-"]
+    variant_line.append(" | ".join(cosmic_ids))
+
+    return variant_line
+
+
+def variant_export_lines_rare(variant: dict, case_obj: dict) -> list:
+    """
+    Get generic rare disease variant info to be exported. Returns a list to be merged into a string
+    in suitable export format.
+    """
+    variant_line = []
+
+    variant_gts = variant["samples"]  # list of coverage and gt calls for case samples
+    for individual in case_obj["individuals"]:
+        for variant_gt in variant_gts:
+            if individual["individual_id"] != variant_gt["sample_id"]:
+                continue
+
+            variant_line.append(variant_gt["genotype_call"])
+            # gather coverage info
+            variant_line.append(variant_gt["allele_depths"][0])  # AD reference
+            variant_line.append(variant_gt["allele_depths"][1])  # AD alternate
+            # gather genotype quality info
+            variant_line.append(variant_gt["genotype_quality"])
+
+    return variant_line
+
+
+def variant_export_lines(
+    store: MongoAdapter, case_obj: dict, variants_query: CursorType, category: Optional[str] = None
+) -> List[str]:
     """Get variants info to be exported to file, one list (line) per variant.
-    Args:
-        store(scout.adapter.MongoAdapter)
-        case_obj(scout.models.Case)
-        variants_query: a list of variant objects, each one is a dictionary
+
     Returns:
         export_variants: a list of strings. Each string  of the list corresponding to the fields
-                         of a variant to be exported to file, separated by comma
+                         of a variant to be exported to file, separated by comma.
     """
 
     export_variants = []
 
     for variant in variants_query:
-        variant_line = []
-        position = variant["position"]
-        change = variant["reference"] + ">" + variant["alternative"]
-        variant_line.append(variant["rank_score"])
-        variant_line.append(variant["chromosome"])
-        variant_line.append(position)
-        variant_line.append(change)
-        variant_line.append("_".join([str(position), change]))
+        variant_line = variant_export_lines_common(store, variant, case_obj)
 
-        # gather gene info:
-        gene_list = variant.get("genes")  # this is a list of gene objects
-
-        # if variant is in genes
-        if gene_list:
-            gene_info = variant_export_genes_info(store, gene_list, case_obj.get("genome_build"))
-            variant_line += gene_info
+        if category == "fusion":
+            variant_line.extend(variant_export_lines_fusion(variant, case_obj))
+        elif case_obj.get("track") == "cancer":
+            variant_line.extend(variant_export_lines_cancer(variant))
         else:
-            empty_col = 0
-            while empty_col < 4:
-                variant_line.append(
-                    "-"
-                )  # empty HGNC id, empty gene name and empty transcripts columns
-                empty_col += 1
-
-        if variant.get("cadd_score"):
-            variant_line.append(round(variant["cadd_score"], 2))
-        else:
-            variant_line.append("N/A")
-
-        if variant.get("gnomad_frequency"):
-            variant_line.append(round(variant["gnomad_frequency"], 5))
-        else:
-            variant_line.append("N/A")
-
-        if case_obj.get("track") == "cancer":
-            # Add cancer and normal VAFs
-            for sample in ["tumor", "normal"]:
-                allele = variant.get(sample)
-                if not allele:
-                    variant_line.append("-")
-                    continue
-                alt_freq = round(allele.get("alt_freq", 0), 4)
-                alt_depth = allele.get("alt_depth")
-                ref_depth = allele.get("ref_depth")
-
-                vaf_sample = f"{alt_freq} ({alt_depth}|{ref_depth})"
-                variant_line.append(vaf_sample)
-
-            # ADD eventual COSMIC ID
-            cosmic_ids = variant.get("cosmic_ids") or ["-"]
-            variant_line.append(" | ".join(cosmic_ids))
-
-        else:
-            variant_gts = variant["samples"]  # list of coverage and gt calls for case samples
-            for individual in case_obj["individuals"]:
-                for variant_gt in variant_gts:
-                    if individual["individual_id"] != variant_gt["sample_id"]:
-                        continue
-
-                    variant_line.append(variant_gt["genotype_call"])
-                    # gather coverage info
-                    variant_line.append(variant_gt["allele_depths"][0])  # AD reference
-                    variant_line.append(variant_gt["allele_depths"][1])  # AD alternate
-                    # gather genotype quality info
-                    variant_line.append(variant_gt["genotype_quality"])
+            variant_line.extend(variant_export_lines_rare(variant, case_obj))
 
         variant_line = [str(i) for i in variant_line]
         export_variants.append(",".join(variant_line))
@@ -1104,16 +1316,20 @@ def variant_export_genes_info(store, gene_list, genome_build="37"):
     return gene_info
 
 
-def variants_export_header(case_obj):
+def variants_export_header(case_obj: dict, category: str = "snv") -> List[str]:
     """Returns a header for the CSV file with the filtered variants to be exported.
     Args:
         case_obj(scout.models.Case)
+        category: Variant category to prepare export for e.g. "fusion"
     Returns:
         header: includes the fields defined in scout.constants.variants_export EXPORT_HEADER
                 + AD_reference, AD_alternate, GT_quality for each sample analysed for a case
     """
+
     header = []
-    if case_obj.get("track") == "cancer":
+    if category == "fusion":
+        header = header + FUSION_EXPORT_HEADER
+    elif case_obj.get("track") == "cancer":
         header = header + CANCER_EXPORT_HEADER
     else:
         header = header + EXPORT_HEADER
@@ -1124,6 +1340,7 @@ def variants_export_header(case_obj):
             header.append("AD_reference_" + display_name)  # Add AD reference field for a sample
             header.append("AD_alternate_" + display_name)  # Add AD alternate field for a sample
             header.append("GT_quality_" + display_name)  # Add Genotype quality field for a sample
+
     return header
 
 
@@ -1206,34 +1423,6 @@ def cancer_variants(store, institute_id, case_name, variants_query, variant_coun
     return data
 
 
-def get_clinvar_submission(store, institute_id, case_name, variant_id, submission_id):
-    """Collects all variants from the clinvar submission collection with a specific submission_id
-    Args:
-        store(scout.adapter.MongoAdapter)
-        institute_id(str): Institute ID
-        case_name(str): case ID
-        variant_id(str): variant._id
-        submission_id(str): clinvar submission id, i.e. SUB76578
-    Returns:
-        A dictionary with all the data to display the clinvar_update.html template page
-    """
-
-    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
-    pinned = [
-        store.variant(variant_id) or variant_id for variant_id in case_obj.get("suspects", [])
-    ]
-    variant_obj = store.variant(variant_id)
-    clinvar_submission_objs = store.clinvars(submission_id=submission_id)
-    return dict(
-        today=str(date.today()),
-        institute=institute_obj,
-        case=case_obj,
-        variant=variant_obj,
-        pinned_vars=pinned,
-        clinvars=clinvar_submission_objs,
-    )
-
-
 def upload_panel(store, institute_id, case_name, stream):
     """Parse out HGNC symbols from a stream."""
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
@@ -1307,9 +1496,6 @@ def populate_filters_form(store, institute_obj, case_obj, user_obj, category, re
     Returns:
         form: FiltersForm
     """
-    form = None
-    clinical_filter_panels = []
-
     default_panels = []
     for panel in case_obj.get("panels", []):
         if panel.get("is_default"):
@@ -1331,7 +1517,7 @@ def populate_filters_form(store, institute_obj, case_obj, user_obj, category, re
             }
         )
         clinical_filter = MultiDict(clinical_filter_dict)
-    elif category in ("sv", "cancer", "cancer_sv"):
+    elif category in ("sv", "cancer", "cancer_sv", "mei", "outlier"):
         clinical_filter_dict = FiltersFormClass.clinical_filter_base
         clinical_filter_dict.update(
             {
@@ -1398,7 +1584,23 @@ def persistent_filter_actions(
 
     if bool(request_form.get("audit_filter")):
         filter_id = request_form.get("filters")
-        filter_obj = store.audit_filter(filter_id, institute_obj, case_obj, user_obj, category)
+        audit_for = dict(
+            category=category, variant_type=request_form.get("variant_type", "clinical")
+        )
+        link: str = url_for(
+            VARIANTS_TARGET_FROM_CATEGORY.get(category),
+            case_name=case_obj.get("display_name"),
+            institute_id=institute_obj.get("_id"),
+            **audit_for,
+        )
+        filter_obj = store.audit_filter(
+            filter_id=filter_id,
+            institute_obj=institute_obj,
+            case_obj=case_obj,
+            user_obj=user_obj,
+            category=category,
+            link=link,
+        )
         if filter_obj is not None:
             filter_obj = store.retrieve_filter(filter_id)
             form = FiltersFormClass(MultiDict(filter_obj))
@@ -1417,7 +1619,47 @@ def persistent_filter_actions(
         filter_id = request_form.get("filters")
         filter_obj = store.retrieve_filter(filter_id)
         if filter_obj is not None:
-            form = FiltersFormClass(MultiDict(filter_obj))
+
+            def _coerce_formdata(filter: dict) -> MultiDict:
+                """According to wtforms docs https://wtforms.readthedocs.io/en/3.1.x/forms/#the-form-class,
+                formdata passed to Form init needs to be pre-coerced to types. Hence especially the replacement
+                of locale specific chars in numbers on class process_formdata would not be enough for the
+                better_decimal form fields.
+
+                Check all filters in the current FiltersFormClass by making an instance, finding any BetterDecimalField
+                or DecimalFields. Replace "," with "." in any string value, and check that the remaining string will
+                convert to a number before finally instantiating the form with values.
+                """
+
+                test_form = FiltersFormClass()
+                for decimal_value_form_field in dir(FiltersFormClass):
+                    if decimal_value_form_field not in filter:
+                        continue
+
+                    if not isinstance(
+                        test_form[decimal_value_form_field],
+                        (BetterDecimalField, DecimalField),
+                    ):
+                        continue
+
+                    if type(filter[decimal_value_form_field][0]) is not str:
+                        continue
+
+                    target_value = filter[decimal_value_form_field][0].replace(",", ".")
+                    if not target_value.replace(".", "", 1).isnumeric():
+                        flash(
+                            f"Requested filter field {decimal_value_form_field} not numeric",
+                            "warning",
+                        )
+                        del filter[decimal_value_form_field]
+                        continue
+
+                    raw_value = decimal.Decimal(target_value)
+                    filter[decimal_value_form_field] = [raw_value]
+
+                return MultiDict(filter)
+
+            form = FiltersFormClass(_coerce_formdata(filter_obj))
         else:
             flash("Requested filter was not found", "warning")
 
@@ -1495,6 +1737,46 @@ def populate_sv_filters_form(store, institute_obj, case_obj, category, request_o
     return form
 
 
+def populate_fusion_filters_form(store, institute_obj, case_obj, category, request_obj):
+    """Populate a filters form object of the type FusionFiltersForm
+
+    Accepts:
+        store(adapter.MongoAdapter)
+        institute_obj(dict)
+        case_obj(dict)
+        category(str)
+        request_obj(Flask.requests obj)
+
+    Returns:
+        form(FusionFiltersForm)
+    """
+
+    form = FusionFiltersForm(request_obj.args)
+    user_obj = store.user(current_user.email)
+
+    if request_obj.method == "GET":
+        if category == "fusion":
+            form = FusionFiltersForm(request_obj.args)
+        variant_type = request_obj.args.get("variant_type", "clinical")
+        form.variant_type.data = variant_type
+        # set chromosome to all chromosomes
+        form.chrom.data = request_obj.args.get("chrom", "")
+        if form.gene_panels.data == [] and variant_type == "clinical":
+            form.gene_panels.data = case_default_panels(case_obj)
+
+    else:  # POST
+        form = populate_filters_form(
+            store, institute_obj, case_obj, user_obj, category, request_obj.form
+        )
+
+    populate_force_show_unaffected_vars(institute_obj, form)
+
+    # populate available panel choices
+    form.gene_panels.choices = gene_panel_choices(store, institute_obj, case_obj)
+
+    return form
+
+
 def _flash_gene_symbol_errors(
     non_clinical_symbols, not_found_symbols, not_found_ids, outdated_symbols, aliased_symbols
 ):
@@ -1695,7 +1977,7 @@ def activate_case(store, institute_obj, case_obj, current_user):
         store.update_status(institute_obj, case_obj, user_obj, "active", case_link)
 
 
-def reset_all_dimissed(store, institute_obj, case_obj):
+def reset_all_dismissed(store, institute_obj, case_obj):
     """Reset all dismissed variants for a case.
 
     Args:
