@@ -1,4 +1,5 @@
 """Views for the variants"""
+
 import io
 import logging
 
@@ -14,14 +15,25 @@ from scout.constants import (
     GENETIC_MODELS_PALETTE,
     MANUAL_RANK_OPTIONS,
     SEVERE_SO_TERMS,
+    SEVERE_SO_TERMS_SV,
 )
 from scout.server.extensions import store
 from scout.server.utils import institute_and_case, templated
 
 from . import controllers
-from .forms import CancerFiltersForm, FiltersForm, StrFiltersForm, SvFiltersForm
+from .forms import (
+    CancerFiltersForm,
+    FiltersForm,
+    FusionFiltersForm,
+    MeiFiltersForm,
+    StrFiltersForm,
+    SvFiltersForm,
+)
 
 LOG = logging.getLogger(__name__)
+
+VARIANT_PAGE = "variant.variant"
+
 variants_bp = Blueprint(
     "variants",
     __name__,
@@ -35,7 +47,7 @@ variants_bp = Blueprint(
 def reset_dismissed(institute_id, case_name):
     """Reset all dismissed variants for a case"""
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
-    controllers.reset_all_dimissed(store, institute_obj, case_obj)
+    controllers.reset_all_dismissed(store, institute_obj, case_obj)
     return redirect(request.referrer)
 
 
@@ -43,12 +55,15 @@ def reset_dismissed(institute_id, case_name):
 @templated("variants/variants.html")
 def variants(institute_id, case_name):
     """Display a list of SNV variants."""
-    page = int(Markup.escape(request.form.get("page", "1")))
+    page = controllers.get_variants_page(request.form)
     category = "snv"
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
     variant_type = Markup.escape(
         request.args.get("variant_type", request.form.get("variant_type", "clinical"))
     )
+    if variant_type not in ["clinical", "research"]:
+        variant_type = "clinical"
+
     variants_stats = store.case_variants_count(case_obj["_id"], institute_id, variant_type, False)
 
     if request.form.get("hpo_clinical_filter"):
@@ -61,7 +76,7 @@ def variants(institute_id, case_name):
                 store,
                 institute_obj,
                 case_obj,
-                "variant.variant",
+                VARIANT_PAGE,
                 request.form.getlist("dismiss"),
                 request.form.getlist("dismiss_choices"),
             )
@@ -108,7 +123,6 @@ def variants(institute_id, case_name):
             return redirect(request.referrer)
 
         hgnc_symbols_set = set(form.hgnc_symbols.data)
-        LOG.debug("Symbols prior to upload: {0}".format(hgnc_symbols_set))
         new_hgnc_symbols = controllers.upload_panel(store, institute_id, case_name, stream)
         hgnc_symbols_set.update(new_hgnc_symbols)
         form.hgnc_symbols.data = hgnc_symbols_set
@@ -117,35 +131,42 @@ def variants(institute_id, case_name):
 
     controllers.update_form_hgnc_symbols(store, case_obj, form)
 
-    cytobands = store.cytoband_by_chrom(case_obj.get("genome_build"))
+    genome_build = "38" if "38" in str(case_obj.get("genome_build", "37")) else "37"
+    cytobands = store.cytoband_by_chrom(genome_build)
 
-    variants_query = store.variants(case_obj["_id"], query=form.data, category=category)
-    result_size = store.count_variants(case_obj["_id"], form.data, None, category)
+    variants_query = store.variants(
+        case_obj["_id"], query=form.data, category=category, build=genome_build
+    )
+    result_size = store.count_variants(
+        case_obj["_id"], form.data, None, category, build=genome_build
+    )
 
     if request.form.get("export"):
         return controllers.download_variants(store, case_obj, variants_query)
 
     data = controllers.variants(
-        store, institute_obj, case_obj, variants_query, result_size, page, query_form=form.data
+        store,
+        institute_obj,
+        case_obj,
+        variants_query,
+        result_size,
+        page,
+        query_form=form.data,
     )
 
-    expand_search = request.method == "POST" and request.form.get("expand_search") in [
-        "True",
-        "",
-    ]
     return dict(
-        institute=institute_obj,
-        case=case_obj,
-        form=form,
-        filters=available_filters,
-        manual_rank_options=MANUAL_RANK_OPTIONS,
-        dismiss_variant_options=DISMISS_VARIANT_OPTIONS,
         cancer_tier_options=CANCER_TIER_OPTIONS,
-        severe_so_terms=SEVERE_SO_TERMS,
-        genetic_models_palette=GENETIC_MODELS_PALETTE,
+        case=case_obj,
         cytobands=cytobands,
+        dismiss_variant_options=DISMISS_VARIANT_OPTIONS,
+        expand_search=controllers.get_expand_search(request.form),
+        filters=available_filters,
+        form=form,
+        genetic_models_palette=GENETIC_MODELS_PALETTE,
+        institute=institute_obj,
+        manual_rank_options=MANUAL_RANK_OPTIONS,
         page=page,
-        expand_search=expand_search,
+        severe_so_terms=SEVERE_SO_TERMS,
         show_dismiss_block=controllers.get_show_dismiss_block(),
         result_size=result_size,
         total_variants=variants_stats.get(variant_type, {}).get(category, "NA"),
@@ -157,12 +178,13 @@ def variants(institute_id, case_name):
 @templated("variants/str-variants.html")
 def str_variants(institute_id, case_name):
     """Display a list of STR variants."""
-
-    page = int(Markup.escape(request.form.get("page", "1")))
+    page = controllers.get_variants_page(request.form)
     category = "str"
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
 
     variant_type = Markup.escape(request.args.get("variant_type", "clinical"))
+    if variant_type not in ["clinical", "research"]:
+        variant_type = "clinical"
 
     variants_stats = store.case_variants_count(case_obj["_id"], institute_id, variant_type, False)
 
@@ -184,6 +206,7 @@ def str_variants(institute_id, case_name):
         form.chrom.data = request.args.get("chrom", "")
 
     controllers.populate_force_show_unaffected_vars(institute_obj, form)
+    controllers.update_form_hgnc_symbols(store, case_obj, form)
 
     # populate filters dropdown
     available_filters = list(store.filters(institute_id, category))
@@ -199,12 +222,15 @@ def str_variants(institute_id, case_name):
 
     controllers.activate_case(store, institute_obj, case_obj, current_user)
 
-    cytobands = store.cytoband_by_chrom(case_obj.get("genome_build"))
+    genome_build = "38" if "38" in str(case_obj.get("genome_build", "37")) else "37"
+    cytobands = store.cytoband_by_chrom(genome_build)
 
     query = form.data
     query["variant_type"] = variant_type
 
-    variants_query = store.variants(case_obj["_id"], category=category, query=query).sort(
+    variants_query = store.variants(
+        case_obj["_id"], category=category, query=query, build=genome_build
+    ).sort(
         [
             ("str_repid", pymongo.ASCENDING),
             ("chromosome", pymongo.ASCENDING),
@@ -212,7 +238,7 @@ def str_variants(institute_id, case_name):
         ]
     )
 
-    result_size = store.count_variants(case_obj["_id"], query, None, category)
+    result_size = store.count_variants(case_obj["_id"], query, None, category, build=genome_build)
 
     if request.form.get("export"):
         return controllers.download_str_variants(case_obj, variants_query)
@@ -222,19 +248,19 @@ def str_variants(institute_id, case_name):
     )
 
     return dict(
-        institute=institute_obj,
         case=case_obj,
-        dismiss_variant_options=DISMISS_VARIANT_OPTIONS,
-        variant_type=variant_type,
-        manual_rank_options=MANUAL_RANK_OPTIONS,
         cytobands=cytobands,
-        form=form,
-        page=page,
+        dismiss_variant_options=DISMISS_VARIANT_OPTIONS,
+        expand_search=controllers.get_expand_search(request.form),
         filters=available_filters,
-        expand_search=str(request.method == "POST"),
+        form=form,
+        institute=institute_obj,
+        manual_rank_options=MANUAL_RANK_OPTIONS,
+        page=page,
         result_size=result_size,
         show_dismiss_block=controllers.get_show_dismiss_block(),
         total_variants=variants_stats.get(variant_type, {}).get(category, "NA"),
+        variant_type=variant_type,
         **data,
     )
 
@@ -243,13 +269,14 @@ def str_variants(institute_id, case_name):
 @templated("variants/sv-variants.html")
 def sv_variants(institute_id, case_name):
     """Display a list of structural variants."""
-
-    page = int(Markup.escape(request.form.get("page", "1")))
+    page = controllers.get_variants_page(request.form)
     category = "sv"
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
     variant_type = Markup.escape(
         request.args.get("variant_type", request.form.get("variant_type", "clinical"))
     )
+    if variant_type not in ["clinical", "research"]:
+        variant_type = "clinical"
     variants_stats = store.case_variants_count(case_obj["_id"], institute_id, variant_type, False)
 
     if request.form.get("hpo_clinical_filter"):
@@ -278,14 +305,18 @@ def sv_variants(institute_id, case_name):
     # Populate chromosome select choices
     controllers.populate_chrom_choices(form, case_obj)
 
-    genome_build = "38" if "38" in str(case_obj.get("genome_build")) else "37"
+    genome_build = "38" if "38" in str(case_obj.get("genome_build", "37")) else "37"
     cytobands = store.cytoband_by_chrom(genome_build)
 
     controllers.update_form_hgnc_symbols(store, case_obj, form)
 
-    variants_query = store.variants(case_obj["_id"], category=category, query=form.data)
+    variants_query = store.variants(
+        case_obj["_id"], category=category, query=form.data, build=genome_build
+    )
 
-    result_size = store.count_variants(case_obj["_id"], form.data, None, category)
+    result_size = store.count_variants(
+        case_obj["_id"], form.data, None, category, build=genome_build
+    )
 
     # if variants should be exported
     if request.form.get("export"):
@@ -294,22 +325,115 @@ def sv_variants(institute_id, case_name):
     data = controllers.sv_variants(
         store, institute_obj, case_obj, variants_query, result_size, page
     )
-    expand_search = request.method == "POST" and request.form.get("expand_search") in [
-        "True",
-        "",
-    ]
+
     return dict(
         case=case_obj,
         cytobands=cytobands,
         dismiss_variant_options=DISMISS_VARIANT_OPTIONS,
-        expand_search=expand_search,
+        expand_search=controllers.get_expand_search(request.form),
         filters=available_filters,
         form=form,
         institute=institute_obj,
         manual_rank_options=MANUAL_RANK_OPTIONS,
         page=page,
         result_size=result_size,
-        severe_so_terms=SEVERE_SO_TERMS,
+        severe_so_terms=SEVERE_SO_TERMS_SV,
+        show_dismiss_block=controllers.get_show_dismiss_block(),
+        total_variants=variants_stats.get(variant_type, {}).get(category, "NA"),
+        variant_type=variant_type,
+        **data,
+    )
+
+
+@variants_bp.route("/<institute_id>/<case_name>/mei/variants", methods=["GET", "POST"])
+@templated("variants/mei-variants.html")
+def mei_variants(institute_id, case_name):
+    """Display a list of mobile element insertion (MEI) variants."""
+    page = controllers.get_variants_page(request.form)
+    category = "mei"
+    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+    variant_type = Markup.escape(
+        request.args.get("variant_type", request.form.get("variant_type", "clinical"))
+    )
+    variants_stats = store.case_variants_count(case_obj["_id"], institute_id, variant_type, False)
+
+    if request.form.get("hpo_clinical_filter"):
+        case_obj["hpo_clinical_filter"] = True
+
+    if "dismiss_submit" in request.form:  # dismiss a list of variants
+        controllers.dismiss_variant_list(
+            store,
+            institute_obj,
+            case_obj,
+            "variant.sv_variant",
+            request.form.getlist("dismiss"),
+            request.form.getlist("dismiss_choices"),
+        )
+
+    # update status of case if visited for the first time
+    controllers.activate_case(store, institute_obj, case_obj, current_user)
+
+    user_obj = store.user(current_user.email)
+    if request.method == "POST":
+        form = controllers.populate_filters_form(
+            store, institute_obj, case_obj, user_obj, category, request.form
+        )
+    else:
+        form = MeiFiltersForm(request.args)
+
+        if form.gene_panels.data == [] and variant_type == "clinical":
+            form.gene_panels.data = controllers.case_default_panels(case_obj)
+
+        # set form variant data type the first time around
+        form.variant_type.data = variant_type
+        # set chromosome to all chromosomes
+        form.chrom.data = request.args.get("chrom", "")
+
+    # populate filters dropdown
+    available_filters = list(store.filters(institute_obj["_id"], category))
+    form.filters.choices = [
+        (filter.get("_id"), filter.get("display_name")) for filter in available_filters
+    ]
+
+    # Populate chromosome select choices
+    controllers.populate_chrom_choices(form, case_obj)
+
+    # populate available panel choices
+    form.gene_panels.choices = controllers.gene_panel_choices(store, institute_obj, case_obj)
+
+    genome_build = "38" if "38" in str(case_obj.get("genome_build", "37")) else "37"
+    cytobands = store.cytoband_by_chrom(genome_build)
+
+    controllers.update_form_hgnc_symbols(store, case_obj, form)
+
+    variants_query = store.variants(
+        case_obj["_id"], category=category, query=form.data, build=genome_build
+    )
+
+    result_size = store.count_variants(
+        case_obj["_id"], form.data, None, category, build=genome_build
+    )
+
+    # if variants should be exported
+    if request.form.get("export"):
+        return controllers.download_variants(store, case_obj, variants_query)
+
+    data = controllers.mei_variants(
+        store, institute_obj, case_obj, variants_query, result_size, page
+    )
+
+    return dict(
+        case=case_obj,
+        cytobands=cytobands,
+        dismiss_variant_options=DISMISS_VARIANT_OPTIONS,
+        expand_search=controllers.get_expand_search(request.form),
+        filters=available_filters,
+        form=form,
+        institute=institute_obj,
+        manual_rank_options=MANUAL_RANK_OPTIONS,
+        page=page,
+        result_size=result_size,
+        severe_so_terms=SEVERE_SO_TERMS_SV,
         show_dismiss_block=controllers.get_show_dismiss_block(),
         total_variants=variants_stats.get(variant_type, {}).get(category, "NA"),
         variant_type=variant_type,
@@ -321,11 +445,16 @@ def sv_variants(institute_id, case_name):
 @templated("variants/cancer-variants.html")
 def cancer_variants(institute_id, case_name):
     """Show cancer variants overview."""
+
+    page = controllers.get_variants_page(request.form)
+
     category = "cancer"
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
     variant_type = Markup.escape(
         request.args.get("variant_type", request.form.get("variant_type", "clinical"))
     )
+    if variant_type not in ["clinical", "research"]:
+        variant_type = "clinical"
     variants_stats = store.case_variants_count(case_obj["_id"], institute_id, variant_type, False)
 
     user_obj = store.user(current_user.email)
@@ -335,7 +464,7 @@ def cancer_variants(institute_id, case_name):
                 store,
                 institute_obj,
                 case_obj,
-                "variant.variant",
+                VARIANT_PAGE,
                 request.form.getlist("dismiss"),
                 request.form.getlist("dismiss_choices"),
             )
@@ -353,20 +482,15 @@ def cancer_variants(institute_id, case_name):
             # Flash a message with errors
             for field, err_list in form.errors.items():
                 for err in err_list:
-                    flash(f"Content of field '{field}' does not have a valid format", "warning")
+                    flash(
+                        f"Content of field '{field}' does not have a valid format",
+                        "warning",
+                    )
             # And do not submit the form
             return redirect(
-                url_for(
-                    ".cancer_variants",
-                    institute_id=institute_id,
-                    case_name=case_name,
-                    expand_search=True,
-                )
+                url_for(".cancer_variants", institute_id=institute_id, case_name=case_name)
             )
-        page = int(Markup.escape(request.form.get("page", "1")))
-
     else:
-        page = int(Markup.escape(request.args.get("page", "1")))
         form = CancerFiltersForm(request.args)
         # set chromosome to all chromosomes
         form.chrom.data = request.args.get("chrom", "")
@@ -388,7 +512,8 @@ def cancer_variants(institute_id, case_name):
     controllers.populate_chrom_choices(form, case_obj)
 
     form.gene_panels.choices = controllers.gene_panel_choices(store, institute_obj, case_obj)
-    genome_build = "38" if "38" in str(case_obj.get("genome_build")) else "37"
+
+    genome_build = "38" if "38" in str(case_obj.get("genome_build", "37")) else "37"
     cytobands = store.cytoband_by_chrom(genome_build)
 
     controllers.update_form_hgnc_symbols(store, case_obj, form)
@@ -396,7 +521,9 @@ def cancer_variants(institute_id, case_name):
     variants_query = store.variants(
         case_obj["_id"], category="cancer", query=form.data, build=genome_build
     )
-    result_size = store.count_variants(case_obj["_id"], form.data, None, category)
+    result_size = store.count_variants(
+        case_obj["_id"], form.data, None, category, build=genome_build
+    )
 
     if request.form.get("export"):
         return controllers.download_variants(store, case_obj, variants_query)
@@ -410,22 +537,19 @@ def cancer_variants(institute_id, case_name):
         form,
         page=page,
     )
-    expand_search = request.method == "POST" and request.form.get("expand_search") in [
-        "True",
-        "",
-    ]
+
     return dict(
-        variant_type=variant_type,
         cytobands=cytobands,
-        filters=available_filters,
         dismiss_variant_options={
             **DISMISS_VARIANT_OPTIONS,
             **CANCER_SPECIFIC_VARIANT_DISMISS_OPTIONS,
         },
-        expand_search=expand_search,
-        show_dismiss_block=controllers.get_show_dismiss_block(),
+        expand_search=controllers.get_expand_search(request.form),
+        filters=available_filters,
         result_size=result_size,
+        show_dismiss_block=controllers.get_show_dismiss_block(),
         total_variants=variants_stats.get(variant_type, {}).get(category, "NA"),
+        variant_type=variant_type,
         **data,
     )
 
@@ -435,12 +559,14 @@ def cancer_variants(institute_id, case_name):
 def cancer_sv_variants(institute_id, case_name):
     """Display a list of cancer structural variants."""
 
-    page = int(Markup.escape(request.form.get("page", "1")))
+    page = controllers.get_variants_page(request.form)
     category = "cancer_sv"
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
     variant_type = Markup.escape(
         request.args.get("variant_type", request.form.get("variant_type", "clinical"))
     )
+    if variant_type not in ["clinical", "research"]:
+        variant_type = "clinical"
     variants_stats = store.case_variants_count(case_obj["_id"], institute_id, variant_type, False)
 
     if request.form.get("hpo_clinical_filter"):
@@ -469,14 +595,18 @@ def cancer_sv_variants(institute_id, case_name):
     # Populate chromosome select choices
     controllers.populate_chrom_choices(form, case_obj)
 
-    genome_build = "38" if "38" in str(case_obj.get("genome_build")) else "37"
+    genome_build = "38" if "38" in str(case_obj.get("genome_build", "37")) else "37"
     cytobands = store.cytoband_by_chrom(genome_build)
 
     controllers.update_form_hgnc_symbols(store, case_obj, form)
 
-    variants_query = store.variants(case_obj["_id"], category=category, query=form.data)
+    variants_query = store.variants(
+        case_obj["_id"], category=category, query=form.data, build=genome_build
+    )
 
-    result_size = store.count_variants(case_obj["_id"], form.data, None, category)
+    result_size = store.count_variants(
+        case_obj["_id"], form.data, None, category, build=genome_build
+    )
 
     # if variants should be exported
     if request.form.get("export"):
@@ -485,10 +615,7 @@ def cancer_sv_variants(institute_id, case_name):
     data = controllers.sv_variants(
         store, institute_obj, case_obj, variants_query, result_size, page
     )
-    expand_search = request.method == "POST" and request.form.get("expand_search") in [
-        "True",
-        "",
-    ]
+
     return dict(
         case=case_obj,
         cancer_tier_options=CANCER_TIER_OPTIONS,
@@ -497,7 +624,93 @@ def cancer_sv_variants(institute_id, case_name):
             **DISMISS_VARIANT_OPTIONS,
             **CANCER_SPECIFIC_VARIANT_DISMISS_OPTIONS,
         },
-        expand_search=expand_search,
+        expand_search=controllers.get_expand_search(request.form),
+        filters=available_filters,
+        form=form,
+        institute=institute_obj,
+        manual_rank_options=MANUAL_RANK_OPTIONS,
+        page=page,
+        result_size=result_size,
+        severe_so_terms=SEVERE_SO_TERMS,
+        show_dismiss_block=controllers.get_show_dismiss_block(),
+        total_variants=variants_stats.get(variant_type, {}).get(category, "NA"),
+        variant_type=variant_type,
+        **data,
+    )
+
+
+@variants_bp.route("/<institute_id>/<case_name>/fusion/variants", methods=["GET", "POST"])
+@templated("variants/fusion-variants.html")
+def fusion_variants(institute_id, case_name):
+    """Display a list of fusion variants."""
+
+    page = controllers.get_variants_page(request.form)
+    category = "fusion"
+    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+    variant_type = Markup.escape(
+        request.args.get("variant_type", request.form.get("variant_type", "clinical"))
+    )
+    if variant_type not in ["clinical", "research"]:
+        variant_type = "clinical"
+    variants_stats = store.case_variants_count(case_obj["_id"], institute_id, variant_type, False)
+
+    if request.form.get("hpo_clinical_filter"):
+        case_obj["hpo_clinical_filter"] = True
+
+    if "dismiss_submit" in request.form:  # dismiss a list of variants
+        controllers.dismiss_variant_list(
+            store,
+            institute_obj,
+            case_obj,
+            VARIANT_PAGE,
+            request.form.getlist("dismiss"),
+            request.form.getlist("dismiss_choices"),
+        )
+
+    # update status of case if visited for the first time
+    controllers.activate_case(store, institute_obj, case_obj, current_user)
+    form = controllers.populate_fusion_filters_form(
+        store, institute_obj, case_obj, category, request
+    )
+
+    # populate filters dropdown
+    available_filters = list(store.filters(institute_obj["_id"], category))
+    form.filters.choices = [
+        (filter.get("_id"), filter.get("display_name")) for filter in available_filters
+    ]
+
+    # Populate chromosome select choices
+    controllers.populate_chrom_choices(form, case_obj)
+
+    genome_build = "38" if "38" in str(case_obj.get("genome_build", "37")) else "37"
+    cytobands = store.cytoband_by_chrom(genome_build)
+
+    controllers.update_form_hgnc_symbols(store, case_obj, form)
+
+    variants_query = store.variants(
+        case_obj["_id"], category=category, query=form.data, build=genome_build
+    )
+
+    result_size = store.count_variants(
+        case_obj["_id"], form.data, None, category, build=genome_build
+    )
+
+    # if variants should be exported
+    if request.form.get("export"):
+        return controllers.download_variants(store, case_obj, variants_query, category=category)
+
+    data = controllers.fusion_variants(
+        store, institute_obj, case_obj, variants_query, result_size, page
+    )
+
+    return dict(
+        case=case_obj,
+        cancer_tier_options=CANCER_TIER_OPTIONS,
+        cytobands=cytobands,
+        dismiss_variant_options={
+            **DISMISS_VARIANT_OPTIONS,
+        },
+        expand_search=controllers.get_expand_search(request.form),
         filters=available_filters,
         form=form,
         institute=institute_obj,
@@ -531,6 +744,8 @@ def upload_panel(institute_id, case_name):
 
     if category == "sv":
         form = SvFiltersForm(request.args)
+    elif category == "fusion":
+        form = FusionFiltersForm(request.args)
     else:
         form = FiltersForm(request.args)
 
@@ -562,3 +777,12 @@ def toggle_show_dismiss_block():
     """Endpoint to toggle the show dismiss block session variable."""
     session["show_dismiss_block"] = not session.get("show_dismiss_block")
     return f"Toggled to {session['show_dismiss_block']}"
+
+
+@variants_bp.route("/variants/un-audit_filter", methods=["GET"])
+def unaudit_filter():
+    """Un-audit an audited filter."""
+    store.unaudit_filter(
+        audit_id=request.args.get("audit_id"), user_obj=store.user(current_user.email)
+    )
+    return redirect(request.referrer)
