@@ -6,9 +6,11 @@ from flask_login import LoginManager
 from flask_mail import Mail
 
 from scout.adapter import MongoAdapter
-from scout.utils.cloud_resources import AlignTrackHandler
+from scout.utils.track_resources import AlignTrackHandler
 
 from .beacon_extension import Beacon
+from .bionano_extension import BioNanoAccessAPI
+from .chanjo_extension import ChanjoReport
 from .clinvar_extension import ClinVarApi
 from .gens_extension import GensViewer
 from .ldap_extension import LdapManager
@@ -32,4 +34,6 @@ phenopacketapi = PhenopacketAPI()
 rerunner = RerunnerService()
 matchmaker = MatchMaker()
 beacon = Beacon()
-cloud_tracks = AlignTrackHandler()
+config_igv_tracks = AlignTrackHandler()
+bionano_access = BioNanoAccessAPI()
+chanjo_report = ChanjoReport()
