@@ -1,3 +1,6 @@
+from typing import Any, Dict, List, Optional, Tuple
+from urllib.parse import quote
+
 from flask import current_app
 
 from scout.constants import SPIDEX_HUMAN
@@ -11,15 +14,14 @@ BEACON_LINK_TEMPLATE = (
 )
 
 
-def add_gene_links(gene_obj, build=37):
+def add_gene_links(
+    gene_obj: Dict[str, Any], build: int = 37, institute: Optional[Dict[str, Any]] = None
+):
     """Update a gene object with links
 
     Args:
-        gene_obj(dict)
-        build(int)
-
-    Returns:
-        gene_obj(dict): gene_obj updated with many links
+        gene_obj (scout.models.variant.Gene)
+        institute(scout.models.Institute)
     """
     try:
         build = int(build)
@@ -38,6 +40,10 @@ def add_gene_links(gene_obj, build=37):
     if not hgnc_symbol:
         hgnc_symbol = gene_obj.get("hgnc_symbol")
 
+    gene_aliases = gene_obj.get("common", {}).get("aliases")
+    if not gene_aliases:
+        gene_aliases = gene_obj.get("aliases", [])
+
     ensembl_37_link = ensembl(ensembl_id, build=37)
     ensembl_38_link = ensembl(ensembl_id, build=38)
     gene_obj["ensembl_37_link"] = ensembl_37_link
@@ -56,6 +62,7 @@ def add_gene_links(gene_obj, build=37):
     # Add links that use entrez_id
     entrez_id = gene_obj.get("common", {}).get("entrez_id")
     gene_obj["entrez_link"] = entrez(entrez_id)
+    gene_obj["pubmed_link"] = pubmed(hgnc_symbol, gene_aliases)
     gene_obj["ckb_link"] = ckb_gene(entrez_id)
     # Add links that use omim id
     gene_obj["omim_link"] = omim(gene_obj.get("omim_id"))
@@ -73,6 +80,15 @@ def add_gene_links(gene_obj, build=37):
     gene_obj["stripy_link"] = stripy_gene(hgnc_symbol)
     gene_obj["gnomad_str_link"] = gnomad_str_gene(hgnc_symbol)
     gene_obj["panelapp_link"] = panelapp_gene(hgnc_symbol)
+    gene_obj["decipher_link"] = decipher_gene(hgnc_symbol)
+    if institute:
+        gene_obj["alamut_link"] = alamut_gene_link(institute, gene_obj, build)
+
+
+def decipher_gene(hgnc_symbol: str) -> Optional[str]:
+    """Create link to Decipher gene."""
+    if hgnc_symbol:
+        return f"https://www.deciphergenomics.org/gene/{hgnc_symbol}/overview/clinical-info"
 
 
 def panelapp_gene(hgnc_symbol):
@@ -95,13 +111,13 @@ def stripy_gene(hgnc_symbol):
 
 
 def gnomad_str_gene(hgnc_symbol):
-    link = "https://gnomad.broadinstitute.org/short-tandem-repeat/{}?dataset=gnomad_r3"
+    link = "https://gnomad.broadinstitute.org/short-tandem-repeat/{}?dataset=gnomad_r4"
 
     if not hgnc_symbol:
         return None
 
     if hgnc_symbol in SHALLOW_REFERENCE_STR_LOCI:
-        return "https://gnomad.broadinstitute.org/short-tandem-repeats?dataset=gnomad_r3"
+        return "https://gnomad.broadinstitute.org/short-tandem-repeats?dataset=gnomad_r4"
 
     return link.format(hgnc_symbol)
 
@@ -143,7 +159,7 @@ def genemania(hgnc_symbol):
 
 
 def genenames(hgnc_id):
-    link = "https://www.genenames.org/cgi-bin/gene_symbol_report?hgnc_id=HGNC:{}"
+    link = "https://www.genenames.org/data/gene-symbol-report/#!/hgnc_id/HGNC:{}"
     if not hgnc_id:
         return None
     return link.format(hgnc_id)
@@ -156,6 +172,18 @@ def omim(omim_id):
     return link.format(omim_id)
 
 
+def disease_link(disease_id: str) -> str:
+    """Returns a link for disease depending on the source of the term"""
+    source, disease_nr = disease_id.split(":")
+    link = None
+    if source == "OMIM":
+        link = f"https://www.omim.org/entry/{disease_nr}"
+    elif source == "ORPHA":
+        link = f"https://www.orpha.net/consor/cgi-bin/OC_Exp.php?lng=en&Expert={disease_nr}"
+
+    return link
+
+
 def ensembl(ensembl_id, build=37):
     link = "http://grch37.ensembl.org/Homo_sapiens/Gene/Summary?db=core;g={}"
     if build == 38:
@@ -182,7 +210,7 @@ def gnomad(ensembl_id, build=37):
     if build == 37:
         link += "gnomad_r2_1"
     if build == 38:
-        link += "gnomad_r3"
+        link += "gnomad_r4"
 
     return link.format(ensembl_id)
 
@@ -247,9 +275,19 @@ def entrez(entrez_id):
     return link.format(entrez_id)
 
 
-def ppaint(hgnc_symbol):
-    link = "https://pecan.stjude.cloud/proteinpaint/{}"
+def pubmed(hgnc_symbol: str, gene_aliases: List[str]) -> str:
+    if not len(gene_aliases):
+        link = "https://pubmed.ncbi.nlm.nih.gov/?term={}"
+        return link.format(hgnc_symbol)
 
+    link = "https://pubmed.ncbi.nlm.nih.gov/?term=" + hgnc_symbol
+    for alias in gene_aliases:
+        link += "+OR+" + alias
+    return link
+
+
+def ppaint(hgnc_symbol):
+    link = "https://pecan.stjude.cloud/variants/proteinpaint?gene={}"
     if not hgnc_symbol:
         return None
 
@@ -419,11 +457,10 @@ def iarctp53(hgnc_symbol):
 ############# Variant links ####################
 
 
-def get_variant_links(institute_obj, variant_obj, build=None):
-    """Update a variant object with links
+def get_variant_links(institute_obj: dict, variant_obj: dict, build: int = None):
+    """Return links for a variant object
 
     Args:
-        institute_obj(scout.models.Institute)
         variant_obj(scout.models.Variant)
         build(int)
 
@@ -434,6 +471,7 @@ def get_variant_links(institute_obj, variant_obj, build=None):
         build = int(build)
     except (ValueError, TypeError) as err:
         build = 37
+
     links = dict(
         thousandg_link=thousandg_link(variant_obj, build),
         exac_link=exac_link(variant_obj),
@@ -445,12 +483,13 @@ def get_variant_links(institute_obj, variant_obj, build=None):
         ucsc_link=ucsc_link(variant_obj, build),
         decipher_link=decipher_link(variant_obj, build),
         ensembl_link=ensembl_link(variant_obj, build),
-        alamut_link=alamut_link(institute_obj, variant_obj, build),
         mitomap_link=mitomap_link(variant_obj),
         hmtvar_link=hmtvar_link(variant_obj),
         spidex_human=spidex_human(variant_obj),
+        spliceai_link=spliceai_link(variant_obj, build),
         str_source_link=str_source_link(variant_obj),
         snp_links=snp_links(variant_obj),
+        alamut_link=alamut_variant_link(institute_obj, variant_obj, build),
     )
     return links
 
@@ -515,18 +554,18 @@ def decipher_link(variant_obj, build=37):
         my_end = variant_obj["position"]
 
     if build == 37:
-        url_template = "https://decipher.sanger.ac.uk/search/patients/browser?q=grch37:{this[chromosome]}:{this[position]}-{my_end}"
+        url_template = "https://www.deciphergenomics.org/search/patients/browser?q=grch37:{this[chromosome]}:{this[position]}-{my_end}"
     else:
-        url_template = "https://decipher.sanger.ac.uk/browser#q/{this[chromosome]}:{this[position]}-{this[end]}/location/{this[chromosome]}:{this[position]}-{my_end}"
+        url_template = "https://www.deciphergenomics.org/browser#q/{this[chromosome]}:{this[position]}-{this[end]}/location/{this[chromosome]}:{this[position]}-{my_end}"
     return url_template.format(this=variant_obj, my_end=my_end)
 
 
 def exac_link(variant_obj):
     """Compose link to ExAC website for a variant position."""
     url_template = (
-        "https://exac.broadinstitute.org/variant/"
+        "https://gnomad.broadinstitute.org/variant/"
         "{this[chromosome]}-{this[position]}-{this[reference]}"
-        "-{this[alternative]}"
+        "-{this[alternative]}?dataset=exac"
     )
     return url_template.format(this=variant_obj)
 
@@ -538,8 +577,22 @@ def gnomad_link(variant_obj, build=37):
         "{this[position]}-{this[reference]}-{this[alternative]}"
     ).format(this=variant_obj)
 
+    if build == 37:
+        url_template += "?dataset=gnomad_r2_1"
+        return url_template
+
     if build == 38 or variant_obj["chromosome"] in ["M", "MT"]:
-        url_template += "?dataset=gnomad_r3"
+        url_template += "?dataset=gnomad_r4"
+
+    return url_template
+
+
+def spliceai_link(variant_obj, build=37):
+    """Compopse a link to BROADs SpliceAI Lookup for a somewhat live view of SpliceAI and Pangolin scores."""
+    url_template = (
+        "https://spliceailookup.broadinstitute.org/#variant={this[chromosome]}-"
+        "{this[position]}-{this[reference]}-{this[alternative]}&hg={build}&distance=500&mask=1"
+    ).format(this=variant_obj, build=build)
 
     return url_template
 
@@ -547,14 +600,11 @@ def gnomad_link(variant_obj, build=37):
 def gnomad_sv_link(variant_obj, build=37):
     """Compose link to gnomAD website for a structural variant.
 
-    GnomAD SVs are not yet public for hg38 or MT as 2023-02-01.
-
     Since we do not track the GnomAD variant ID we link to the region view instead.
     For balanced variants, we pick the region for the start position (the var is available in both).
-    """
 
-    if build == 38 or variant_obj["chromosome"] in ["M", "MT"]:
-        return "https://gnomad.broadinstitute.org/"
+    MT SVs are not available for 38 yet.
+    """
 
     url_template = (
         "https://gnomad.broadinstitute.org/region/{this[chromosome]}-{this[position]}"
@@ -565,7 +615,11 @@ def gnomad_sv_link(variant_obj, build=37):
     else:
         url_template += f"-{variant_obj['position']}"
 
-    url_template += "?dataset=gnomad_sv_r2_1"
+    if build == 37:
+        url_template += "?dataset=gnomad_sv_r2_1"
+        return url_template
+
+    url_template += "?dataset=gnomad_sv_r4"
 
     return url_template
 
@@ -625,9 +679,9 @@ def snp_links(variant_obj):
         if "rs" in snp:
             snp_links[snp] = f"https://www.ncbi.nlm.nih.gov/snp/{snp}"  # dbSNP
         elif snp.isnumeric():
-            snp_links[
-                snp
-            ] = f"https://www.ncbi.nlm.nih.gov/clinvar/variation/{snp}"  # ClinVar variation
+            snp_links[snp] = (
+                f"https://www.ncbi.nlm.nih.gov/clinvar/variation/{snp}"  # ClinVar variation
+            )
 
     return snp_links
 
@@ -696,49 +750,125 @@ def mutantp53(hgnc_id, protein_variant):
     return url_template.format(protein_variant)
 
 
-def alamut_link(
-    institute_obj,
-    variant_obj,
-    build=None,
-):
+def alamut_variant_link(
+    institute_obj: Dict[str, Any],
+    variant_obj: Dict[str, Any],
+    build: Optional[int] = None,
+) -> str:
     """Compose a link which open up variants in the Alamut software
+    Alamut links require some settings from the institute object.
+    This link is rendered on the variant side. Alamut has issues with GATK style genome coordinates for indels, but
+    it can sometimes be good to be able to link to a given genome coordinate, e.g. for non coding variantion.
+
+    We use variant coordinates, effectively making a build dependent g. string.
 
     Args:
         institute_obj(scout.models.Institute)
         variant_obj(scout.models.Variant):
-        build(str): "37" or "38"
 
     Returns:
         url_template(str): link to Alamut browser
     """
-    build = build or 37
-    build_str = ""
-    if build == 38:
-        build_str = "(GRCh38)"
 
     if current_app.config.get("HIDE_ALAMUT_LINK"):
         return False
 
+    if not institute_obj:
+        return
+
+    (search_verb, alamut_key_arg, alamut_inst_arg) = _get_alamut_config(institute_obj)
+
     url_template = (
-        "http://localhost:10000/{search_verb}?{alamut_key_arg}{alamut_inst_arg}request={this[chromosome]}{build_str}:"
+        "http://localhost:10000/{search_verb}?{alamut_key_arg}{alamut_inst_arg}request={chromosome}{build_str}:"
         "{this[position]}{this[reference]}>{this[alternative]}"
     )
-    alamut_key = institute_obj.get("alamut_key")
-    alamut_institution = institute_obj.get("alamut_institution")
-    # Alamut Visual Plus API has a different search verb
-    search_verb = "search" if alamut_key else "show"
-    alamut_key_arg = f"apikey={alamut_key}&" if alamut_key else ""
-    alamut_inst_arg = f"institution={alamut_institution}&" if alamut_institution else ""
+    chromosome = variant_obj.get("chromosome")
+
+    build = build or 37
+    build_str = ""
+    if build == 38:
+        build_str = "(GRCh38)"
+        chromosome = chromosome.replace("M", "MT")
 
     return url_template.format(
         search_verb=search_verb,
         alamut_key_arg=alamut_key_arg,
         alamut_inst_arg=alamut_inst_arg,
+        chromosome=chromosome,
         this=variant_obj,
         build_str=build_str,
     )
 
 
+def alamut_gene_link(
+    institute_obj: Dict[str, Any],
+    gene_obj: Dict[str, Any],
+    build: Optional[int] = None,
+):
+    """Compose a link which open up variants in the Alamut software.
+    Alamut links require some settings from the institute object.
+    The link is rendered on the gene side as Alamut has issues with GATK style genome coordinates for indels.
+
+    We utilise the "canonical" transcript for each gene, as well as the HGVS c. string.
+
+    Args:
+        institute_obj(scout.models.Institute)
+        variant_obj(scout.models.Variant):
+
+    Returns:
+        url_template(str): link to Alamut browser
+    """
+
+    if current_app.config.get("HIDE_ALAMUT_LINK"):
+        return False
+
+    if not institute_obj:
+        return False
+
+    (search_verb, alamut_key_arg, alamut_inst_arg) = _get_alamut_config(institute_obj)
+
+    url_template = (
+        "http://localhost:10000/{search_verb}?{alamut_key_arg}{alamut_inst_arg}request={this[canonical_transcript]}{build_str}:"
+        "{hgvs_identifier}"
+    )
+
+    build = build or 37
+    build_str = ""
+    if build == 38:
+        build_str = "(GRCh38)"
+
+    hgvs_raw = gene_obj.get("hgvs_identifier")
+    if not hgvs_raw:
+        return False
+
+    return url_template.format(
+        search_verb=search_verb,
+        alamut_key_arg=alamut_key_arg,
+        alamut_inst_arg=alamut_inst_arg,
+        this=gene_obj,
+        build_str=build_str,
+        hgvs_identifier=quote(hgvs_raw),
+    )
+
+
+def _get_alamut_config(institute_obj: dict) -> Tuple[str, ...]:
+    """
+    Prepare Alamut connection string specifics from institute level configuration.
+
+    Args:
+        institute_obj:   scout.models.Institute
+    """
+
+    alamut_key = institute_obj.get("alamut_key")
+    search_verb = "search" if alamut_key else "show"
+    alamut_key_arg = f"apikey={alamut_key}&" if alamut_key else ""
+
+    alamut_institution = institute_obj.get("alamut_institution")
+    alamut_inst_arg = f"institution={alamut_institution}&" if alamut_institution else ""
+
+    return (search_verb, alamut_key_arg, alamut_inst_arg)
+
+
 def mitomap_link(variant_obj):
     """Compose a link to a variant in mitomap"""
     url_template = "https://mitomap.org/cgi-bin/search_allele?variant={this[position]}{this[reference]}%3E{this[alternative]}"
