@@ -1,4 +1,5 @@
 """Common utilities for the server code"""
+
 import datetime
 import logging
 import os
@@ -6,10 +7,11 @@ import pathlib
 import zipfile
 from functools import wraps
 from io import BytesIO
+from typing import Dict, Optional, Tuple
 
 import pdfkit
 from bson.objectid import ObjectId
-from flask import abort, flash, render_template, request
+from flask import abort, current_app, flash, render_template, request
 from flask_login import current_user
 
 LOG = logging.getLogger(__name__)
@@ -100,6 +102,35 @@ def public_endpoint(function):
     return function
 
 
+def variant_institute_and_case(
+    store, variant_obj: dict, institute_id: Optional[str], case_name: Optional[str]
+) -> Tuple[dict, dict]:
+    """Fetch insitiute and case objects.
+
+    Ensure that case_id on the variant matches that of any case given.
+    Ensure user has access to variant institute, or to the case through institute case sharing.
+    """
+
+    if not case_name:
+        variant_case_obj = store.case(
+            case_id=variant_obj["case_id"], projection={"display_name": 1}
+        )
+        case_name = variant_case_obj["display_name"]
+
+    if not institute_id:
+        institute_id = variant_obj["institute"]
+
+    (institute_obj, case_obj) = institute_and_case(store, institute_id, case_name)
+
+    if case_obj is None:
+        return abort(404)
+
+    if variant_obj.get("case_id") != case_obj.get("_id"):
+        return abort(403)
+
+    return (institute_obj, case_obj)
+
+
 def institute_and_case(store, institute_id, case_name=None):
     """Fetch insitiute and case objects."""
 
@@ -133,6 +164,38 @@ def institute_and_case(store, institute_id, case_name=None):
     return institute_obj
 
 
+def user_cases(store, login_user):
+    """Returns all institutes with case count for a logged user
+
+    Args:
+        store(scout.adapter.mongo.base.MongoAdapter)
+        login_user(werkzeug.local.LocalProxy)
+
+    Returns:
+        pymongo.Cursor
+    """
+
+    match_query = {
+        "$match": {
+            "collaborators": {"$in": login_user.institutes},
+        }
+    }  # Return only cases available for the user
+    group = {
+        "$group": {
+            "_id": {
+                "institute": "$owner",
+            },
+            "count": {"$sum": 1},
+        }
+    }  # Group cases by institute
+    sort = {"$sort": {"_id.institute": 1}}  # Sort by inst _id ascending
+    if login_user.is_admin:
+        pipeline = [group, sort]
+    else:
+        pipeline = [match_query, group, sort]
+    return store.case_collection.aggregate(pipeline)
+
+
 def user_institutes(store, login_user):
     """Preprocess institute objects."""
     if login_user.is_admin:
@@ -143,41 +206,42 @@ def user_institutes(store, login_user):
     return institutes
 
 
-def variant_case(store, case_obj, variant_obj):
-    """Pre-process case for the variant view.
-
-    Adds information about files from case obj to variant
-
-    Args:
-        store(scout.adapter.MongoAdapter)
-        case_obj(scout.models.Case)
-        variant_obj(scout.models.Variant)
-    """
-
-    chrom = None
-    starts = []
-    ends = []
-    for gene in variant_obj.get("genes", []):
-        common_info = gene.get("common")
-        if not common_info:
+def case_has_mtdna_report(case_obj: dict):
+    """Display mtDNA report on the case sidebar only for some specific cases."""
+    if case_obj.get("track", "rare") == "cancer":
+        return
+    for ind in case_obj.get("individuals", []):
+        if ind.get("analysis_type") == "wts":
             continue
-        chrom = common_info.get("chromosome")
-        starts.append(common_info.get("start"))
-        ends.append(common_info.get("end"))
-
-    if not (chrom and starts and ends):
+        case_obj["mtdna_report"] = True
         return
 
-    try:
-        vcf_path = store.get_region_vcf(case_obj, chrom=chrom, start=min(starts), end=max(ends))
 
-        # Create a reduced VCF with variants in the region
-        case_obj["region_vcf_file"] = vcf_path
-    except FileNotFoundError as err:
-        LOG.warning(err)
+def case_has_chanjo_coverage(case_obj: dict):
+    """Set case_obj["chanjo_coverage"] to True if there is an instance of chanjo available and case has coverage stats in chanjo."""
+
+    chanjo_instance: bool = bool(current_app.config.get("chanjo_report"))
+    if case_obj.get("track", "rare") != "cancer" and chanjo_instance:
+        for ind in case_obj.get("individuals", []):
+            if ind.get("analysis_type") != "wts":
+                case_obj["chanjo_coverage"] = True
+                return
 
 
-def case_has_alignments(case_obj):
+def case_has_chanjo2_coverage(case_obj: dict):
+    """Set case_obj["chanjo_coverage"] to True if if there is an instance of chanjo available and case has coverage stats in chanjo2."""
+
+    chanjo2_instance: bool = bool(current_app.config.get("CHANJO2_URL"))
+    if chanjo2_instance is False:
+        return
+    for ind in case_obj.get("individuals", []):
+        ind_d4: str = ind.get("d4_file")
+        if ind_d4 and os.path.exists(ind_d4):
+            case_obj["chanjo2_coverage"] = True
+            return
+
+
+def case_has_alignments(case_obj: dict):
     """Add info on bam/cram files availability to a case dictionary
 
     Args:
@@ -191,7 +255,7 @@ def case_has_alignments(case_obj):
             return
 
 
-def case_has_mt_alignments(case_obj):
+def case_has_mt_alignments(case_obj: dict):
     """Add info on MT bam files availability to a case dictionary
 
     Args:
@@ -199,12 +263,40 @@ def case_has_mt_alignments(case_obj):
     """
     case_obj["mt_bams"] = False  # Availability of alignments for MT chromosome
     for ind in case_obj.get("individuals"):
-        mt_bam_path = ind.get("mt_bam")
-        if mt_bam_path and os.path.exists(mt_bam_path):
+        if _check_path_name(ind, "mt_bam"):
             case_obj["mt_bams"] = True
             return
 
 
+def case_has_rna_tracks(case_obj: Dict) -> bool:
+    """Returns True if one or more individuals of the case contain RNA-seq data
+    Add this info to the case obj dict.
+
+    Args:
+        case_obj(dict)
+    Returns
+        True or False (bool)
+    """
+    # Display junctions track if available for any of the individuals
+    case_obj["has_rna_tracks"] = False
+    for ind in case_obj.get("individuals", []):
+        # RNA can have three different aln track files
+        for path_name in ["splice_junctions_bed", "rna_coverage_bigwig", "rna_alignment_path"]:
+            if _check_path_name(ind, path_name):
+                case_obj["has_rna_tracks"] = True
+                return True
+    return False
+
+
+def _check_path_name(ind: Dict, path_name: str) -> bool:
+    """Returns True if path with name path_name is set on individual and exists on disk."""
+
+    path = ind.get(path_name)
+    if path and os.path.exists(path):
+        return True
+    return False
+
+
 def case_append_alignments(case_obj):
     """Deconvolute information about files to case_obj.
 
