@@ -1,36 +1,5 @@
-def test_diagnose(adapter, institute_obj, case_obj, user_obj, omim_term):
-    """Test update a case onject with a diagnosis"""
-
-    # Given a database with no events
-    assert adapter.event_collection.find_one() is None
-
-    # GIVEN a test case with no assigned diagnosis
-    assert case_obj.get("diagnosis_phenotypes") is None
-    adapter.case_collection.insert_one(case_obj)
-
-    # WHEN case is diagnosis is updated via the "diagnose" function
-    updated_case = adapter.diagnose(
-        institute_obj,
-        case_obj,
-        user_obj,
-        "test_link",
-        omim_term,
-        ["ind1_id|ind1_name", "ind2_id|ind2_name"],
-        False,
-    )
-
-    # THEN case should be updated with diagnosis data
-    assert updated_case["diagnosis_phenotypes"][0]["disease_id"] == omim_term["disease_id"]
-    assert updated_case["diagnosis_phenotypes"][0]["disease_nr"]
-    assert updated_case["diagnosis_phenotypes"][0]["description"]
-    assert updated_case["diagnosis_phenotypes"][0]["individuals"]
-
-    # And a relative event should have been created in database
-    assert adapter.event_collection.find_one()
-
-
 def test_case_dismissed_variants(adapter, institute_obj, case_obj, user_obj, variant_obj):
-    """Test adaptter function that retrieves the list of dismissed variant ids for a case"""
+    """Test adapter function that retrieves the list of dismissed variant ids for a case"""
     # GIVEN a variant db with at least one variant, and no events
     adapter.case_collection.insert_one(case_obj)
     adapter.institute_collection.insert_one(institute_obj)
@@ -49,7 +18,7 @@ def test_case_dismissed_variants(adapter, institute_obj, case_obj, user_obj, var
         dismiss_variant=dismiss_reason,
     )
     # THEN one event should be found in events collection
-    assert sum(1 for i in adapter.event_collection.find()) == 1
+    assert sum(1 for _ in adapter.event_collection.find()) == 1
     # AND case_dismissed_variants should return a list containing the id of the variant
     assert adapter.case_dismissed_variants(institute_obj, case_obj) == [variant_obj["_id"]]
 
@@ -63,7 +32,7 @@ def test_case_dismissed_variants(adapter, institute_obj, case_obj, user_obj, var
         dismiss_variant=[],  # with this list empty the status is reset to not dismissed
     )
     # THEN two events should be found in events collection
-    assert sum(1 for i in adapter.event_collection.find()) == 2
+    assert sum(1 for _ in adapter.event_collection.find()) == 2
     # AND case_dismissed_variants should NOT return a list containing the id of the variant
     assert adapter.case_dismissed_variants(institute_obj, case_obj) == []
 
@@ -77,6 +46,6 @@ def test_case_dismissed_variants(adapter, institute_obj, case_obj, user_obj, var
         dismiss_variant=dismiss_reason,
     )
     # THEN three events should be found in events collection
-    assert sum(1 for i in adapter.event_collection.find()) == 3
+    assert sum(1 for _ in adapter.event_collection.find()) == 3
     # AND case_dismissed_variants should again return a list containing the id of the variant
     assert adapter.case_dismissed_variants(institute_obj, case_obj) == [variant_obj["_id"]]
