@@ -11,29 +11,58 @@ from scout.exceptions import IntegrityError
 logger = logging.getLogger(__name__)
 
 
-def test_add_cases(adapter, case_obj):
+def test_add_cases(adapter, case_obj, institute_obj):
     ## GIVEN an empty database (no cases)
     assert adapter.case_collection.find_one() is None
 
     ## WHEN adding a new case to the database
-    adapter._add_case(case_obj)
+    adapter.add_case(case_obj, institute_obj)
 
     ## THEN it should be populated with the new case
     result = adapter.cases()
-    assert sum(1 for i in result) == 1
+    assert sum(1 for _ in result) == 1
     for case in result:
         assert case["owner"] == case_obj["owner"]
 
 
-def test_add_existing_case(adapter, case_obj):
+def test_add_existing_case(adapter, case_obj, institute_obj):
     ## GIVEN an empty database (no cases)
     assert adapter.case_collection.find_one() is None
 
-    adapter._add_case(case_obj)
+    adapter.add_case(case_obj, institute_obj)
     ## WHEN adding a existing case to the database
     with pytest.raises(IntegrityError):
         ## THEN it should raise integrity error
-        adapter._add_case(case_obj)
+        adapter.add_case(case_obj, institute_obj)
+
+
+def test_add_case_rank_model_version(case_obj, institute_obj, adapter):
+    ## GIVEN a database with no cases
+    assert adapter.case_collection.find_one() is None
+
+    ## WHEN loading a case
+    adapter.add_case(case_obj, institute_obj)
+
+    ## THEN assert that the case have been loaded with rank_model
+    loaded_case = adapter.case_collection.find_one({"_id": case_obj["_id"]})
+
+    assert loaded_case["rank_model_version"] == case_obj["rank_model_version"]
+    assert loaded_case["sv_rank_model_version"] == case_obj["sv_rank_model_version"]
+
+
+def test_add_case_limsid(case_obj, institute_obj, adapter):
+    """Test loading a case with lims_id"""
+
+    ## GIVEN a database with no cases
+    assert adapter.case_collection.find_one() is None
+
+    ## WHEN loading a case
+    adapter.add_case(case_obj, institute_obj)
+
+    ## THEN assert that the case have been loaded with lims id
+    loaded_case = adapter.case_collection.find_one({"_id": case_obj["_id"]})
+
+    assert loaded_case["lims_id"] == case_obj["lims_id"]
 
 
 def test_load_case_existing_case_id(adapter, institute_obj, case_obj):
@@ -42,7 +71,7 @@ def test_load_case_existing_case_id(adapter, institute_obj, case_obj):
     ## GIVEN an empty database with an isntitute
     adapter.institute_collection.insert_one(institute_obj)
     ## AND a case
-    adapter._add_case(case_obj)
+    adapter.add_case(case_obj, institute_obj)
 
     ## GIVEN an attempt to load the same case using the load_case function
     ## THEN it should raise integrity error
@@ -56,7 +85,7 @@ def test_load_case_existing_display_name(adapter, institute_obj, case_obj):
     ## GIVEN an empty database with an isntitute
     adapter.institute_collection.insert_one(institute_obj)
     ## AND a case
-    adapter._add_case(case_obj)
+    adapter.add_case(case_obj, institute_obj)
 
     # GIVEN another case with same institute and display name of first case
     config2 = copy.deepcopy(case_obj)
@@ -74,7 +103,7 @@ def test_load_case_existing_case_different_name(adapter, institute_obj, case_obj
     ## GIVEN an empty database with an isntitute
     adapter.institute_collection.insert_one(institute_obj)
     ## AND a case
-    adapter._add_case(case_obj)
+    adapter.add_case(case_obj, institute_obj)
 
     # GIVEN another case with same _id but different display_name
     config2 = copy.deepcopy(case_obj)
@@ -92,7 +121,7 @@ def test_load_case_existing_case_different_individuals(adapter, institute_obj, c
     ## GIVEN an empty database with an isntitute
     adapter.institute_collection.insert_one(institute_obj)
     ## AND a case
-    adapter._add_case(case_obj)
+    adapter.add_case(case_obj, institute_obj)
 
     # GIVEN another case with same _id but different individuals information
     config2 = copy.deepcopy(case_obj)
@@ -123,10 +152,10 @@ def test_get_cases(adapter, case_obj):
     ## WHEN retreiving an existing case from the database
     result = adapter.cases()
     ## THEN we should get the correct case
-    assert sum(1 for i in result) == 1
+    assert sum(1 for _ in result) == 1
 
 
-def test_get_prioritized_cases(adapter, case_obj, institute_obj):
+def test_cases_by_status(adapter, case_obj, institute_obj):
     ## GIVEN an empty database (no cases)
     assert adapter.case_collection.find_one() is None
     # WHEN inserting a prioritized case
@@ -134,19 +163,10 @@ def test_get_prioritized_cases(adapter, case_obj, institute_obj):
     adapter.case_collection.insert_one(case_obj)
 
     # WHEN retrieving prioritized casese for the institute
-    result = adapter.prioritized_cases(institute_id=institute_obj["_id"])
+    result = adapter.cases_by_status(institute_id=institute_obj["_id"], status="prioritized")
 
     # THEN one prioritized case is returned
-    assert sum(1 for i in result) == 1
-
-
-def test_nr_cases(adapter, case_obj):
-    ## GIVEN an empty database (no cases)
-    ## WHEN adding one case to the case collection
-    adapter.case_collection.insert_one(case_obj)
-    ## THEN the function nr_cases should return number of cases = 1
-    result = adapter.nr_cases(institute_id=case_obj["owner"])
-    assert result == 1
+    assert sum(1 for _ in result) == 1
 
 
 def test_search_active_case(real_adapter, case_obj, institute_obj, user_obj):
@@ -166,13 +186,13 @@ def test_search_active_case(real_adapter, case_obj, institute_obj, user_obj):
     name_query = "status:active"
     # THEN a case should be returned
     cases = adapter.cases(collaborator=case_obj["owner"], name_query=name_query)
-    assert sum(1 for i in cases) == 1
+    assert sum(1 for _ in cases) == 1
 
     # BUT WHEN querying for inactive cases
     name_query = "status:inactive"
     # THEN no case should be returned.
     inactive_cases = adapter.cases(collaborator=case_obj["owner"], name_query=name_query)
-    assert sum(1 for i in inactive_cases) == 0
+    assert sum(1 for _ in inactive_cases) == 0
 
 
 def test_get_research_case(real_adapter, case_obj, institute_obj):
@@ -191,7 +211,7 @@ def test_get_research_case(real_adapter, case_obj, institute_obj):
 
     # THEN searching for reasearch cases should return one case
     research_cases = adapter.cases(owner=case_obj["owner"], is_research=True)
-    assert sum(1 for i in research_cases) == 1
+    assert sum(1 for _ in research_cases) == 1
 
 
 def test_get_cases_no_synopsis(real_adapter, case_obj, institute_obj, user_obj):
@@ -201,14 +221,14 @@ def test_get_cases_no_synopsis(real_adapter, case_obj, institute_obj, user_obj):
 
     # Insert a case
     adapter.case_collection.insert_one(case_obj)
-    assert sum(1 for i in adapter.case_collection.find()) == 1
+    assert sum(1 for _ in adapter.case_collection.find()) == 1
 
     # WHEN providing an empty value for synopsis:
     assert case_obj["synopsis"] == ""
     name_query = "synopsis:"
     # Then case should be returned
     cases = adapter.cases(collaborator=case_obj["owner"], name_query=name_query)
-    assert sum(1 for i in cases) == 1
+    assert sum(1 for _ in cases) == 1
 
     # After adding synopsis to case
     link = "synopsislink"
@@ -226,32 +246,37 @@ def test_get_cases_no_synopsis(real_adapter, case_obj, institute_obj, user_obj):
     name_query = "synopsis:"
     # Then case should NOT be returned
     cases = adapter.cases(collaborator=case_obj["owner"], name_query=name_query)
-    assert sum(1 for i in cases) == 0
+    assert sum(1 for _ in cases) == 0
 
     # but if a term contained in case synopsis is provided in name query:
     name_query = "synopsis:seizures"
 
     # Then updated case should be returned
     cases = adapter.cases(collaborator=updated_case["owner"], name_query=name_query)
-    assert sum(1 for i in cases) == 1
+    assert sum(1 for _ in cases) == 1
 
 
 def test_get_cases_no_HPO(adapter, case_obj):
     # GIVEN an empty database (no cases)
     assert adapter.case_collection.find_one() is None
+
+    # GIVEN a case obj that has neither phenotype groups or phenotype terms
+    case_obj.pop("phenotype_groups", None)
+    case_obj.pop("phenotype_terms", None)
+
     adapter.case_collection.insert_one(case_obj)
 
     # WHEN providing an empty value for term HP:
     name_query = "exact_pheno:"
     # Then case should be returned
     cases = adapter.cases(collaborator=case_obj["owner"], name_query=name_query)
-    assert sum(1 for i in cases) == 1
+    assert sum(1 for _ in cases) == 1
 
     # WHEN providing an empty value for phenotype group:
     name_query = "pheno_group:"
     # Then case should be returned
     cases = adapter.cases(collaborator=case_obj["owner"], name_query=name_query)
-    assert sum(1 for i in cases) == 1
+    assert sum(1 for _ in cases) == 1
 
     # Add phenotype group and HPO term to case object:
     adapter.case_collection.find_one_and_update(
@@ -267,16 +292,16 @@ def test_get_cases_no_HPO(adapter, case_obj):
     name_query = "exact_pheno:"
     # Then case should NOT be returned
     cases = adapter.cases(collaborator=case_obj["owner"], name_query=name_query)
-    assert sum(1 for i in cases) == 0
+    assert sum(1 for _ in cases) == 0
 
     # WHEN providing an empty value for phenotype group:
     name_query = "pheno_group:"
     # Then case should NOT be returned
     cases = adapter.cases(collaborator=case_obj["owner"], name_query=name_query)
-    assert sum(1 for i in cases) == 0
+    assert sum(1 for _ in cases) == 0
 
 
-def test_cases_no_diagnosis(adapter, case_obj, omim_term):
+def test_cases_no_diagnosis(adapter, case_obj):
     """Test filtering cases by empty diagnosis field"""
 
     # GIVEN a case without any diagnosis:
@@ -287,7 +312,7 @@ def test_cases_no_diagnosis(adapter, case_obj, omim_term):
     name_query = "exact_dia:"
     cases = adapter.cases(collaborator=case_obj["owner"], name_query=name_query)
     # THEN a case should be returned
-    assert sum(1 for i in cases) == 1
+    assert sum(1 for _ in cases) == 1
 
 
 def test_get_cases_no_assignees(real_adapter, case_obj):
@@ -298,7 +323,7 @@ def test_get_cases_no_assignees(real_adapter, case_obj):
     # WHEN retreiving an existing case from the database
     result = adapter.cases(name_query="user:john")
     # THEN we should get the correct case
-    assert sum(1 for i in result) == 0
+    assert sum(1 for _ in result) == 0
 
 
 def test_get_cases_display_name(real_adapter, case_obj):
@@ -315,7 +340,7 @@ def test_get_cases_display_name(real_adapter, case_obj):
     # WHEN retreiving cases by partial display name
     result = adapter.cases(name_query="case:643")
     # THEN we should get the correct case
-    assert sum(1 for i in result) == 1
+    assert sum(1 for _ in result) == 1
 
 
 def test_get_cases_existing_individual(real_adapter, case_obj):
@@ -326,7 +351,7 @@ def test_get_cases_existing_individual(real_adapter, case_obj):
     # WHEN retreiving cases by partial individual name
     result = adapter.cases(name_query="case:NA1288")
     # THEN we should get the correct case
-    assert sum(1 for i in result) == 1
+    assert sum(1 for _ in result) == 1
 
 
 def test_get_cases_assignees(real_adapter, case_obj, user_obj):
@@ -343,7 +368,7 @@ def test_get_cases_assignees(real_adapter, case_obj, user_obj):
     # WHEN retreiving cases by partial individual name
     result = adapter.cases(name_query="user:john")
     # THEN we should get the correct case
-    assert sum(1 for i in result) == 1
+    assert sum(1 for _ in result) == 1
 
 
 def test_get_cases_non_existing_assignee(real_adapter, case_obj, user_obj):
@@ -360,7 +385,7 @@ def test_get_cases_non_existing_assignee(real_adapter, case_obj, user_obj):
     # WHEN retreiving cases by partial individual name
     result = adapter.cases(name_query="user:damien")
     # THEN we should get the correct case
-    assert sum(1 for i in result) == 0
+    assert sum(1 for _ in result) == 0
 
 
 def test_get_cases_causatives(adapter, case_obj):
@@ -375,7 +400,7 @@ def test_get_cases_causatives(adapter, case_obj):
     # WHEN retreiving cases that have causatives
     result = adapter.cases(has_causatives=True)
     # THEN we should find one case
-    assert sum(1 for i in result) == 1
+    assert sum(1 for _ in result) == 1
 
 
 def test_get_cases_causatives_no_causatives(adapter, case_obj):
@@ -388,7 +413,7 @@ def test_get_cases_causatives_no_causatives(adapter, case_obj):
     # WHEN retreiving all cases that have causatives
     result = adapter.cases(has_causatives=True)
     # THEN we should get the correct case
-    assert sum(1 for i in result) == 0
+    assert sum(1 for _ in result) == 0
 
 
 def test_get_cases_empty_causatives(adapter, case_obj):
@@ -403,7 +428,7 @@ def test_get_cases_empty_causatives(adapter, case_obj):
     # WHEN retreiving all cases that have causatives
     result = adapter.cases(has_causatives=True)
     # THEN we should not find any cases
-    assert sum(1 for i in result) == 0
+    assert sum(1 for _ in result) == 0
 
 
 def test_get_cases_non_existing_display_name(real_adapter, case_obj):
@@ -414,13 +439,13 @@ def test_get_cases_non_existing_display_name(real_adapter, case_obj):
     # WHEN retreiving cases by partial display name
     result = adapter.cases(name_query="case:hello")
     # THEN we should get the correct case
-    assert sum(1 for i in result) == 0
+    assert sum(1 for _ in result) == 0
 
 
-def test_get_non_existing_case(adapter, case_obj):
+def test_get_non_existing_case(adapter, case_obj, institute_obj):
     # GIVEN an empty database (no cases)
     assert adapter.case_collection.find_one() is None
-    adapter._add_case(case_obj)
+    adapter.add_case(case_obj, institute_obj)
     logger.info("Testing to get case")
 
     # WHEN retreiving an non existing case from the database
@@ -437,7 +462,7 @@ def test_delete_case_by_id(adapter, case_obj):
     # WHEN deleting a case from the database using case _id
     result = adapter.delete_case(case_id=case_obj["_id"])
     # THEN there should be no cases left in the database
-    assert sum(1 for i in adapter.cases()) == 0
+    assert sum(1 for _ in adapter.cases()) == 0
 
 
 def test_delete_case_by_display_name(adapter, case_obj):
@@ -450,7 +475,7 @@ def test_delete_case_by_display_name(adapter, case_obj):
         institute_id=case_obj["owner"], display_name=case_obj["display_name"]
     )
     # THEN there should be no cases left in the database
-    assert sum(1 for i in adapter.cases()) == 0
+    assert sum(1 for _ in adapter.cases()) == 0
 
 
 def test_update_case_collaborators(adapter, case_obj):
@@ -569,9 +594,9 @@ def test_archive_unarchive_case(adapter, case_obj, institute_obj, user_obj):
 
 def test_update_case_rerun_status(adapter, case_obj, institute_obj, user_obj):
     # GIVEN an empty database (no cases)
-    assert sum(1 for i in adapter.cases()) == 0
+    assert sum(1 for _ in adapter.cases()) == 0
     adapter.case_collection.insert_one(case_obj)
-    assert sum(1 for i in adapter.cases()) == 1
+    assert sum(1 for _ in adapter.cases()) == 1
 
     res = adapter.case(case_obj["_id"])
     assert res["status"] == "inactive"
@@ -606,30 +631,30 @@ def test_update_case_rerun_status(adapter, case_obj, institute_obj, user_obj):
     assert res["status"] == "inactive"
 
 
-def test_cases_by_diagnosis(adapter, case_obj, omim_term):
+def test_cases_by_diagnosis(adapter, case_obj, test_omim_database_term):
     """Test filtering cases by assigned OMIM terms"""
 
     # GIVEN a case with a diagnosis:
     case_obj["diagnosis_phenotypes"] = {
-        "disease_nr": omim_term["disease_nr"],
-        "disease_id": omim_term["disease_id"],
-        "description": omim_term["description"],
+        "disease_nr": test_omim_database_term["disease_nr"],
+        "disease_id": test_omim_database_term["disease_id"],
+        "description": test_omim_database_term["description"],
     }
     adapter.case_collection.insert_one(case_obj)
     # WHEN cases are filtered using OMIM terms containing that term
-    name_query = f"exact_dia:{omim_term['disease_id']},OMIM:999999"
+    name_query = f"exact_dia:{test_omim_database_term['disease_id']},OMIM:999999"
 
     # WHEN querying for cases with the given OMIM term
     cases = adapter.cases(collaborator=case_obj["owner"], name_query=name_query)
     # THEN a case should be returned
-    assert sum(1 for i in cases) == 1
+    assert sum(1 for _ in cases) == 1
 
 
 def test_cases_by_phenotype(hpo_database, test_hpo_terms, case_obj):
     adapter = hpo_database
 
     # Make sure database contains HPO terms
-    assert sum(1 for i in adapter.hpo_terms())
+    assert sum(1 for _ in adapter.hpo_terms())
 
     # update test case using test HPO terms
     case_obj["phenotype_terms"] = test_hpo_terms
@@ -640,7 +665,7 @@ def test_cases_by_phenotype(hpo_database, test_hpo_terms, case_obj):
     )
     # insert case into database
     adapter.case_collection.insert_one(case_obj)
-    assert sum(1 for i in adapter.case_collection.find()) == 1
+    assert sum(1 for _ in adapter.case_collection.find()) == 1
 
     # Add another case with slightly different phenotype
     case_2 = copy.deepcopy(case_obj)
@@ -649,7 +674,7 @@ def test_cases_by_phenotype(hpo_database, test_hpo_terms, case_obj):
 
     # insert this case in database:
     adapter.case_collection.insert_one(case_2)
-    assert sum(1 for i in adapter.case_collection.find()) == 2
+    assert sum(1 for _ in adapter.case_collection.find()) == 2
 
     # Add another case with phenotype very different from case_obj
     case_3 = copy.deepcopy(case_obj)
@@ -660,7 +685,7 @@ def test_cases_by_phenotype(hpo_database, test_hpo_terms, case_obj):
 
     # insert this case in database:
     adapter.case_collection.insert_one(case_3)
-    assert sum(1 for i in adapter.case_collection.find()) == 3
+    assert sum(1 for _ in adapter.case_collection.find()) == 3
 
     hpo_query_terms = [term["phenotype_id"] for term in test_hpo_terms]
     similar_cases = adapter.cases_by_phenotype(hpo_query_terms, case_obj["owner"], case_obj["_id"])
@@ -672,11 +697,11 @@ def test_cases_by_phenotype(hpo_database, test_hpo_terms, case_obj):
     assert similar_cases[0][1] > similar_cases[1][1]
 
 
-def test_get_similar_cases_by_name_query(hpo_database, test_hpo_terms, case_obj):
+def test_get_cases_by_phenotype_name_query(hpo_database, test_hpo_terms, case_obj):
     adapter = hpo_database
 
     # Make sure database contains HPO terms
-    assert sum(1 for i in adapter.hpo_terms())
+    assert sum(1 for _ in adapter.hpo_terms())
 
     # Give the case HPO terms
     case_obj["phenotype_terms"] = test_hpo_terms
@@ -688,7 +713,47 @@ def test_get_similar_cases_by_name_query(hpo_database, test_hpo_terms, case_obj)
 
     # Insert a case into the db
     adapter.case_collection.insert_one(case_obj)
-    assert sum(1 for i in adapter.case_collection.find()) == 1
+    assert sum(1 for _ in adapter.case_collection.find()) == 1
+
+    # WHEN querying for a case with one of the test phenotype ids
+    name_query = f"exact_pheno:{test_hpo_terms[0]['phenotype_id']}"
+
+    # THEN one case should be returned
+    cases = list(adapter.cases(collaborator=case_obj["owner"], name_query=name_query))
+    assert len(cases) == 1
+
+    # WHEN repeating the same query with a term not on the case included,
+    name_query = "exact_pheno:HP:0000532"
+
+    # THEN no case should be returned
+    cases = list(adapter.cases(collaborator=case_obj["owner"], name_query=name_query))
+    assert len(cases) == 0
+
+    # WHEN repeating the same query with a term not on the case included AS WELL AS one on the case
+    name_query = f"exact_pheno:HP:0000532, {test_hpo_terms[0]['phenotype_id']}"
+
+    # THEN one case should be returned
+    cases = list(adapter.cases(collaborator=case_obj["owner"], name_query=name_query))
+    assert len(cases) == 1
+
+
+def test_get_similar_cases_by_name_query(hpo_database, test_hpo_terms, case_obj):
+    adapter = hpo_database
+
+    # Make sure database contains HPO terms
+    assert sum(1 for _ in adapter.hpo_terms())
+
+    # Give the case HPO terms
+    case_obj["phenotype_terms"] = test_hpo_terms
+    adapter.case_collection.find_one_and_update(
+        {"_id": case_obj["_id"]},
+        {"$set": {"phenotype_terms": test_hpo_terms}},
+        return_document=pymongo.ReturnDocument.AFTER,
+    )
+
+    # Insert a case into the db
+    adapter.case_collection.insert_one(case_obj)
+    assert sum(1 for _ in adapter.case_collection.find()) == 1
 
     # Add another case with slightly different phenotype:
 
@@ -698,7 +763,7 @@ def test_get_similar_cases_by_name_query(hpo_database, test_hpo_terms, case_obj)
 
     # insert this case in database:
     adapter.case_collection.insert_one(case_2)
-    assert sum(1 for i in adapter.case_collection.find()) == 2
+    assert sum(1 for _ in adapter.case_collection.find()) == 2
 
     # WHEN querying for a similar case
     name_query = f"similar_case:{case_obj['display_name']}"
@@ -707,10 +772,10 @@ def test_get_similar_cases_by_name_query(hpo_database, test_hpo_terms, case_obj)
     assert len(cases) == 1
 
 
-def test_get_cases_cohort(real_adapter, case_obj, user_obj):
+def test_get_cases_cohort(real_adapter, case_obj):
     adapter = real_adapter
     # GIVEN an empty database (no cases)
-    assert sum(1 for i in adapter.cases()) == 0
+    assert sum(1 for _ in adapter.cases()) == 0
 
     cohort_name = "cohort"
 
@@ -720,7 +785,41 @@ def test_get_cases_cohort(real_adapter, case_obj, user_obj):
     # WHEN retreiving cases by a cohort name query
     result = adapter.cases(name_query="cohort:{}".format(cohort_name))
     # THEN we should get the case returned
-    assert sum(1 for i in result) == 1
+    assert sum(1 for _ in result) == 1
+
+
+def test_get_cases_tags(real_adapter, case_obj):
+    adapter = real_adapter
+    # GIVEN an empty database (no cases)
+    assert sum(1 for _ in adapter.cases()) == 0
+
+    # WHEN inserting a case with tags
+    tags = ["diagnostic", "upd"]
+
+    case_obj["tags"] = tags
+    adapter.case_collection.insert_one(case_obj)
+
+    # WHEN retreiving cases by a tags name query
+    result = adapter.cases(name_query="tags:diagnostic")
+
+    # THEN we should get the case returned
+    assert sum(1 for _ in result) == 1
+
+
+def test_get_cases_cohort_with_space(real_adapter, case_obj, user_obj):
+    adapter = real_adapter
+    # GIVEN an empty database (no cases)
+    assert sum(1 for _ in adapter.cases()) == 0
+
+    cohort_name = "cohort with spaceS"
+
+    case_obj["cohorts"] = [cohort_name]
+    adapter.case_collection.insert_one(case_obj)
+
+    # WHEN retreiving cases by a cohort name query
+    result = adapter.cases(name_query="cohort:{}".format(cohort_name))
+    # THEN we should get the case returned
+    assert sum(1 for _ in result) == 1
 
 
 def test_get_cases_solved_since(real_adapter, case_obj, user_obj, institute_obj, variant_obj):
@@ -1027,7 +1126,7 @@ def test_keep_variant_comments_after_reupload(
         content="Hello, globally",
         comment_level="global",
     )
-    assert sum(1 for i in adapter.event_collection.find()) == 2
+    assert sum(1 for _ in adapter.event_collection.find()) == 2
 
     # WHEN the variant is re-uploaded
     adapter.variant_collection.delete_one(old_variant)
@@ -1046,4 +1145,4 @@ def test_keep_variant_comments_after_reupload(
     assert updated_new_vars["is_commented"] == [new_variant["_id"]]
 
     # and 2 new comments should be created in the database
-    assert sum(1 for i in adapter.event_collection.find()) == 4
+    assert sum(1 for _ in adapter.event_collection.find()) == 4
