@@ -1,11 +1,10 @@
 import datetime
 import logging
-from pprint import pprint as pp
 
 import pymongo
 import pytest
 
-from scout.constants import VERBS_MAP
+from scout.constants import CASE_TAGS
 
 logger = logging.getLogger(__name__)
 
@@ -13,7 +12,7 @@ logger = logging.getLogger(__name__)
 def test_create_event(adapter, institute_obj, case_obj, user_obj):
     ## GIVEN a database without any events
 
-    assert sum(1 for i in adapter.event_collection.find()) == 0
+    assert sum(1 for _ in adapter.event_collection.find()) == 0
 
     ## WHEN inserting a event
     verb = "status"
@@ -30,7 +29,7 @@ def test_create_event(adapter, institute_obj, case_obj, user_obj):
 
     # THEN assert that the event was added to the database
 
-    assert sum(1 for i in adapter.event_collection.find()) == 1
+    assert sum(1 for _ in adapter.event_collection.find()) == 1
     res = adapter.event_collection.find_one()
 
     assert res["verb"] == verb
@@ -43,7 +42,7 @@ def test_assign(adapter, institute_obj, case_obj, user_obj):
     adapter.institute_collection.insert_one(institute_obj)
     adapter.user_collection.insert_one(user_obj)
 
-    assert sum(1 for i in adapter.event_collection.find()) == 0
+    assert sum(1 for _ in adapter.event_collection.find()) == 0
 
     ## WHEN assigning a user to a case
     link = "assignlink"
@@ -51,7 +50,7 @@ def test_assign(adapter, institute_obj, case_obj, user_obj):
     # THEN the case should have the user assigned
     assert updated_case["assignees"] == [user_obj["_id"]]
     # THEN an event should have been created
-    assert sum(1 for i in adapter.event_collection.find()) == 1
+    assert sum(1 for _ in adapter.event_collection.find()) == 1
 
     event_obj = adapter.event_collection.find_one()
     assert event_obj["link"] == link
@@ -73,7 +72,7 @@ def test_unassign(adapter, institute_obj, case_obj, user_obj):
     assert updated_case["status"] == "active"
     assert updated_case["assignees"] == [user_obj["_id"]]
 
-    assert sum(1 for i in adapter.event_collection.find()) == 1
+    assert sum(1 for _ in adapter.event_collection.find()) == 1
 
     # WHEN unassigning the only user assigned to case
     # and wishes to inactivate it
@@ -88,7 +87,7 @@ def test_unassign(adapter, institute_obj, case_obj, user_obj):
     assert updated_case["status"] == "inactive"
 
     # THEN two events should have been created
-    assert sum(1 for i in adapter.event_collection.find()) == 2
+    assert sum(1 for _ in adapter.event_collection.find()) == 2
 
     # THEN the case should not be assigned
     assert updated_case.get("assignees") == []
@@ -103,7 +102,7 @@ def test_update_synopsis(adapter, institute_obj, case_obj, user_obj):
     adapter.case_collection.insert_one(case_obj)
     adapter.institute_collection.insert_one(institute_obj)
     adapter.user_collection.insert_one(user_obj)
-    assert sum(1 for i in adapter.event_collection.find()) == 0
+    assert sum(1 for _ in adapter.event_collection.find()) == 0
 
     # WHEN updating synopsis for a case
     link = "synopsislink"
@@ -130,7 +129,7 @@ def test_archive_case(adapter, institute_obj, case_obj, user_obj):
     adapter.institute_collection.insert_one(institute_obj)
     adapter.user_collection.insert_one(user_obj)
 
-    assert sum(1 for i in adapter.event_collection.find()) == 0
+    assert sum(1 for _ in adapter.event_collection.find()) == 0
 
     ## WHEN setting a case in archive status
     link = "archivelink"
@@ -150,7 +149,7 @@ def test_open_research(adapter, institute_obj, case_obj, user_obj):
     adapter.case_collection.insert_one(case_obj)
     adapter.institute_collection.insert_one(institute_obj)
     adapter.user_collection.insert_one(user_obj)
-    assert sum(1 for i in adapter.event_collection.find()) == 0
+    assert sum(1 for _ in adapter.event_collection.find()) == 0
 
     case = adapter.case_collection.find_one({"_id": case_obj["_id"]})
     assert case.get("research_requested", False) is False
@@ -234,9 +233,9 @@ def test_add_phenotype_group(adapter, institute_obj, case_obj, user_obj):
     hpo_term = hpo_obj["hpo_id"]
 
     # GIVEN a populated database with no events
-    assert sum(1 for i in adapter.hpo_term_collection.find()) > 0
+    assert sum(1 for _ in adapter.hpo_term_collection.find()) > 0
     assert adapter.hpo_term_collection.find({"_id": hpo_term})
-    assert sum(1 for i in adapter.event_collection.find()) == 0
+    assert sum(1 for _ in adapter.event_collection.find()) == 0
 
     ## WHEN adding a phenotype group
     updated_case = adapter.add_phenotype(
@@ -252,7 +251,7 @@ def test_add_phenotype_group(adapter, institute_obj, case_obj, user_obj):
     assert len(updated_case["phenotype_groups"]) > 0
 
     # THEN there should be phenotype events
-    assert sum(1 for i in adapter.event_collection.find()) > 0
+    assert sum(1 for _ in adapter.event_collection.find()) > 0
 
 
 def test_add_wrong_hpo(adapter, institute_obj, case_obj, user_obj):
@@ -344,9 +343,9 @@ def test_add_mim(adapter, institute_obj, case_obj, user_obj):
     mim_obj = adapter.disease_term_collection.find_one()
     mim_term = mim_obj["_id"]
 
-    assert sum(1 for i in adapter.hpo_term_collection.find()) > 0
+    assert sum(1 for _ in adapter.hpo_term_collection.find()) > 0
     # GIVEN a populated database
-    assert sum(1 for i in adapter.event_collection.find()) == 0
+    assert sum(1 for _ in adapter.event_collection.find()) == 0
 
     # WHEN adding a existing phenotype term
     updated_case = adapter.add_phenotype(
@@ -360,16 +359,16 @@ def test_add_mim(adapter, institute_obj, case_obj, user_obj):
     assert len(updated_case["phenotype_terms"]) > 0
 
     # THEN there should be phenotype events
-    assert sum(1 for i in adapter.event_collection.find()) > 0
+    assert sum(1 for _ in adapter.event_collection.find()) > 0
 
 
 def test_remove_hpo(hpo_database, institute_obj, case_obj, user_obj):
     adapter = hpo_database
     logger.info("Add a HPO term for a case")
-    adapter._add_case(case_obj)
+    adapter.case_collection.insert_one(case_obj)
 
     # GIVEN a populated database
-    assert sum(1 for i in adapter.event_collection.find()) == 0
+    assert sum(1 for _ in adapter.event_collection.find()) == 0
 
     hpo_term = "HP:0000878"
 
@@ -385,7 +384,7 @@ def test_remove_hpo(hpo_database, institute_obj, case_obj, user_obj):
     assert len(updated_case["phenotype_terms"]) == 1
 
     # Check that the event exists
-    assert sum(1 for i in adapter.event_collection.find()) == 1
+    assert sum(1 for _ in adapter.event_collection.find()) == 1
 
     # WHEN removing the phenotype term
     updated_case = adapter.remove_phenotype(
@@ -399,7 +398,7 @@ def test_remove_hpo(hpo_database, institute_obj, case_obj, user_obj):
     assert len(updated_case["phenotype_terms"]) == 0
 
     # THEN an event should have been created
-    assert sum(1 for i in adapter.event_collection.find()) == 2
+    assert sum(1 for _ in adapter.event_collection.find()) == 2
 
 
 def test_add_cohort(adapter, institute_obj, case_obj, user_obj):
@@ -407,7 +406,7 @@ def test_add_cohort(adapter, institute_obj, case_obj, user_obj):
     adapter.case_collection.insert_one(case_obj)
     adapter.institute_collection.insert_one(institute_obj)
     adapter.user_collection.insert_one(user_obj)
-    assert sum(1 for i in adapter.event_collection.find()) == 0
+    assert sum(1 for _ in adapter.event_collection.find()) == 0
 
     cohort_name = "cohort"
 
@@ -423,7 +422,7 @@ def test_add_cohort(adapter, institute_obj, case_obj, user_obj):
     # THEN the case should have the cohort saved
     assert set(updated_case["cohorts"]) == set([cohort_name])
     # THEN an event should have been created
-    assert sum(1 for i in adapter.event_collection.find()) == 1
+    assert sum(1 for _ in adapter.event_collection.find()) == 1
 
     event_obj = adapter.event_collection.find_one()
     assert event_obj["link"] == link
@@ -434,7 +433,7 @@ def test_remove_cohort(adapter, institute_obj, case_obj, user_obj):
     adapter.case_collection.insert_one(case_obj)
     adapter.institute_collection.insert_one(institute_obj)
     adapter.user_collection.insert_one(user_obj)
-    assert sum(1 for i in adapter.event_collection.find()) == 0
+    assert sum(1 for _ in adapter.event_collection.find()) == 0
 
     cohort_name = "cohort"
 
@@ -447,7 +446,7 @@ def test_remove_cohort(adapter, institute_obj, case_obj, user_obj):
         link=link,
         tag=cohort_name,
     )
-    assert sum(1 for i in adapter.event_collection.find()) == 1
+    assert sum(1 for _ in adapter.event_collection.find()) == 1
 
     remove_cohort_link = "removeCohortlink"
     ## WHEN removing a cohort from a case
@@ -461,7 +460,34 @@ def test_remove_cohort(adapter, institute_obj, case_obj, user_obj):
     # THEN the case should have the cohort saved
     assert updated_case["cohorts"] == []
     # THEN an event should have been created
-    assert sum(1 for i in adapter.event_collection.find()) == 2
+    assert sum(1 for _ in adapter.event_collection.find()) == 2
+
+
+def test_tag_case(adapter, institute_obj, case_obj, user_obj):
+    ## GIVEN a populated database
+    adapter.case_collection.insert_one(case_obj)
+    adapter.institute_collection.insert_one(institute_obj)
+    adapter.user_collection.insert_one(user_obj)
+    assert sum(1 for _ in adapter.event_collection.find()) == 0
+
+    case_tag = list(CASE_TAGS.keys())[0]
+
+    link = "taglink"
+    ## WHEN adding a cohort to a case
+    updated_case = adapter.tag_case(
+        institute=institute_obj,
+        case=case_obj,
+        user=user_obj,
+        tags=[case_tag],
+        link=link,
+    )
+    # THEN the case should have the tag saved
+    assert updated_case["tags"] == [case_tag]
+    # THEN an event should have been created
+    assert sum(1 for _ in adapter.event_collection.find()) == 1
+
+    event_obj = adapter.event_collection.find_one()
+    assert event_obj["link"] == link
 
 
 def test_update_clinical_filter_hpo(adapter, institute_obj, case_obj, user_obj):
@@ -470,7 +496,7 @@ def test_update_clinical_filter_hpo(adapter, institute_obj, case_obj, user_obj):
     adapter.institute_collection.insert_one(institute_obj)
     adapter.user_collection.insert_one(user_obj)
     # GIVEN no events in the event collection
-    assert sum(1 for i in adapter.event_collection.find()) == 0
+    assert sum(1 for _ in adapter.event_collection.find()) == 0
 
     # WHEN calling update function
     hpo_clinical_filter = True
@@ -484,7 +510,7 @@ def test_update_clinical_filter_hpo(adapter, institute_obj, case_obj, user_obj):
     # THEN hpo_clinical_filter is actually updated
     assert updated_case["hpo_clinical_filter"] == hpo_clinical_filter
     # THEN an event should have been created
-    assert sum(1 for i in adapter.event_collection.find()) == 1
+    assert sum(1 for _ in adapter.event_collection.find()) == 1
 
 
 def test_filter_stash(adapter, institute_obj, case_obj, user_obj, filter_obj):
@@ -499,10 +525,10 @@ def test_filter_stash(adapter, institute_obj, case_obj, user_obj, filter_obj):
     filters = adapter.filters(institute_id, category)
 
     # THEN no filters are returned
-    assert sum(1 for i in filters) == 0
+    assert sum(1 for _ in filters) == 0
 
     # WHEN no events are yet in the events collection
-    assert sum(1 for i in adapter.event_collection.find()) == 0
+    assert sum(1 for _ in adapter.event_collection.find()) == 0
     # WHEN storing a filter
     filter_id = adapter.stash_filter(
         filter_obj, institute_obj, case_obj, user_obj, category, link="mock_link"
@@ -510,12 +536,12 @@ def test_filter_stash(adapter, institute_obj, case_obj, user_obj, filter_obj):
     # THEN a filter id is returned
     assert filter_id
     # THEN an event can be found in the event collection
-    assert sum(1 for i in adapter.event_collection.find()) > 0
+    assert sum(1 for _ in adapter.event_collection.find()) > 0
 
     # WHEN listing filters
     filters = adapter.filters(institute_id, category)
     # THEN one filter is returned
-    assert sum(1 for i in filters) == 1
+    assert sum(1 for _ in filters) == 1
 
     # WHEN retrieving a stored filter
     retrieved_filter_obj = adapter.retrieve_filter(filter_id)
@@ -527,7 +553,7 @@ def test_filter_stash(adapter, institute_obj, case_obj, user_obj, filter_obj):
     result = adapter.delete_filter(filter_id, institute_id, user_id)
     # THEN no filters are returned
     filters = adapter.filters(institute_id, category)
-    assert sum(1 for i in filters) == 0
+    assert sum(1 for _ in filters) == 0
 
 
 def test_filter_lock(adapter, institute_obj, case_obj, user_obj, filter_obj):
@@ -544,7 +570,7 @@ def test_filter_lock(adapter, institute_obj, case_obj, user_obj, filter_obj):
     # THEN a filter id is returned
     assert filter_id
     # THEN an event can be found in the event collection
-    assert sum(1 for i in adapter.event_collection.find()) > 0
+    assert sum(1 for _ in adapter.event_collection.find()) > 0
 
     owner_id = "someone@somewhere.se"
     # WHEN locking the filter
@@ -575,7 +601,7 @@ def test_filter_lock(adapter, institute_obj, case_obj, user_obj, filter_obj):
     assert filters[0].get("lock") is False
 
 
-def test_filter_audit(adapter, institute_obj, case_obj, user_obj, filter_obj):
+def test_filter_audit_unaudit(adapter, institute_obj, case_obj, user_obj, filter_obj):
     # GIVEN a case, institute and user in a store
     adapter.case_collection.insert_one(case_obj)
     adapter.institute_collection.insert_one(institute_obj)
@@ -587,7 +613,7 @@ def test_filter_audit(adapter, institute_obj, case_obj, user_obj, filter_obj):
         filter_obj, institute_obj, case_obj, user_obj, category, link="mock_link"
     )
     # THEN an event can be found in the event collection
-    n_events_before = sum(1 for i in adapter.event_collection.find())
+    n_events_before = sum(1 for _ in adapter.event_collection.find())
     assert n_events_before > 0
 
     # WHEN marking a filter audited for a case
@@ -597,8 +623,19 @@ def test_filter_audit(adapter, institute_obj, case_obj, user_obj, filter_obj):
     # THEN the operation was successful
     assert returned_filter is not None
     # THEN another event has been logged for the audit
-    n_events_after = sum(1 for i in adapter.event_collection.find())
+    n_events_after = sum(1 for _ in adapter.event_collection.find())
     assert n_events_after > n_events_before
+    audit_event = adapter.event_collection.find_one({"verb": "filter_audit"})
+    assert audit_event
+
+    # WHEN a user un-audits the filter
+    adapter.unaudit_filter(audit_id=audit_event["_id"], user_obj=user_obj)
+
+    # THEN audit event should disappear
+    assert adapter.event_collection.find_one({"verb": "filter_audit"}) is None
+
+    # And un-audit event should be found instead
+    assert adapter.event_collection.find_one({"verb": "filter_unaudit"})
 
 
 def test_update_default_panels(adapter, institute_obj, case_obj, user_obj, testpanel_obj):
@@ -649,21 +686,13 @@ def test_update_default_panels(adapter, institute_obj, case_obj, user_obj, testp
         elif panel["panel_name"] == "panel2":
             assert panel["is_default"] is True
 
-    # assert sum(1 for i in adapter.event_collection.find()) == 2
-    #
-    # # THEN the case should not be assigned
-    # assert updated_case.get('assignees') == []
-    # # THEN a unassign event should be created
-    # event = adapter.event_collection.find_one({'verb': 'unassign'})
-    # assert event['link'] == 'unassignlink'
-
 
 def test_update_case_group(adapter, institute_obj, case_obj, user_obj):
     adapter.case_collection.insert_one(case_obj)
     adapter.institute_collection.insert_one(institute_obj)
     adapter.user_collection.insert_one(user_obj)
     # GIVEN no events in the event collection
-    assert sum(1 for i in adapter.event_collection.find()) == 0
+    assert sum(1 for _ in adapter.event_collection.find()) == 0
 
     group_ids = ["1234", "5678"]
 
@@ -679,4 +708,4 @@ def test_update_case_group(adapter, institute_obj, case_obj, user_obj):
     # THEN group ids are actually updated
     assert updated_case["group"] == group_ids
     # THEN an event should have been created
-    assert sum(1 for i in adapter.event_collection.find()) == 1
+    assert sum(1 for _ in adapter.event_collection.find()) == 1
