@@ -7,57 +7,57 @@ from scout.models.hgnc_map import HgncGene
 #################### HGNC gene tests ####################
 def test_insert_gene(adapter, parsed_gene):
     ##GIVEN a empty adapter
-    assert sum(1 for i in adapter.all_genes()) == 0
+    assert sum(1 for _ in adapter.all_genes()) == 0
 
     ##WHEN inserting a gene
 
-    gene_obj = HgncGene(**parsed_gene)
+    gene_obj = HgncGene(**parsed_gene).model_dump(exclude_none=True)
 
     obj_id = adapter.load_hgnc_gene(gene_obj)
 
     ##THEN assert that the gene is there
-    assert sum(1 for i in adapter.all_genes()) == 1
+    assert sum(1 for _ in adapter.all_genes()) == 1
     ##THEN assert that no genes are in the '38' build
-    assert sum(1 for i in adapter.all_genes(build="38")) == 0
+    assert sum(1 for _ in adapter.all_genes(build="38")) == 0
 
 
 def test_insert_many_genes(adapter, parsed_gene):
     adapter = adapter
     gene_objs = []
     ##GIVEN a empty adapter
-    assert sum(1 for i in adapter.all_genes()) == 0
+    assert sum(1 for _ in adapter.all_genes()) == 0
 
     ##WHEN inserting a bulk of genes
     for i in range(300):
         parsed_gene["hgnc_id"] = i
-        gene_objs.append(HgncGene(**parsed_gene))
+        gene_objs.append(HgncGene(**parsed_gene).model_dump(exclude_none=True))
 
     result = adapter.load_hgnc_bulk(gene_objs)
 
     ##THEN assert that the genes are loaded
-    assert sum(1 for i in adapter.all_genes()) == 300
+    assert sum(1 for _ in adapter.all_genes()) == 300
     ##THEN assert that no genes are in the '38' build
-    assert sum(1 for i in adapter.all_genes(build="38")) == 0
+    assert sum(1 for _ in adapter.all_genes(build="38")) == 0
 
 
 def test_insert_bulk(adapter, gene_bulk):
     ## GIVEN an empty adapter and a bulk of genes
     adapter = adapter
 
-    assert sum(1 for i in adapter.all_genes()) == 0
+    assert sum(1 for _ in adapter.all_genes()) == 0
     assert len(gene_bulk) > 0
 
     ## WHEN inserting the gene objects
     result = adapter.load_hgnc_bulk(gene_bulk)
 
     ##THEN assert that the genes are loaded
-    assert sum(1 for i in adapter.all_genes()) == len(gene_bulk)
+    assert sum(1 for _ in adapter.all_genes()) == len(gene_bulk)
 
 
 def test_insert_many_genes_duplicate(adapter):
     adapter = adapter
     ##GIVEN a empty adapter
-    assert sum(1 for i in adapter.all_genes()) == 0
+    assert sum(1 for _ in adapter.all_genes()) == 0
 
     gene_objs = []
     gene_obj = {"_id": 1, "hgnc_id": 1, "hgnc_symbol": "AAA", "build": "37"}
@@ -74,7 +74,7 @@ def test_insert_many_genes_duplicate(adapter):
 def test_get_gene(adapter):
     # adapter = real_adapter
     ##GIVEN a empty adapter
-    assert sum(1 for i in adapter.all_genes()) == 0
+    assert sum(1 for _ in adapter.all_genes()) == 0
 
     ##WHEN inserting a gene and fetching it
     gene_obj = {"hgnc_id": 1, "hgnc_symbol": "AAA", "build": "37"}
@@ -93,7 +93,7 @@ def test_get_gene(adapter):
 
 def test_get_genes(adapter):
     ##GIVEN a empty adapter
-    assert sum(1 for i in adapter.all_genes()) == 0
+    assert sum(1 for _ in adapter.all_genes()) == 0
 
     ##WHEN inserting two genes and fetching one
     gene_obj = {
@@ -123,7 +123,7 @@ def test_get_genes(adapter):
 
 def test_get_genes_alias(adapter):
     ##GIVEN a empty adapter
-    assert sum(1 for i in adapter.all_genes()) == 0
+    assert sum(1 for _ in adapter.all_genes()) == 0
 
     ##WHEN inserting two genes and fetching one
     gene_obj = {
@@ -154,7 +154,7 @@ def test_get_genes_alias(adapter):
 def test_get_genes_regex(real_adapter):
     adapter = real_adapter
     ##GIVEN a empty adapter
-    assert sum(1 for i in adapter.all_genes()) == 0
+    assert sum(1 for _ in adapter.all_genes()) == 0
 
     ##WHEN inserting two genes and fetching one
     gene_obj = {
@@ -184,30 +184,30 @@ def test_get_genes_regex(real_adapter):
 
     ##THEN assert that only the correct gene was fetched for a full match
     res = adapter.hgnc_genes(hgnc_symbol="AA", search=True)
-    assert sum(1 for i in res) == 1
+    assert sum(1 for _ in res) == 1
 
     ##THEN assert that the correct gene was fetched
     res = adapter.hgnc_genes(hgnc_symbol="AB", search=True)
-    assert sum(1 for i in res) == 1
+    assert sum(1 for _ in res) == 1
 
     ##THEN assert that the correct gene was fetched
     res = adapter.hgnc_genes(hgnc_symbol="K", search=True)
-    assert sum(1 for i in res) == 0
+    assert sum(1 for _ in res) == 0
 
     ##THEN assert that the correct gene was fetched
     res = adapter.hgnc_genes(hgnc_symbol="A", search=True)
-    assert sum(1 for i in res) == 3
+    assert sum(1 for _ in res) == 3
 
     # This will only work with a real pymongo adapter
     ##THEN assert that the correct gene was fetched
     res = adapter.hgnc_genes(hgnc_symbol="a", search=True)
-    assert sum(1 for i in res) == 3
+    assert sum(1 for _ in res) == 3
 
 
 def test_get_genes_per_build(real_adapter):
     adapter = real_adapter
     ##GIVEN a empty adapter
-    assert sum(1 for i in adapter.all_genes()) == 0
+    assert sum(1 for _ in adapter.all_genes()) == 0
 
     ##WHEN inserting two genes and fetching one
     gene_obj = {
@@ -236,28 +236,28 @@ def test_get_genes_per_build(real_adapter):
 
     ##THEN assert default genome build is 37
     res = adapter.hgnc_genes(hgnc_symbol="AA", search=True)
-    assert sum(1 for i in res) == 1
+    assert sum(1 for _ in res) == 1
 
     ##THEN assert gene is excluded when using genome build is 38
     res = adapter.hgnc_genes(hgnc_symbol="AA", build="38", search=True)
-    assert sum(1 for i in res) == 0
+    assert sum(1 for _ in res) == 0
 
     ##THEN assert that build==37 excludes 38 variants when using regex
     res = adapter.hgnc_genes(hgnc_symbol="A", build="37", search=True)
-    assert sum(1 for i in res) == 2
+    assert sum(1 for _ in res) == 2
 
     ##THEN assert that build==38 excludes 37 variants when using regex
     res = adapter.hgnc_genes(hgnc_symbol="A", build="38", search=True)
-    assert sum(1 for i in res) == 1
+    assert sum(1 for _ in res) == 1
 
     ##THEN assert that build==all includes both 37 and 38 variants when using regex
     res = adapter.hgnc_genes(hgnc_symbol="A", build="all", search=True)
-    assert sum(1 for i in res) == 3
+    assert sum(1 for _ in res) == 3
 
 
 def test_get_all_genes(adapter):
     ##GIVEN a empty adapter
-    assert sum(1 for i in adapter.all_genes()) == 0
+    assert sum(1 for _ in adapter.all_genes()) == 0
 
     ##WHEN inserting two genes and fetching one
     gene_obj = {
@@ -280,12 +280,12 @@ def test_get_all_genes(adapter):
     res = adapter.all_genes()
 
     ##THEN assert that the correct number of genes where fetched
-    assert sum(1 for i in res) == 2
+    assert sum(1 for _ in res) == 2
 
 
 def test_hgnc_gene_caption(adapter):
     ##GIVEN a empty adapter
-    assert sum(1 for i in adapter.all_genes()) == 0
+    assert sum(1 for _ in adapter.all_genes()) == 0
 
     ## WHEN inserting a gene with all caption keys
     gene_obj = {
@@ -325,7 +325,7 @@ def test_hgnc_gene_caption(adapter):
 
 def test_drop_genes(adapter):
     ##GIVEN a empty adapter
-    assert sum(1 for i in adapter.all_genes()) == 0
+    assert sum(1 for _ in adapter.all_genes()) == 0
 
     ##WHEN inserting two genes and fetching one
     gene_obj = {
@@ -346,17 +346,17 @@ def test_drop_genes(adapter):
     adapter.load_hgnc_gene(gene_obj2)
 
     res = adapter.all_genes()
-    assert sum(1 for i in res) == 2
+    assert sum(1 for _ in res) == 2
 
     ##THEN assert that the correct number of genes where fetched
     adapter.drop_genes()
     res = adapter.all_genes()
-    assert sum(1 for i in res) == 0
+    assert sum(1 for _ in res) == 0
 
 
 def test_hgncid_to_gene(adapter):
     ##GIVEN a empty adapter
-    assert sum(1 for i in adapter.all_genes()) == 0
+    assert sum(1 for _ in adapter.all_genes()) == 0
 
     ##WHEN inserting two genes and fetching one
     gene_obj = {
@@ -377,7 +377,7 @@ def test_hgncid_to_gene(adapter):
     adapter.load_hgnc_gene(gene_obj2)
 
     res = adapter.all_genes()
-    assert sum(1 for i in res) == 2
+    assert sum(1 for _ in res) == 2
 
     ##THEN assert that the correct number of genes where fetched
     res = adapter.hgncid_to_gene()
@@ -391,7 +391,7 @@ def test_hgncid_to_gene(adapter):
 
 def test_hgnc_symbol_to_gene(adapter):
     ##GIVEN a empty adapter
-    assert sum(1 for i in adapter.all_genes()) == 0
+    assert sum(1 for _ in adapter.all_genes()) == 0
 
     ##WHEN inserting two genes and fetching one
     gene_obj = {
@@ -412,7 +412,7 @@ def test_hgnc_symbol_to_gene(adapter):
     adapter.load_hgnc_gene(gene_obj2)
 
     res = adapter.all_genes()
-    assert sum(1 for i in res) == 2
+    assert sum(1 for _ in res) == 2
 
     ##THEN assert that the correct number of genes where fetched
     res = adapter.hgncsymbol_to_gene()
@@ -438,12 +438,38 @@ def test_gene_by_symbol_or_aliases(adapter, parsed_gene):
     assert type(result) != list
 
 
+def test_ensembl_to_hgnc_id_mapping(adapter, parsed_gene):
+    """Test the function that maps Ensembl gene IDs to HGNC gene IDs."""
+
+    # GIVEN a database containing a gene
+    adapter.load_hgnc_gene(parsed_gene)
+
+    # WHEN using the mapping function
+    result = adapter.ensembl_to_hgnc_id_mapping()
+
+    # THEN it should return the expected result
+    assert result == {parsed_gene["ensembl_id"]: parsed_gene["hgnc_id"]}
+
+
+def test_hgnc_symbol_ensembl_id_mapping(adapter, parsed_gene):
+    """Test the function that maps HGNC symbols to Ensembl gene IDs."""
+
+    # GIVEN a database containing a gene
+    adapter.load_hgnc_gene(parsed_gene)
+
+    # WHEN using the mapping function
+    result = adapter.hgnc_symbol_ensembl_id_mapping()
+
+    # THEN it should return the expected result
+    assert result == {parsed_gene["hgnc_symbol"]: parsed_gene["ensembl_id"]}
+
+
 #################### HGNC transcript tests ####################
 
 
 def test_insert_transcript(adapter):
     ##GIVEN a empty adapter
-    assert sum(1 for i in adapter.all_genes()) == 0
+    assert sum(1 for _ in adapter.all_genes()) == 0
 
     ##WHEN inserting a transcript
     transcript_obj = {
@@ -457,15 +483,15 @@ def test_insert_transcript(adapter):
     obj_id = adapter.load_hgnc_transcript(transcript_obj)
 
     ##THEN assert that the transcript is there
-    assert sum(1 for i in adapter.all_genes()) == 1
+    assert sum(1 for _ in adapter.all_genes()) == 1
     ##THEN assert that no transcripts are in the '38' build
-    assert sum(1 for i in adapter.all_genes(build="38")) == 0
+    assert sum(1 for _ in adapter.all_genes(build="38")) == 0
 
 
 def test_insert_many_transcripts(adapter):
     adapter = adapter
     ##GIVEN a empty adapter
-    assert sum(1 for i in adapter.all_genes()) == 0
+    assert sum(1 for _ in adapter.all_genes()) == 0
 
     transcript_objs = []
     ##WHEN inserting a bulk of transcripts
@@ -484,9 +510,9 @@ def test_insert_many_transcripts(adapter):
     result = adapter.load_transcript_bulk(transcript_objs)
 
     ##THEN assert that the transcripts are loaded
-    assert sum(1 for i in adapter.transcripts()) == 300
+    assert sum(1 for _ in adapter.transcripts()) == 300
     ##THEN assert that no transcripts are in the '38' build
-    assert sum(1 for i in adapter.all_genes(build="38")) == 0
+    assert sum(1 for _ in adapter.all_genes(build="38")) == 0
 
 
 def test_insert_many_transcripts_duplicate(adapter):
@@ -516,15 +542,15 @@ def test_insert_many_transcripts_duplicate(adapter):
 def test_insert_transcripts(adapter, transcript_objs):
     adapter = adapter
     ##GIVEN a empty adapter
-    assert sum(1 for i in adapter.all_genes()) == 0
+    assert sum(1 for _ in adapter.all_genes()) == 0
 
     ##WHEN inserting a bulk of transcripts
     result = adapter.load_transcript_bulk(transcript_objs)
 
     ##THEN assert that the transcripts are loaded
-    assert sum(1 for i in adapter.transcripts()) == len(transcript_objs)
+    assert sum(1 for _ in adapter.transcripts()) == len(transcript_objs)
     ##THEN assert that no transcripts are in the '38' build
-    assert sum(1 for i in adapter.all_genes(build="38")) == 0
+    assert sum(1 for _ in adapter.all_genes(build="38")) == 0
 
 
 #################### Combined transcript/gene tests ####################
@@ -532,8 +558,8 @@ def test_insert_transcripts(adapter, transcript_objs):
 
 def test_insert_transcript(adapter):
     ##GIVEN a empty adapter
-    assert sum(1 for i in adapter.transcripts()) == 0
-    assert sum(1 for i in adapter.all_genes()) == 0
+    assert sum(1 for _ in adapter.transcripts()) == 0
+    assert sum(1 for _ in adapter.all_genes()) == 0
 
     ##WHEN inserting a gene and some transcripts
     hgnc_id = 257
