@@ -1,6 +1,5 @@
-from pprint import pprint as pp
-
 import pytest
+from bson.objectid import ObjectId
 
 from scout.exceptions import IntegrityError
 
@@ -66,7 +65,7 @@ def test_get_panel_multiple_versions(adapter, testpanel_obj):
     adapter.panel_collection.insert_one(testpanel_obj)
 
     res = adapter.gene_panels()
-    assert sum(1 for i in res) == 2
+    assert sum(1 for _ in res) == 2
     ## WHEN getting a panel
     res = adapter.gene_panel(panel_id=testpanel_obj["panel_name"])
     ## THEN assert that the last version is fetched
@@ -121,7 +120,7 @@ def test_add_pending_wrong_action(adapter, testpanel_obj, gene_obj):
     ## WHEN adding a pending action with invalid action
     with pytest.raises(ValueError):
         ## THEN assert that an error is raised
-        res = adapter.add_pending(panel_obj=panel_obj, hgnc_gene=hgnc_obj, action="hello")
+        adapter.add_pending(panel_obj=panel_obj, hgnc_gene=hgnc_obj, action="hello")
 
 
 def test_update_panel_panel_name(adapter, testpanel_obj):
@@ -130,7 +129,7 @@ def test_update_panel_panel_name(adapter, testpanel_obj):
     panel_obj = adapter.panel_collection.find_one()
     assert panel_obj
 
-    old_name = panel_obj["panel_name"]
+    panel_obj["panel_name"]
     new_name = "new name"
     ## WHEN updating the panel name
     panel_obj["panel_name"] = new_name
@@ -366,3 +365,32 @@ def test_clinical_hgnc_ids(case_obj, real_panel_database):
     # THEN the clinical_hgnc_ids function should return a valid set of hgnc IDs for the case panel
     clinical_hgnc_ids = adapter.clinical_symbols(case_obj)
     assert len(clinical_hgnc_ids) > 0
+
+
+def test_panel_to_genes(adapter, testpanel_obj):
+    """Test function that converts gene panels to list of gene symbols/ids"""
+
+    adapter.panel_collection.insert_one(testpanel_obj)
+
+    # GIVEN a adapter with a gene panel
+    panel_obj = adapter.panel_collection.find_one()
+    assert panel_obj["genes"]
+
+    # WHEN converting gene panel to list of gene symbols
+    object_id = panel_obj["_id"]
+    assert isinstance(object_id, ObjectId)
+
+    # THEN return list of gene symbols from correct panel
+    gene_symbols = adapter.panel_to_genes(panel_id=panel_obj["_id"])
+    assert sorted(gene_symbols) == ["AAA", "BBB"]
+
+    # WHEN converting panel to list of hgnc ids
+    gene_symbols = adapter.panel_to_genes(panel_id=panel_obj["_id"], gene_format="hgnc_id")
+
+    # THEN return list of hgnc ids
+    assert sorted(gene_symbols) == [100, 222]
+
+    # WHEN converting panel to gene list by panel name
+    panel_name = testpanel_obj["panel_name"]
+    gene_symbols = adapter.panel_to_genes(panel_name=panel_name)
+    assert sorted(gene_symbols) == ["AAA", "BBB"]
