@@ -206,16 +206,6 @@ def test_build_gnomad_query(adapter):
     ]
 
 
-def test_build_non_existing_gnomad(adapter):
-    case_id = "cust000"
-    freq = "-1"
-    query = {"gnomad_frequency": freq}
-
-    mongo_query = adapter.build_query(case_id, query=query)
-
-    assert mongo_query["gnomad_frequency"] == {"$exists": False}
-
-
 def test_build_cadd_exclusive(adapter):
     case_id = "cust000"
     cadd = 10.0
@@ -334,7 +324,7 @@ def test_build_clinsig_filter(real_variant_database):
             ]
         }
     )
-    n_results_raw_query = sum(1 for i in res)
+    n_results_raw_query = sum(1 for _ in res)
     assert n_results_raw_query
 
     # filter real variants using query:
@@ -351,7 +341,7 @@ def test_build_clinsig_filter(real_variant_database):
 
     # there should be no variant with clnsig.value=='Pathogenic, Likely pathogenic'
     res = adapter.variant_collection.find({"clnsig.value": "Pathogenic, Likely pathogenic"})
-    assert sum(1 for i in res) == 0
+    assert sum(1 for _ in res) == 0
 
     # Modify clnsig value of this variant to 'Pathogenic, Likely pathogenic'
     adapter.variant_collection.update_one(
@@ -361,7 +351,7 @@ def test_build_clinsig_filter(real_variant_database):
 
     # One variant has multiple clssig now:
     res = adapter.variant_collection.find({"clnsig.value": "Pathogenic, Likely pathogenic"})
-    assert sum(1 for i in res) == 1
+    assert sum(1 for _ in res) == 1
 
     # Update raw query to find this variant as well
     res = adapter.variant_collection.find(
@@ -385,11 +375,11 @@ def test_build_clinsig_filter(real_variant_database):
             ]
         }
     )
-    n_results_raw_query = sum(1 for i in res)
+    n_results_raw_query = sum(1 for _ in res)
 
     # Makes sure that the variant is found anyway by the query:
     n_filtered_variants = sum(
-        1 for i in adapter.variants(case_id=case_id, nr_of_variants=-1, query=query)
+        1 for _ in adapter.variants(case_id=case_id, nr_of_variants=-1, query=query)
     )
     assert n_results_raw_query == n_filtered_variants
 
@@ -453,7 +443,7 @@ def test_build_clinsig_always(real_variant_database):
     case_id = case_obj["_id"]
 
     res = adapter.variants(case_id=case_id, nr_of_variants=-1)
-    assert sum(1 for i in res)
+    assert sum(1 for _ in res)
 
     # filter variants using query:
     filtered_variants = list(adapter.variants(case_id=case_id, nr_of_variants=-1, query=query))
@@ -665,6 +655,59 @@ def test_build_swegen_sv(adapter):
     ]
 
 
+def test_build_local_obs(adapter):
+    """Test building a query containing local archived observations (RD and cancer variants."""
+
+    # GIVEN query parameters for local observations
+    LOCAL_OLD_OBS_FIELDS = [
+        "local_obs_old",
+        "local_obs_cancer_somatic_old",
+        "local_obs_cancer_germline_old",
+    ]
+    case_id = "cust000"
+    count = 5
+    query = {}
+    for query_field in LOCAL_OLD_OBS_FIELDS:
+        query[query_field] = count
+
+    # WHEN asking adapter to build a db query
+    mongo_query = adapter.build_query(case_id, query=query)
+
+    # THEN the expected query part for local observations is returned
+    for query_field in LOCAL_OLD_OBS_FIELDS:
+        query_item = {
+            "$or": [
+                {query_field: None},
+                {query_field: {"$lt": query[query_field] + 1}},
+            ]
+        }
+        assert query_item in mongo_query["$and"]
+
+
+def test_build_local_obs_freq(adapter):
+    """Test building query. Given query parameters from interface, check that
+    a correct db query is made. This tests local observations frequency.
+    """
+
+    # GIVEN query parameters for local observations
+    case_id = "cust000"
+    count = 5
+    query = {"local_obs_freq": count}
+
+    # WHEN asking adapter to build a db query
+    mongo_query = adapter.build_query(case_id, query=query)
+
+    # THEN the expected query part for local observations is returned
+    assert mongo_query["$and"] == [
+        {
+            "$or": [
+                {"local_obs_old_freq": None},
+                {"local_obs_old_freq": {"$lt": query["local_obs_freq"]}},
+            ]
+        }
+    ]
+
+
 def test_build_decipher(adapter):
     case_id = "cust000"
     count = 1
@@ -811,7 +854,7 @@ def test_query_svs_by_coordinates(real_populated_database, sv_variant_objs, case
     assert list(results)[0] == updated_variant
 
 
-def test_get_overlapping_variant(real_variant_database, case_obj, variant_objs):
+def test_get_overlapping_variant(real_variant_database, case_obj, variant_obj, sv_variant_obj):
     """Test function that finds SVs overlapping to a given SNV"""
 
     ## GIVEN a database with snv variants
@@ -821,28 +864,39 @@ def test_get_overlapping_variant(real_variant_database, case_obj, variant_objs):
     adapter.load_variants(
         case_obj, variant_type="clinical", category="sv", rank_threshold=-10, build="37"
     )
-    # GIVEN a SV variant from this database
-    sv_variant = adapter.variant_collection.find_one({"category": "sv"})
+    # GIVEN a SV variant in this database
+    sv_variant = adapter.variant_collection.find_one({"_id": sv_variant_obj["_id"]})
     assert sv_variant
     sv_variant_id = sv_variant["_id"]
 
-    # WITH a given gene from sv variant
-    gene_id = sv_variant["hgnc_ids"][0]
+    # WITH a given gene on the SV
+    gene_id = 17978
+    updated_sv_variant = adapter.variant_collection.find_one_and_update(
+        {"_id": sv_variant["_id"]},
+        {"$set": {"hgnc_ids": [gene_id]}},
+        return_document=ReturnDocument.AFTER,
+    )
+
+    # Retrieve a SNV variant occurring in the same case:
+    snv_variant = adapter.variant_collection.find_one({"_id": variant_obj["_id"]})
+    assert snv_variant
 
-    # Retrieve a SNV variant occurring in the same gene:
-    snv_variant = adapter.variant_collection.find_one({"category": "snv"})
     # And arbitrary set its hgnc_ids to gene_id
     updated_snv_variant = adapter.variant_collection.find_one_and_update(
-        {"_id": snv_variant["_id"]}, {"$set": {"hgnc_ids": [gene_id]}}
+        {"_id": snv_variant["_id"]},
+        {"$set": {"hgnc_ids": [gene_id]}},
+        return_document=ReturnDocument.AFTER,
     )
+
     # THEN the function that finds overlapping variants to the snv_variant
-    results = adapter.overlapping(updated_snv_variant)
+    results = adapter.overlapping(updated_snv_variant, limit=10000)
     for res in results:
-        # SHOULD return SV variant
+        # SHOULD return the SV variant
         assert res["category"] == "sv"
         assert res["_id"] == sv_variant_id
 
     # The function should also work the other way around:
     # and return snv variants that overlaps with sv variants
-    results = list(adapter.overlapping(sv_variant))
-    assert updated_snv_variant in results
+    result_vars = list(adapter.overlapping(updated_sv_variant, limit=10000))
+    result_ids = [result_var["_id"] for result_var in result_vars]
+    assert updated_snv_variant["_id"] in result_ids
