@@ -1,14 +1,27 @@
 """Tests for variant handling"""
+
 import logging
-import os
-
-import pytest
-
-TRAVIS = os.getenv("TRAVIS")
 
 LOG = logging.getLogger(__name__)
 
 
+def test_variant_update_field(real_variant_database):
+    """Test the function that updates a value for a given key."""
+    adapter = real_variant_database
+    # GIVEN a variant in the database:
+    variant_obj = adapter.variant_collection.find_one()
+    # GIVEN a key not set in the variant
+    A_KEY = "a_key"
+    A_VALUE = "a_value"
+    assert A_KEY not in variant_obj
+    # WHEN setting the key using the "variant_update_field" function
+    updated_variant_obj = adapter.variant_update_field(
+        variant_id=variant_obj["_id"], field_name=A_KEY, field_value=A_VALUE
+    )
+    # THEN the returned variant document should contain the expected key/value
+    assert updated_variant_obj[A_KEY] == A_VALUE
+
+
 def test_variant(real_variant_database, variant_objs, case_obj):
     """Test querying a variant"""
     adapter = real_variant_database
@@ -38,7 +51,7 @@ def test_load_variants(real_populated_database, variant_objs, case_obj):
     # Make sure that there are no variants in the database
     # GIVEN a populated database without any variants
     res = adapter.variants(case_id=case_id, nr_of_variants=-1)
-    assert sum(1 for i in res) == 0
+    assert sum(1 for _ in res) == 0
 
     # WHEN adding a number of variants
     index = 0
@@ -47,7 +60,7 @@ def test_load_variants(real_populated_database, variant_objs, case_obj):
 
     # THEN the same number of variants should have been loaded
     result = adapter.variants(case_id=case_id, nr_of_variants=-1)
-    nr_variants = sum(1 for i in result)
+    nr_variants = sum(1 for _ in result)
     LOG.info("Number of variants loaded:%s", nr_variants)
     assert nr_variants == index + 1
 
@@ -59,7 +72,7 @@ def test_load_sv_variants(real_populated_database, sv_variant_objs, case_obj):
 
     # GIVEN a populated database without any sv variants
     res = adapter.variants(case_id=case_id, nr_of_variants=-1)
-    assert sum(1 for i in res) == 0
+    assert sum(1 for _ in res) == 0
 
     # WHEN adding a number of sv variants
     index = 0
@@ -68,7 +81,7 @@ def test_load_sv_variants(real_populated_database, sv_variant_objs, case_obj):
 
     # THEN the same number of SV variants should have been loaded
     result = adapter.variants(case_id=case_id, nr_of_variants=-1, category="sv")
-    assert sum(1 for i in result) == index + 1
+    assert sum(1 for _ in result) == index + 1
 
 
 def test_load_all_variants(real_populated_database, case_obj):
@@ -77,7 +90,7 @@ def test_load_all_variants(real_populated_database, case_obj):
 
     ## GIVEN a populated database without any variants
     res = adapter.variants(case_id=case_id, nr_of_variants=-1)
-    assert sum(1 for i in res) == 0
+    assert sum(1 for _ in res) == 0
 
     ## WHEN loading all variants into the database
     nr_loaded = adapter.load_variants(
@@ -94,7 +107,7 @@ def test_load_all_variants(real_populated_database, case_obj):
     # THEN the same number of SV variants should have been loaded
     result = adapter.variants(case_id=case_id, nr_of_variants=-1, category="snv")
 
-    assert nr_loaded == sum(1 for i in result)
+    assert nr_loaded == sum(1 for _ in result)
 
 
 def test_load_whole_gene(real_populated_database, variant_objs, case_obj):
@@ -102,7 +115,7 @@ def test_load_whole_gene(real_populated_database, variant_objs, case_obj):
     case_id = case_obj["_id"]
 
     res = adapter.variants(case_id=case_id, nr_of_variants=-1)
-    assert sum(1 for i in res) == 0
+    assert sum(1 for _ in res) == 0
 
     nr_loaded = adapter.load_variants(
         case_obj=case_obj,
@@ -120,7 +133,7 @@ def test_load_whole_gene(real_populated_database, variant_objs, case_obj):
     gene_obj = adapter.hgnc_gene(hgnc_id)
     assert gene_obj
     res = adapter.variant_collection.find({"hgnc_ids": hgnc_id})
-    nr_variants_in_gene = sum(1 for i in res)
+    nr_variants_in_gene = sum(1 for _ in res)
 
     ## WHEN loading all variants for that gene
     nr_loaded = adapter.load_variants(
@@ -135,7 +148,7 @@ def test_load_whole_gene(real_populated_database, variant_objs, case_obj):
     )
 
     res = adapter.variant_collection.find({"hgnc_ids": hgnc_id})
-    new_nr_variants_in_gene = sum(1 for i in res)
+    new_nr_variants_in_gene = sum(1 for _ in res)
 
     ## Then assert that the other variants where loaded
     assert new_nr_variants_in_gene > nr_variants_in_gene
@@ -146,7 +159,7 @@ def test_load_coordinates(real_populated_database, variant_objs, case_obj):
     case_id = case_obj["_id"]
 
     res = adapter.variants(case_id=case_id, nr_of_variants=-1)
-    assert sum(1 for i in res) == 0
+    assert sum(1 for _ in res) == 0
 
     nr_loaded = adapter.load_variants(
         case_obj=case_obj,
@@ -164,7 +177,7 @@ def test_load_coordinates(real_populated_database, variant_objs, case_obj):
     gene_obj = adapter.hgnc_gene(hgnc_id)
     assert gene_obj
     res = adapter.variant_collection.find({"hgnc_ids": hgnc_id})
-    nr_variants_in_gene = sum(1 for i in res)
+    nr_variants_in_gene = sum(1 for _ in res)
 
     ## WHEN loading all variants for that gene
     nr_loaded = adapter.load_variants(
@@ -179,79 +192,12 @@ def test_load_coordinates(real_populated_database, variant_objs, case_obj):
     )
 
     res = adapter.variant_collection.find({"hgnc_ids": hgnc_id})
-    new_nr_variants_in_gene = sum(1 for i in res)
+    new_nr_variants_in_gene = sum(1 for _ in res)
 
     ## Then assert that the other variants where loaded
     assert new_nr_variants_in_gene > nr_variants_in_gene
 
 
-@pytest.mark.skipif(TRAVIS, reason="Tempfiles seems to be problematic on travis")
-def test_get_region_vcf(populated_database, case_obj):
-    adapter = populated_database
-    case_id = case_obj["_id"]
-
-    file_name = adapter.get_region_vcf(
-        case_obj,
-        chrom=None,
-        start=None,
-        end=None,
-        gene_obj=None,
-        variant_type="clinical",
-        category="snv",
-        rank_threshold=None,
-    )
-    ## GIVEN a populated database with variants in a certain gene
-    nr_variants = 0
-    with open(file_name, "r") as f:
-        for line in f:
-            if not line.startswith("#"):
-                nr_variants += 1
-
-    os.remove(file_name)
-
-    assert nr_variants > 0
-
-
-def test_get_region_vcf_non_existing(adapter, case_obj):
-    """Test to get a region VCF when file does not exist"""
-    # GIVEN a case obj without a cancer VCF
-    assert case_obj["vcf_files"].get("vcf_cancer") is None
-
-    # WHEN creating a region vcf
-    with pytest.raises(FileNotFoundError):
-        # THEN assert a file not found error is raised
-        adapter.get_region_vcf(
-            case_obj,
-            chrom=None,
-            start=None,
-            end=None,
-            gene_obj=None,
-            variant_type="cancer",
-            category="snv",
-            rank_threshold=None,
-        )
-
-
-def test_get_region_vcf_missing_file(adapter, case_obj):
-    """Test to get a region VCF when file does not exist"""
-    # GIVEN a case obj without a cancer VCF
-    case_obj["vcf_files"]["vcf_cancer"] = "afile.vcf"
-
-    # WHEN creating a region vcf
-    with pytest.raises(FileNotFoundError):
-        # THEN assert a file not found error is raised
-        adapter.get_region_vcf(
-            case_obj,
-            chrom=None,
-            start=None,
-            end=None,
-            gene_obj=None,
-            variant_type="cancer",
-            category="snv",
-            rank_threshold=None,
-        )
-
-
 def test_variant_non_existing(adapter):
     """Test to get a variant when it does not exist"""
     # GIVEN a adapter and the id of a non existing variant
