@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 import datetime
 import logging
+from pathlib import PosixPath
+from typing import Iterable, List
 
 import pymongo
 import pytest
@@ -22,6 +24,7 @@ from scout.demo import (
     cancer_load_path,
     cancer_snv_path,
     cancer_sv_path,
+    clinical_fusion_path,
     clinical_snv_path,
     clinical_str_path,
     clinical_sv_path,
@@ -30,6 +33,7 @@ from scout.demo import (
     load_path,
     panel_path,
     ped_path,
+    rnafusion_load_path,
     vep_97_annotated_path,
     vep_104_annotated_path,
 )
@@ -38,25 +42,30 @@ from scout.demo import (
 from scout.demo.resources import genes38_reduced_path  # noqa
 from scout.demo.resources import transcripts38_reduced_path  # noqa
 from scout.demo.resources import (
-    exac_reduced_path,
+    constraint_reduced_path,
     exons37_reduced_path,
     exons38_reduced_path,
     genemap2_reduced_path,
     genes37_reduced_path,
     genes_to_phenotype_reduced_path,
     hgnc_reduced_path,
+    hpo_phenotype_annotation_reduced_path,
     hpoterms_reduced_path,
     mim2gene_reduced_path,
+    orpha_inheritance_reduced_path,
+    orpha_to_genes_reduced_path,
+    orpha_to_hpo_reduced_path,
     phenotype_to_genes_reduced_path,
     transcripts37_reduced_path,
 )
 from scout.load import load_hgnc_genes
-from scout.load.hpo import load_hpo
+from scout.load.disease import load_disease_terms
+from scout.load.hpo import load_hpo_terms
 from scout.load.transcript import load_transcripts
 from scout.models.hgnc_map import HgncGene
 from scout.parse.case import parse_case_config
 from scout.parse.ensembl import parse_ensembl_exons, parse_ensembl_transcripts, parse_transcripts
-from scout.parse.exac import parse_exac_genes
+from scout.parse.exac import parse_constraint_genes
 from scout.parse.hgnc import parse_hgnc_genes
 from scout.parse.panel import parse_gene_panel
 from scout.parse.variant import parse_variant
@@ -116,16 +125,18 @@ def mock_redirect():
 def gene_obj():
     """Get a dictionary with with gene obj information"""
     gene = HgncGene(
-        hgnc_symbol="B3GALT6",
-        hgnc_id=17978,
-        ensembl_id="ENSG00000176022",
-        chrom="1",
-        start=1232237,
-        end=1235041,
-        build="38",
+        **dict(
+            hgnc_symbol="B3GALT6",
+            hgnc_id=17978,
+            ensembl_id="ENSG00000176022",
+            chromosome="1",
+            start=1232237,
+            end=1235041,
+            build="38",
+        )
     )
 
-    return gene
+    return gene.model_dump(exclude_none=True)
 
 
 @pytest.fixture
@@ -140,6 +151,8 @@ def unparsed_transcript(request):
         refseq_mrna_pred="",
         refseq_ncrna="",
         start=1167629,
+        mane_select="NM_022114.4",
+        mane_plus_clinical="NM_001160331.2",
     )
     return unparsed_transcript
 
@@ -173,7 +186,6 @@ def genes(
     hpo_genes_handle,
 ):
     """Get a dictionary with the linked genes"""
-    print("")
 
     gene_dict = link_genes(
         ensembl_lines=genes37_handle,
@@ -256,7 +268,6 @@ def gene_bulk_all(gene_bulk, gene_bulk_38):
 @pytest.fixture
 def transcript_objs(request, parsed_transcripts):
     """Return a list with transcript objs"""
-    print("")
 
     _transcripts = []
     for tx_id in parsed_transcripts:
@@ -321,6 +332,19 @@ def hpo_disease_handle(request, phenotype_to_genes_file):
     return handle
 
 
+@pytest.fixture
+def hpo_phenotype_annotation_file(request):
+    """Get a file handle to a phenotype.hpoa file."""
+    return hpo_phenotype_annotation_reduced_path
+
+
+@pytest.fixture
+def hpo_phenotype_annotation_handle(request, hpo_phenotype_annotation_file):
+    """Get a file handle to a phenotype.hpoa file."""
+    handle = get_file_handle(hpo_phenotype_annotation_file)
+    return handle
+
+
 @pytest.fixture(scope="function")
 def hpo_database(
     request,
@@ -332,35 +356,218 @@ def hpo_database(
     "Returns an adapter to a database populated with hpo terms"
     adapter = gene_database
 
-    load_hpo(
+    load_hpo_terms(
         adapter=gene_database,
-        disease_lines=get_file_handle(genemap_file),
         hpo_lines=get_file_handle(hpo_terms_file),
         hpo_gene_lines=get_file_handle(phenotype_to_genes_file),
     )
+    # Load diseases
+    # load_disease_terms(adapter=gene_database, genemap_lines=get_file_handle(genemap_file))
+    return adapter
+
+
+@pytest.fixture(scope="function")
+def disease_database(
+    request,
+    gene_database,
+    genemap_file,
+):
+    "Returns an adapter to a database populated with disease terms"
+    adapter = gene_database
+
+    # Load diseases
+    load_disease_terms(
+        adapter=gene_database,
+        genemap_lines=get_file_handle(genemap_file),
+        orpha_to_hpo_lines=get_file_handle(orpha_to_hpo_reduced_path),
+        orpha_to_genes_lines=get_file_handle(orpha_to_genes_reduced_path),
+        orpha_inheritance_lines=get_file_handle(orpha_inheritance_reduced_path),
+    )
     return adapter
 
 
 #############################################################
-################# OMIM terms fixtures #######################
+################# disease terms fixtures #######################
 #############################################################
 
+TEST_OMIM_DISEASES = {
+    "OMIM:614116": {
+        "inheritance": {"AD"},
+        "description": "Neuropathy hereditary sensory type IE",
+        "hgnc_symbols": {"DNMT1"},
+        "hpo_terms": {
+            "HP:0000741",
+            "HP:0000737",
+            "HP:0000407",
+            "HP:0001251",
+            "HP:0100710",
+            "HP:0011462",
+            "HP:0000726",
+            "HP:0003676",
+            "HP:0001265",
+            "HP:0001262",
+            "HP:0002460",
+            "HP:0002354",
+            "HP:0000006",
+            "HP:0000365",
+            "HP:0002059",
+        },
+        "hgnc_ids": set(),
+    },
+    "OMIM:604121": {
+        "inheritance": {"AD"},
+        "description": "Cerebellar ataxia deafness and narcolepsy autosomal dominant",
+        "hgnc_symbols": {"DNMT1"},
+        "hpo_terms": set(),
+        "hgnc_ids": set(),
+    },
+    "OMIM:260005": {
+        "inheritance": {"AR", "AD"},
+        "description": "5-oxoprolinase deficiency",
+        "hpo_terms": {"HP:0002027", "HP:0008672", "HP:0003137"},
+        "hgnc_ids": set(),
+        "hgnc_symbols": {"OPLAH"},
+    },
+}
+
+TEST_ORPHA_DISEASES = {
+    "ORPHA:585": {
+        "inheritance": {"AR"},
+        "description": "Multiple sulfatase deficiency",
+        "hgnc_ids": {20376},
+        "hpo_terms": {"HP:0000238", "HP:0000252", "HP:0000256", "HP:0000280"},
+    },
+    "ORPHA:118": {
+        "inheritance": {"AR"},
+        "description": "Beta-mannosidosis",
+        "hgnc_ids": {6831},
+        "hpo_terms": {
+            "HP:0000365",
+            "HP:0001249",
+        },
+    },
+}
+
+
+@pytest.fixture(scope="function")
+def test_parsed_hpo_annotations(request):
+    """Returns information for a sub set of omim diseases found in the demo resource-files
+    in the format expected after parsing of hpo information from omim-files"""
+    test_parsed_hpo_annotations = {}
+    for key, content in TEST_OMIM_DISEASES.items():
+        test_parsed_hpo_annotations[key] = {
+            "source": "OMIM",
+            "description": content["description"],
+            "hpo_terms": content["hpo_terms"],
+        }
+    test_parsed_hpo_annotations.update(
+        {
+            "OMIM:612201": {
+                "source": "OMIM",
+                "description": "Atrial fibrillation, familial, 6",
+                "hpo_terms": {"HP:0001712", "HP:0012664", "HP:0000006", "HP:0005110", "HP:0011462"},
+            },
+        },
+    )
+    return test_parsed_hpo_annotations
+
+
+@pytest.fixture(scope="function")
+def test_genemap_diseases(request):
+    """Returns information for a sub set of omim diseases found in the demo resource-files
+    in the format expected after parsing of gene information from omim-files"""
+    test_genemap_diseases = {}
+    for key, content in TEST_OMIM_DISEASES.items():
+        test_genemap_diseases[key] = {
+            "inheritance": content["inheritance"],
+            "description": content["description"],
+            "hgnc_symbols": content["hgnc_symbols"],
+        }
+
+    return test_genemap_diseases
+
+
+@pytest.fixture(scope="function")
+def test_orpha_hpo_annotations(request):
+    """Returns information for a sub set of orpha diseases found in the demo resource-files
+    in the format expected after parsing of hpo information from orpha-files"""
+    test_orpha_hpo_annotations = {}
+    for key, content in TEST_ORPHA_DISEASES.items():
+        test_orpha_hpo_annotations[key] = {
+            "description": content["description"],
+            "hgnc_ids": content["hgnc_ids"],
+            "hpo_terms": content["hpo_terms"],
+        }
+
+    return test_orpha_hpo_annotations
+
+
+@pytest.fixture(scope="function")
+def test_orpha_gene_annotations(request):
+    """Returns information for a sub set of orpha diseases found in the demo resource-files
+    in the format expected after parsing of gene information from orpha-files"""
+    test_orpha_gene_annotations = {}
+    for key, content in TEST_ORPHA_DISEASES.items():
+        test_orpha_gene_annotations[key] = {
+            "description": content["description"],
+            "hgnc_ids": content["hgnc_ids"],
+        }
+
+    return test_orpha_gene_annotations
+
+
+@pytest.fixture(scope="function")
+def test_orpha_disease_terms(request):
+    """Returns a set of orpha diseases found in the demo resource-files"""
+    orpha_disease_terms = TEST_ORPHA_DISEASES
+
+    return orpha_disease_terms
+
+
+@pytest.fixture(scope="function")
+def test_omim_disease_terms(request):
+    """Returns a sub set of omim diseases found in the demo resource-files"""
+    test_omim_diseases = TEST_OMIM_DISEASES
+    return test_omim_diseases
+
+
+@pytest.fixture(scope="function")
+def test_omim_database_term(request):
+    """Return a test OMIM disease object formatted as expected in the scout-database"""
+    omim_term = {}
+    for key, content in TEST_OMIM_DISEASES.items():
+        if key == "OMIM:260005":
+            source, disease_nr = key.split(":")
+            omim_term = {
+                "_id": key,
+                "disease_id": key,
+                "disease_nr": int(disease_nr),
+                "description": content["description"],
+                "source": source,
+                "genes": [8149],
+                "hpo_terms": list(content["hpo_terms"]),
+            }
+    return omim_term
+
 
 @pytest.fixture
-def test_omim_term(request):
-    """Return a test OMIM object"""
+def test_orpha_database_term(request):
+    """Return a test ORPHA object formatted as expected in the scout-database"""
+    orpha_term = {}
+    for key, content in TEST_ORPHA_DISEASES.items():
+        if key == "ORPHA:585":
+            source, disease_nr = key.split(":")
+            orpha_term = {
+                "_id": key,
+                "disease_id": key,
+                "disease_nr": disease_nr,
+                "description": content["description"],
+                "source": source,
+                "genes": [8149],
+                "hpo_terms": list(content["hpo_terms"]),
+            }
 
-    omim_term = {
-        "_id": "OMIM:260005",
-        "disease_id": "OMIM:260005",
-        "disease_nr": 260005,
-        "description": "5-oxoprolinase deficiency",
-        "source": "OMIM",
-        "genes": [8149],
-        "inheritance": ["AR", "AD"],
-        "HPO_terms": ["HP:00022027", "HP:0008672"],
-    }
-    return omim_term
+    return orpha_term
 
 
 #############################################################
@@ -379,26 +586,25 @@ def ped_lines(request):
 
 
 @pytest.fixture(scope="function")
-def case_lines(request, scout_config):
-    """Get the lines for a case"""
+def parsed_case(request, scout_config) -> dict:
+    """Get a WES parsed case."""
     case = parse_case_config(scout_config)
     return case
 
 
 @pytest.fixture(scope="function")
-def parsed_case(request, scout_config):
-    """Get the lines for a case"""
-    case = parse_case_config(scout_config)
-    return case
-
-
-@pytest.fixture(scope="function")
-def cancer_parsed_case(request, cancer_scout_config):
-    """Get the lines for a cancer case"""
+def cancer_parsed_case(request, cancer_scout_config) -> dict:
+    """Get a cancer panel parsed case."""
     case = parse_case_config(cancer_scout_config)
     return case
 
 
+@pytest.fixture(scope="function")
+def fusion_parsed_case(request, fusion_scout_config) -> dict:
+    """Get a parsed RNA fusion case."""
+    return parse_case_config(fusion_scout_config)
+
+
 @pytest.fixture(scope="function")
 def cancer_case_obj(request, cancer_parsed_case):
     """Return a cancer case object"""
@@ -422,6 +628,7 @@ def case_obj(request, parsed_case):
     case = parsed_case
     case["_id"] = parsed_case["case_id"]
     case["owner"] = parsed_case["owner"]
+    case["collaborators"] = [parsed_case["owner"]]
     case["created_at"] = parsed_case["analysis_date"]
     case["dynamic_gene_list"] = []
     case["has_svvariants"] = True
@@ -450,20 +657,31 @@ def case_obj(request, parsed_case):
     case["synopsis"] = ""
     case["updated_at"] = parsed_case["analysis_date"]
     case["delivery_report"] = parsed_case["delivery_report"]
-    case["custom_images"] = parsed_case["custom_images"]["case"]
+    case["custom_images"] = parsed_case["custom_images"]
     case["assignees"] = []
     case["phenotype_terms"] = []  # do not assign any phenotype
+    case["phenotype_groups"] = []  # do not assign any phenotype groups
     case["cohorts"] = []  # do not assign any cohort
 
     return case
 
 
+@pytest.fixture(scope="function")
+def fusion_case_obj(request, fusion_parsed_case) -> dict:
+    """Returns a DNA fusion case."""
+    case: dict = fusion_parsed_case
+    case["_id"] = fusion_parsed_case["case_id"]
+    case["status"] = "inactive"
+    case["phenotype_terms"] = []  # do not assign any phenotype
+    case["cohorts"] = []  # do not assign any cohort
+    return case
+
+
 #############################################################
 ##################### Institute fixtures ####################
 #############################################################
 @pytest.fixture(scope="function")
 def parsed_institute(request):
-    print("")
     institute = {
         "institute_id": "cust000",
         "display_name": "test_institute",
@@ -475,7 +693,6 @@ def parsed_institute(request):
 
 @pytest.fixture(scope="function")
 def institute_obj(request, parsed_institute):
-    print("")
     LOG.info("Building a institute")
     institute = build_institute(
         internal_id=parsed_institute["institute_id"],
@@ -729,34 +946,34 @@ def real_panel_database(request, real_gene_database, parsed_panel):
 
 
 @pytest.fixture(scope="function")
-def case_database(request, panel_database, parsed_case):
+def case_database(request, panel_database, parsed_case, institute_obj):
     "Returns an adapter to a database populated with institute, user and case"
     adapter = panel_database
     case_obj = build_case(parsed_case, adapter)
-    adapter._add_case(case_obj)
+    adapter.add_case(case_obj, institute_obj)
 
     return adapter
 
 
 @pytest.fixture(scope="function")
-def populated_database(request, panel_database, parsed_case):
+def populated_database(request, panel_database, parsed_case, institute_obj):
     "Returns an adapter to a database populated with user, institute case, genes, panels"
     adapter = panel_database
 
     LOG.info("Adding case to adapter")
     case_obj = build_case(parsed_case, adapter)
-    adapter._add_case(case_obj)
+    adapter.add_case(case_obj, institute_obj)
     return adapter
 
 
 @pytest.fixture(scope="function")
-def real_populated_database(real_panel_database, parsed_case):
+def real_populated_database(request, real_panel_database, parsed_case, institute_obj):
     "Returns an adapter to a database populated with user, institute case, genes, panels"
     adapter = real_panel_database
 
     LOG.info("Adding case to real adapter")
     case_obj = build_case(parsed_case, adapter)
-    adapter._add_case(case_obj)
+    adapter.add_case(case_obj, institute_obj)
 
     return adapter
 
@@ -1080,7 +1297,7 @@ def cancer_variants(cancer_snv_file):
 @pytest.fixture(scope="function")
 def parsed_variant(request, one_variant, case_obj):
     """Return a parsed variant"""
-    print("")
+
     variant_dict = parse_variant(one_variant, case_obj)
     return variant_dict
 
@@ -1088,7 +1305,7 @@ def parsed_variant(request, one_variant, case_obj):
 @pytest.fixture(scope="function")
 def parsed_str_variant(request, one_str_variant, case_obj):
     """Return a parsed variant"""
-    print("")
+
     variant_dict = parse_variant(one_str_variant, case_obj, category="str")
     return variant_dict
 
@@ -1096,7 +1313,7 @@ def parsed_str_variant(request, one_str_variant, case_obj):
 @pytest.fixture(scope="function")
 def variant_obj(request, parsed_variant):
     """Return a variant object"""
-    print("")
+
     institute_id = "cust000"
     variant = build_variant(parsed_variant, institute_id=institute_id)
     return variant
@@ -1105,7 +1322,7 @@ def variant_obj(request, parsed_variant):
 @pytest.fixture(scope="function")
 def str_variant_obj(request, parsed_str_variant):
     """Return a variant object"""
-    print("")
+
     institute_id = "cust000"
     variant = build_variant(parsed_str_variant, institute_id=institute_id)
     return variant
@@ -1135,7 +1352,7 @@ def cyvcf2_variant():
 @pytest.fixture(scope="function")
 def parsed_sv_variant(request, one_sv_variant, case_obj):
     """Return a parsed variant"""
-    print("")
+
     variant_dict = parse_variant(one_sv_variant, case_obj)
     return variant_dict
 
@@ -1157,7 +1374,7 @@ def parsed_variants(request, variants, case_obj):
 @pytest.fixture(scope="function")
 def parsed_sv_variants(request, sv_variants, case_obj):
     """Get a generator with parsed variants"""
-    print("")
+
     individual_positions = {}
     for i, ind in enumerate(sv_variants.samples):
         individual_positions[ind] = i
@@ -1171,96 +1388,122 @@ def parsed_sv_variants(request, sv_variants, case_obj):
 @pytest.fixture(scope="function")
 def variant_objs(request, parsed_variants, institute_obj):
     """Get a generator with parsed variants"""
-    print("")
+
     return (build_variant(variant, institute_obj) for variant in parsed_variants)
 
 
 @pytest.fixture(scope="function")
 def sv_variant_objs(request, parsed_sv_variants, institute_obj):
     """Get a generator with parsed variants"""
-    print("")
+
     return (build_variant(variant, institute_obj) for variant in parsed_sv_variants)
 
 
+@pytest.fixture(scope="function")
+def fusion_variants(request) -> VCF:
+    """Return a VCF object containing RNA fusion variants."""
+    return VCF(clinical_fusion_path)
+
+
+@pytest.fixture(scope="function")
+def one_cyvcf2_fusion_variant(request, fusion_variants) -> "Cyvcf2Variant":
+    "Return one fusion variant."
+    return next(fusion_variants)
+
+
+@pytest.fixture(scope="function")
+def parsed_fusion_variants(request, fusion_variants, fusion_case_obj) -> Iterable:
+    """Get a generator with parsed fusion variants"""
+    individual_positions = {}
+    for i, ind in enumerate(fusion_variants.samples):
+        individual_positions[ind] = i
+
+    return (
+        parse_variant(variant, fusion_case_obj, individual_positions=individual_positions)
+        for variant in fusion_variants
+    )
+
+
+@pytest.fixture(scope="function")
+def fusion_variant_objs(request, parsed_fusion_variants, institute_obj) -> Iterable:
+    """Get an iterator containing fusion variants as they would be loaded in the database."""
+    return (build_variant(variant, institute_obj) for variant in parsed_fusion_variants)
+
+
+@pytest.fixture(scope="function")
+def one_fusion_variant(institute_obj, parsed_fusion_variants) -> dict:
+    """Return one fusion variant as it would be loaded in the database."""
+    return build_variant(next(parsed_fusion_variants), institute_id=institute_obj["_id"])
+
+
 #############################################################
-##################### File fixtures #####################
+##################### File fixtures #########################
 #############################################################
 
 
 @pytest.fixture
 def config_file(request):
     """Get the path to a config file"""
-    print("")
     return load_path
 
 
 @pytest.fixture
 def panel_1_file(request):
     """Get the path to a config file"""
-    print("")
     return panel_path
 
 
 @pytest.fixture
 def hgnc_file(request):
     """Get the path to a hgnc file"""
-    print("")
     return hgnc_reduced_path
 
 
 @pytest.fixture
 def transcripts_file(request):
     """Get the path to a ensembl transcripts file"""
-    print("")
     return transcripts37_reduced_path
 
 
 @pytest.fixture
 def exons_file(request):
-    """Get the path to a ensembl exons file"""
-    print("")
+    """Get the path to an ensembl exons file"""
     return exons37_reduced_path
 
 
 @pytest.fixture
 def exons_38_file(request):
-    """Get the path to a ensembl exons file build 38"""
-    print("")
+    """Get the path to an ensembl exons file build 38"""
     return exons38_reduced_path
 
 
 @pytest.fixture
 def genes37_file(request):
-    """Get the path to a ensembl genes file"""
-    print("")
+    """Get the path to an ensembl genes file"""
     return genes37_reduced_path
 
 
 @pytest.fixture
 def exac_file(request):
-    """Get the path to a exac genes file"""
-    print("")
-    return exac_reduced_path
+    """Get the path to an GnomAD/ExAC genes file"""
+    return constraint_reduced_path
 
 
 @pytest.fixture
 def mim2gene_file(request):
     """Get the path to the mim2genes file"""
-    print("")
     return mim2gene_reduced_path
 
 
 @pytest.fixture
 def genemap_file(request):
     """Get the path to the mim2genes file"""
-    print("")
     return genemap2_reduced_path
 
 
 @pytest.fixture(scope="function")
 def variant_clinical_file(request):
     """Get the path to a variant file"""
-    print("")
     return clinical_snv_path
 
 
@@ -1289,62 +1532,63 @@ def vep_94_manta_annotated_SV_variants_file(request):
 @pytest.fixture(scope="function")
 def cancer_snv_file(request):
     """Get the path to a variant file"""
-    print("")
     return cancer_snv_path
 
 
 @pytest.fixture(scope="function")
 def sv_clinical_file(request):
     """Get the path to a variant file"""
-    print("")
     return clinical_sv_path
 
 
 @pytest.fixture(scope="function")
 def str_clinical_file(request):
     """Get the path to a variant file"""
-    print("")
     return clinical_str_path
 
 
 @pytest.fixture(scope="function")
 def empty_sv_clinical_file(request):
     """Get the path to a variant file without variants"""
-    print("")
     return empty_sv_clinical_path
 
 
 @pytest.fixture(scope="function")
 def customannotation_snv_file(request):
     """Get the path to a variant file with custom annotations"""
-    print("")
     return customannotation_snv_path
 
 
 @pytest.fixture(scope="function")
 def ped_file(request):
     """Get the path to a ped file"""
-    print("")
     return ped_path
 
 
 @pytest.fixture(scope="function")
-def scout_config(request, config_file):
+def scout_config(request, config_file) -> dict:
     """Return a dictionary with scout configs"""
-    print("")
     in_handle = get_file_handle(config_file)
     data = yaml.safe_load(in_handle)
     return data
 
 
 @pytest.fixture(scope="function")
-def cancer_scout_config(request):
+def cancer_scout_config(request) -> dict:
     """Return a dictionary with cancer case scout configs"""
     in_handle = get_file_handle(cancer_load_path)
     data = yaml.safe_load(in_handle)
     return data
 
 
+@pytest.fixture(scope="function")
+def fusion_scout_config(request) -> dict:
+    """Return a dictionary with fusion case scout configs"""
+    in_handle = get_file_handle(rnafusion_load_path)
+    data = yaml.safe_load(in_handle)
+    return data
+
+
 @pytest.fixture(scope="function")
 def minimal_config(request, scout_config):
     """Return a minimal config"""
@@ -1358,7 +1602,6 @@ def minimal_config(request, scout_config):
     config.pop("rank_model_version")
     config.pop("rank_score_threshold")
     config.pop("sv_rank_model_version")
-    config.pop("human_genome_build")
 
     return config
 
@@ -1366,77 +1609,66 @@ def minimal_config(request, scout_config):
 @pytest.fixture
 def panel_handle(request, panel_1_file):
     """Get a file handle to a gene panel file"""
-    print("")
     return get_file_handle(panel_1_file)
 
 
 @pytest.fixture
 def hgnc_handle(request, hgnc_file):
-    """Get a file handle to a hgnc file"""
-    print("")
+    """Get a file handle to an hgnc file"""
     return get_file_handle(hgnc_file)
 
 
 @pytest.fixture
 def hgnc_genes(request, hgnc_handle):
     """Get a dictionary with hgnc genes"""
-    print("")
     return parse_hgnc_genes(hgnc_handle)
 
 
 @pytest.fixture
 def genes37_handle(request, genes37_file):
-    """Get a file handle to a ensembl gene file"""
-    print("")
+    """Get a file handle to an ensembl gene file"""
     return get_file_handle(genes37_file)
 
 
 @pytest.fixture
 def transcripts_handle(request, transcripts_file):
-    """Get a file handle to a ensembl transcripts file"""
-    print("")
+    """Get a file handle to an ensembl transcripts file"""
     return get_file_handle(transcripts_file)
 
 
 @pytest.fixture
 def transcripts(request, transcripts_handle):
     """Get the parsed ensembl transcripts"""
-    print("")
     return parse_ensembl_transcripts(transcripts_handle)
 
 
 @pytest.fixture
 def exons_handle(request, exons_file):
-    """Get a file handle to a ensembl exons file"""
-    print("")
+    """Get a file handle to an ensembl exons file"""
     return get_file_handle(exons_file)
 
 
 @pytest.fixture
 def exons_38_handle(request, exons_38_file):
-    """Get a file handle to a ensembl exons file"""
-    print("")
+    """Get a file handle to an ensembl exons file"""
     return get_file_handle(exons_38_file)
 
 
 @pytest.fixture
 def exons(request, exons_handle):
     """Get the parsed ensembl transcripts"""
-    print("")
     return parse_ensembl_exons(exons_handle)
 
 
 @pytest.fixture
 def exons_38(request, exons_38_handle):
     """Get the parsed ensembl transcripts"""
-    print("")
     return parse_ensembl_exons(exons_38_handle)
 
 
 @pytest.fixture
 def parsed_transcripts(request, transcripts_handle, ensembl_genes):
     """Get the parsed ensembl transcripts"""
-    print("")
     transcripts = parse_transcripts(transcripts_handle)
     for tx_id in transcripts:
         tx_info = transcripts[tx_id]
@@ -1461,7 +1693,7 @@ def exac_handle(request, exac_file):
 def exac_genes(request, exac_handle):
     """Get the parsed exac genes"""
 
-    return parse_exac_genes(exac_handle)
+    return parse_constraint_genes(exac_handle)
 
 
 @pytest.fixture
@@ -1478,6 +1710,51 @@ def genemap_handle(request, genemap_file):
     return get_file_handle(genemap_file)
 
 
+"""Fixtures supplying paths to demo-files from orphadata"""
+
+
+@pytest.fixture
+def orphadata_en_product4_file(request) -> str:
+    """Get the path to the orphadata_en_product4 file, which contains orpha_to_hpo_lines."""
+    return orpha_to_hpo_reduced_path
+
+
+@pytest.fixture
+def orphadata_en_product6_file(request) -> str:
+    """Get the path to the orphadata_en_product6 file, which contains orpha_to_genes_lines."""
+    return orpha_to_genes_reduced_path
+
+
+@pytest.fixture
+def en_product9_ages_file(request) -> str:
+    """Get the path to the en_product9_ages file, which contains orpha_inheritance_lines."""
+    return orpha_inheritance_reduced_path
+
+
+"""Fixtures supplying read lines from orphadata files"""
+
+
+@pytest.fixture
+def orpha_to_genes_lines(request, orphadata_en_product6_file: str) -> List:
+    """Get the lines of the orphadata_en_product6_file, which contain orpha_to_genes info."""
+    orpha_to_genes_lines = get_file_handle(orphadata_en_product6_file)
+    return orpha_to_genes_lines
+
+
+@pytest.fixture
+def orpha_to_hpo_lines(request, orphadata_en_product4_file: str) -> List[str]:
+    """Get the lines of the orphadata_en_product4_file, which contain orpha_to_hpo info."""
+    orpha_to_hpo_lines = get_file_handle(orphadata_en_product4_file)
+    return orpha_to_hpo_lines
+
+
+@pytest.fixture
+def orpha_inheritance_lines(request, en_product9_ages_file: str) -> List[str]:
+    """Get the lines of the en_product9_ages_file, which contain orpha_inheritance."""
+    orpha_inheritance_lines = get_file_handle(en_product9_ages_file)
+    return orpha_inheritance_lines
+
+
 #############################################################
 #################### MatchMaker Fixtures ####################
 #############################################################
@@ -1602,3 +1879,16 @@ def match_objs():
         },
     ]
     return matches
+
+
+@pytest.fixture(name="custom_temp_file")
+def custom_temp_file(tmp_path) -> PosixPath:
+    """Returns a temp file with the provided extension."""
+
+    def _get_file_with_extension(extension):  # extension example -> '.bam'
+        tmp_file = tmp_path / extension
+        tmp_file.touch()
+        tmp_file.write_text("some_content")
+        return tmp_file
+
+    return _get_file_with_extension
