@@ -44,6 +44,7 @@ def test_parse_frequencies(cyvcf2_variant):
     # GIVEN a variant dict with a differenct frequencies
     variant.INFO["1000GAF"] = "0.01"
     variant.INFO["EXACAF"] = "0.001"
+    variant.INFO["SWEGENAF"] = "0.02"
 
     # WHEN frequencies are parsed
     frequencies = parse_frequencies(variant, [])
@@ -51,6 +52,7 @@ def test_parse_frequencies(cyvcf2_variant):
     # THEN the frequencies should be returned in a dictionary
     assert frequencies["thousand_g"] == float(variant.INFO["1000GAF"])
     assert frequencies["exac"] == float(variant.INFO["EXACAF"])
+    assert frequencies["swegen"] == float(variant.INFO["SWEGENAF"])
 
 
 def test_parse_sv_frequencies_clingen_benign(cyvcf2_variant):
@@ -140,6 +142,34 @@ def test_parse_gnomad_popmax(cyvcf2_variant):
     assert frequencies["gnomad_max"] == float(variant.INFO["GNOMADAF_popmax"])
 
 
+def test_parse_gnomad_echtvar(cyvcf2_variant):
+    """Make sure GNOMAD AF is parsed correctly from variants annotated with echtvar."""
+    variant = cyvcf2_variant
+
+    # GIVEN a variant dict with a certain gnomad_af allele frequency
+    variant.INFO["gnomad_af"] = "0.117036"
+
+    # WHEN frequencies are parsed
+    frequencies = parse_frequencies(variant, [])
+
+    # THEN assert that gnomad frequency is collected
+    assert frequencies["gnomad"] == float(variant.INFO["gnomad_af"])
+
+
+def test_parse_gnomad_popmax_echtvar(cyvcf2_variant):
+    """Make sure GNOMAD POPMAX AF is parsed correctly from variants annotated with echtvar."""
+    variant = cyvcf2_variant
+
+    # GIVEN a variant dict with a certain gnomad_af allele frequency
+    variant.INFO["gnomad_popmax_af"] = "0.831118"
+
+    # WHEN frequencies are parsed
+    frequencies = parse_frequencies(variant, [])
+
+    # THEN assert that gnomad_max frequency is collected
+    assert frequencies["gnomad_max"] == float(variant.INFO["gnomad_popmax_af"])
+
+
 def test_parse_sv_frequencies_ngi(cyvcf2_variant):
     variant = cyvcf2_variant
     # GIVEN a variant dict with a differenct frequencies
@@ -152,3 +182,16 @@ def test_parse_sv_frequencies_ngi(cyvcf2_variant):
 
     # THEN assert that the last frequency is returned
     assert frequencies["clingen_ngi"] == float(variant.INFO["clingen_ngi"])
+
+
+def test_parse_colorsdb(cyvcf2_variant):
+    """Make sure CoLoRSdb AF is parsed correctly from variants.."""
+    variant = cyvcf2_variant
+    # GIVEN a variant with CoLoRSdb AF in the INFO field
+    variant.INFO["colorsdb_af"] = "0.4982"
+
+    # WHEN frequencies are parsed
+    frequencies = parse_frequencies(variant, [])
+
+    # THEN assert that CoLoRSdb frequency is collected
+    assert frequencies["colorsdb_af"] == float(variant.INFO["colorsdb_af"])
