@@ -1,11 +1,13 @@
 import logging
 from datetime import datetime
+from os import path
 
 import pytest
 from pydantic import ValidationError
 
+from scout.build.individual import BUILD_INDIVIDUAL_FILES
 from scout.constants import REV_SEX_MAP
-from scout.exceptions import ConfigError, PedigreeError
+from scout.exceptions import PedigreeError
 from scout.parse.case import parse_case_config, parse_case_data, parse_ped, remove_none_values
 
 LOG = logging.getLogger(__name__)
@@ -72,8 +74,8 @@ def test_parse_case_parsing(scout_config, param_name):
     # GIVEN you load sample information from a scout config
     # WHEN case is parsed
     case_data = parse_case_config(scout_config)
-    # THEN the case should have the parameter
-    assert case_data[param_name] == scout_config[param_name]
+    # THEN the case should have the parameter, either as string of full path to a resource
+    assert case_data[param_name] == scout_config[param_name] or path.exists(case_data[param_name])
 
 
 @pytest.mark.parametrize(
@@ -81,6 +83,7 @@ def test_parse_case_parsing(scout_config, param_name):
     (
         [
             ("case_id", "family"),
+            ("display_name", "family_name"),
             ("default_panels", "default_gene_panels"),
             ("peddy_ped_check", "peddy_check"),
             ("peddy_sex_check", "peddy_sex"),
@@ -127,8 +130,9 @@ def test_parse_custom_images(scout_config):
     assert original_custom_images.keys() == parsed_custom_images.keys()
 
     assert all(
-        len(parsed_custom_images["case"][section]) == len(original_custom_images["case"][section])
-        for section in parsed_custom_images["case"]
+        len(parsed_custom_images["case_images"][section])
+        == len(original_custom_images["case_images"][section])
+        for section in parsed_custom_images["case_images"]
     )
 
 
@@ -136,7 +140,7 @@ def test_parse_incorrect_custom_images(scout_config):
     """Test parsing of case with a mix of accepted file types and not-accepted
     file types"""
 
-    # GIVEN one valid suffix and two invalid suffixes (.bnp, .pdf)
+    # GIVEN one or more custom images with unsupported format
     scout_config["custom_images"] = {
         "case": {
             "section_one": [
@@ -161,12 +165,9 @@ def test_parse_incorrect_custom_images(scout_config):
         }
     }
 
-    # WHEN images is parsed
-    parsed_data = parse_case_config(scout_config)
-
-    # THEN check that non valid image formats are being rejected
-    assert len(parsed_data["custom_images"]["case"]["section_one"]) == 1
-    assert "section_two" not in parsed_data["custom_images"]
+    # THEN image validation when loading a case should fail
+    with pytest.raises(TypeError):
+        parse_case_config(scout_config)
 
 
 def test_parse_case_collaborators(scout_config):
@@ -178,20 +179,30 @@ def test_parse_case_collaborators(scout_config):
 
 
 @pytest.mark.parametrize(
-    "vcf_file", ["vcf_snv", "vcf_sv", "vcf_str", "vcf_snv_research", "vcf_sv_research"]
+    "vcf_file",
+    [
+        "vcf_snv",
+        "vcf_sv",
+        "vcf_str",
+        "vcf_mei",
+        "vcf_snv_research",
+        "vcf_sv_research",
+        "vcf_mei_research",
+    ],
 )
 def test_parse_case_vcf_files(scout_config, vcf_file):
     # GIVEN you load sample information from a scout config
     # WHEN case is parsed
     case_data = parse_case_config(scout_config)
-    # THEN the case should the same vcf files as specified in the
-    assert case_data["vcf_files"][vcf_file] == scout_config[vcf_file]
+
+    # THEN the case should contain the absolute path to the resources specified in the case config
+    assert path.exists(case_data["vcf_files"][vcf_file])
 
 
 @pytest.mark.parametrize("bam_name", ["alignment_path", "bam_file", "bam_path"])
-def test_parse_case_bams(scout_config, bam_name):
+def test_parse_case_bams(scout_config, bam_name, custom_temp_file):
     # GIVEN a load config with bam_path as key to bam/cram files
-    bam_path = "a bam"
+    bam_path = str(custom_temp_file(".bam"))
     for sample in scout_config["samples"]:
         sample[bam_name] = bam_path
     # WHEN case is parsed
@@ -202,13 +213,13 @@ def test_parse_case_bams(scout_config, bam_name):
         assert ind["bam_file"] == bam_path
 
 
-def test_parse_case_multiple_alignment_files(scout_config):
+def test_parse_case_multiple_alignment_files(scout_config, custom_temp_file):
     # GIVEN a load config with both cram and bam files
-    bam_path = "a bam"
+    bam_path = str(custom_temp_file(".bam"))
     for sample in scout_config["samples"]:
         sample["bam_file"] = bam_path
 
-    cram_path = "a cram"
+    cram_path = str(custom_temp_file(".cram"))
     for sample in scout_config["samples"]:
         sample["alignment_path"] = cram_path
 
@@ -220,6 +231,20 @@ def test_parse_case_multiple_alignment_files(scout_config):
         assert ind["bam_file"] == cram_path
 
 
+def test_parse_case_ribonucleic_acid_alignment_files(scout_config, custom_temp_file):
+    # GIVEN a load config with RNA alignment paths
+    cram_path = str(custom_temp_file(".cram"))
+    for sample in scout_config["samples"]:
+        sample["rna_alignment_path"] = cram_path
+
+    # WHEN case is parsed
+    case_data = parse_case_config(scout_config)
+
+    # THEN assert that cram files are added correctly, ignoring bam
+    for ind in case_data["individuals"]:
+        assert ind["rna_alignment_path"] == cram_path
+
+
 def test_parse_ped_file(ped_file):
     # GIVEN a pedigree with three samples
     with open(ped_file, "r") as case_lines:
@@ -365,61 +390,25 @@ def test_remove_none_values():
     assert {"a": "1", "b": 2} == remove_none_values(d)
 
 
-def test_parse_optional_igv_param(scout_config):
-    # GIVEN a dict contains optional igv params
-    # i.e. rhocall_wig
-    samples = scout_config["samples"]
+def test_parse_individual_files(scout_config, custom_temp_file):
+    """Make sure the individual-specific config params are parsed correctly."""
 
-    # WHEN optional parameters are added to config
-    for sample in samples:
-        sample["rhocall_bed"] = "path/to/rb"
-        sample["rhocall_wig"] = "path/to/rw"
-        sample["upd_regions_bed"] = "path/to/up"
-        sample["upd_sites_bed"] = "path/to/us"
-        sample["tiddit_coverage_wig"] = "path/to/tc"
-    scout_config["samples"] = samples
+    # GIVEN that the samples contained in the scout load config file have a path associated to each possible file
+    for sample_config in scout_config["samples"]:
+        sample_config["bam_path"] = str(custom_temp_file(".cram"))
+        sample_config["rhocall_bed"] = str(custom_temp_file(".bed"))
+        sample_config["rhocall_wig"] = str(custom_temp_file(".wig"))
+        sample_config["tiddit_coverage_wig"] = str(custom_temp_file(".wig"))
+        sample_config["upd_regions_bed"] = str(custom_temp_file(".bed"))
+        sample_config["upd_sites_bed"] = str(custom_temp_file(".bed"))
 
-    # THEN parsing the config will add those to case data
+    # THEN config file should be parsed correctly
     case_data = parse_case_config(scout_config)
-    case_list = []
-    config_list = []
+
+    # AND parsed case individuals should contain all files key/values expected by the next loading step (build individual)
     for individual in case_data["individuals"]:
-        case_list.append(
-            (
-                individual["rhocall_wig"],
-                individual["rhocall_bed"],
-                individual["upd_regions_bed"],
-                individual["upd_sites_bed"],
-                individual["tiddit_coverage_wig"],
-            )
-        )
-
-    for sample in samples:
-        config_list.append(
-            (
-                sample["rhocall_wig"],
-                sample["rhocall_bed"],
-                sample["upd_regions_bed"],
-                sample["upd_sites_bed"],
-                sample["tiddit_coverage_wig"],
-            )
-        )
-
-    assert config_list == case_list
-
-
-def test_missing_optional_igv_param(scout_config):
-    # WHEN a dict is missing optinal wig param (later passed to igv.js)
-    # i.e. rhocall_wig
-    scout_config.pop("rhocall_bed", "ignore_return")
-    scout_config.pop("rhocall_wig", "ignore_return")
-    scout_config.pop("upd_regions_bed", "ignore_return")
-    scout_config.pop("upd_sites_bed", "ignore_return")
-    scout_config.pop("tiddit_coverage_wig", "ignore_return")
-
-    # THEN parsing the config will not raise an exception
-    case_data = parse_case_config(scout_config)
-    assert case_data
+        for file_type in BUILD_INDIVIDUAL_FILES:
+            assert individual.get(file_type)
 
 
 @pytest.mark.parametrize("key", ["owner", "family"])
@@ -429,5 +418,59 @@ def test_missing_mandatory_config_key(scout_config, key):
     ## WHEN deleting key
     scout_config.pop(key)
     ## THEN calling parse_case_config() will raise ConfigError
-    with pytest.raises(ConfigError):
+    with pytest.raises(ValueError):
         parse_case_config(scout_config)
+
+
+@pytest.mark.parametrize("key", ["genome_build", "human_genome_build"])
+def test_load_case_wrong_genome_build(scout_config, key):
+    """Test loading a case with a genome build of wrong format."""
+
+    ## GIVEN a scout_config (dict) containing user case information
+    ## WHEN setting one of the genome build keys to a non-supported value
+    scout_config.pop(key, None)
+    scout_config[key] = "xyz"
+
+    ## THEN calling parse_case_config() will raise ConfigError
+    with pytest.raises(ValueError):
+        parse_case_config(scout_config)
+
+
+def test_load_case_missing_genome_build(scout_config):
+    """Test loading a case with without providing a genome build."""
+
+    ## GIVEN a scout_config (dict) containing user case information
+    ## WHEN deleting the genome_build key
+    scout_config.pop("human_genome_build")
+
+    ## THEN calling parse_case_config() will raise ConfigError
+    with pytest.raises(ValueError):
+        parse_case_config(scout_config)
+
+
+@pytest.mark.parametrize("key", ["genome_build", "human_genome_build"])
+def test_load_case_int_genome_build(scout_config, key):
+    """Test loading a case with a genome build as an int: 37 or 38."""
+
+    ## GIVEN a scout_config (dict) containing user case information
+    ## WHEN setting one of the genome build keys to an integer (either 37 or 38)
+    for num_build in [37, 38]:
+        scout_config.pop(key, None)
+        scout_config[key] = num_build
+
+        ## THEN calling parse_case_config() should return parsed data
+        assert parse_case_config(scout_config)
+
+
+@pytest.mark.parametrize("key", ["genome_build", "human_genome_build", "rna_human_genome_build"])
+def test_load_case_str_genome_build(scout_config, key):
+    """Test loading a case with a genome build as string: '37' or '38´."""
+
+    ## GIVEN a scout_config (dict) containing user case information
+    ## WHEN setting one of the genome build keys to a string (either "37" or "38")
+    for str_build in ["37", "38"]:
+        scout_config.pop(key, None)
+        scout_config[key] = str_build
+
+        ## THEN calling parse_case_config() should return parsed data
+        assert parse_case_config(scout_config)
