@@ -1,4 +1,4 @@
-from scout.parse.hpo_mappings import parse_hpo_diseases, parse_hpo_to_genes
+from scout.parse.hpo_mappings import parse_hpo_annotations, parse_hpo_to_genes
 
 
 def test_parse_hpo_to_genes(hpo_disease_handle):
@@ -13,11 +13,11 @@ def test_parse_hpo_to_genes(hpo_disease_handle):
         assert item["hgnc_symbol"]
 
 
-def test_parse_hpo_diseases(hpo_disease_handle):
-    """Test function that extracts disease mapping info from phenotype_to_genes.txt file"""
+def test_parse_hpo_annotations(hpo_phenotype_annotation_handle):
+    """Test function that extracts disease mapping info from phenotype.hpoa file"""
 
     # WHEN parsing phenotype_to_genes.txt using the parse_hpo_diseases function
-    diseases = parse_hpo_diseases(hpo_disease_handle)
+    diseases = parse_hpo_annotations(hpo_phenotype_annotation_handle)
 
     # THEN the resulting dictionary has OMIM terms as keys
     omim_ids = list(diseases.keys())
@@ -25,6 +25,7 @@ def test_parse_hpo_diseases(hpo_disease_handle):
 
     # and disease info as values
     one_disease = diseases[omim_ids[0]]
-    assert one_disease["disease_nr"]
-    assert one_disease["hgnc_symbols"]
+
+    assert one_disease["hpo_terms"]
     assert one_disease["source"] == "OMIM"
+    assert one_disease["description"]
