@@ -2,7 +2,7 @@
 import datetime
 
 from bson.objectid import ObjectId
-from flask import current_app, json, url_for
+from flask import json, url_for
 
 from scout.constants import CUSTOM_CASE_REPORTS
 from scout.server.blueprints.cases.views import parse_raw_gene_ids, parse_raw_gene_symbols
@@ -114,9 +114,8 @@ def test_add_individual_phenotype(app, institute_obj):
         }
     ]
 
-    # AND a relatove event with specific HPO term and affected individual should be created in database
-    update_event = store.event_collection.find_one()
-    assert update_event["hpo_term"] == phenotype_term["phenotype_id"]
+    # AND a relative event with specific HPO term and affected individual should be created in database
+    update_event = store.event_collection.find_one({"hpo_term": phenotype_term["phenotype_id"]})
     assert update_event["individuals"] == [ind_name]
 
 
@@ -181,8 +180,7 @@ def test_rerun_monitor(app, institute_obj, mocker, mock_redirect):
         assert updated_case["rerun_monitoring"] is True
 
         # AND an unmonitor event should be created
-        rerun_event = store.event_collection.find_one()
-        assert rerun_event.get("verb") == "rerun_monitor"
+        assert store.event_collection.find_one({"verb": "rerun_monitor"})
 
 
 def test_research(app, institute_obj, case_obj, mocker, mock_redirect):
@@ -350,6 +348,7 @@ def test_case_custom_images(app, institute_obj, case_obj):
     with app.test_client() as client:
         # GIVEN that the user could be logged in
         resp = client.get(url_for("auto_login"))
+        assert resp.status_code == 200
 
         # WHEN case page is loaded
         resp = client.get(
@@ -361,10 +360,30 @@ def test_case_custom_images(app, institute_obj, case_obj):
         )
         # THEN it should display the two custom images section
         dta = resp.get_data()
-        for section_name in case_obj["custom_images"]:
+        for section_name in case_obj["custom_images"]["case_images"]:
             assert bytes(f"{section_name}-accordion", "utf-8") in dta
 
 
+def test_case_by_id(app, case_obj):
+    """Test that cases can be retrieved using case_id only"""
+    # GIVEN an initialized app
+    with app.test_client() as client:
+        # GIVEN that the user could be logged in
+        resp = client.get(url_for("auto_login"))
+        assert resp.status_code == 200
+
+        # WHEN case page is loaded
+        resp = client.get(
+            url_for(
+                "cases.case",
+                case_id=case_obj["_id"],
+            )
+        )
+
+        # THEN it should return a valid page
+        assert resp.status_code == 200
+
+
 def test_case_outdated_panel(app, institute_obj, case_obj):
     """Test case displaying an outdated panel warning badge"""
 
@@ -385,6 +404,7 @@ def test_case_outdated_panel(app, institute_obj, case_obj):
     with app.test_client() as client:
         # GIVEN that the user could be logged in
         resp = client.get(url_for("auto_login"))
+        assert resp.status_code == 200
 
         # WHEN case page is loaded
         resp = client.get(
@@ -423,6 +443,30 @@ def test_case_sma(app, case_obj, institute_obj):
         assert resp.status_code == 200
 
 
+def test_case_fusion(app, fusion_case_obj, institute_obj):
+    """Test the RNA fusion case page."""
+
+    # GIVEN an initialized app
+    with app.test_client() as client:
+        # GIVEN a valid user, case and institute
+        client.get(url_for("auto_login"))
+
+        # GIVEN a database containing a fusion case object
+        assert store.case_collection.insert_one(fusion_case_obj)
+
+        # WHEN accessing the RNA fusion case
+        resp = client.get(
+            url_for(
+                "cases.case",
+                institute_id=institute_obj["internal_id"],
+                case_name=fusion_case_obj["display_name"],
+            )
+        )
+
+        # THEN it should return a page
+        assert resp.status_code == 200
+
+
 def test_update_individual(app, user_obj, institute_obj, case_obj, mocker, mock_redirect):
     mocker.patch("scout.server.blueprints.cases.views.redirect", return_value=mock_redirect)
     # GIVEN an initialized app
@@ -716,20 +760,30 @@ def test_case_report(app, institute_obj, case_obj):
         assert resp.status_code == 200
 
 
-def test_case_diagnosis(app, institute_obj, case_obj, mocker, mock_redirect):
-    # Test the web page containing the general case report
+def test_case_diagnosis(
+    app, institute_obj, case_obj, test_omim_database_term, mocker, mock_redirect
+):
+    """Test the cases.case_diagnosis by adding and removing a diagnosis."""
 
     mocker.patch("scout.server.blueprints.cases.views.redirect", return_value=mock_redirect)
 
+    # GIVEN a case with no diagnosis:
+    assert case_obj.get("diagnosis_phenotypes") is None
+    # And no events in the database
+    assert not store.event_collection.find_one({"verb": "update_diagnosis"})
+
+    # GIVEN a disease term present in the database
+    store.disease_term_collection.insert_one(test_omim_database_term)
+    disease_id = test_omim_database_term["_id"]
+
     # GIVEN an initialized app and a valid user and institute
     with app.test_client() as client:
         # GIVEN that the user could be logged in
-        resp = client.get(url_for("auto_login"))
-        assert resp.status_code == 200
+        client.get(url_for("auto_login"))
 
-        req_data = {"omim_term": "OMIM:615349"}
+        req_data = {"disease_term": disease_id}
 
-        # When updating an OMIM diagnosis for a case
+        # WHEN updating a diagnosis for a case
         resp = client.post(
             url_for(
                 "cases.case_diagnosis",
@@ -738,8 +792,32 @@ def test_case_diagnosis(app, institute_obj, case_obj, mocker, mock_redirect):
             ),
             data=req_data,
         )
-        # Response should be redirected to case page
+        # THEN response should be redirected to case page
         assert resp.status_code == 302
+        # And case should have a diagnosis:
+        case_obj = store.case_collection.find_one({"_id": case_obj["_id"]})
+        assert case_obj.get("diagnosis_phenotypes")
+        # And a new event should have been saved into the database
+        assert store.event_collection.find_one({"verb": "update_diagnosis"})
+
+        # WHEN using the same endpoint to remove the diagnosis
+        req_data = {"disease_term": disease_id}
+        resp = client.post(
+            url_for(
+                "cases.case_diagnosis",
+                institute_id=institute_obj["internal_id"],
+                case_name=case_obj["display_name"],
+                remove="yes",
+            ),
+            data=req_data,
+        )
+        # THEN response should be redirected to case page
+        assert resp.status_code == 302
+        # And case should have no diagnoses
+        case_obj = store.case_collection.find_one({"_id": case_obj["_id"]})
+        assert not case_obj.get("diagnosis_phenotypes")
+        # And a new event should have been saved into the database
+        assert sum(1 for _ in store.event_collection.find({"verb": "update_diagnosis"})) == 2
 
 
 def test_pdf_case_report(app, institute_obj, case_obj):
@@ -840,11 +918,11 @@ def test_caselist(app, case_obj):
         assert case_obj["display_name"] in str(resp.data)
 
 
-def test_omimterms(app, test_omim_term):
-    """Test The API which returns all OMIM terms when queried from case page"""
+def test_diseaseterms(app, test_omim_database_term):
+    """Test The API which returns all disease terms when queried from case page"""
 
     # GIVEN a database containing at least one OMIM term
-    store.disease_term_collection.insert_one(test_omim_term)
+    store.disease_term_collection.insert_one(test_omim_database_term)
 
     # GIVEN an initialized app
     # GIVEN a valid user and institute
@@ -853,13 +931,13 @@ def test_omimterms(app, test_omim_term):
         resp = client.get(url_for("auto_login"))
         assert resp.status_code == 200
 
-        # WHEN the API is invoked with a query string containing part of the OMIM term description
-        resp = client.get(url_for("cases.omimterms", query="5-oxo"))
+        # WHEN the API is invoked with a query string containing part of the disease term description
+        resp = client.get(url_for("cases.diseaseterms", query="5-oxo"))
         # THEN it should return a valid response
         assert resp.status_code == 200
 
-        # containing the OMIM term
-        assert test_omim_term["_id"] in str(resp.data)
+        # containing the disease term
+        assert test_omim_database_term["_id"] in str(resp.data)
         assert resp.mimetype == "application/json"
 
 
@@ -905,3 +983,30 @@ def test_beacon_remove_variants(app, institute_obj, case_obj, mocker, mock_redir
             data=data,
         )
         assert resp.status_code == 302
+
+
+def test_host_custom_image_aux(app, institute_obj, case_obj):
+    """Test the endpoint that returns a custom image given its path."""
+
+    # GIVEN an app with an authenticated user
+    with app.test_client() as client:
+        # GIVEN that the user could be logged in
+        client.get(url_for("auto_login"))
+
+        # GIVEN a case with custom images
+        custom_image: dict = case_obj["custom_images"]["case_images"]["section_one"][0]
+        assert custom_image
+
+        # WHEN retrieving ae custom image using the host_custom_image_aux endpoint
+        resp = client.get(
+            url_for(
+                "cases.host_custom_image_aux",
+                institute_id=institute_obj["internal_id"],
+                case_name=case_obj["display_name"],
+                image_path=custom_image["path"],
+            )
+        )
+
+        # THEN it should return an image
+        assert resp.status_code == 200
+        assert resp.mimetype == "image/png"
