@@ -127,7 +127,7 @@ def test_delete_panel(app, real_panel_database):
         assert panel_obj.get("hidden")
 
 
-def test_panels(app, institute_obj):
+def test_panels(app):
     # GIVEN an initialized app
     # GIVEN a valid user and institute
 
@@ -143,19 +143,33 @@ def test_panels(app, institute_obj):
         assert resp.status_code == 200
 
 
-# This test is slow since pdf rendering is slow
-def test_panel_export(client, real_panel_database):
+def test_gene_panel_export_txt(client, real_panel_database):
+    """Test the endpoint that exports gene panels in TXT format"""
+
     adapter = real_panel_database
     # GIVEN a panel in the database
     panel_obj = adapter.panel_collection.find_one()
-    assert True
-    # WHEN accessing the panel view
-    resp = client.get(url_for("panels.panel_export", panel_id=panel_obj["_id"]))
-    # THEN it should display the panel with all the genes
+    # WHEN using the panels.panel_export_txt endpoint
+    resp = client.get(url_for("panels.panel_export_txt", panel_id=panel_obj["_id"]))
+    # THEN it should download the panel in the right format
     assert resp.status_code == 200
+    assert resp.mimetype == "text/txt"
 
 
-def test_panel_export_case_hits(client, real_panel_database):
+def test_panel_export_pdf(client, real_panel_database):
+    """Test the endpoint that exports gene panels in PDF format"""
+
+    adapter = real_panel_database
+    # GIVEN a panel in the database
+    panel_obj = adapter.panel_collection.find_one()
+    # WHEN using the panels.panel_export_pdf endpoint
+    resp = client.get(url_for("panels.panel_export_pdf", panel_id=panel_obj["_id"]))
+    # THEN it should download the panel in PDF format
+    assert resp.status_code == 200
+    assert resp.mimetype == "application/pdf"
+
+
+def test_panel_export_case_hits(app, real_panel_database):
     """Test function used for exporting all genes with variant hits for a case"""
 
     # GIVEN a case and a gene panel in the database
@@ -163,14 +177,19 @@ def test_panel_export_case_hits(client, real_panel_database):
     panel_obj = adapter.panel_collection.find_one()
     case_obj = adapter.case_collection.find_one()
 
-    # WHEN downloading the case variants hits report
-    form_data = {"case_name": " - ".join([case_obj["owner"], case_obj["display_name"]])}
-    resp = client.post(url_for("panels.panel_export", panel_id=panel_obj["_id"]), data=form_data)
+    # GIVEN an initialized app and a valid user
+    with app.test_client() as client:
+        client.get(url_for("auto_login"))
 
-    # THEN the response should be successful
-    assert resp.status_code == 200
-    # And should download a PDF file
-    assert resp.mimetype == "application/pdf"
+        # WHEN downloading the case variants hits report
+        form_data = {"case_name": " - ".join([case_obj["owner"], case_obj["display_name"]])}
+        resp = client.post(
+            url_for("panels.panel_export_case_hits", panel_id=panel_obj["_id"]), data=form_data
+        )
+        # THEN the response should be successful
+        assert resp.status_code == 200
+        # And should download a PDF file
+        assert resp.mimetype == "application/pdf"
 
 
 def test_gene_edit(client, real_panel_database):
