@@ -11,14 +11,14 @@ from scout.server.app import create_app
 from scout.server.blueprints.variant.controllers import (
     check_reset_variant_classification,
     get_igv_tracks,
-    has_rna_tracks,
     observations,
     tx_overview,
     variant,
     variant_rank_scores,
 )
 from scout.server.blueprints.variant.utils import evaluation
-from scout.server.extensions import cloud_tracks, loqusdb, store
+from scout.server.extensions import config_igv_tracks, loqusdb, store
+from scout.server.utils import case_has_rna_tracks
 
 LOG = logging.getLogger(__name__)
 
@@ -152,7 +152,7 @@ def test_has_rna_tracks(case_obj, tmpdir):
         ind["rna_coverage_bigwig"] = str(rna_cov_bw)
 
     # THEN case should result having RNA tracks
-    assert has_rna_tracks(case_obj) is True
+    assert case_has_rna_tracks(case_obj) is True
 
 
 def test_get_igv_tracks():
@@ -160,7 +160,7 @@ def test_get_igv_tracks():
 
     # GIVEN an app with public cloud tracks initialized
     patched_track = {"37": [{"name": "test track"}]}
-    cloud_tracks.public_tracks = patched_track
+    config_igv_tracks.tracks = patched_track
 
     # THEN the get_igv_tracks controller should return the default tracks
     igv_tracks = get_igv_tracks()
@@ -198,10 +198,9 @@ def test_observations_controller_non_existing(app, institute_obj, case_obj, loqu
     ## WHEN updating the case_id for the variant
     var_obj["case_id"] = "internal_id2"
 
-    data = None
     with app.test_client() as client:
-        resp = client.get(url_for("auto_login"))
-        data = observations(store, loqusdb, case_obj, var_obj)
+        client.get(url_for("auto_login"))
+        data = observations(store, loqusdb, var_obj)
 
     ## THEN assert that the number of cases is still returned
     assert data[loqus_id]["total"] == n_cases
@@ -241,10 +240,9 @@ def test_observations_controller_snv(app, institute_obj, loqusdburl):
     ## WHEN updating the case_id for the variant
     var_obj["case_id"] = "internal_id2"
 
-    data = None
     with app.test_client() as client:
-        resp = client.get(url_for("auto_login"))
-        data = observations(store, loqusdb, case_obj, var_obj)
+        client.get(url_for("auto_login"))
+        data = observations(store, loqusdb, var_obj)
 
     ## THEN loqus should return the occurrence from the first case
     assert case_obj["_id"] in data[loqus_id]["families"]
@@ -286,9 +284,9 @@ def test_observations_controller_sv(app, sv_variant_obj, institute_obj, loqusdbu
     sv_variant_obj["variant_id"] = "someOtherVarID"
 
     with app.test_client() as client:
-        resp = client.get(url_for("auto_login"))
+        client.get(url_for("auto_login"))
         # THEN the observation of the original case should be found
-        data = observations(store, loqusdb, case_obj, sv_variant_obj)
+        data = observations(store, loqusdb, sv_variant_obj)
 
     ## THEN loqus should return the occurrence from the first case
     assert case_obj["_id"] in data[loqus_id]["families"]
@@ -329,7 +327,7 @@ def test_case_matching_causatives(app, real_variant_database):
     other_variant["_id"] = "other_variant"
     adapter.variant_collection.insert_one(other_variant)
 
-    assert sum(1 for _ in adapter.event_collection.find()) == 0
+    assert sum(1 for _ in adapter.event_collection.find({"verb": "mark_causative"})) == 0
 
     # WHEN the original case has a causative variant flagged,
     link = "junk/{}".format(variant_obj["_id"])
@@ -342,7 +340,7 @@ def test_case_matching_causatives(app, real_variant_database):
     )
 
     # THEN an event object should have been created linking the variant
-    event_obj = adapter.event_collection.find_one()
+    event_obj = adapter.event_collection.find_one({"verb": "mark_causative"})
     assert event_obj["link"] == link
 
     # THEN an function will find the matching causative
@@ -426,10 +424,9 @@ def test_variant_controller_with_compounds(app, institute_obj, case_obj):
         ## WHEN fetching the variant from the controller
         data = variant(
             store,
-            institute_id,
-            case_name,
+            institute_id=institute_id,
+            case_name=case_name,
             variant_id=var_id,
-            add_case=True,
             add_other=True,
             get_overlapping=True,
             variant_type=category,
@@ -464,10 +461,9 @@ def test_variant_controller_with_clnsig(app, institute_obj, case_obj):
         ## WHEN fetching the variant from the controller
         data = variant(
             store,
-            institute_id,
-            case_name,
             variant_id=var_id,
-            add_case=True,
+            institute_id=institute_id,
+            case_name=case_name,
             add_other=True,
             get_overlapping=True,
             variant_type=category,
@@ -493,10 +489,9 @@ def test_variant_controller(app, institute_obj, case_obj, variant_obj):
         ## WHEN fetching the variant from the controller
         data = variant(
             store,
-            institute_id,
-            case_name,
             variant_id=var_id,
-            add_case=True,
+            institute_id=institute_id,
+            case_name=case_name,
             add_other=True,
             get_overlapping=True,
             variant_type=category,
