@@ -134,10 +134,18 @@ def test_bulk_reset_dismiss_variants(app, institute_obj, case_obj, mocker, mock_
         assert updated_variant.get("dismiss_variant") is None
 
         # 2 variant-relative events should be found in the database
-        assert sum(1 for i in store.event_collection.find({"category": "variant"})) == 2
+        assert sum(1 for _ in store.event_collection.find({"category": "variant"})) == 2
 
-        # And one case-specifuc event should also be created
-        assert sum(1 for i in store.event_collection.find({"category": "case"})) == 1
+        # And one case-specific event should also be created
+        assert (
+            sum(
+                1
+                for _ in store.event_collection.find(
+                    {"category": "case", "verb": "reset_dismiss_all_variants"}
+                )
+            )
+            == 1
+        )
 
 
 def test_variants_research(app, institute_obj, case_obj):
@@ -254,6 +262,101 @@ def test_str_variants(app, institute_obj, case_obj):
         assert resp.status_code == 200
 
 
+def test_fusion_variants(app, institute_obj, fusion_case_obj, fusion_variant_objs):
+    """Test the page that displays a list of RNA fusion variants."""
+
+    # GIVEN an initialized app
+    with app.test_client() as client:
+        # GIVEN a valid user and institute
+        client.get(url_for("auto_login"))
+
+        # GIVEN a RNA fusion case present in the database
+        assert store.case_collection.insert_one(fusion_case_obj)
+
+        # GIVEN that the case has RNA fusion variants
+        store.variant_collection.insert_many([variant for variant in fusion_variant_objs])
+
+        # WHEN accessing the fusion variants page
+        resp = client.get(
+            url_for(
+                "variants.fusion_variants",
+                institute_id=institute_obj["internal_id"],
+                case_name=fusion_case_obj["display_name"],
+            )
+        )
+        # THEN it should return a page
+        assert resp.status_code == 200
+
+
+def test_mei_variants(app, institute_obj, case_obj):
+    # GIVEN an initialized app
+    # GIVEN a valid user and institute
+
+    with app.test_client() as client:
+        # GIVEN that the user could be logged in
+        resp = client.get(url_for("auto_login"))
+        assert resp.status_code == 200
+
+        # WHEN accessing the mei-variants page
+        resp = client.get(
+            url_for(
+                "variants.mei_variants",
+                institute_id=institute_obj["internal_id"],
+                case_name=case_obj["display_name"],
+            )
+        )
+        # THEN it should return a page
+        assert resp.status_code == 200
+
+
+def test_mei_variants_research(app, institute_obj, case_obj):
+    with app.test_client() as client:
+        # GIVEN that the user could be logged in
+        resp = client.get(url_for("auto_login"))
+        assert resp.status_code == 200
+
+        # WHEN accessing the sv-variants page
+        resp = client.get(
+            url_for(
+                "variants.mei_variants",
+                institute_id=institute_obj["internal_id"],
+                case_name=case_obj["display_name"],
+                variant_type="research",
+            )
+        )
+        # THEN it should return a page
+        assert resp.status_code == 200
+        # THEN a reset filters link with variant type should have been made
+        assert "variant_type=research" in str(resp.data)
+
+
+def test_mei_variants_post_data(app, institute_obj, case_obj):
+    # GIVEN an initialized app
+    # GIVEN a valid user and institute
+
+    with app.test_client() as client:
+        # GIVEN that the user could be logged in
+        resp = client.get(url_for("auto_login"))
+        assert resp.status_code == 200
+
+        # WHEN requesting a clinical filter from the page (POST method)
+        data = urlencode({"clinical_filter": True})  # clinical filter
+
+        # WHEN posting an update description request to panel page
+        resp = client.post(
+            url_for(
+                "variants.mei_variants",
+                institute_id=institute_obj["internal_id"],
+                case_name=case_obj["display_name"],
+            ),
+            data=data,
+            content_type="application/x-www-form-urlencoded",
+        )
+
+        # THEN it should return a page
+        assert resp.status_code == 200
+
+
 def test_cancer_variants(app, institute_obj, case_obj):
     # GIVEN an initialized app
     # GIVEN a valid user and institute
@@ -384,7 +487,7 @@ def test_sv_cancer_variants(app, institute_obj, cancer_case_obj):
 
 
 def test_filter_export_cancer_variants(app, institute_obj, case_obj):
-    """Test the variant export functionaliy in cancer_variants page"""
+    """Test the variant export functionality in cancer_variants page"""
 
     # GIVEN an initialized app
     # GIVEN a valid user and institute
