@@ -1,9 +1,7 @@
 # -*- coding: utf-8 -*-
-import logging
 import uuid
 
 import pytest
-from flask import request
 from flask_login import login_user
 from werkzeug.datastructures import ImmutableMultiDict
 
@@ -593,20 +591,21 @@ def clinvar_form(request):
             "last_evaluated": "2022-09-19",
             "inheritance_mode": "Autosomal dominant inheritance",
             "assertion_method": "ACMG Guidelines, 2015",
-            "assertion_method_cit": "PMID:25741868",
+            "assertion_method_cit_db": "PMID",
+            "assertion_method_cit_id": "25741868",
             "variations_ids": "rs116916706",
             "clinsig": "Likely pathogenic, low penetrance",
             "clinsig_comment": "test clinsig comment",
             "clinsig_cit": "test clinsig cit",
-            "hpo_terms": "HP:0001298",
             "condition_comment": "test condition comment",
             "include_ind": ["NA12882"],
             "individual_id": ["NA12882", "NA12877", "NA12878"],
             "affected_status": ["yes", "no", "no"],
             "allele_of_origin": ["germline"] * 3,
             "collection_method": ["clinical testing"] * 3,
-            "condition_type": "HP",
-            "conditions": ["HP:0001298", "HP:0001250"],
+            "condition_type": "HPO",
+            "conditions": ["0001298", "0001250"],
+            "multiple_condition_explanation": "Novel disease",
         }
     )
     return data
