@@ -1,7 +1,5 @@
 """Tests for the loqusdb REST API extension"""
-import pytest
 
-from scout.exceptions.config import ConfigError
 from scout.server.extensions import loqus_extension, loqusdb
 
 
@@ -78,7 +76,7 @@ def test_loqusdb_api_snv_variant(loqus_api_app, monkeypatch, loqus_api_variant):
 def test_loqus_api_snv_variant_not_found(loqus_api_app, monkeypatch, loqus_api_variant):
     # GIVEN a mocked loqus API that doesn't return usable info
     def mockapi(*args):
-        return {"message": {"details": "not found"}}
+        return {"content": {"detail": "Not Found"}, "status_code": 404}
 
     monkeypatch.setattr(loqus_extension, "api_get", mockapi)
 
@@ -86,7 +84,7 @@ def test_loqus_api_snv_variant_not_found(loqus_api_app, monkeypatch, loqus_api_v
         # WHEN fetching the variant info
         var_info = loqusdb.get_variant({"_id": "a variant", "category": "snv"})
 
-        # THEN the loqus extensions should return an empty dictionary
+        # THEN the loqusdb extensions should return an empty dictionary
         assert var_info == {}
 
 
@@ -114,55 +112,3 @@ def test_loqusdb_api_sv_variant(loqus_api_app, monkeypatch, loqus_api_variant):
 
         # THEN assert the info was retrieved correctly
         assert var_info["observations"] == loqus_api_variant["observations"]
-
-
-def test_loqus_api_cases_no_instance(loqus_api_app):
-    """Test fetching info on number of cases from loqusdb API when the instance is not available"""
-
-    with loqus_api_app.app_context():
-        # WHEN fetching the nr_cases with SNV variants from an instance not available
-        n_cases = loqusdb.case_count("snv", "default")
-
-        # THEN the API shoud return 0 cases
-        assert n_cases == 0
-
-
-def test_loqusdb_api_cases(loqus_api_app, monkeypatch):
-    """Test fetching info on number of cases from loqusdb API"""
-    nr_snvs = 15
-    nr_svs = 12
-
-    # GIVEN a mocked loqus API
-    def mockapi(*args):
-        return {
-            "content": {"nr_cases_snvs": nr_snvs, "nr_cases_svs": nr_svs},
-            "status_code": 200,
-        }
-
-    monkeypatch.setattr(loqus_extension, "api_get", mockapi)
-
-    with loqus_api_app.app_context():
-        # WHEN fetching the nr_cases with SNV variants
-        n_cases = loqusdb.case_count("snv", "default")
-        # THEN the API should parse the returned info correctly
-        assert n_cases == nr_snvs
-
-        # WHEN fetching the nr_cases with SV variants
-        n_cases = loqusdb.case_count("sv", "default")
-        # THEN the API should parse the returned info correctly
-        assert n_cases == nr_svs
-
-
-def test_loqusdb_api_cases_not_found(loqus_api_app, monkeypatch):
-    """Test fetching info on number of cases from loqusdb API when the API is not funct"""
-
-    def mockapi(*args):
-        return {"message": {"details": "not found"}}
-
-    monkeypatch.setattr(loqus_extension, "api_get", mockapi)
-
-    with loqus_api_app.app_context():
-        # WHEN fetching the nr_cases with SNV variants
-        n_cases = loqusdb.case_count("snv", "default")
-        # THEN the if no cases are found, it should return 0 cases
-        assert n_cases == 0
