@@ -5,7 +5,8 @@ from flask import url_for
 from scout.server.links import (
     BEACON_LINK_TEMPLATE,
     add_gene_links,
-    alamut_link,
+    alamut_gene_link,
+    alamut_variant_link,
     beacon_link,
     cbioportal,
     ckb_gene,
@@ -62,7 +63,7 @@ def test_alamut_link_build38(app, institute_obj, variant_obj):
         assert resp.status_code == 200
 
         # WHEN the alamut link is created
-        link_to_alamut = alamut_link(institute_obj, variant_obj, BUILD_38)
+        link_to_alamut = alamut_variant_link(institute_obj, variant_obj, BUILD_38)
         # THEN the link should contain genome build info
         assert "GRCh38" in link_to_alamut
         # As well as Alamut Visual Plus API key and institution
@@ -70,6 +71,35 @@ def test_alamut_link_build38(app, institute_obj, variant_obj):
         assert alamut_api_institute in link_to_alamut
 
 
+def test_alamut_gene_link(app, institute_obj):
+    """Test to add a link to alamut browser"""
+    gene_obj = {
+        "hgnc_id": 257,
+        "canonical_transcript": "NM_00545352.3",
+        "hgvs_identifier": "c.523dup",
+    }
+    # GIVEN an institute with settings for Alamut Visual Plus
+    alamut_api_key = "test_alamut_key"
+    alamut_api_institute = "test_institute"
+    institute_obj["alamut_key"] = alamut_api_key
+    institute_obj["alamut_institution"] = alamut_api_institute
+
+    # GIVEN that the app settings contain parameter HIDE_ALAMUT_LINK = False
+    app.config["HIDE_ALAMUT_LINK"] = False
+
+    with app.test_client() as client:
+        # GIVEN that the user could be logged in
+        resp = client.get(url_for("auto_login"))
+        assert resp.status_code == 200
+
+        # WHEN the alamut link is created
+        link_to_alamut = alamut_gene_link(institute_obj, gene_obj, BUILD_38)
+
+        # Asssert key and institution found in link
+        assert alamut_api_key in link_to_alamut
+        assert alamut_api_institute in link_to_alamut
+
+
 def test_add_gene_links_build37():
     """Test to add gene links to a gene object"""
     # GIVEN a minimal gene and a genome build
