@@ -1,6 +1,6 @@
 """Tests for scout requests"""
+
 import tempfile
-import zlib
 from urllib.error import HTTPError
 
 import requests
@@ -117,7 +117,7 @@ def test_get_request_bad_request():
 
 
 @responses.activate
-def test_send_request_timout():
+def test_send_request_timeout():
     """This test will trigge a timout error."""
     # GIVEN a request and a request that timouts
     url = "http://www.badurl.com"
@@ -314,8 +314,8 @@ def test_fetch_hgnc(hgnc_file, mocker):
     assert "hgnc_id\tsymbol" in data[0]
 
 
-def test_fetch_exac_constraint(exac_file, mocker):
-    """Test fetch exac constraint file"""
+def test_fetch_constraint(exac_file, mocker):
+    """Test fetch ExAC / GnomAD constraint file"""
 
     # GIVEN file with hgnc info
     mocker.patch.object(scout_requests.urllib.request, "urlopen")
@@ -326,22 +326,22 @@ def test_fetch_exac_constraint(exac_file, mocker):
         temp.seek(0)
         scout_requests.urllib.request.urlopen.return_value = temp
         # WHEN fetching the resource
-        data = scout_requests.fetch_exac_constraint()
+        data = scout_requests.fetch_constraint()
 
     # THEN assert that the exac header is there
-    assert "transcript\tgene" in data[0]
+    assert "gene\ttranscript" in data[0]
 
 
 @responses.activate
-def test_fetch_exac_constraint_failed_ftp(variant_clinical_file, mocker):
-    """Test fetch exac constraint file when ftp request fails"""
+def test_fetch_constraint_failed_mirror(variant_clinical_file, mocker):
+    """Test fetch GnomAD constraint file when one of the mirrors fails"""
 
     # GIVEN file with hgnc info
     # GIVEN a mocked call that raises a HTTPError when fetching from ftp
     mocker.patch.object(scout_requests.urllib.request, "urlopen")
     url = (
-        "https://storage.googleapis.com/gnomad-public/legacy/exacv1_downloads/release0.3.1"
-        "/manuscript_data/forweb_cleaned_exac_r03_march16_z_data_pLI.txt.gz"
+        "https://storage.googleapis.com/gcp-public-data--gnomad"
+        "/release/v4.0/constraint/gnomad.v4.0.constraint_metrics.tsv"
     )
     scout_requests.urllib.request.urlopen.return_value = HTTPError(
         url, 500, "Internal Error", {}, None
@@ -358,7 +358,7 @@ def test_fetch_exac_constraint_failed_ftp(variant_clinical_file, mocker):
     )
 
     # WHEN fetching the resource
-    data = scout_requests.fetch_exac_constraint()
+    data = scout_requests.fetch_constraint()
 
     # THEN some content is returned
     assert len(data) > 10
@@ -387,58 +387,6 @@ def test_fetch_mim_files_mim2genes(phenotype_to_genes_file):
     assert isinstance(data, dict)
 
 
-def test_fetch_ensembl_biomart(mocker):
-    """Test fetch resource"""
-
-    # GIVEN a mock
-    mocker.patch.object(scout_requests, "EnsemblBiomartClient")
-    attributes = [
-        "chromosome_name",
-        "start_position",
-    ]
-    # WHEN fetching the resource
-    client = scout_requests.fetch_ensembl_biomart(attributes=attributes, filters=None)
-
-    # THEN assert that a result is returned
-    assert client
-
-
-def test_fetch_ensembl_genes(mocker):
-    """Test fetch resource"""
-
-    # GIVEN a mock
-    mocker.patch.object(scout_requests, "EnsemblBiomartClient")
-    # WHEN fetching the resource
-    client = scout_requests.fetch_ensembl_genes()
-
-    # THEN assert that a result is returned
-    assert client
-
-
-def test_fetch_ensembl_transcripts(mocker):
-    """Test fetch resource"""
-
-    # GIVEN a mock
-    mocker.patch.object(scout_requests, "EnsemblBiomartClient")
-    # WHEN fetching the resource
-    client = scout_requests.fetch_ensembl_transcripts()
-
-    # THEN assert that a result is returned
-    assert client
-
-
-def test_fetch_ensembl_exons(mocker):
-    """Test fetch resource"""
-
-    # GIVEN a mock
-    mocker.patch.object(scout_requests, "EnsemblBiomartClient")
-    # WHEN fetching the resource
-    client = scout_requests.fetch_ensembl_exons()
-
-    # THEN assert that a result is returned
-    assert client
-
-
 @responses.activate
 def test_fetch_resource_json():
     """Test fetch resource"""
